$bases = {
           'base_orig' => {
                            '__DOS_BODY_TICKER,[l=1]' => '\\b[A-Z]{4}\\.(?:OB|PK)\\b',
                            '__KAM_VIAGRA8B,[l=1]' => '(?i)AM...?BIEN',
                            '__KAM_SPAMKING6,[l=1]' => '(?is)(?:please send|Forward postal) correspondence to',
                            'IMPOTENCE,[l=1]' => '(?i)\\b(?:impotence (?:problem|cure|solution)|Premature Ejaculation|erectile dysfunction)',
                            '__KAM_LIST3_3,[l=1]' => '(?i)(information|data) field|verified email|(\\d{4,8}|complete) (contact|details)|with email address|target geograph|counts and pric|decision maker|specific parameters|job titles|Specific lists|current attendee|each record|post show attendee|(attendees|counts)\\:|(List|contacts|fields) (consists?|Contains?|includes?)|visitors and price|pricing, counts|information about the list|sample (file|record)|direct email|100\\% populated|installed users|(compiled|selling) (a )?list|pricing and further|(validated|buy a) dataset|counts, pricing|procure the list|samples for (your )?review|attendees who might|decision.makers|samples and pricing|pricing details|demographics|few samples|database (organization|provider)|expense and count|(samples|counts?) and cost|multichannel marketing|count of email|users of the following',
                            '__KAM_USB1,[l=0]' => '(?i)(debi|deborah brown|Melissa Sylvan)',
                            '__HK_SCAM_N16,[l=1]' => '(?i)\\b(?:arrangement secret|secret arrangement)\\b',
                            '__KAM_REFI3,[l=1]' => '(?is)(restructure (?:proposal|program|opportunity|your loan)|switch from an adjustable rate to a fixed|new lending program|(low|reasonable) interest (loan|rate)|lowest monthly payment|\\d% interest|unsecured personal|better credit terms|lower your mortgage|low-interest refinance|see your credit score|credit score.{1,15}updated|refi with HARP)|obama announce(s|d) (the )?harp program|obama\'?s.refi|a.fortune.off|lower.home.rate|your.home|home.loan|gov.program|official.harp|currently.overpaying',
                            '__KAM_SHAM3,[l=0]' => '(?i)ShamWow',
                            'FIN_FREE,[l=1]' => '(?i)\\bfinancial(?:ly)? (?:free|independen)',
                            '__KAM_JUDGE1,[l=1]' => '(?is)(unpaid court|(un-?collected|unsatisfied) judgments)',
                            '__KAM_GINA4,[l=0]' => '(?i)mandatory poster|remain in compliance|GINA regulations',
                            '__KAM_UNIV15,[l=1]' => '(?is)(No Study Required|Without Exams|No (examinations|[eÉ]xams)|without attending a single class|no classes|no textbooks|no (?:required )?tests|degree .{0,30}you deserve)',
                            '__KAM_SIGN3,[l=0]' => '(?i)verification is processed',
                            '__KAM_FAKEAD4,[l=0]' => '(?i)Sweet passion|no plastic surgery',
                            '__KAM_GOOGLE_AWARD4,[l=0]' => '(?i)Official Notification Letter',
                            '__KAM_VIAGRA8C,[l=1]' => '(?i)VA...?LIUM',
                            '__WILL_LEGAL,[l=1]' => '(?i)\\b(?:codicil|last\\stestament|probate|executor|intestate|bequest|mandamus)\\b',
                            'LIVE_PORN,[l=1]' => '(?i)\\blive .{0,9}(?:fuck(?:ing)?|sex|naked|girls?|virgins?|teens?|porno?)\\b',
                            '__KAM_STOCK2_4,[l=0]' => '(?i)trader|investor|analyst|royalties',
                            '__KAM_COVID1,[l=0]' => '(?i)International Monetary fund|world health organization|empowerment fund',
                            '__KAM_STOCKTIP144,[l=1]' => '(?is)Fleet Management Solutions|(\\b|^)FLMG(\\b|$)',
                            '__BURKINA_FASO,[l=1]' => '(?i)\\bburkina\\s?faso\\b',
                            '__KAM_GOVT4,[l=1]' => '(?i)No.Money?.{0,4}No.Problem',
                            '__AM_DYING,[l=1]' => '(?i)\\b(?:am\\s(?:\\S+\\s)?dying|terminally\\sill|cancer|en\\sphase\\sterminale|(?:become|is|devenu|maladie)\\sincurable|que\\sje\\smeurs)\\b',
                            '__KAM_DIABETES2,[l=1]' => '(?i)Reverse.{0,10}(Diabetes|type.2|type.1)|reverse.type.2|beat.type.2|conventional.medical',
                            '__hk_win_2,[l=1]' => '(?i)\\battn.{0,10}winner',
                            '__KAM_WORKHOME1,[l=0]' => '(?i)online jobs|Full-time (and|&) Part-time|at home employment',
                            '__KAM_SLICEOMATIC3,[l=0]' => '(?i)Slice-o-matic',
                            '__KAM_SALEA_3,[l=1]' => '(?i)touchfire|just.became.perfect|never.be.the.same',
                            '__FRAUD_AUM,[l=1]' => '(?i)\\bthe desk of\\b',
                            '__KAM_JESUS2,[l=1]' => '(?i)sister.in.the.lord|need for bible',
                            '__KAM_FUN3,[l=1]' => '(?i)This Offer is (only )?for (unite. state|USA)|(can ?not|won\\\'t|can\\\'t) see this image|visit the page below|Continue Reading|watch now|this is an ad|update preferences|click here now',
                            '__FOR_SALE_NET,[l=1]' => '(?i)00\\.? NET',
                            '__KAM_WHITEN3,[l=0]' => '(?i)(Celebrity Smile|Carbamide Peroxide)',
                            '__YOUR_CONSIGNMENT,[l=1]' => '(?i)\\b(?:received?|pa(?:y|id)|sen[dt]|h[oe]ld|delay(?:ed)?|impound(?:ed)?|released?|ship(?:ped)?)\\syour(?:\\s\\w+)?\\sconsignment\\b',
                            '__KAM_SPAMKING5,[l=1]' => '(?is)This (communication|message) was delivered to you by',
                            '__KAM_PRODUCT2_2,[l=1]' => '(?i)meal delivery|no chopping|i ?can ?read|zippy ?loan|car ?shield|Lick their paws|excessive scratching|trugreen|slice.?n.?seal|kitchen gadget|savage.?grow',
                            'TVD_APPROVED,[l=1]' => '(?i)you.{1,2}re .{0,20}approved',
                            '__KAM_KORS3,[l=0]' => '(?i)sent you this item|register to receive|latest updates|win great prizes|shop michael kors|kors insider|handbag collection',
                            '__YOU_ASSIST,[l=1]' => '(?i)\\b(?:your\\sas+istan(?:ce|t)|votre\\s(?:as+istance|aide))\\b',
                            '__KAM_MED1,[l=1]' => '(?i)e.?c.?o.?n.?o.?m.?i.?z.?e.{1,10}med',
                            '__KAM_FLEXHOSE3,[l=1]' => '(?i)stretch but not kink|flex.?hose|expanding.hose|garden.hose',
                            '__KAM_GARAGE3,[l=1]' => '(?i)surface protection plus|industrial strength|Concrete.{0,5}metal.{0,8}wood|protect.and.beautify|industrial.grade|common.flooring|treat.your.deck|professional.coating',
                            '__DRUGS_DIET5,[l=1]' => '(?i)\\bdiethylpropion\\b',
                            '__KAM_FAKEBBB3,[l=0]' => '(?i)(complaint|compliant|Abuse) ID',
                            '__TVD_PH_BODY_ACCOUNTS_PRE,[l=1]' => '(?i)\\baccounts? (?:[a-z_,-]+ )+?(?:record[a-z]*|suspen[a-z]+|notif(?:y|ication)|updated|verifications?|credited)\\b',
                            '__KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1]' => '(?i)\\b(I am missing you all the time|I am waiting for your answer|I send you my tender love|I would really like to know you|quest of love|I am lonely and tired)\\b',
                            '__KAM_HEARTPROD2,[l=0]' => '(?i)enzyme',
                            '__FRAUD_ETX,[l=1]' => '(?i)\\byour\\b[^.]{0,99}\\b(?:contact (?:details|information)|private (?:e?[- ]?mail|telephone|tel|phone|fax))\\b',
                            '__KAM_PAYPAL3D,[l=1]' => '(?i)security.process|more.information|has.limitation|verify.your.information',
                            '__KAM_NOCONFIDENCE1,[l=1]' => '(?i)confidential.information',
                            '__STAY_HOME,[l=1]' => '(?i)\\b(?:going out of|leaving)(?: your)? (?:home|house|residence)\\b',
                            '__ADMITS_SPAM,[l=1]' => '(?i)\\bth(?:e[- ]+above|is)(?:\\?+s|[- ]+is)[- ]+(?:intended[- ]+as[- ]+)?an?[- ]+(?:e-?mail[- ]+)?[a@]dvert[i1l]sement\\b',
                            '__KAM_BENEFICIARY3_1,[l=0]' => '(?i)Mikhail Fridman',
                            '__KAM_GRANT1,[l=0]' => '(?i)government grant',
                            '__KAM_INVOICE4,[l=1]' => '(?i)(billing error|problem with the address).{2,10}invoice',
                            '__KAM_CARDEAL3,[l=1]' => '(?i)201\\d Closeout pricing|New Vehicles near you|new automobiles|brand new car|\\d{4} makes and models',
                            '__KAM_JUDGE4,[l=0]' => '(?i)judgment',
                            '__KAM_SNORE3,[l=1]' => '(?i)stop snoring|zquiet|Jaw Supporter|get.rest|end.snoring|more.rest|to.be.tired',
                            '__KAM_DEALS3,[l=1]' => '(?i)exclusive.savings',
                            '__KAM_STOCK3,[l=1]' => '([sS].?ymbol|Sym|SYM|SYMB|Symb|SYMBOL|SYmN|SYMN|Symn|Ticker|TICKER|Lookup|PINKSHEETS)\\s*[-_:]\\s*[A-Z0-9][-\\._ ]?[A-Z0-9][-\\._ ]?[A-Z0-9][-\\._ ]?[A-Z0-9]',
                            '__KAM_SEARCH3,[l=1]' => '(?i)(first on|all of) the major search|not ranked number one|Website promotion|popular keywords|mobile.website|complete.solution|back.link|india.based|surfing|not.ranking.on|top in Google|1st page|more (clients|customers)|organic search',
                            '__DOS_BODY_SAT,[l=1]' => '(?i)\\bsat(?:day)?\\b',
                            '__KAM_LENS1,[l=0]' => '(?i)pro quality (pho|pic)|Bill gates|best camera',
                            '__FRAUD_FVU,[l=0]' => '(?i)award notification',
                            '__KAM_PEEL1,[l=1]' => '(?is)Titan Peeler',
                            '__KAM_FDA1,[l=1]' => '(?i)statements.{1,10}not.{1,10}evaluated.{1,10}(FDA|Food ?(and|&) ?Drug Administration)',
                            '__KAM_BUS2,[l=0]' => '(?i)sensitive by nature',
                            '__KAM_SMOKE1,[l=1]' => '(?i)smoke.anywhere|electronic cig|smoking alternative|prado|e.?-?cig|wanting to quit',
                            '__PUMPDUMP_10,[l=1]' => '(?i)\\btrading at (?:such )?a (?:bargain|cheap|low)\\b',
                            '__KAM_SETTING3,[l=1]' => '(?i)settings?.zip',
                            '__FRAUD_NEB,[l=0]' => '(?i)(?:government|bank) of nigeria',
                            '__KAM_PET3,[l=1]' => '(?i)pet health insurance|doggy.loot|coupon.notice|reduce.your.cost',
                            '__KAM_ADVERTISE3,[l=1]' => '(?i)advertising.for.samsung|no.application.fee|carry.this.advert',
                            '__FRAUD_IRJ,[l=0]' => '(?i)(?:finance|holding|securit(?:ies|y)) (?:company|firm|storage house)',
                            '__KAM_VIAGRA4B,[l=1]' => '(?i)V (. )?[I\\/t] (. )?A (. )?G (. )?R (. )?A',
                            '__KAM_PIC3,[l=1]' => '(?is)like to chat|feelings can be true|like to have friendship|friendly guy|gave me your photos|waiting on you|found your pictures|send me a note|more information about you|text me ASAP',
                            '__KAM_VIAGRA1,[l=0]' => '(?i)V I A G R A|C I A L I S|V A L I U M|X A N A X',
                            '__KAM_CHECK2,[l=0]' => '(?i)let me know when you recieve your money',
                            '__KAM_BIZ1,[l=1]' => '(?is)You always need new cards|free full color business cards|get 250 more ?- ?free|business card offer|500 business cards',
                            '__KAM_LANDSCAPE3,[l=1]' => '(?i)landscape.designs|(simple|cheap).strategies|design.troph',
                            '__MAIL_ACCT_ACCESS1,[l=1]' => '(?i)\\b(?:your (?:web ?|e-?)?mail (?:account|log-?in) (?:has )?been accessed|r(?:=F3|[\\xf3])zne komputery zalogowaniu sie)\\b',
                            'SHORT_TERM_PRICE,[l=1]' => '(?i)short\\W+term\\W+(target|projected)(\\W+price)?',
                            '__KAM_GAS2,[l=1]' => '(?i)We have a solution|save \\d+ cents per gallon|competitive rewards',
                            '__JMQ_WIRE3,[l=1]' => '(?i)bank.wire|sent.out.asap',
                            '__KAM_PIC2,[l=1]' => '(?is)(nice girl|2\\d years old|25 y.o. girl|pretty russian|I russian girl|age is 25|long legs, cute|see my pictures|I\'m 19|searching for a bad girl|meet with such attractive|cute lady)',
                            '__KAM_TUB3,[l=1]' => '(?i)Walk.?in (hot.?|bath.?)?tub|bath and massage|easy transfer from a wheelchair',
                            '__KAM_ANDROGEL3,[l=1]' => '(?i)healthcare|medwatch|drug|testosterone|therapy|manhood|your.woman',
                            '__KAM_WTA2,[l=1]' => '(?is)Alliance for Retirement Prosperity Association|Social Security Institute',
                            '__KAM_BUS3,[l=0]' => '(?i)have not met',
                            '__KAM_URZEST5,[l=0]' => '(?i)(back into shape|made me healthier after my disease)',
                            '__KAM_WEIGHT1,[l=1]' => '(?is)(overweight|extra weight|glutting|shed fat|burns fat|burn calories|appetite suppressant|stimulate your metabolism|unwanted weight|duet of the year|healthy energy boost|Suppresses Appetite|internal cleansing|detoxify|cellulite|unsightly bulges|fat burn|Diet of the year|acai|cuts cholesterol|cleanse excess waste|free sample|unwanted weight|Acai suppl[ie]ments|Diet\\/Detox|#1 Weight Loss|lose body fat|(lose|drop) (about )?\\d+\\s*[li]b|calorie burning machine|before eating carbs)|flush.fat.away|slimming.down|\\d+.pounds.gone|lose.\\dx|highest.rated.episode|unwanted..?gain|too.goo?d.to.be.true|get.slim|tv.segment|weird.solution',
                            '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]' => '(?i)\\b(?:(?:[dr]e-?)?activat[a-z]*|(?:re-?)?validate|secure|restore|confirm|update|suspend) (?!your)(?:[a-z_,-]+ )+?accounts?\\b',
                            '__KAM_REP2,[l=1]' => '(?i)www\\s+[-!~\\.]',
                            '__ACH_CANCELLED_02,[l=1]' => '(?i)(?:rejected|cancel+ed|declined|your)[-_ ](?:(?-i:ACH)|direct[-_ ]deposit)[-_ ](?:payment|transfer|transaction|declin(?:ed|ing))',
                            '__KAM_MILLIONAIRE2,[l=0]' => '(?i)huge success stor(y|ies)|controversial',
                            '__TVD_PH_BODY_03,[l=1]' => '(?i)\\byou(?:\'ve| have) been (?:[a-z_,-]+ )+?payment',
                            '__KAM_CLOUD4,[l=1]' => '(?i)hacking|complimentary.(lunch|breakfast)',
                            '__KAM_NIGERIAN4,[l=1]' => '(?is)(?:American oil merchant|independent contractor|removallink|claim the funds|international corporation|bank draft|becoming our contract staff|contractual employment|customers\\s*in Europe,\\s*America|new partner from UK|great investment site|money orders|cashiers check|access to the funds|piloting the business|moving the funds|next of kin|syrian.refugees|reply.for.detail)|security.reason|(his|her).account|new.investor|directly.beneficial|business.discussion|promise.to|need.to.spend',
                            '__KAM_PRIV3,[l=0]' => '(?i)the attache?ment|attached file',
                            '__DRUGS_ERECTILE_V,[l=1]' => '(?i)\\bViagra\\b',
                            '__KAM_STOCKTIP163,[l=1]' => '(?is)(\\b|^)(brixmor)(\\b|$)',
                            '__KAM_URUNIT3,[l=1]' => '(?is)(unsatisfied|not satisfied|nagging|complaining|complaints|complained|unlimited prowess|increase your volume)',
                            '__KAM_FAVOR2,[l=0]' => '(?i)I need a favor from you|Are you available to work on a request for me today',
                            '__KAM_TELEWORK4,[l=1]' => '(?is)fully qualified|no experience needed|all the training|managing expectations|accountability|stronger results',
                            '__KAM_REAL1,[l=1]' => '(?is)(^|\\b)RE market',
                            '__DOS_CORRESPOND_EMAIL,[l=1]' => 'correspond with me using my email',
                            '__KAM_SHOCK3,[l=0]' => '(?i)drinking this beverage',
                            '__DOS_BODY_MON,[l=1]' => '(?i)\\bmon(?:day)?\\b',
                            '__KAM_UNIV13,[l=1]' => '(?is)(degree|field|diploma) of your (choice|expertise)',
                            '__YOUR_FUND,[l=1]' => '(?i)\\b(?:your|ihr)\\s(?:unpaid\\s|win+ing\\s|ap+roved\\s|foreign\\s|overdue\\s|outstanding\\s|contract\\s|inheritance\\s|nicht\\sausbezahlten\\s){0,3}(?:fund|f\\su\\sn\\sd|payment|geld)\\b',
                            '__KAM_POLITICS2,[l=1]' => '(?i)Minuteman Civil Defense Corps|National Campaign Fund|Right vs Left|Restore America PAC|penntransportation.com|getliberty.org|Americans for Limited Government|radical|true.conservative|true.liberal|job.killing|wasteful.spending|senate.takeover|liberal.agenda|smear.campaign|america.s future|liberty|obama|governor|election.day|v-o-t-e|sign.the.petition|paid.for.by|dear.conservative|dear.liberal|winning.the.senate|election.cycle|return.power|failed.policy|(left|right).is.claiming|bigwigs|favorable.voters',
                            '__KAM_CHOSEN3,[l=1]' => '(?i)You (were|have been|are) (recently )?(chosen|invited)|you.are.(very.)?welcome',
                            '__KAM_GOOGLE_AWARD3,[l=0]' => '(?i)Dear Google',
                            '__KAM_LABEL8,[l=1]' => '(?i)face ?mask|(^|\\b)PPE(\\b|$)',
                            'REMOVE_BEFORE_LINK,[l=1]' => '(?i)(?:no thanks|not interested|unsubscribe here).{0,5}http://',
                            '__KAM_FAKEDELIVER9,[l=1]' => 'CARGO',
                            '__KAM_GIVE4,[l=0]' => '(?i)verify your shipping address',
                            '__THEY_INHERIT,[l=1]' => '(?i)\\b(?:inherit\\sth(?:e|is)\\smoney|herede\\sest[ea]\\sdinero)\\b',
                            '__KAM_ABOUT2,[l=0]' => '(?i)Spyware',
                            'FREE_QUOTE_INSTANT,[l=1]' => '(?i)free.{0,12}(?:(?:instant|express|online|no.?obligation).{0,4})+.{0,32}\\bquote',
                            '__KAM_VERIZON5,[l=0]' => '(?i)update your account information',
                            '__KAM_SHARP1,[l=0]' => '(?i)sharp for life',
                            '__KAM_PEST3,[l=0]' => '(?i)revolutionary pes?t control system',
                            '__KAM_STOCKTIP124,[l=1]' => '(?is)(VGPM|Vega Promotional Sys)',
                            '__DOS_EMAIL_DIRECTLY,[l=1]' => '(?:Email m[a-z]?e|address) direc(?:tl|lt)y at',
                            '__KAM_FUN2,[l=1]' => '(?i)Addify Link|Kennett Pike|PetPlan|Newton Sq|1st Avenue|Jones Blvd|permanently opt-out from our all newsletters|(wish|prefer) (to not|not to|to) receive (these|future) (messages|emails)|purehealth|leave any time|too good to be true|try(ing)? this trick|doesn?\'t like this update|(click here|wish) +to unsubscribe|send post-mail to|to be removed from receiving|to unsubscribe.+click|no longer like to receive|this is an advertisement',
                            '__KAM_INVEST3,[l=1]' => '(?i)earn \\d+\\%|(more|full|elaborate) details|discuss further|risk.?free|give details|profitable|\\% (yearly|commission)|bank draft|remuneration|(needs|seek|seeks|seeking) fund|employ you|split.?ration|(receive|secure) my fund',
                            '__KAM_FUN6,[l=0]' => '(?i)finds the secret|new discovery|natural medicine|health channel|medicinal plants|simple tweak|doctors are shocked|mysterious liquid|massive mistake|scientifically shown',
                            '__KAM_VM3,[l=1]' => '(?i)(Voice ?Audio|VN Audio|VM Meant|Listen to (your )?Voice|voicemail message|Fax(ed)? (document|message)|new voicemail)',
                            '__KAM_2ND_2,[l=0]' => '(?i)2nd am?mendment|concealed carry|right to carry',
                            '__PLS_REVIEW,[l=1]' => '(?i)\\b(?:please|kindly)\\s(?:(?:re)?view|see)(?:\\s\\w+)?\\sattach(?:ed|ment)\\b',
                            '__KAM_VERIZON6,[l=0]' => '(?i)deactivated',
                            '__KAM_RXPLAN3,[l=0]' => '(?i)gap coverage',
                            '__KAM_EXPOPIRATE2,[l=0]' => '(?i)Business Traveller',
                            '__KAM_GUN1,[l=0]' => '(?i)Keep and Bear Arms',
                            '__KAM_UNIV4B,[l=1]' => '(?is)1.?0.?0.?% (legit|verifiable|online|no pre|non[- ]?accredited)',
                            '__KAM_ENGINEER3,[l=1]' => '(?i)construction.engineering|engineering . architect|marketing.manager',
                            '__hk_win_3,[l=1]' => '(?i)\\bhappily aa?nnounce',
                            '__KAM_GIFT4,[l=1]' => '(?i)card will be yours free|card on us|buy you the dyson animal|amazon.gift.?card|superstore|starbucks.card|card.egift|redeem.before|offering.you.this|enter.promo.code',
                            'EXCUSE_24,[l=1]' => '(?i)you(?:\'ve|\'re| have| are)? receiv(?:e|ed|ing) this (?:advertisement|offer|special|recurring|paid).{0,16}\\b(?:by either|because)',
                            '__KAM_TRUMPCOIN3,[l=0]' => '(?i)special colored coin',
                            '__KAM_SPO2_1,[l=0]' => '(?i)pulse oximeter|touchless thermometer',
                            '__KAM_WHATS3,[l=1]' => 'WhatsApp',
                            '__KAM_HAIRTRANS3,[l=1]' => '(?i)hair restoration|man look as young|losing your hair|hair ?loss|get.your.hair|(look|feel).younger',
                            '__KAM_WEIGHT2,[l=1]' => '(?is)(\\d pounds|lose[_ ]weight|suppress appetite|appetite out of control|Oprah|for cancer patients|colon cure|colon cleanse|colonmate|avai berry|acai burn|ultraslim|feel energized|excess[_ ]weight|no diet changes|no exercise|hollywood\'?s hottest -?diet|acai berry edge|Acai Diet|top secret diet|Power HCG|Sensa|shocking method|Jennifer Aniston|before eating carbs|all natural weight.?loss|green fruit|top celeb\'s diet)|one.secret|enjoying.food|f-a-t|melt.fat|squeeze into them|crazy.workout|celebs.everywhere|zero.effort|nothing.to.lose',
                            '__KAM_STOCKTIP156,[l=1]' => '(?is)Progress Watch|(\\b|^)PROW(\\b|$)',
                            '__KAM_JOINT5,[l=0]' => '(?i)free bottle',
                            '__COMPENSATION,[l=1]' => '(?i)\\b(?:compensat(?:e|ion)|recompensed?|ausgleich)\\b',
                            '__NOT_DEAD_YET,[l=1]' => '(?i)\\b(?:will\\sinherit|que\\sherede|your\\sdeath|your?\\sbeing\\sdead)\\b',
                            'SCC_SPAMMER_ADDR_2,[l=1]' => '6130 W Flamingo Rd',
                            '__KAM_TIMESHARE2,[l=1]' => '(?is)goldmine|sell or rent it|we pay cash|sell\\/rent your time|own a timeshare or condo|get.cash|find.your.value',
                            '__KAM_ZWNJ3,[l=0]' => '(?i)\\&#x200B;',
                            '__KAM_LIST5,[l=1]' => '(?is)(reply with "stop" as a subject|Send an email with "rem" in the subject to discontinue|put "cease" in the subject of an email|for termination of this e?mail|reply with .{1,8} in the subject)|you will have your email taken off|for the datacard|send.a.reply',
                            '__DESTROY_ME,[l=1]' => '(?i)\\b(?:destroy|hunt|quemar)\\sm[eyi]\\b',
                            '__KAM_GOVT3,[l=0]' => '(?i)complimentary information kit',
                            '__KAM_ITC3,[l=0]' => '(?i)enclosed',
                            '__FRAUD_YJA,[l=0]' => '(?i)over-invoice',
                            '__KAM_SOCKET3,[l=0]' => '(?i)side socket',
                            '__KAM_VIAGRA7A,[l=1]' => '(?i)V[ij]+AGRA',
                            '__KAM_IDENTNET2,[l=0]' => '(?i)ADVERTISE WITH IDENTITY NETWORK',
                            '__PASSWORD_EXP_CLUMSY,[l=1]' => '(?i)\\bpassword is due for expiration yesterday\\b',
                            '__BENIN,[l=1]' => '(?i)\\bb(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])nin\\b',
                            '__DESTROY_YOU,[l=1]' => '(?i)\\b(?:destroy\\syou|deine Zukunft zerst\\S{1,3}ren)',
                            '__DOS_DROP_ME_A_LINE,[l=1]' => 'Drop me a line at',
                            '__PUMPDUMP_01,[l=1]' => '(?i)\\b(?:times|multiply|tripl(?:e|ing)|quadrupl(?:e|ing)|quintupl(?:e|ing)) (?:your|an) (?:princip(?:al|le)|investment)\\b',
                            'KAM_BODY,[l=0]' => '(?i){_BODY_HTML}',
                            '__KAM_CAD3,[l=1]' => '(?i)our.products',
                            '__KAM_HOODIA3,[l=1]' => '(?is)(?:fat loss product|sur?p?press appetite|Reduce Your Appetite)',
                            '__THIS_AD,[l=1]' => '(?i)(?:\\b|_)this[- _]+(?:ad(?:vert[i1l]sement)?|promo(?:tion)?)s?(?:\\b|_)',
                            '__DRUGS_PAIN2,[l=1]' => '(?i)\\b_{0,3}c[o0\\xF2-\\xF6]deine_{0,3}\\b',
                            '__KAM_HEALTH2,[l=1]' => '(?i)save up to \\d+% on health insurance|affordable health coverage|quality term life insurance|nationalhealthxchange.com|view.rate|no.obligation|start.saving',
                            '__KAM_UNIV1,[l=1]' => '(?is)(University Administration|University Enrollment|Education Assessment|Faculty Assessment|University Degree|Administration Office|Education office|Schools office|Enrollment Office|Online University)',
                            'TVD_ACT_193,[l=1]' => '(?i)\\bact of (?:193|nineteen thirty)',
                            '__MY_FORTUNE,[l=1]' => '(?i)\\b(?:my|his|her)\\s(?:fortune|heritage)\\b',
                            '__KAM_KIWIBANK3,[l=1]' => '(?i)security.procedure|customer.safety|security.details',
                            'EM_ROLEX,[l=1]' => '(?i)[^\\s\\w.]rolex',
                            '__FRAUD_QXX,[l=1]' => '(?i)\\b(?:my name is|i am) (?:mrs?|engr|barrister|dr|prince(?:ss)?)[. ]',
                            '__KAM_GOOGLE2,[l=0]' => '(?i)learn how to earn|automated income kit|online from home|as much money as you wish|be the boss',
                            '__KAM_GEVALIA1,[l=1]' => '(?is)Gevalia Kaffe|premium coffee delivered',
                            '__DRUGS_PAIN_VICO,[l=0]' => '(?i)vicodin',
                            '__LOTTO_WIN_01,[l=1]' => '(?i)\\bwin+ing\\s(?:prize|number|notification|draw|check|cheque|details|information|payment)',
                            '__KAM_TIME4,[l=1]' => '(?i)(\\b|^)(time|watch)(\\b|$)',
                            '__KAM_LOTTO2,[l=1]' => '(?is)((ticket|serial|lucky) number|secret pin ?code|pin number|batch number|reference number|promotion date|lottery|sweepstake|\\d+ lucky recipients|for claim and inquiring)|Micros(oft)? ID',
                            '__FRAUD_YPO,[l=0]' => '(?i)the total sum',
                            '__DRUGS_ANXIETY_VAL,[l=0]' => '(?i)valium',
                            '__KAM_DRILL4,[l=0]' => '(?i)(buy today|Check this deal out)',
                            '__KAM_INVEST4,[l=1]' => '(?i)malta|oil company|joint venture|(fund|business) proposal|dubai|mutual business|bahrain|compensation fund|barrister|minister of|ghana|strategic development|your region|Mineral.Rich|africa|non.?european|your country',
                            'VIA_GAP_GRA,[l=1]' => '(?i)\\bvia.gra\\b',
                            '__DIED_IN,[l=1]' => '(?i)\\bdied\\sin\\b',
                            '__KAM_CIGAR3,[l=0]' => '(?i)Thompson Cigar|Premium Cigar',
                            '__KAM_STUDENTLOAN3,[l=0]' => '(?i)doesn\'t injured',
                            '__KAM_DIRECT3,[l=0]' => '(?i)(Complimentary|Visitor|attend our open house|30-day member|VIP Pass|Wholesale Direct Pricing|guest pass and catalog)',
                            '__BOUNCE_OOO_B1,[l=1]' => '\\bI ?.m away until .{10,20} and am unable to read your message\\b',
                            '__KAM_CVS2,[l=1]' => 'CVS',
                            '__KAM_LANG3,[l=1]' => '(?i)pimsleur|Language in just \\d+ Day',
                            '__KAM_URUNIT4,[l=1]' => '(?is)(bedroom|the bed|nighttime activit|male power|show your girl)',
                            '__KAM_JOB2_2,[l=0]' => '(?i)represent the company',
                            '__JMQ_RESUME2,[l=0]' => '(?i)hello my name|my name is',
                            '__DOS_LET_GO_JOB,[l=1]' => 'I was (?:let go|fired|layed off|dismissed) from a job I h(?:el|a)d for (?:2\\d years|\\d{3} months)',
                            '__KAM_REP2_1,[l=1]' => '(?is)(Just|Please|all you need to do is to) (copy|type):? (www\\s)?.{0,10}[\\[\\(]([-!~\\.]|dot)[\\]\\)]',
                            '__KAM_BAD_REVIEW2,[l=0]' => '(?i)Reputation Giant',
                            '__NEVER_HEAR_EN,[l=0]' => '(?i)(never hear me again|destroy all your secrets|not bother you again|leave you alone)',
                            '__DRUGS_ERECTILE_C,[l=1]' => '(?i)\\bCialis(?!\\xc3\\xa9|\\xe9)\\b',
                            '__KAM_DRUG2,[l=1]' => '(?is)cheaper|redeem in bulk and save|bigger quantities and Save|drugstore accredi[dt]ations|economical (?:value|amount)|drug.online.supplies',
                            '__KAM_RICH1,[l=1]' => '(?i)financial.success story',
                            '__KAM_CRIM2_2,[l=0]' => '(?i)address\\:',
                            '__KAM_LABEL4,[l=1]' => '(?i)(suits start at \\$|shirts at \\$)|\\d\\d per mask|\\d masks',
                            '__KAM_REFINEW2,[l=1]' => '(?i)(rate|payment).reduction|score-update',
                            'DEAR_SOMETHING,[l=1]' => '(?i)\\bDear (?:IT\\W|Internet|candidate|sirs?|madam|investor|travell?er|car shopper|web)\\b',
                            '__KAM_MOP3,[l=1]' => '(?i)filthy floor|cut cleaning time+absorbs \\d+x its own weight|the mop that',
                            '__KAM_STOCKTIP138,[l=1]' => '(?is)Cobra Oil (and|&) Gas|(\\b|^)CGCA(\\b|$)',
                            '__PDS_SEO2,[l=1]' => '(?i)losing your (?:[a-z]+ )?(?:rank(?:ing)?|results)|rank well on [a-z]+\\b',
                            '__KAM_SPAMKING2,[l=1]' => '(?is)If you have any questions or concerns regarding this communication, please send correspondence',
                            '__KAM_WEB2_2,[l=0]' => '(?i)affordable (quot|price)|less than half',
                            '__KAM_QUOTA1,[l=0]' => '(?i)Mailbox Quota Has Exceeded|exceeded its storage limit',
                            'TVD_PH_SEC,[l=1]' => '(?i)\\byour .{0,40}account .{0,40}security',
                            '__KAM_HACK2,[l=0]' => '(?i)read attached|click here for verification',
                            '__KAM_FAKEDELIVER7,[l=0]' => '(?i)USPS',
                            '__KAM_NIGERIAN2_8,[l=1]' => '(?i)courier|diplomat agent|direct wire transfer|my.gold|the.gold',
                            '__KAM_SHADYCC1,[l=1]' => '(?i)(transactions?|purchases?) from your (online store|web-?shop)',
                            '__TRAVEL_ITINERARY,[l=0]' => '(?i)(?:travel|ticketed|your|current) itinerary',
                            '__KAM_BENEFICIARY4,[l=0]' => '(?i)(Ghana|South Africa|China|Greece|Estonia|United kingdom|foreign|(your|my) country|Benin|africa|Foreign Op|international Airport|portugal|business trip|Ivory Coast|Royal Bank|Syria|Libyan|Ministry of |Buffett Foundation|audit unit)|postmaster general',
                            'KAM_HOLLY,[l=0]' => '(?i)1 0 2 0 N H o l l y w o o d W a y ',
                            '__KAM_BADNAME1,[l=1]' => '(?i)CocoMedia|CMI Free Stuff|Vista Del Mar Productions|by SuperClub|Buil tech Services|eMarketing Alliance|aSHARPi Media|Satell Center for Executive Education|Pacific Shores Investments|R. Allen Media|The Only Virginia Team|Ban Amnesty Now|Intrust Domains|New Heights Development and Research|Red Base Interactive|RateMarketplace|WORLD COMPANY REGISTER|Mobie Concepts, Inc.|Clickingz IT Research Lab|Leadz[,\\.].?Co|Pimsleur Approach|Business Who\'s Who|Who\'s Who Among Executives|Buena Vista Catalogue|Ashray Medical Center|Bethany Christian Services|Preston Energy|SteelCityAds|Beyond Human, LLC|Research Promo Center|OmegaK, Inc|Momentum.Ads|Dove Lighting Co|BrandRoot SEO|Team TPW|WEB ANALYTICS MEDIA LLC',
                            '__KAM_URGENT2,[l=0]' => '(?i)urgent respond',
                            '__KAM_HEALTH1,[l=1]' => '(?i)as low as \\$\\d+\\s*(per|\\/)\\s*month|at \\$\\d+ including dental',
                            '__KAM_DOMAIN_SALE3,[l=1]' => '(?i)\\bdomain (name owner|advanced avail|backordering)\\b',
                            '__KAM_TINNI2,[l=0]' => '(?i)Stop the ringing in your ears',
                            '__KAM_INVOICEPO3,[l=0]' => '(?i)invoice copies',
                            '__KAM_FLAG3,[l=1]' => '(?i)performance.flags|shopping.online|scoop on flags|need your flag|best flag|flag design|new flag|flag.needs|flags?.you.need',
                            '__FRAUD_WNY,[l=1]' => '(?i)\\b(?:disburse?(?:ment)?|incurr?(?:ed)?|remunerr?at(?:ed?|ion)|remm?itt?(?:ed|ance|ing)?)\\b',
                            '__KAM_GEVALIA2,[l=1]' => '(?is)(Gevalia coffee lover\'s|I love coffee) kit',
                            '__TVD_PH_BODY_05,[l=1]' => '(?i)\\bthis is (?:[a-z_,-]+ )+?protect (?:[a-z_,-]+ )+?your',
                            '__KAM_DOMAIN3,[l=1]' => '(?i)(?:have|own) a domain (that is )?.{0,5}similar|(have|own) a similar domain|offer on the Domain|similar to your (current )?domain|Domain Division|all.domains|main.webpage|visibility.platform|solicitation|potential.owner|your.offer|domain.match|domain.notification|domain.will.be|interest.{1,20}.domain.name|fully.responsive|website.included|list.your.website|opportt?unity.regarding|courtesy.notification',
                            '__KAM_DRUG2_6,[l=1]' => '(?i)(Express|Prompt|Day|Trusty|Trustworthy|Reliable|fast|true|discreet|confidential|rapid)[_ ~\\.]?Shippin|anonymous packing|shipped.right.away|adderrx|clinically.proven|support.formula',
                            '__UNSUB_GOOG_FORM,[l=1]' => '(?i)Unsub?sc?ribe\\s<?https?://docs\\.google\\.com/forms/',
                            '__GAPPY_SALES_LEADS,[l=1]' => '(?i)\\b(?:business|e?-?mail|your|marketing|advertising)\\s(?!sales|leads|campaign)(?:s\\s?a\\s?l\\s?e\\s?s|l\\s?e\\s?a\\s?d\\s?s|c\\s?a\\s?m\\s?p\\s?a\\s?i\\s?g\\s?n)\\b',
                            '__KAM_UPS3,[l=0]' => '(?i)invoice copy attached',
                            '__KAM_MM_FOREX_1,[l=1]' => '(?i)program.{0,10}ktory\\ssam\\sgra\\sna\\sgieldzie|program\\sdo\\sgry\\sna\\sgieldzie|Potega\\stego\\sprogramu\\stkwi|program.{0,10}handluje.{0,10}zarabia.{0,10}gieldzie.{0,10}udzialu.{0,10}czlowieka|zarabiaj.{0,10}program.{0,10}nie.{0,10}jest.{0,10}zabroniony|Program.{0,10}zrobi.{0,10}wszystko.{0,10}sam|handluj.{0,10}na.{0,10}gieldzie.{0,10}programowi|100.{0,10}%.{0,10}pewnych.{0,10}transakcji|program.{0,10}100.{0,10}%.{0,10}zysk|handel.{0,10}bedzie.{0,10}zabroniony|program.{0,10}odmieni.{0,10}twoje.{0,10}zycie|system.{0,10}finansow.{0,10}przed.{0,10}upadkiem|grupa.{0,10}niemieckich.{0,10}matematykow.{0,10}inteligentny.{0,10}program|zostan\\sobrzydliwie\\sbogaty|technologia.{0,10}100%.{0,10}pewne.{0,10}decyzje|zarabianie.{0,10}w.{0,10}sieci|swoja.{0,10}szanse.{0,10}zarabianie|internet.{0,10}doprowadzil.{0,10}pieniedzy|zarabia.{0,10}(w|przez).{0,10}internet|karaluch.{0,10}dom.{0,10}brzeg.{0,10}morza|odmieni.{0,10}zycie|pieniadz|pieniedz|zarabia|zarobi',
                            '__KAM_REAL2,[l=0]' => '(?i)(crashing|declining)',
                            'MARKETING_PARTNERS,[l=1]' => '(?i)\\b(?:marketing|network) partner|\\bpartner (?:web)?site',
                            '__LOTTO_AGENT_02,[l=1]' => '(?i)\\blot+ery[^\\.]{1,40} ticket agent',
                            '__FRAUD_GBW,[l=1]' => '(?i)god gives .{1,10}second chance',
                            '__KAM_USB3,[l=1]' => '(?i)usbsmg.com',
                            '__KAM_GIFTCERT1,[l=0]' => '(?i)Our gift to you',
                            'KAM_TRUTHINESS,[l=1]' => '[Tt]he TRUTH',
                            '__KAM_LOGO3,[l=1]' => '(?i)(guru.level|ready.made) logo',
                            '__KAM_PIC5,[l=0]' => '(?i)picture|photo|my pics|appended my pic',
                            '__KAM_CERT3,[l=0]' => '(?i)link below',
                            '__KAM_DUCHESS6,[l=0]' => '(?i)For account number:',
                            '__KAM_HONOR3,[l=0]' => '(?i)profession women',
                            '__KAM_CBD1,[l=0]' => '(?i)Meridian CBD',
                            '__KAM_REP3_1,[l=1]' => '(?is)\\*omit empty spaces',
                            'TVD_SECTION,[l=1]' => '(?i)\\bSection (?:27A|21B)',
                            '__KAM_LIKE2,[l=1]' => '(?is)a link from .{1,54} would be greatly appreciated',
                            '__KAM_STOCKTIP150,[l=0]' => '(?i)MONARCHY RESOURCES',
                            '__KAM_BACK2,[l=1]' => '(?is)(Property & Personal history|Asset & Background) (Investigation|Search)|check anyone|know.anything|registered.offense|their.name|publicly.available',
                            '__KAM_LOAN3,[l=1]' => '(?i)Financial Relief|need to borrow|Business Loan|instant.funds|approval department|\\$\\d+ down|loan option|offer.loan|expenses|times.are.tough|money.problems|zippy ?loan|advanced lender|pay off debt|development.project|just.been.approved|for.your.business|loan.solution|ease your stress',
                            'FREE_PORN,[l=1]' => '(?i)\\bfree (?:porn|xxx|adult)',
                            '__UN,[l=1]' => '(?i)\\bunited\\snations?\\b',
                            '__DRUGS_ANXIETY9,[l=1]' => '(?i)\\brivotril\\b',
                            '__TRTMT_DEFILED,[l=1]' => '(?i)\\bdefiled\\sall\\s(?:forms\\sof\\s)?(?:medical\\s)?treatments?\\b',
                            '__FRAUD_UUY,[l=1]' => '(?i)\\blegitimate business(?:es)?\\b',
                            '__KAM_ADVERT1,[l=1]' => '(?is)email advertising|\\d{3}%.roi',
                            '__KAM_SEARCH4,[l=1]' => '(?i)guaranteed type of exposure|free website search engine optimi|increase your revenue|improve your website traffice|website rank higher|marketing service|popular.keyword|media.presence|media.portal|brand.awareness|analytics.certified|optimized.content|white.label|website.optimization|digital.marketing|in.your.industry|high.revenue|plans? and pric|keyword|full proposal|online reputation|(blog|article|pr|search engine) (promotion|submission)',
                            '__KAM_OPRAH2,[l=0]' => '(?i)hotel',
                            '__KAM_NEW_CREDITCARD3,[l=1]' => '(?i)Select your new card|Increase Your Spending|Higher Limit|rewards|business credit|which.credit.card|find.out.now',
                            '__KAM_HOWRU2,[l=0]' => '(?i)My name is|what\'s your name|ask your name|keep company with you',
                            '__RUDE_HTML_3,[l=0]' => '(?i)This message contains an HTML formatted message but your email client does',
                            '__PUMPDUMP_06,[l=1]' => '(?i)\\brecommend(?:ed|s)? (?:a|this) (?:company|stock)\\b',
                            '__KAM_MARIJUANA3,[l=1]' => '(?i)colorado|washington|profit|without.a.(prescription|doctor)|lets.you.vape|no.doctor',
                            '__KAM_HEARTPROD1,[l=1]' => '(?i)heart ?attack',
                            '__KAM_AQUA3,[l=1]' => '(?is)while on vacation',
                            '__HK_SCAM_N3,[l=1]' => '(?i)\\bdirect telephone numbers?\\b',
                            '__KAM_BEAUTY2,[l=0]' => '(?i)reveals exactly',
                            '__KAM_ADVERT2,[l=1]' => '(?is)instant traffic (to your website|and sales)|demand.generation',
                            'TVD_VISIT_PHARMA,[l=1]' => '(?i)Online Ph.rmacy',
                            '__PUMPDUMP_07,[l=1]' => '(?i)\\b(?:buy|grab it) for (?:around |about |less than )?\\d+ cents\\b',
                            '__KAM_TRAINING2,[l=0]' => '(?i)intranet|training calendar',
                            '__KAM_BITCOIN2,[l=1]' => '(?i)price.of.bitcoin|bitcoin.price|crypto.?currenc(y|ies)|currency.pioneer|cartel|financial.security|abandoned.our.dollar|money.map',
                            '__KAM_STOCKTIP143,[l=1]' => '(?is)AmeriLithium',
                            '__MAKE_XTRA_DOLLAR,[l=1]' => '(?i)\\bmake an extra dollar\\b',
                            '__DRUGS_ERECTILE2,[l=1]' => '(?i)\\bV(?:agira|igara|iaggra|iaegra)\\b',
                            '__YOU_WON_04,[l=1]' => '(?i)\\bqu[ei]\\s?(?:vous (?:[\\xc3][\\xaa]|=C3=AA|[\\xea]|e)tes\\s?gagnant|en\\scons(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])quence\\sgagne)\\b',
                            '__KAM_2ND_1,[l=1]' => '(?i)police can no longer be trusted|protect yourself|anti-?gun ban|no classes',
                            '__ADULTDATINGCOMPANY_BODY,[l=1]' => '(?i)\\bAdultDatingCompany\\b',
                            '__DIPLOMATIC,[l=1]' => '(?i)\\bdiplomatic\\b',
                            '__BANK_DRAFT,[l=1]' => '(?i)\\bbank\\sdraft',
                            '__KAM_DRAPES3,[l=1]' => '(?i)banner.stand|print.project',
                            '__hk_win_a,[l=1]' => '(?i)\\bwinning (?:e-?mail|numbers|information)',
                            '__KAM_PAPERLESS3,[l=1]' => '(?i)fax service|service plan|view.(fax|this.fax)|\\d.page.fax|voice.message',
                            '__EARLY_DEMISE,[l=1]' => '(?i)\\buntimely\\sdeath\\b',
                            '__KAM_STOCKTIP140,[l=1]' => '(?is)BIO-SOLUTIONS|(\\b|^)BISU(\\b|$)',
                            '__KAM_LIST3_4,[l=1]' => '(?i)contacts and email|(visitors?|contacts?|attendee.?s?|users?) (mailing )?(list|record|database)|end users|our lists|\\d\\+? (attendee|contact)|users? database|Opt-in email list|(professionals?|user\'?s|attendees?) (contact|list)|not spammer|delegates|marketing (analyst|campaigns)|(complete|emailed) list|unique account|contacts\\:|titles\\:|business profiles|database of|list from USA|(complete|contact) (Name|information|details)|geography|target audience|list.database|data (intelligence|include)|emails, phone|marketing list|unlimited usage|target (attendees|audience|industry)|opt-?in (contact|emails)|offices and clinics|specialties\\:|showcase our capabilit|share samples|list includes',
                            '__KAM_LIST1,[l=1]' => '(?is)((Hospital|MD) directory|Nursing Home (List|directory)|doctor lists|marketing lists|Licensed Physicians|practicing MDs|practicing Medical doctors|Physicians in America|emails for every state|(vip|laywers|planners|Business Email|HR Directors Email|Sales & Marketing Directors|Managing Director Email) database)',
                            '__KAM_PHISH4_2,[l=1]' => '(?i)dear.{0,50}customer|automated.message|spam.activities|attempted.gaining.access|your.account.expires|authorized.government|important.message|message.alert|suspended',
                            '__KAM_STOCKTIP136,[l=1]' => '(?is)(PrimeGen Energy|(\\b|$)PGNE(\\b|^))',
                            '__FRAUD_XWW,[l=1]' => '(?i)\\b(?:honest(?:ly)?\\sco(?:-?operat(?:e|ion)|llaborat(?:e|ion))|ehrliche\\szusammenarbeit|sichere [kc]o+p[eo]ration|col+aboration\\swith\\sme)\\b',
                            '__KAM_CAD2,[l=1]' => '(?i)we.specialize.in',
                            '__KAM_CREDIT2,[l=1]' => '(?i)View (all 3 reports|your credit score|your up.to.the.minute credit)|(EXPERIAN|Transunion|Equifax) report|check my credit score|3.free credit scores|credit restoration|changes in your.score|get your \\d+ score online|3 major sources|all three bureau|all 3 credit score|credit (may )?ha(ve|s) been revised|payment.options|complimentary 3 scores|credit scores? in seconds|TRANSUNION,\\s+EQUIFAX,\\s+(and|.)\\s+EXPERIAN|just (been )?changed|score.breakdown|credit.summary|score.is.waiting|confirmation #\\d+|average.credit.score|what.?s.your.score|(3|three).free.score|check.your.score|we.can.help|credit.record|complimentary.score',
                            '__KAM_UNIV5,[l=1]' => '(?is)novelty (degree|use)',
                            '__FRAUD_YWW,[l=1]' => '(?i)\\bfurnish you with\\b',
                            'DRUG_ED_SILD,[l=1]' => '(?i)\\bsildenafil\\b',
                            '__KAM_FDA3,[l=0]' => '(?i)FDA Recall',
                            '__FOR_SALE_PRC_10K,[l=1]' => '(?i)\\bprice:? \\$\\d\\d,\\d\\d\\d',
                            '__KAM_HAPPYTALK3,[l=1]' => '(?i)beautiful.mail',
                            '__hk_win_9,[l=1]' => '(?i)\\blucky (?:nl )number',
                            '__KAM_ITC2,[l=0]' => '(?i)International Trade Council',
                            '__KAM_INQUIRY_4,[l=0]' => '(?i)certificate of origin|import\\export|trading company',
                            '__KAM_NIGERIAN2_6,[l=1]' => '(?i)full contact information requested|need your contacts informations|your bank account information|out.of.the.country',
                            '__DOS_LINK,[l=1]' => '\\blink\\b',
                            '__WEBMAIL_ACCT,[l=1]' => '(?i)\\byour web ?mail account',
                            '__URG_BIZ,[l=1]' => '(?i)urgent.{0,16}(?:assistance|business|buy|confidential|notice|proposal|reply|request|response)',
                            '__KAM_PHISH2_4,[l=1]' => '(?i)unauthori[sz]ed use|security.enhancement|dropbox|hold.(on.)?your.fund',
                            '__KAM_URZEST3,[l=0]' => '(?i)(?:(?:wanting|looking|seeking) to get in the gym|(?:dreaming|seeking|hoping) to get (?:into shape|fit))',
                            '__KAM_REMEMBERWHEN3,[l=1]' => '(?i)medication|\\d+%.discount|lots?.of.drug',
                            '__KAM_SPY3,[l=1]' => '(?i)spy.?camera.?system|hidden.spy.camera|valuables.safe|protect.your.children',
                            '__KAM_WEB2,[l=1]' => '(?i)INDIA based IT|indian.based.website|certified.it.company',
                            '__KAM_FAKEPDF2,[l=1]' => '(?is)Reader 2010',
                            '__DRUGS_ERECTILE5,[l=1]' => '(?i)\\b_{0,3}s[_\\W]?[i1!|l\\xEC-\\xEF][_\\W]?l[_\\W]?d[_\\W]?[e3\\xE8-\\xEB][_\\W]?n[_\\W]?[a4\\xE0-\\xE6@][_\\W]?f[_\\W]?[i1!|l\\xEC-\\xEF][_\\W]?l c[_\\W]?[i1!|l\\xEC-\\xEF][_\\W]?t[_\\W]?r[_\\W]?[a4\\xE0-\\xE6@][_\\W]?t[_\\W]?[e3\\xE8-\\xEB]_{0,3}(?:\\b|\\s)',
                            '__JMQ_DROPBOX3,[l=1]' => '(?i)ach.(payment|transfer)',
                            '__FRAUD_ZFJ,[l=1]' => '(?i)\\b(?:wife|son|brother|daughter) of the late\\b',
                            '__FRAUD_WDR,[l=1]' => '(?i)\\bprivate lawyer\\b',
                            '__KAM_DETOX3,[l=1]' => '(?i)detox.program|right.for.you|clean(ing)? up your life|a.little.easier',
                            '__KAM_CLAIMS3,[l=1]' => '(?i)claim.payment|claim.processing|kindly.confirm',
                            '__hk_win_n,[l=1]' => '(?i)\\bcollect your prize',
                            '__KAM_JOB2,[l=1]' => '(?is)twice as much',
                            '__KAM_HONOR1,[l=0]' => '(?i)greatest thing of your life',
                            '__KAM_CITIZEN2,[l=0]' => '(?i)Important (message|Notice) From Citizens',
                            '__KAM_RICH3,[l=0]' => '(?i)talking about my blog',
                            '__KAM_LABEL5,[l=0]' => '(?i)(premier|top|luxury) (clothing|fabric)|fortune 500',
                            '__TVD_PH_BODY_02,[l=1]' => '(?i)\\brecords (?:[a-z_,-]+ )+?(?:feature|(?:a|re)ward)',
                            '__KAM_WEIGHT2_3,[l=1]' => '(?i)melissa mccarthy|now looks \\d+',
                            'STRONG_BUY,[l=0]' => '(?i)strong buy',
                            '__KAM_DUCHESS3,[l=1]' => '(?i)Mr. Media Group|BLM Marketing Services|4801 l[yi]nton b',
                            '__KAM_URUNIT5,[l=1]' => '(?is)(size of (there|their|your) .{0,11}(unit|thing)|using them for a couple months|enhancing formula)',
                            '__KAM_ACCOUNTPHISH3,[l=1]' => '(?i)update.your.information|problems.with.your|billing.information|order.details|personal.data|detailed.order|order.information|for.activation|account.{1,30}.inactive|information.required|secure.browser|recently.compromised|classified.document|with.your.email|complete.your.account|account.confirmed|claim.your.order|free.money|forced.to.cancel|immediate.access|upgrading.all.staff|advice.to.update|confirm.your.account',
                            '__KAM_PATRIOT3,[l=1]' => '(?i)the truth about|financial collapse|your guns|hidden agenda|unprecedented.crisis|disaster|fema (stock.?piling|storing)|Gor?vernment Not Telling|survival.plan|nation.gone.under|blind.with.patriotism|government shutdown|only chance|civil.unrest|high.crimes|behind.our.back|know.the.truth|PatriotNewsNet|second civil war|for.the.cia|market.crash|american.meltdown|concerned.american|military force|we.were.right|our.suspicions|vindicated|abuse.of.power|american.empire',
                            '__KAM_CRIM2_1,[l=1]' => '(?i)bit.{0,2}coin',
                            '__hk_win_8,[l=1]' => '(?i)\\bunexpected luck',
                            '__KAM_SIGN2,[l=0]' => '(?i)review your account',
                            '__KAM_AQUARUG3,[l=1]' => '(?i)stop.slipping|unique.carpet|aqua.rug|bare.feet.love',
                            'TVD_INCREASE_SIZE,[l=1]' => '(?i)\\bsize of .{1,20}(?:penis|dick|manhood)',
                            '__FRAUD_IPK,[l=1]' => '(?i)\\b(?:in|to|visit) your country\\b',
                            '__KAM_ADHD3,[l=0]' => '(?i)struggling with adh?d|treatment options',
                            'JOIN_MILLIONS,[l=1]' => '(?i)\\bjoin (?:millions|thousands)\\b',
                            'TVD_LINK_SAVE,[l=1]' => '(?i)\\blink to save\\b',
                            '__KAM_REFI2,[l=1]' => '(?is)(Free Evaluation (?:online|on your (?:current )?home loan)|No hidden costs|no strings attached|good credit or not|personalized consultation|in need of loan|consolidation loan|loan processing|apply by sending|loan of any amount|clean up any inacccuracies|lock in saving|save on monthly mortgage|absolutely no cost|underwater)|Reverse.?Mortgage|qualify for a VA loan|Refi now.? and Save|obama..?announces|rate.calculator|save.thousands|update: \\d.\\d\\d..available|homeowner|over.your.head|rate.service|now.eligi?[bl]{2}e|a.second.mortgage|urgent.loan|loan.offer',
                            '__KAM_MILLIONAIRE1,[l=0]' => '(?i)internet millionai?re',
                            '__KAM_MEDICARE3,[l=1]' => '(?i)medicare.(plan|recipient|annual election)',
                            '__DRUGS_ANXIETY2,[l=1]' => '(?i)\\bAlprazolam\\b',
                            '__KAM_HOLIDAY2020_2,[l=0]' => '(?i)(illusional|Vortex|3d) Rug|wireless earbuds|canvas print|get your (personalized christmas )?ornament|holiday novelty|personalized ornament|rising laptop|HOME Ear endoscope|Gadget ?Junk',
                            '__KAM_WEIGHT2_1,[l=0]' => '(?i)goodbye to her waist|wild transformation',
                            '__hk_win_o,[l=1]' => '(?i)\\bclarification and procedure',
                            '__KAM_SPAMKING3,[l=1]' => '(?is)To .{0,30}(?:unsubscribe|stop|remove) .{0,35}(?:email|messages) from third party advertisers',
                            '__KAM_BAD_PRODUCT2,[l=0]' => '(?i)Dolphin sealer|hotstreak plug|Rapid thaw tray',
                            '__KAM_QTJARS4,[l=1]' => 'private message',
                            '__KAM_RUIN1,[l=0]' => '(?i)do not deposit',
                            '__KAM_PROPHET4,[l=1]' => '(?i)Christian ?Media ?(Daily|Ministry)',
                            '__KAM_OILCHANGE3,[l=1]' => '(?i)fresh savings|find your favorite|discount.coupons|oil.change.is.due|local.provider|favorite.location|coupon',
                            '__KAM_KITCHEN3,[l=1]' => '(?i)special.gift|kitchen.remodel|special.offer',
                            '__KAM_FUNERAL3,[l=1]' => '(?i)untimely death|death notification|funeral.costs',
                            'KAM_VIAGRA2,[l=0]' => '(?i)(?:Xan|Som|CIA|VAL|VIA|Pro|Amb|Lev|Mer) (?:Xan|Som|CIA|VAL|VIA|Pro|Amb|Lev|Mer) (?:Xan|Som|CIA|VAL|VIA|Pro|Amb|Lev|Mer)',
                            '__KAM_UNIV5B,[l=1]' => '(?is)F A S T[ ]{0,4}T R A C K',
                            '__KAM_NIGERIAN1,[l=1]' => '(?is)(?:payment officer|personal treasurer|experienced marketers|Chairman of the Finance Committee|contact my secretary|field of Financial Services|Head of Human Resources|Public Relation Officer|field of Business Services|payment agent|representing partner|vacancy in my company|representative\\/book ?keeper|executor|search and selection of both experienced|retired chief economist|foreign partner|diplomatic courier|senior auditor|online book-?keeper)|in.your.country|united.state[^s]|states?.citizen|retired.ceo|nigeria|origin.finland|serious.illness|brain.(tumor|cancer)|former.minister|investment.partner|got.mugged|losing.my.(wife|only.son)',
                            '__KAM_GIFT5,[l=1]' => '(?i)member incentive program|complet(e|ing) the survey|your.customer.id|security.code|promotional.points',
                            '__KAM_VISION3,[l=1]' => '(?i)100%.natural|vision.restored|currently.wear.(glasses|contacts)|perfect.vision|risky.surgery|corrective.surgery|dangers.of.surgery|laser.eye|eye.care|making.your.eyes.worse|your.glasses|worsen.your.vision|special.prices|vision.in.\\d+.day|vision.in.\\d+.week',
                            '__KAM_EBAY1,[l=0]' => '(?i)Succeed on ebay|thousands with ebay|ebay success|money-making secret',
                            '__KAM_KN_1,[l=1]' => '(?i)(respirator|KN95) .{0,25}Mask|Ultramasx|upgrade your mask',
                            '__KAM_TELEWORK1,[l=1]' => '(?is)(generate|make) .{0,10}1.5K? (to|-) 3.5K (a day|daily|per day|per month)|makes? \\$[\\d,]+\\/month|upgrade your salary',
                            '__KAM_NIGERIAN2_4,[l=1]' => '(?i)e-?mail id is found among those that have been scammed|paid the fee for your cheque draft|contact the bank director',
                            'ACT_NOW_CAPS,[l=1]' => '\\bA(?i:ct) N(?i:ow)\\b',
                            '__FRAUD_BEP,[l=1]' => '(?i)\\b(?:bank of nigeria|central bank of|trust bank|apex bank|amalgamated bank)\\b',
                            '__SURVEY,[l=1]' => '(?i)\\bsurvey\\b',
                            '__KAM_COMPANY2_1,[l=1]' => '(?is)Member Services MGM, LLC',
                            '__PILL_PRICE_01,[l=1]' => '(?i)(?=[\\d .f])(?:free|[\\d .]{3}(?:/|per|each)) ?(?=[ptc])(?:pill|tablet|cap(?:sule|let))s?\\b',
                            '__FRAUD_QFY,[l=1]' => '(?i)\\bover-? *(?:invoiced?|cost(?:s|ing)?)\\b',
                            '__KAM_URUNIT3A,[l=1]' => '(?is)\\b(exasperated|fatigued|drained|tired) all the time',
                            '__KAM_AP3,[l=0]' => '(?i)American Grants and Loans Catalog',
                            '__FRAUD_LTX,[l=1]' => '(?i)\\bmilli?on (?:.{1,25} thousand\\s*)?(?:(?:united states|u\\.?s\\.?) dollars|(?i:U\\.?S\\.?D?))\\b',
                            '__KAM_STOCKTIP134,[l=1]' => '(?is)(United Consortium|(\\b|^)UCSO(\\b|$))',
                            '__KAM_DON3,[l=1]' => '(?i)donnob\\.(?:biz|net)|emarketnow.com|watersolutiontoday.com',
                            '__KAM_SHOP1,[l=1]' => '(?is)chosen to participate as a Mystery Shopper',
                            '__KAM_PROJECT2,[l=0]' => '(?i)business project',
                            '__KAM_DRIVE3,[l=1]' => '(?i)to.be.furnished|office.equipment.item',
                            '__KAM_GIFT1,[l=1]' => '(?is)(Claim your free \\$500 Target Gift Card|complimentary gift-?card|received a Victoria\'s Secret Giftcard|\\$500 airline gift card|\\$1000 gift card for you to shop|\\$\\d+.{0,50}gift card|Secret gift card)|costco.coupon|facebook.gift|claim.my.credit',
                            '__KAM_GRIPPY3,[l=1]' => '(?i)gripeez.bonus|interior.decorator|sticky.grip',
                            '__KAM_RAT2_2,[l=0]' => '(?i)dear shopper',
                            '__KAM_TESTOSTERONE4,[l=1]' => '(?i)Testoril|sexual confidence|androgel|axiron+androderm',
                            '__KAM_UNIV1B,[l=1]' => '(?i)\\d (months|weeks)',
                            '__KAM_FAKE_FAX2,[l=0]' => '(?i)incoming fax|fax received',
                            '__KAM_REVIEW3,[l=1]' => '(?i)unverified|major.local.search|search.sites|company(.s)?.information',
                            '__KAM_MARIJUANA1,[l=0]' => '(?i)marijuana|cannabis',
                            'CUM_SHOT,[l=1]' => '(?i)\\bcum[ -]?shots?\\b',
                            '__KAM_MASCARA3,[l=0]' => '(?i)smartlash',
                            'GUARANTEED_100_PERCENT,[l=0]' => '(?i)100% GUARANTEED',
                            '__COPY_PASTE_FR,[l=0]' => '(?i)le copier (et le|\\+) coller',
                            '__KAM_EMAILPHISH1,[l=0]' => '(?i)Please login to complete update process',
                            '__KAM_BADUNSUB,[l=0]' => '(?i)(?:remove|Unsubscribe) from (?:MindTCommunications|LunarMessages)',
                            '__KAM_BADZIP1,[l=0]' => '(?i)attached (to email|document)|take a look',
                            '__KAM_TRIAL,[l=1]' => '(?i)RISK-FREE Trial|Free \\d+ day trial|try it free|free.dvd.info|free.info.kit|limited..?trial|claim.package',
                            '__KAM_SEX04_1,[l=1]' => '(?is)(curative|medicinal|salutary|wholesome|beneficial|satisfaction) effect|(first-rated|splendid) drugs|(yellow|blue|famos) (tablet|pill)|good medical supplies|(commendable|valuable) medicines|canadian pharmacy|GNC|nugenix',
                            '__KAM_TVDOCTOR3,[l=1]' => '(?i)clinical|miracle|dermatologist|anti.?.?aging.tip|\\d+.years.younger|wrinkle.(reduction|prevention)|\\bOMG!\\b|loose.\\d+.lb|tv.doctor',
                            '__KAM_SEX2,[l=1]' => '(?i)(?:(\\b|^)cunt(\\b|$)|busty|interracial|hardcore|peni(s|le) enlarge|generic quality|enlarge your manhood|stone-hard manhood|XXL Dick|intense pleasure|spend a night with you|efficient medicine|turn on your wife|with your boner|dick dangl)|\\d.(extra.)?inches.of.girth|best.sex',
                            '__DOS_I_DRIVE_A,[l=1]' => 'I drive a',
                            '__KAM_STOCKTIP153,[l=1]' => '(?is)INSCOR|(\\b|^)IOGA(\\b|$)',
                            '__DRUGS_DIET3,[l=1]' => '(?i)\\bbontril\\b',
                            '__KAM_SHADYCC4,[l=0]' => '(?i)(detailed|full) statement',
                            '__KAM_CHICKEN3,[l=1]' => '(?i)your.own.chicken|fresh.egg|chicken.coop|build.your.own',
                            '__KAM_GIVE1,[l=0]' => '(?i)receive your gift',
                            '__DECEASED,[l=1]' => '(?i)\\b(?:the|my|your|der|du|le|meu?)\\s(?:deceased|late|verstorbenen|d(?:i|e|=E9|[\\xe9]|[\\xc3][\\xa9])funto?|d(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])nt|falecido)\\b',
                            '__KAM_LOTTO6,[l=1]' => '(?is)(Dear (Award|Consultation Prize|Lucky) Winner|Winning Notification|Attention:Winner|Dear:? Winner|Amount won:|Sincere Congratulations|Lucky Numbers:|you are a winner|prize attached|prize notification|claims requirement|winning number|winning sum|payout of|qualification number)|attached.file|numbers.on.email|active email address|dear e-?mail',
                            '__DOS_BODY_SUN,[l=1]' => '(?i)\\bsun(?:day)?\\b',
                            '__KAM_DEATH4,[l=1]' => '(?i)heart.(attack|stops)',
                            '__FB_COST,[l=1]' => '(?i)\\bcost\\b',
                            '__KAM_FAKEVOUCHER4,[l=1]' => '(?i)your.opinion|submit.your.email',
                            '__KAM_ADMIN3,[l=0]' => '(?i)next tax return',
                            '__KAM_HERPES3,[l=1]' => '(?i)permanent.remedy|ugly.sores|herpes.episode|got.herpes|your.herpes|herpes.issue',
                            '__KAM_FAKEPDF1,[l=1]' => '(?is)Download PDF Reader.Writer',
                            '__KAM_SWIFT3,[l=0]' => '(?i)balance payment',
                            '__KAM_DOMAINEXPIRY2,[l=0]' => '(?i)Attached letter',
                            '__KAM_TIRES3,[l=0]' => '(?i)savings on tire|new tires',
                            'BODY_ENHANCEMENT,[l=1]' => '(?i)\\b(?:enlarge|increase|grow|lengthen|larger\\b|bigger\\b|longer\\b|thicker\\b|\\binches\\b).{0,50}\\b(?:penis|male organ|pee[ -]?pee|dick|sc?hlong|wh?anger|breast(?!\\s+cancer))',
                            '__JMQ_WIRE2,[l=1]' => '(?i)medical.support|payment.sent',
                            '__KAM_SEX04_2,[l=1]' => '(?is)fun in bed|(bed|night) adventures|aid your bed|(lift|heave|ascent|hoist|raise|boost|aid) your (belove|love|darling|sex|sweet)|sexuality with assistance|ascent your sweet|bed experience|love sexuality',
                            '__JMQ_TRACKR3,[l=1]' => '(?i)locate anything|find.anything|never.lose.anything|new.invention|never.lose.your|tired.of.losing|find.any.lost',
                            '__KAM_CAR3,[l=1]' => '(?i)unbelievable payment terms|no commitment|free price quote|get competitive quotes|offering better rates|no obligation quote|Pay Later|No risk|save up to \\d+%',
                            '__KAM_SEO6,[l=1]' => '(?i)will not get your website banned|Google.?s SEO policies|six month ongoing campaign|web.promotion|quality junk spam',
                            '__KAM_SWIPE3,[l=1]' => '(?i)pennies on the dollar|join, bid|penny (auctions|stock)|\\d% .{0,10}retail|ipads on auction|bid now|factory sealed ipads|cheap ipads|for pennies|ebay killer|Inventory Clearance on iPads|crazy auctions|XPS for \\d\\dUSD|iphone.{1,10}clearance|the.hottest',
                            '__KAM_BEAUTY1,[l=1]' => '(?i)she now looks \\d+',
                            '__KAM_GIFTCERT2,[l=1]' => '(?i)\\$\\d+ gift certificate',
                            'GTUBE,[l=1]' => 'XJS\\*C4JDBQADN1\\.NSBN3\\*2IDNEN\\*GTUBE-STANDARD-ANTI-UBE-TEST-EMAIL\\*C\\.34X',
                            '__hk_win_b,[l=1]' => '(?i)\\byour e-?mail (?:address )?(?:has )?w[io]n',
                            'DIET_1,[l=1]' => '(?i)\\b(?:(?:without|no) (?:exercis(?:e(?! price)|ing)|dieting)|weight.?loss|(?:extra|lose|lost|losing).{0,10}(?:pounds|weight|inches|lbs)|burn.{1,10}fat)\\b',
                            '__KAM_UNIV7,[l=1]' => '(?is)(life|work) experience (diploma|degree|transcript)',
                            'REFINANCE_NOW,[l=1]' => '(?i)time to refinance|refinanc\\w{1,3}\\b.{0,16}\\bnow\\b',
                            '__KAM_TAX4,[l=1]' => '(?i)MSNBC|fox news|CNN|please.confirm|you.qualify|obtain.now|must.see.tax',
                            '__KAM_TIP3,[l=0]' => '(?i)undereye bags',
                            'TVD_QUAL_MEDS,[l=1]' => '(?i)\\bquality med(?:ication)?s\\b',
                            '__SUBSCRIPTION_INFO,[l=1]' => '(?i)\\b(?:e?newsletters?|(?:un)?(?:subscrib|register)|you(?:r| are) subscri(?:b|ption)|opt(?:.|ing)?out\\b|further info|you do ?n[o\']t w(?:ish|ant)|remov\\w{1,3}.{1,9}\\blists?\\b|to your white.?list)',
                            '__KAM_CELL3,[l=1]' => '(?i)phone.(information|deals|reviews)|(free|latest|hottest)..?(cell)?.?phone|selection.of.phones|hottest.(brands|models)|check.out.these.smartphones|smartphones.do.more|refurbished.phone|bored.with.your.phone',
                            '__KAM_REAL2_4,[l=1]' => '(?i)(?:home sites|raw land|vacation home|wooded.property)',
                            '__KAM_CEP5,[l=0]' => '(?i)degree\\/certificates|certification',
                            '__KAM_LANDSCAPE4,[l=1]' => '(?i)stone.carving',
                            '__KAM_TRAINING3,[l=0]' => '(?i)Human Resources',
                            '__KAM_DRILL3,[l=1]' => '(?i)(exceed(ed)? .{0,10}expectations|see your brokers website)',
                            '__CAN_HELP,[l=1]' => '(?i)\\bcan help\\b',
                            '__KAM_DISCLOSE1,[l=0]' => '(?i)enable me disclose|indicate your? interest|something important',
                            '__KAM_REAL2_5,[l=0]' => '(?i)(?:developers|estates|buyer flying in|retirement plans|liquidation)',
                            '__KAM_DIET2_3,[l=1]' => '(?i)secret to being skinny|doctors? are raving|testosterone|could be \\d+ ?lbs? lighter|feeling chubby',
                            '__KAM_PRIV2,[l=0]' => '(?i)(personal|private) video',
                            '__KAM_COVID3_4,[l=0]' => '(?i)assist me',
                            '__KAM_TESTOSTERONE3,[l=1]' => '(?i)Boost your testosterone|get your body back|low.testosterone',
                            '__TVD_PH_BODY_04,[l=1]' => '(?i)\\bfunds? (?!transfer from)(?!from)(?!in)(?!via)(?:[a-z_,-]+ )+?to your (?:[a-z_,-]+ )*?account',
                            '__KAM_STOCKTIP166,[l=1]' => '(?is)(\\b|^)(INCT|Incapta)(\\b|$)',
                            '__KAM_COLLECT4,[l=0]' => '(?i)recovery rate',
                            '__LOTSA_MONEY_05,[l=1]' => '(?i)(?:(?:sum|value|amount)\\sof\\s)<NUM_NOT_DATE_IP>[\\d.,\\sO]{7,20}[\\dO\\.][\\)\\]\\(\\s]{0,3}(?:pounds?|dollars?|euros?|bucks)\\b',
                            '__KAM_WEB3,[l=1]' => '(?i)Online Marketing Consultant|possible.redesign|seo.service|mobiles?.app|business.develop|commerce.solution',
                            '__KAM_BADZIP2,[l=0]' => '(?i)Encrypted zip',
                            '__KAM_CEP3,[l=1]' => '(?i)Career Education program|customize a learning program|certified.instructor',
                            '__LOTTO_DEPT,[l=1]' => '(?i)\\b(?:claim(?:s|ing)?(?:\\sprocessing)?|fiducia\\w+|reimbursement|(?:international|foreign|win+ing)(?:\\s(?:rem+it+ance|settlement|payment|award))+|payment|award|compensation|lot+ery)(?:\\s\\w+)?\\s?(?:department|dept|unit|group|committee|bureau)',
                            '__ACCESS_RESTORE,[l=1]' => '(?i)\\bto (?:(?:restore|regain) access|(?:remove|uplift) (?:the|this) suspens|continue using your (?:account|online|mailbox)|zugreifen wiederhergestellt)',
                            '__KAM_WHOSWHO3,[l=1]' => '(?i)(global|executive) who.s who|represent your community|you have been selected|complete your listing|prominent registry|accomplished individuals',
                            '__BOUNCE_OOO_CB1,[l=1]' => '(?i)\\bout of (?:the )?office\\b',
                            '__KAM_SEO4,[l=1]' => '(?i)SEO Specialists|online marketing services|S.?E.?O.? Company in INDIA|google.panda|google.penguin|not.ranking|SEO Packages',
                            '__KAM_KN_2,[l=0]' => '(?i)get your|for the public|biden wants to curb|Prevent Corona|quick delivery|do your part|while supplies last|(smart|your) mask',
                            '__hk_win_0,[l=1]' => '(?i)\\byour? e-?mail just w[oi]n',
                            '__KAM_REAL2_3,[l=1]' => '(?i)(?:unbelievable deals|buyer with CA[s\\$]h|pennies.on.the.dollar)',
                            '__KAM_STOCKTIP148,[l=1]' => '(?i)(\\b|^)STBV(\\b|$)',
                            '__HK_LOTTO_BALLOT,[l=1]' => '(?i)\\b(?:promotional|on.?line|computer|internet|e-?mail|fran.aise) (?:ballot|draw|sweepstake)',
                            '__KAM_VIAGRA9C,[l=1]' => '(?i)VAL..IUM',
                            '__KAM_STUDENTLOAN4,[l=0]' => '(?i)866-351-4693',
                            '__KAM_VERIZON7,[l=0]' => '(?i)credit card|bank account',
                            '__DOS_BODY_STOCK,[l=1]' => '(?i)\\bstock\\b',
                            '__JMQ_REALESTATE3,[l=1]' => '(?i)preferred.choice|looking.for.real.estate|online.platform|systems.placement',
                            '__KAM_FAKEWEST4,[l=0]' => '(?i)Wrong Transfer',
                            '__KAM_PHISH2_2,[l=1]' => '(?is)Virginia Credit Union|Lloyds|HSBC|usaa|barclay|credit card account',
                            '__KAM_VIAGRA9B,[l=1]' => '(?i)AMB..IEN',
                            '__RELEASE_MESSAGES,[l=1]' => '(?i)\\b(?:release messages|(?:retrieve|release|download) your(?: undelivered|unreceived|held|pending)? e?-?mails|(?:e?-?mails|messages).{1,20}download them now)\\b',
                            '__KAM_HOOKUP3,[l=1]' => '(?i)match.?me.?networks',
                            '__LUCKY_WINNER,[l=1]' => '(?i)\\b(?:lucky|gl.cklich(?:en)?|afortunados)\\s(?:(?:ge)?win+ers?|ganador(?:es)?|individuals?)\\b',
                            '__FOR_SALE_PRC_100K,[l=1]' => '(?i)\\bprice:? \\$\\d\\d\\d,\\d\\d\\d',
                            '__KAM_HACK3,[l=0]' => '(?i)save yourself|lead to your arrest',
                            '__KAM_UNIV11,[l=1]' => '(?is)(degree|transcript) in any field|Field of yourr? ch[oò][iì]ce',
                            '__KAM_DISCAIR3,[l=0]' => '(?i)Fly Cheap in Business Class',
                            '__RUDE_HTML_4,[l=1]' => '(?i)Your mailer do not support HTML messages. Switch to a better mailer',
                            '__KAM_INVOICEPO2,[l=0]' => '(?i)consignment',
                            '__YOU_WON_02,[l=1]' => '(?i)\\bw[io]n\\s(?:(?:for|by)\\s)?your?\\b',
                            '__FRAUD_JYG,[l=1]' => '(?i)\\bgive\\s+you .{0,15}(?:fund|money|total|sum|contact|percent)\\b',
                            '__KAM_DOMAIN_SALE4,[l=1]' => '(?i)\\b(domain you might be interested|interested in the domain|interested in obtain|benefit acquiring|complete ownership transfer|brokering the domain)\\b',
                            '__KAM_RICH4,[l=1]' => '(?i)bec.me financially independent',
                            '__KAM_PROFORMA4,[l=0]' => '(?i)Proforma Invoice',
                            '__KAM_INQUIRY_1,[l=0]' => '(?i)inquiry for purchase|product catalog|price list|reply with catalog',
                            '__INHERIT_PMT,[l=1]' => '(?i)\\binheritance\\spayment\\s',
                            '__KAM_SEX05_2,[l=0]' => '(?i)buy rubber friends|big bait in your pants|she sees your size|women will be funk|biggest tool|immense monster|women will be daydreaming|have so much meat|prolonging your size|last a lot longer',
                            '__FRAUD_PTX,[l=1]' => '(?i)\\b(?:ass?ass?inat(?:ed|ion)|murder(?:e?d)?|poison(?:e?d)?|kill(?:ed|ing|ers)\\b[^.]{0,99}\\b(?:war veterans|rebels?)|les tueurs)\\b',
                            'KAM_OVERPAY,[l=1]' => '(?i)O . V . E . R . P . A . Y',
                            '__IVORY_COAST,[l=1]' => '(?i)\\b(?:Cote\\s?D.Ivoire|Ivory\\s?Coast|Costa\\sde\\sMarfil)\\b',
                            '__KAM_COVID3_1,[l=0]' => '(?i)Prince',
                            '__KAM_SEENTHIS1,[l=1]' => '(?i)have.you.seen|seen.this',
                            '__KAM_GOVT2,[l=0]' => '(?i)government funding',
                            '__KAM_FAKESHAREPOINT4,[l=0]' => '(?i)Sharepoint Fileshare',
                            '__KAM_RECALL3,[l=1]' => '(?i)protect.your.dog|recall?s.on.dog.?food|processing.standards|commercial.food',
                            '__DLND_ATTACH,[l=1]' => '(?i)\\bdownload\\sthe\\sattach(?:ed|ment)\\b',
                            '__KAM_SHARP3,[l=0]' => '(?i)zirconium oxide',
                            '__KAM_HIP1,[l=0]' => '(?i)hip replacement|medical alert',
                            '__KAM_NEWNOTICE1,[l=1]' => '(?i)- - -\\s?(start |begin )?(of |new )?(notification|notice)( \\d\\d\\/\\d\\d\\/\\d\\d)?\\s?- - -|notice of',
                            '__DRUGS_DIET_PHEN,[l=1]' => '(?i)\\bphentermine\\b',
                            '__DRUGS_DIET4,[l=1]' => '(?i)\\bphendimetrazine\\b',
                            '__KAM_STATLER3,[l=0]' => '(?i)Mike Statler',
                            '__KAM_VM4,[l=1]' => '(?i)recorded voice|audio message|Caller.id|CID:|mailbox \\d|sign document',
                            '__KAM_MAILER1,[l=0]' => '(?i){!firstname_fix}',
                            '__FRAUD_WFC,[l=1]' => '(?i)\\bsecur(?:e|ing) (?:the )?(?:funds?|monies)\\b',
                            '__FRAUD_EZY,[l=1]' => '(?i)\\b(?:of|the) late president\\b',
                            '__KAM_HAPPYTALK2,[l=1]' => '(?i)honest.and.nice',
                            '__TRUNK_BOX,[l=1]' => '(?i)\\b(?:(?:trunk|metallic|proof|security|consignment)\\sbox(?:es)?|sealed\\ssafe|une mallette m(?:e|=E9|[\\xe9]|[\\xc3][\\xa9])tallique)\\b',
                            '__FRAUD_IOU,[l=1]' => '(?i)\\b(?:no risks?|risk-? *free|free of risks?|100% safe)\\b',
                            '__DOS_STRONG_CF,[l=1]' => '(?i)\\bstrong cash flow',
                            '__KAM_ADVANCE3,[l=0]' => '(?i)Pre-Approved',
                            'NO_MEDICAL,[l=1]' => '(?i)\\bno medical exam',
                            '__KAM_SEX4,[l=0]' => '(?i)(?:bring your girlfriend back|satisfied with their size|penis so huge and heavy|more semen|volume of your loads|wondercum|ejaculate|bargain offers on medic|improve xxx|improve your lovemaking|youngest teen|teen pics|monster in his pants|(female|multiple) orgasms|extreme penetration)',
                            '__KAM_STOCKTIP154,[l=1]' => '(?is)mLight Tech|(\\b|^)MLGT(\\b|$)',
                            '__KAM_MARIJUANA2,[l=1]' => '(?i)medicinal|recreational|legal.cannabis',
                            '__KAM_NEWS2,[l=0]' => '(?i)(?:Hello|hey|hi)!',
                            '__KAM_STOCK2_2,[l=1]' => '(?i)(easy cash|losses and victories|backstage trading|market facts|succeed in trading|destined to skyrocket|make traders rich|times your principal)|good.investment|overvalued.companies|company.is.soaring|economic.opportunity|amazing.company|take.notice|rental.yield|high.return',
                            '__KAM_INSURE2,[l=1]' => '(?i)find better Health Insurance Rates Today|get information about health coverage|protect your family|overpay for auto insurance|been recently,? lowered|gas prices are going up|Auto Insurnace go with it|no examination|get (?:a )?free quote|have been.{0,2}reduced|AutoWarranty|plans as low as|plans starting at|complete your health profile|Secure \\d+k coverage|growing.family|milestone|special.enroll|updated.rate|lifeinsurance|no.medical.exam|accuquote|no.tobacco.rate|denied.coverage|business.policy|reduced.rate|coverage.starts.immediately|obama|respect.your.privacy',
                            '__KAM_GOOGLEFORM_3,[l=0]' => '(?i)foundation is donating',
                            '__KAM_UNIV4,[l=1]' => '(?is)not official degree|non[ -]?accredited',
                            'PREST_NON_ACCREDITED,[l=1]' => '(?i)prestigi?ous\\b.{0,20}\\bnon-accredited\\b.{0,20}\\buniversities',
                            '__JMQ_PICKUP2,[l=1]' => '(?i)(dirty|freaky|naughty|good)(pix|pic)|hey.cutie',
                            'REPLICA_WATCH,[l=1]' => '(?i)\\breplica.{1,20}rolex',
                            '__DRUGS_PAIN12,[l=1]' => '(?i)\\besgic plus\\b',
                            '__KAM_SUPERHUMAN3,[l=1]' => '(?i)reclaim your glory|stay hot and sexy|unfair.advantage|better sex|weird trick|testosterone',
                            '__KAM_STOCKTIP130,[l=1]' => '(?is)(Pricester|(\\b|^)PRCC(\\b|$))',
                            '__KAM_JUDGE3,[l=1]' => '(?is)collect your money',
                            '__KAM_LIST4,[l=1]' => '(?is)(?:database|list|[\\d,]+ (total records|e-?mails))',
                            '__KAM_COBRA3,[l=0]' => '(?i)find cobra health',
                            'EXCUSE_4,[l=1]' => '(?i)To Be Removed,? Please',
                            '__BTC_OBFU_5,[l=0]' => '(?i)&#x62;&#x69;&#x74;&#x63;&#x6F;&#x69;&#x6E;',
                            '__KAM_STOCKTIP146,[l=1]' => '(?is)Plandai|(\\b|^)PLPL(\\b|$)',
                            '__LOTTO_ADMITS_2,[l=1]' => '(?i)\\b(?:free)?(?:lot(?:to|tery|erie)|sweepstakes)\\s(?:(?:inter)?na[tz]ional|department|bureau|group|award|microsoft)',
                            '__HAS_WON_01,[l=1]' => '(?i)\\bque ha ganado\\b',
                            '__KAM_AQUA2,[l=1]' => '(?is)watering your plants',
                            '__KAM_HOME1,[l=1]' => '(?i)YOUR HOME|Federal Housing Assistance Program|near.your.area',
                            'UNCLAIMED_MONEY,[l=1]' => '(?i)\\bunclaimed\\s(?:assets?|accounts?|mon(?:ey|ies)|balance|funds?|prizes?|rewards?|payments?|deposits?)\\b',
                            '__TVD_PH_BODY_06,[l=1]' => '(?i)Dear [a-z]+ bank (?:member|customer)',
                            '__KAM_PROJECT4,[l=0]' => '(?i)please respond',
                            '__KAM_CANDY3,[l=0]' => '(?i)you deserve a treat|sweet tooth',
                            '__FRAUD_FCW,[l=0]' => '(?i)fiduciary agent',
                            '__KAM_SKINCELL1,[l=1]' => '(?i)Skincell.Pro',
                            '__ACCESS_REVOKE,[l=1]' => '(?i)(?:(?:temporary|permanent) (?:de-?activation|removal) of your (?:\\w{1,30} )?(?:access|account)|Ihre Kreditkarte wird gesperrt)',
                            '__DOS_STEADY_COURSE,[l=1]' => '(?i)\\bsteady (?:and increasing )?course\\b',
                            '__KAM_GIVE2,[l=1]' => '(?i)laptop giveaway|deliver your dell.? laptop',
                            '__KAM_SUNGLASSES3,[l=1]' => '(?i)style rocks|today.only',
                            '__KAM_WEB2_4,[l=0]' => '(?i)portfolio|sample|insights',
                            '__KAM_REFI6,[l=1]' => '(?is)((?:reduce your monthly payment|save you) (between )?\\d{2}\\s*%|save yourself hundreds of dollars|great rate available|completely unsecured|instantly connect with\\s+lenders|get you back on the right financial|get report today|protect against identity|know your credit score|crazy payments)|u.?s.? homeowners|drop.your.rate|in.your.pocket|our.records|apply.for.your',
                            '__KAM_AUTONEW3,[l=1]' => '(?i)just.{1,2}been.{1,2}lowered|reduced.recently|has been reduced|free.repair|easy.steps|overpaying|view.plan|overpaid.your|premiums?.as.low|lenders.compete',
                            '__KAM_NIGERIAN2_3,[l=1]' => '(?i)high court|central bank|payment center|customs?.officer',
                            '__KAM_DEBT1,[l=1]' => '(?is)(debts disappear|reduce your payments|piling bills|creditors|late bills|vanish some of your bills|reduce your payments|looming bills|all that debt|outstanding debt|debt.{0,7}accumulated|all my debt|penalties,? and fees are gone|banking laws|select legal|change your life|get out of .?d.?e.?b.?t|Free[- ]Credit Report|debt relief options|are you in debt|pay off all your debt|get better rates|credit card debt|could.be.easy)',
                            '__KAM_BLOOD4,[l=1]' => '(?i)Marine Essentials|this mineral|drug.companies.hate',
                            '__FRAUD_SNT,[l=1]' => '(?i)\\blocate(?: .{1,20})? extended relative',
                            '__FOUND_YOU,[l=1]' => '(?i)\\b(?:I|we)\\sfound\\syour?\\b',
                            '__KAM_STOCKTIP133,[l=1]' => '(?is)(Pluris Energy|(\\b|^)PEYG(\\b|$))',
                            '__KAM_QTJARS3,[l=1]' => 'qtjars',
                            'KAM_VIAGRA5,[l=1]' => '(?i)(V [1li|\\]] [a&] G R A|VljAG+R+A)',
                            '__KAM_TIME6,[l=0]' => '(?i)(Cx?ARTIER|Bx?REITLING|Px?ATEK|Rx?OLEX|Bx?VLGARI|Tx?IFFANY)',
                            '__KAM_TIME5,[l=1]' => '(?i)(funny|low) price|treat.yourself',
                            '__KAM_VEST1,[l=0]' => '(?i)(heated|thermal) vest',
                            '__WIDOW,[l=1]' => '(?i)\\b(?:widow(?:e[rd])\'?s?|veuve)\\b',
                            '__KAM_RBL_OBFU1,[l=1]' => '(?i)b2b.{1,4}salesprospects.{1,4}com',
                            '__KAM_HEALTH2_1,[l=0]' => '(?i)affordable health coverage',
                            '__KAM_DON4,[l=0]' => '(?i)\\$1,000 A Day ATM|J\\.O\\.B\\.',
                            '__HK_SCAM_S25,[l=1]' => '(?i)\\bbank (?:in|of) ghana',
                            '__KAM_QUOTA2,[l=1]' => '(?i)Limited Access|termination of your email|restore.your.account|will.not.be.able',
                            'NOT_ADVISOR,[l=0]' => '(?i)not a registered investment advisor',
                            '__KAM_FAKEWEST5,[l=1]' => '(?i)0[\\.,]?000[\\.,]?00\\s?USD',
                            '__KAM_LOTTO4,[l=1]' => '(?is)(claims (office|agent|manager|requirement)|lottery coordinator|(certificate|fiduciary) (officer|agent|claims)|accredited agent|payment agency board|promotion manager|promotions? department|Name of +Agent:|executive secretary|claims & Management|lottery approved courier|promo.team)',
                            '__KAM_DATINGTIPS3,[l=1]' => '(?i)seduction|certain.type.of.guy|secret to their hearts|women.excited|real.love|one.night.stand',
                            '__PAY_YOU,[l=1]' => '\\bpay\\syou\\b',
                            'FORWARD_LOOKING,[l=1]' => '(?i)\\bcontains forward-looking statements\\b',
                            '__AUTO_ACCIDENT,[l=0]' => '(?i)auto(?:mobile)? accident',
                            '__KAM_MAID3,[l=1]' => '(?i)Pre-Screened Housekeepers|local.maid',
                            '__KAM_FOOTBALL3,[l=0]' => '(?i)Mercato',
                            'BAD_CREDIT,[l=1]' => '(?i)\\b((?:bad|poor|eliminate|repair|(?:re)?establish|damag).{0,10} (?:credit|debt)|no credit (?:check|histor|need))',
                            '__KAM_STOCK2_1,[l=1]' => '(?i)(good trader|trading experience|bad trading day|hard trading day|FREE Stock Market Outlook|Market Watch)|more.than.\\d+%|most.valuable|morning.report|real.?estate.authority|commercial.real.estate',
                            '__KAM_STOCKTIP128,[l=1]' => '(?is)(MONUMENTAL MARKETING|(\\b|^)MNUM(\\b|$))',
                            '__KAM_SOFTWARE4,[l=0]' => '(?i)download for no cost|FREE Software|Free Analysis|Free Report',
                            '__KAM_DRILL2,[l=0]' => '(?i)oil (company|partnership|and gas rights)',
                            '__KAM_RBL_OBFU3,[l=0]' => '(?i)jrgpartners\\(\\.\\)com',
                            '__KAM_URONLINE1,[l=1]' => '(?i)(chat|chat with me|hook ?up) on Y ?A ?H ?O ?O (tonight|or MSN)|add me with yahoo or msn|view now|press this web link|send me your? photo|can u turn me on|kissing you|begin.a.chat',
                            '__KAM_CERT2,[l=0]' => '(?i)review this certificate',
                            '__KAM_ENGINEER2,[l=1]' => '(?i)email.list|target.audience|databank|verified.email',
                            '__I_INHERIT,[l=1]' => '(?i)\\b(?:I|eu)\\s[a-z\\s]{0,30}(?:inherited|herdei)\\b',
                            '__KAM_GRANT3,[l=0]' => '(?i)discontinue from this promotion',
                            '__KAM_DIRECT4,[l=1]' => '(?i)Direct.?Buy',
                            '__KAM_INK1,[l=1]' => '(?is)Ink (and|&|n) Toner|SimplyInk|101 inks|1ink|printer ink sale|full.price',
                            '__KAM_SEO5,[l=1]' => '(?i)more traffic guaranteed|results in thirty day|top 5 organic|high revenue|free.analysis|guaranteed.top|pricelist|completely free|No upfront fees|free trial',
                            '__DRUGS_PAIN11,[l=1]' => '(?i)\\bzebutal\\b',
                            '__KAM_FAKE_REGISTRY1,[l=0]' => '(?i)www(\\.|\\(dot\\))domainregistryasia(\\.|\\(dot\\))net',
                            '__FRAUD_FBI,[l=1]' => '(?i)\\bdisburs',
                            '__KAM_BACK3,[l=1]' => '(?is)(background check|detective|investigator|investigate backgrounds|arrest.record|public.record)|remain.anonymous|anonymous.report|says.about.you|instant.database|the.truth|reveal.the.information|screening.services',
                            '__KAM_URZEST4,[l=0]' => '(?i)(wks it has been|been mos) since we(\'| ha)ve chatted',
                            '__KAM_COVID3_2,[l=0]' => '(?i)reliable source',
                            '__KAM_TOLL3,[l=1]' => '(?i)have.not.paid|your.debt|invoice',
                            '__KAM_LIKE3,[l=1]' => '(?is)(link exchange|in return to me linking back)',
                            '__MONERO_CURNCY,[l=1]' => 'Monero \\(XMR\\)',
                            '__KAM_CAREER3,[l=1]' => '(?is)unstable.economy|secure.a.position|fast.growing|extraordinary.benefits|work.from.home',
                            '__KAM_BARK1,[l=1]' => '(?i)Bark.Off|petzoom sonic|comfy control harness|dogs? behavior|four legged',
                            '__KAM_COLLECT2,[l=0]' => '(?i)No Fee',
                            '__KAM_ACNE4,[l=0]' => '(?i)Online Gift Rewards',
                            '__KAM_UNIV9,[l=1]' => '(?is)non[- ]?ac(creditee?d)?.{1,10}universit',
                            '__MILLIONS,[l=1]' => '(?i)\\bmillions\\sof\\s(?:dollar|euro|pound)',
                            '__FRAUD,[l=1]' => '(?i)\\b(?:de)?fraud',
                            '__COURIER,[l=1]' => '(?i)\\bcourier\\s(?:company|service)\\b',
                            '__KAM_BUSINESSPHONE3,[l=0]' => '(?i)business phone system',
                            'MORE_SEX,[l=1]' => '(?i)increased?.{0,9}(?:sex|stamina)',
                            '__DOS_FIN_ADVANTAGE,[l=1]' => '(?i)\\bfinancial advantage',
                            '__KAM_LISTSALE1,[l=0]' => '(?i)interested in acquiring',
                            'STOCK_ALERT,[l=1]' => '(?i)\\bstock alert',
                            '__KAM_SELLPHONE1,[l=0]' => '(?i)Turn iphones into cash',
                            '__KAM_CEP2,[l=1]' => '(?i)legitimate verifiable degree|build a better you|domain.knowledge',
                            '__KAM_PHISHCP3_1,[l=1]' => 'cPanel Cloud Service',
                            '__KAM_WINDOWS3,[l=1]' => '(?i)Find Your Windows|replacement.window|window.design|home.a.new.look|dingy.old.windows|high.heating|high.cooling|let a draft|energy.efficient|double.pane.window|shop.windows|energy.tax|window.(installation|discount|replacement)|summer.is.coming',
                            '__KAM_VIAGRA7D,[l=1]' => '(?i)VAL[ij]+UM',
                            '__KAM_REP2_2,[l=0]' => '(?i)in your (IE|internet|explorer|browser)',
                            '__KAM_GALLERY2,[l=1]' => '(?i)(?:Infinite|Multi|Elite|Extreme|Complete|Instant|Ultimate|Multi|approved|Free|HD|Guaranteed|Unreal) Access|(?:Ultimate|Babes|Elite|Extreme|P.?o.?r.?n) Collection|(?:Girls|Adu.?lt|Babes|Celeb.?rities) Passwords|(?:Ultimate|p.?o.?r.?n|extreme|elite|Girls) gallery|HD Video|Access Now',
                            '__GHANA,[l=1]' => '(?i)\\bghana\\b',
                            '__FRAUD_THJ,[l=0]' => '(?i)modalit(?:y|ies)',
                            '__KAM_GOOGLE3,[l=1]' => '(?i)tons of money|making \\$[\\d,]*s with Google|extra cash|making serious money',
                            '__HK_SCAM_N15,[l=1]' => '(?i)\\b(?:account (?:overseas?|offshore)|(?:overseas?|offshore) account)\\b',
                            '__KAM_LIST2,[l=1]' => '(?is)(?:hospital|dentist|chiropractor|physician|medical doctors|nursing directors|medical marketing|\\d sortable fields|records all with emails|business director(y|ies)|direct marketing data)|nursing assistant',
                            '__KAM_STOCKTIP152,[l=0]' => '(?i)Siga Resources',
                            'LOOPHOLE_1,[l=1]' => '(?i)loop-?hole in the banking',
                            '__KAM_PROFORMA2,[l=0]' => '(?i)no responds',
                            'CURR_PRICE,[l=1]' => '\\bCurrent Price:',
                            '__KAM_ALT1,[l=1]' => '(?is)reply to my alternative E-?mail',
                            '__TO_YOUR_ORG,[l=1]' => '(?i)\\b(?:to|for) your organi[sz]ation\\b',
                            '__TVD_PH_BODY_01,[l=1]' => '(?i)\\baccount .{0,20}placed? [io]n restricted status',
                            '__COPY_PASTE_IT,[l=1]' => '(?i)copia(r?)lo (e|\\&) incolla(r?)lo',
                            '__KAM_WEIRDTRICK2,[l=1]' => '(?i)\'?(weird|odd|strange)\'?.(new.)?(trick|tip)|strange trick|shocking.truth',
                            '__KAM_FAKEWEST2,[l=0]' => '(?i)Western Union',
                            '__KAM_HANGOVER3,[l=0]' => '(?i)hangover patch',
                            '__KAM_HOME3,[l=1]' => '(?i)tax saving plans|\\d+K Mortgage Credit|no.more.of',
                            '__KAM_WARRANTY2,[l=0]' => '(?i)Protect your home|choice home warranty|unexpected repair',
                            '__KAM_SETTLEMENT3,[l=1]' => '(?i)lawsuit.information',
                            '__KAM_HIP2,[l=0]' => '(?i)implant recall|recall list',
                            '__KAM_BACK1,[l=1]' => '(?i)backgrounds in seconds|Instant..?Checkmate|federal.record|background.report|reputation',
                            '__KAM_FAKEBBB4,[l=1]' => '(?i)(incident:|case:)[\\d:;]{6,}',
                            '__DEAL,[l=1]' => '(?i)\\b(?:(?:business|financial|this|the|mutual|die(?:se)?r?|cette|profitable)\\s(?:deal|transa[ck]tion|proposal|off[er]{2}|venture|suggestion|partnership)|your\\spartnership)',
                            '__KAM_LIKE1,[l=1]' => '(?is)been working (extremely|very) hard on my friend\'s website',
                            '__KAM_STOCKTIP142,[l=1]' => '(?is)Hawk Systems Inc|(\\b|^)HWSYD(\\b|$)',
                            '__KAM_ASSASSIN4,[l=1]' => '(?i)like.an.accident',
                            '__KAM_SEX_EXPLICIT6,[l=0]' => '(?i)virus on a porn web',
                            '__KAM_CAR2,[l=0]' => '(?i)buying a new car|dream car|new car you want|free auto insurance(?:-| )quote|save money on your auto|roadside assistance|extended warranty',
                            '__KAM_PATRIOT4,[l=1]' => '(?i)projectprophet|financial.threat|nuke.deal',
                            '__KAM_GERMAN_BUSINESS_CONTACTS4,[l=0]' => '(?i)Unlimited exportation capabilities',
                            '__YOU_WON_01,[l=1]' => '(?i)\\byou(?:r|\'re|\'ve|\'ll|\\shave|\\sdid)?\\s(?:e-?mail\\s)?(?:\\w+\\s){0,2}(?:a\\s)?w[io]n+(?:er|ing)?(?!\\xe2\\x80\\x99t)(?![`\'\\x92]t)\\b',
                            '__KAM_FAVOR3,[l=0]' => '(?i)email me back as soon as possible|send me your personal cell phone number',
                            '__AFR_UNION,[l=1]' => '(?i)\\bafrican\\sunion\\b',
                            '__KAM_SELL3,[l=0]' => '(?i)Selling Credit Cards',
                            '__KAM_PAPERLESS4,[l=0]' => '(?i)link expires',
                            '__DBLCLAIM,[l=1]' => 'avoid double claiming',
                            '__KAM_SEO3,[l=1]' => '(?i)(came across|never find) your web.?site|major search engines|paid access to tools|WEBSITE AUDIT REPORT|specific.keyword|targeted.email|visited.your.website|not ranking well|Google rankings',
                            '__KAM_URZEST2,[l=0]' => '(?i)or still (?:jaded|worn|drained|exasperated) all the time',
                            '__KAM_UNIV12,[l=1]' => '(?is)(obtain your diploma|diploma that you want|Criminal Justice or Homeland Security degree)',
                            '__KAM_CEP4,[l=1]' => '(MBA|CEP)',
                            '__KAM_ADVANCE2,[l=0]' => '(?i)Advance Details',
                            '__KAM_PRODUCT2,[l=0]' => '(?i)phones for discerning individuals',
                            '__ACCOUNT_UPGRADE,[l=1]' => '(?i)\\b(?:upgrade (?:of )your (?:account|access)|your (?:access|account) is[\\w\\s]{0,40}being upgraded|Weiter zur Aktualisierung)\\b',
                            'DEAR_BENEFICIARY,[l=1]' => '(?i)\\b(?:De[ae]r\\s|At+(?:ention|n):?\\s?)(?:\\S+\\s)?Ben[ei]ficiary\\b',
                            '__KAM_MESH3,[l=0]' => '(?i)have a mesh implant|entitled to compensation|consumer injury|injured consumer',
                            'MILLION_USD,[l=1]' => '(?i)Million\\b.{0,40}\\b(?:United States? Dollars?|USD)',
                            '__KAM_BOXQUOTA,[l=1]' => '(?i)mailbox.{0,5}exceeded.{4,14}quota|low email storage',
                            '__FRAUD_DPR,[l=1]' => '(?i)\\b(?:(?:respond|reply) (?:urgently|immediately)|(?:urgent|immediate|earliest) (?:reply|response))\\b',
                            '__KAM_COMPROMISED3,[l=1]' => '\\d{1,2}[\\\\\\/]\\d{1,2}[\\\\\\/]\\d{2,4} \\d{1,2}\\:\\d{1,2}\\:\\d{1,2} (AM|PM)',
                            '__KAM_FOUNTAINOFYOUTH3,[l=1]' => '(?i)look & feel old|\\d+.years.of.aging|weird.\\d+.second.trick',
                            '__KAM_CRIM2_3,[l=1]' => '(?is)adult.{0,2}video|sex.{0,2}sites',
                            '__DRUGS_MUSCLE5,[l=1]' => '(?i)\\bskelaxin\\b',
                            '__COPY_PASTE_ES,[l=0]' => '(?i)copiarlo y pegarlo',
                            '__ISO_2022_JP_DELIM,[l=1]' => '\\e\\$B',
                            '__KAM_TRUMPCOIN1,[l=0]' => '(?i)Donald Trump',
                            '__KAM_PACKAGE1,[l=1]' => '(?i)dysfunction|\\dx longer',
                            '__FRAUD_CKF,[l=0]' => '(?i)computer ballot system',
                            '__JMQ_RESUME3,[l=1]' => '(?i)appreciate.your.cooperation|my.resume.is.pdf|resume.attach|pdf.file.is|is.my.resume',
                            '__KAM_STOCKTIP151,[l=0]' => '(?i)Alanco Tech',
                            '__FRAUD_BGP,[l=1]' => '(?i)\\battached to ticket number\\b',
                            '__KAM_HACK1,[l=0]' => '(?i)(phone|electronic|computer) have been hacked|suspected online scam',
                            '__KAM_REPAIR2_3,[l=1]' => '(?i)never.pay|covered.home.repair|the.trouble|warning.signs|roofing.problem|roof.repair',
                            '__ACCOUNT_SECURE,[l=1]' => '(?i)\\b(?:make your (?:"?[^\\@\\s]+\\@\\S+"? |e-?mail )?account more secure|Ihre Kreditkarte weist einige Sicherheitsprobleme)\\b',
                            '__VBOUNCE_MAILSWEEP2,[l=1]' => '(?i)\\bblocked by Mailsweeper\\b',
                            '__KAM_FLASH1,[l=1]' => '(?i)Flash Player Code: \\d\\d',
                            '__SCAM,[l=1]' => '(?i)\\bscam(?:m?e[dr])?s?\\b',
                            '__KAM_STOCKTIP122,[l=1]' => '(?is)(Shandong Zhouyuan Seed and Nursery|(\\b|^)SZSN(\\b|$))',
                            '__KAM_WRITING3,[l=0]' => '(?i)Professional Writing|world famous (writer|poet)',
                            '__DOS_BODY_THU,[l=1]' => '(?i)\\bthu(?:r(?:s(?:day)?)?)?\\b',
                            '__freemail_safe_fwd,[l=1]' => '(?i)---\\s?(?:(?:Forwarded|Original) message|Alkuper(?:\\xe4|\\xc3\\xa4)inen viesti)',
                            '__KAM_SINGING3,[l=1]' => '(?i)terrible.singer|more.talent|love.songs',
                            '__FOR_SALE_OBO,[l=1]' => '(?i)\\bor best offer\\b',
                            '__KAM_VIAGRA8D,[l=1]' => '(?i)CI...?ALIS',
                            '__KAM_SPAMKING1,[l=1]' => '(?is)This advertisement is presented by',
                            '__RUDE_HTML_2,[l=1]' => '(?i)not support the display of HTML. Please view this message in a different',
                            '__KAM_WALKINTUB3,[l=1]' => '(?i)walk.?in.?tub',
                            '__DOS_WRITE_ME_AT,[l=1]' => '[Ww].?r.?i.?t.?e me at',
                            '__DOS_TAKING_HOME,[l=1]' => 'Taking home \\d (?:digit level|figures) in \\d{1,2} months',
                            '__KAM_AUTONEW2,[l=1]' => '(?i)car.{1,2}insurance.{1,2}payment|monthly.payment|plan.has.expired|auto.loan|auto.coverage|coverage.benefits|premium.reduc|compare.quote|financing.your.way',
                            '__KAM_ALERT3,[l=0]' => '(?i)help button',
                            '__KAM_MOVIE2,[l=0]' => '(?i)Movie Extra',
                            '__KAM_NIGERIAN3,[l=1]' => '(?is)(?:\\d{1,2}\\% (?:commission on each transaction|of the total will be set|will be mapped out|is made available to you|of the total sum for your partner|of the money for your effort|for\\s+sales)|pay for performance|floating deficit|for your compensation|financial independence|their financial dreams|work from home part\\s*-?\\s*time|employing your services|get extra income|deduct your weekly salary \\d\\d%|transfer of the funds|make successful career at us|you will get \\d{1,2}% on each|funds can be directed to your account as a grant|reasonable parentage|dormant domiciliary account|share would be \\d+\\%|pay you \\d+%)|invest|have.a.sum|make.a.donation|immense.benefits|transact.a?.?business|company.sponsor|loan me \\$',
                            '__INVEST_COUNTRY,[l=1]' => '(?i)\\binvest\\sin\\syour?\\scountry\\b',
                            '__KAM_TELEWORK3,[l=1]' => '(?is)return(?:ing)? (phone )?calls|working a few hours each day|positive work environment',
                            '__KAM_LIKE5,[l=1]' => '(?is)I apologize if this message was sent, in error',
                            '__KAM_BADZIP3,[l=0]' => '(?i)(order|urgent|report|dialogue)',
                            '__KAM_SEO2,[l=1]' => '(?i)(?:top|first page) (?:in|of) (?:Google|MSN|Yahoo|Bing)|rank number one|top page rank|guarantee you 1st|link.building|business SEO|ranking report',
                            '__NEXT_OF_KIN,[l=1]' => '(?i)\\bnext[-\\s]of[-\\s]kin\\b',
                            '__PDS_OFFER_ONLY_AMERICA,[l=0]' => '(?i)This offer (?:is )?(?:only )?for (United States|USA)',
                            '__KAM_DEATH3,[l=1]' => '(?i)Eating this|before it.?s too late',
                            '__KAM_ADMIN4,[l=0]' => '(?i)read this document',
                            '__KAM_DRILL1,[l=0]' => '(?i)drilling',
                            '__KAM_RICH2,[l=1]' => '(?i)see me on the channel \\d news',
                            '__KAM_DRUG1,[l=1]' => '(?is)Quality and cheap|premier quality|supor-collosal mixture|Discount-?Pharmacy|hi.quality.drug',
                            '__KAM_SHADYCC3,[l=0]' => '(?i)(four|4) of (my|the) (master)?card',
                            '__BOUNCE_OOO_B2,[l=1]' => '\\bI am currently out of the office\\b',
                            '__KAM_LASIK3,[l=1]' => '(?i)free (?:Lasik )?eval|\\d+ per eye|get lasik info|L.SI. V....n In.t.tut. Summ.r S.v.ng.|works.faster.than',
                            '__KAM_HSR1,[l=1]' => '(?i)hsrupdates.com|progressiverailroading.com',
                            'BANG_OPRAH,[l=1]' => '(?i)\\boprah!',
                            '__JMQ_PICKUP4,[l=1]' => '(?i)\\d+.year.old|female',
                            '__KAM_SWIPE4,[l=1]' => '(?i)SwipeBids|Swipe Auction|CIRCLE MEDIA BIDS|Wavee|BIGGER BIDDER|Bidooka|Sellmoo|overstocked auctions|for pennies|\\d{1,2} cent',
                            '__FRAUD_TDP,[l=1]' => '(?i)\\b(?:business partner(?:s|ship)?|silent partner(?:s|ship)?)\\b',
                            '__KAM_FAKE_INVOICE2,[l=0]' => '(?i)Payment advice',
                            '__KAM_JESUS3,[l=1]' => '(?i)nigeria|muslim.women',
                            '__KAM_UNIV8,[l=1]' => '(?is)Career Path',
                            '__hk_win_i,[l=1]' => '(?i)\\bfunds? transfer',
                            '__PASSWORD_UPGRADE,[l=1]' => '(?i)\\bpassword upgrade\\b',
                            '__PDS_EXPIRATION_NOTICE,[l=1]' => '(?i)\\bexpiration (notice|alert|date)\\b',
                            '__KAM_PACKAGE2,[l=1]' => '(?i)sexual.performance|longer.in.bed',
                            '__KAM_INSURE4,[l=1]' => '(?i)why pay more for.{0,30}coverage|save up to \\d+%|accuquote|Life Insurance Coverage|protect.your.family.{1,20}insurance|Protect home and belonging|Affordable Care Act|new health insurance plan for you|home.?.?protection|\\d+k.life.insurance|eligible for auto.coverage|set to expire|\\$\\d+\\/mo|new.rate|your.auto.?insurance.policy|term.life|update.policy|legacy|estate|your.package|your.own.life|prepared.for.anything|paying.(far.)?too',
                            '__KAM_NOTIFY2,[l=1]' => '(?i)[2-9] friend request( |\\b)|sell your personal|mandatory validation|verify your Account|unread messages',
                            '__KAM_WEED1,[l=1]' => '(?i)legal.weed|jim kramer|kevin james',
                            '__HUSH_HUSH,[l=1]' => '(?i)\\b(?:confiden[tc]i[ae]l(?:\\b|ity\\b|it(?:=E9|[\\xe9]|[\\xc3][\\xa9]))|private\\b|secr[e\\xe8](?:te?|cy)\\b|sensitive\\b|concealed\\b|obscured?\\b|discre(?:et|tion)\\b|very\\sdiscrete|top\\ssecret|vertraulich(?:en)?\\b|geheim\\b|priv(?:e|=E9|[\\xe9]|[\\xc3][\\xa9]))',
                            'KAM_ADVERT2,[l=1]' => '(?is)No longer interested in our offers|This (message|email)? is an Ad|Continue in your Secure Web Browser|Can\\\'t see the images( below|, continue)|To view this email as a webpage|see images for this offer|support best practices in responsible email marketing|This email is not unsolicited|You registered with one of our partners websites|a d v e r t i s (?:e )?m e n t|No\\-?Images? Click|Program is not endorsed, sponsored by or affiliated|can\\\'t read or see this email|By clicking any image and\\/or text link in this Email|This is a (commercial|commericial)|This message brought to you|THIS EMAIL IS A COMMERCIAL|If you no longer wish to receive further offers|business solicitation message|link is for removal|end these weekly ad\\-messages|cancel these Ads go|This is an email advertisement|end all Advertisements go below|We are not spammers|Unsolicited email\\?|Quit receiving these admail|I.{0,3}am not spamming|commercial.advertisement|adv.ertisement|if.you.are.not.interested|Brought to you by\\:|This communication is an advertisement|removal from further update|inbox by requesting removal|No more incoming messages will be delivered|Never receive these again|This is an ad\\-coresspondance|this page is an advertise?ment|this is an \\(adver\\-?tisement\\)|this page are an.ad|statements above are an.ad|advertis.e.ment',
                            '__KAM_REPAIR1_3,[l=1]' => '(?i)car.repair|Auto Protection|repair.bill|lowest.rates|need.repairs|cost.you.thousands|auto.warranty|costs.keep.rising|repair.cost|do.it.yourself|auto.body|body.repair|protection.quote',
                            '__KAM_PILLS2,[l=0]' => '(?i)be (thrifty|smart|clever), buy your (pills|drugs|medications)',
                            '__FRAUD_JNB,[l=1]' => '(?i)\\boperat(?:e|ing)\\b[^.]{0,99}\\b(?:for(?:ei|ie)gn|off-? ?shore|over-? ?seas?) (?:bank )?accounts?\\b',
                            '__KAM_UKINV3,[l=1]' => '(?i)INV-\\d+|Check out what .{4,30} shared with you',
                            '__KAM_MEDTOUR2,[l=0]' => '(?i)lowest cost in India',
                            '__AGREED_RATIO,[l=1]' => '(?i)\\b(?:agreed|sharing)\\s(?:ratios?|percent\\w+)\\b',
                            '__SUM_OF_FUND,[l=1]' => '(?i)\\b(?:sum|release|freigabe)\\s(?:of|der)\\s(?:amount|fund|investment|mittel)\\b',
                            '__ACH_CANCELLED_04,[l=1]' => '(?i)\\bregarding[-_ ]your[-_ ]direct[-_ ]deposit[-_ ]via[-_ ](?-i:ACH)',
                            '__KAM_COLLECT3,[l=0]' => '(?i)collection professionals',
                            '__KAM_UNIV2,[l=1]' => '(?is)\\d (week|month).{0,30}degree',
                            '__hk_win_j,[l=1]' => '(?i)\\b(?:winning|ready for|sum) pay ?out',
                            '__KAM_CEP1,[l=1]' => '(?i)Job Prospect Newsletter|training.workshop',
                            '__KAM_NURSE3,[l=1]' => '(?i)nurses (?:are NOW in high.?demand|are needed)|nursing Degree|indispensable.position|growing.career|nursing.assist|certified.nurs',
                            '__KAM_WATERHACK2,[l=0]' => '(?i)water hack',
                            '__KAM_STOCKTIP121,[l=1]' => '(?is)(VISION AIRSHIPS|(\\b|^)VPSN(\\b|$))',
                            '__KAM_CARD2,[l=1]' => '(?i)(laughing kitty|crazy cat) card|enjoy your awesome card|Click on your .{0,15}card(\'s)? (link|direct www address) below|To see your custom .{0,15}card, simply click on the (link below|following)|(as you can see on the ecard)|^your .{1,15}card link:$|I bet your wife won\\\'?t do this for you|Your temporary Login Info|temp\\.? password id|pics I took of my Ex-Wife|card will be aviailable|our.new.collection',
                            '__YOU_INHERIT,[l=1]' => '(?i)\\byour\\s[a-z\\s]{0,30}inherit+ance\\b',
                            '__KAM_NUMEROLOGY3,[l=0]' => '(?i)Control your destiny',
                            '__KAM_STOCKTIP155,[l=1]' => '(?is)Alanco Technologies',
                            '__KAM_SETTING2,[l=0]' => '(?i)security upgrade|Maintenance Process on our email system ',
                            '__BACK_SCRATCH,[l=1]' => '(?i)\\bmutual+y?\\s(?:benefi(?:t|cial)|interest)\\b',
                            '__KAM_DROPBOX3,[l=1]' => '(?i)shared.a.folder',
                            '__KAM_JURY4,[l=1]' => '(?i)in Court|hearing date|notice to appear|Pretrial notice|compulsory.attendance|court.notice',
                            '__KAM_BLOOD5,[l=1]' => '(?i)Anti-Aging Expert|worst.food',
                            '__KAM_COVID3_5,[l=0]' => '(?i)Saudi Arabia',
                            '__KAM_WATER1,[l=0]' => '(?i)Never Drink Water',
                            '__KAM_CLICK,[l=0]' => '(?i)Please click on the link below|Copy and paste this link into your internet browser',
                            '__KAM_GIVE3,[l=0]' => '(?i)answering a short survey',
                            '__KAM_NUWAVE3,[l=1]' => '(?i)nuwave|energy.saving|temperature.control|meal.prep|cooktop',
                            '__FRAUD_MQO,[l=0]' => '(?i)foreign (?:business partner|customer)',
                            '__KAM_TOURS3,[l=1]' => '(?i)your.adventure.tour|your.event',
                            '__KAM_GALLERY4,[l=1]' => '(?i)(Fantastic|Insane|Mega|Extreme|Extreme|New|Many|Fresh|Your|Check) P.?o.?r.?n|cele.?brities elite|(Insane|P.?o.?r.?n|More|Awesome|All|Mega) Model|(Your|Mega|Asian|Bad|Cool|Fresh|Real|Awesome|More) Girl|(Sweet|Incredible|Insane|The|Grand) chick|(Many|New|Infinite|Cool|All) Cele.?b|The N.?u.?des|(Infinite|Awesome|Many|Sweet|Bad|Get|Fresh|Hot|More|Black) Babe|Amat.?e.?urs|(All|Fresh|Fantastic|The|Mega) Adu.?lt|(Extraordinary) Chicks',
                            '__KAM_HIDDEN_URI1,[l=1]' => '(?is)\\[DOT\\]com',
                            '__KAM_URONLINE3,[l=1]' => '(?i)get (naked|naughty)|horny|naughty toys|I will do anything|TOTALLY msg me on MSN|tell me your mobile|I remember you|let\'s talk|ran across someone like u|sexywebdating|chatting with someone|saw you by BJs|private e-?mail|dating portal|looking.for.fun',
                            '__ACCOUNT_ERROR,[l=1]' => '(?i)\\b(?:your account (?:is|appears to be) (?:incorrect|missing|in error|invalid))\\b',
                            '__DOS_BODY_TUE,[l=1]' => '(?i)\\btue(?:s(?:day)?)?\\b',
                            '__FEES,[l=1]' => '(?i)\\b(?:security|safe\\w*|courier|registration|pay|paid|up-?front|processing|delivery|transfer|keeping)[\\s\\w]{0,15}\\s(?:fee|charge)s?\\b',
                            '__KAM_SALE3,[l=1]' => '(?i)\\d+%.off|just.shipped|touch.?fire|just.became.perfect|transform.your.ipad',
                            '__KAM_DUJOUR2,[l=0]' => '(?i)(Worst Food|Tinnitus|Reflux|CVS Gift Card)',
                            '__KAM_GIFT3,[l=1]' => '(?i)every girl loves to buy|do you need a new|offer pass you by|shopping.online|best.price|activate.my|valued.{0,20}user|extra.deals|sign.up.today',
                            '__KAM_UNIV6,[l=1]' => '(?is)verifiable University Degree',
                            '__KAM_FAKE_TRUST1,[l=1]' => '(?i)Message is from a .{0,40}trusted source',
                            '__KAM_SHOP3,[l=1]' => '(?is)make money while you shop',
                            '__KAM_STUDENT3,[l=1]' => '(?i)penalt(y|ies)|garnish|your.debt|president.loan|reduce.(your.)?(student.)?loan|forgiveness.plan|qualify.for|federal.program|low.monthly',
                            '__KAM_UNIV3B,[l=1]' => '(?is)(dead end job|improve your future, and your income|high paying jobs|bec[óo]me a do[cç]tor|get your diploma today)',
                            '__KAM_SOLAR3,[l=1]' => '(?i)power bill in half|go solar|approved for solar|solar system saves|reduce your electric|energy.cost|energy.bill|government.incentive|can.profit|utility.bill|switch(ing)?.to.solar|solar.incentive|solar.now|US Solar Dept|your.electric.bill|your.home.qualifies|yard lights|solarglow',
                            '__KAM_JOB1,[l=1]' => '(?is)let go from (a job|my employment) I held for.{1,19} (month|year|forever|life)',
                            '__BOUNCE_OOO_CB2,[l=1]' => '(?i)\\bon (?:vacation|holiday)\\b',
                            '__KAM_LISTSALE3,[l=0]' => '(?i)share counts and samples|send focused campaigns|compiled a dataset',
                            '__RANDOM_PICK,[l=1]' => '(?i)\\b(?:random(?:ly)?\\s(?:\\w+\\s)?(?:select(?:ion|ed)|pick(?:ed)?|computer)|(?:select|pick)ed\\s(?:at\\s)?random(?:ly)?|(?:esco(?:g|lh)idos|seleccion) (?:aleatoria(?:mente)?|al azar))\\b',
                            '__hk_win_l,[l=1]' => '(?i)\\b(?:make|file) (?:for )?your claim',
                            '__KAM_REAL2_1,[l=1]' => '(?i)(?:Property available|on the water|costa rica|mountain.top)',
                            '__DRUGS_MUSCLE2,[l=1]' => '(?i)\\b_{0,3}cycl[o0\\xF2-\\xF6]b[e3\\xE8-\\xEB]nz[a4\\xE0-\\xE6@]pr[i1!|l\\xEC-\\xEF]n[e3\\xE8-\\xEB]_{0,3}(?:\\b|\\s)',
                            '__HK_SCAM_N2,[l=1]' => '(?i)\\bnext of kin\\b',
                            '__FRAUD_MLY,[l=1]' => '(?i)\\b(?:reply|respond)\\b[^.]{0,50}\\b(?:to|through)\\b[^.]{0,50}\\@\\b',
                            '__KAM_DEATHINSURE3,[l=1]' => '(?i)inheritance.tax|your.loved.ones|funeral.costs',
                            '__KAM_OPRAH3,[l=0]' => '(?i)oprah',
                            '__RECEIVE_BONUS,[l=1]' => '(?i)\\byou(?:\'ll)?(?: also| will)* (?:rec[ei]*ve|get|earn|collect|be (?:awarded|handed|remitted|given|paid|(?:greeted|welcomed|started) with)) (?:an? )?(?:gift|bonus|extra)(?: of|:)? \\$[\\d,]+',
                            '__DRUGS_ANXIETY_XAN,[l=1]' => '(?i)xan[ae]x',
                            '__FRAUD_IRT,[l=1]' => '(?i)\\b(?:compliments? of the|dear friend|dear sir|yours faithfully|season\'?s greetings)\\b',
                            '__KAM_SHARP4,[l=0]' => '(?i)ceramic knife',
                            '__KAM_BADZIP4,[l=0]' => '(?i)password:',
                            '__KAM_STOCKTIP137,[l=1]' => '(?is)Dynamic Response Group|(\\b|^)DRGZ(\\b|$)',
                            '__KAM_HOWRU3,[l=0]' => '(?i)visit the site|visit this site|visiting this website|have some social networks|meet you in private|write me tomorrow',
                            '__KAM_GOOGLEFORM_2,[l=0]' => '(?i)Untitled|Formulaire sans titre',
                            '__DOS_MEET_EACH_OTHER,[l=1]' => '(?:meet each other|[Mm]ay ?be we can meet)',
                            'MONEY_BACK,[l=0]' => '(?i)money back guarantee',
                            '__KAM_FAKEBBB2,[l=1]' => '(?i)(Fair Labor Standards Act|Safety and Health act|Better Business Bureau|(\\b|$)BBB(\\b|^))',
                            '__KAM_REAL2_2,[l=1]' => '(?i)(?:pre-development prices|finish building|torn down to build|exclusive place|ready.for.construction)',
                            '__KAM_SURVEY3,[l=0]' => '(?i)Do You Use Instagram|Complete the survey|win a great prize',
                            '__KAM_TV1,[l=1]' => '(?i)watch unlimited television|DTV4PC|Online TV Code|Free DVD-CD Burner|100% legal|Rabbit TV|reliable.cable.service|existing.smart.tv',
                            '__KAM_VIAGRA9A,[l=1]' => '(?i)V[IL1]A..GRA',
                            '__KAM_NEWNOTICE2,[l=1]' => '(?i)- - -\\s?(finish |end )?(of |new )?(notification|notice)( \\d\\d\\/\\d\\d\\/\\d\\d)?\\s?- - -|end notice:',
                            '__KAM_LOTTO5,[l=1]' => '(?is)(POWERBALL-?LOTTO|freelotto group|(microsoft|Royal Heritage) (promotion|Lottery)|(British|UK) National( Online)? Lottery|U\\.?K\\.? Grand Promotions|Lottery Department UK|Euromillion Loteria|Luckyday International Lottery|International Lottery|Euro - Afro Asian Sweepstake|urawinner|Free Lotto Sweepstakes|PROMOTION DEPARTMENT|PROMOTION\\/PRIZE AWARD|Nederlandse Internationale Loterij|EURO MILLIONS|APPLE LOTTERY ONLINE|MSW MEGA JACKPOT|MICROSOFT EMAIL PROMO|MSNlottery|ECOWAS|Nigeria|National Lottery|claim.{1,10}your.gbp|won.you.{1,10}gbp)|cola lotto online|on-?line promotion',
                            '__KAM_HIDDEN_URI2,[l=1]' => '(?is)replace "?\\[DOT\\]',
                            '__KAM_PAYMENT_LOWERED2,[l=1]' => '(?i)new monthly payment|just.recently.been..?lowered',
                            '__KAM_ASIAN2,[l=0]' => '(?i)Adoring Asian',
                            '__KAM_LUNAR4,[l=1]' => '(?i)sleep you really need|sleep(ing)? aid|trouble.sleeping|miracle.sleep|lunar.?sleep|all.natural|fall.asleep|refreshed|sleep.cycle|sleep.aid|lack.of.sleep|stay.asleep|somnapure|weird.trick',
                            '__FRAUD_UOQ,[l=0]' => '(?i)vital documents',
                            '__DOS_PERSONAL_EMAIL,[l=1]' => 'personal email at',
                            '__FB_TOUR,[l=1]' => '(?i)\\btour',
                            '__LUCRATIVE,[l=1]' => '(?i)\\b(?:lucrative|profitable|tr[\\xe8]s\\ssalutaire)\\b',
                            '__FAILED_LOGINS,[l=1]' => '(?i)unsuc+es+ful log-?[io]n at+empts',
                            '__KAM_PAYMENTSCAM2,[l=0]' => '(?i)attached (payment|herewith)|ready for release',
                            '__KAM_MERCHANT3,[l=1]' => '(?i)merchant.processing|small.business|yearly.credit|monthly.fee|100%.free',
                            '__KAM_SEX04_4,[l=1]' => '(?is)longer your tool|sexual experience|empower your (belove|sex)|sweet sex|(not bad|great|nice|special|awesome|free) bonus|sex all night|lovers package|male.vitality|sex with new boys',
                            '__KAM_TIP4,[l=0]' => '(?i)Find Out This Quick New Trick',
                            '__KAM_PROJECT3,[l=0]' => '(?i)email is active',
                            '__KAM_FAKEINV2_2,[l=0]' => '(?i)(find|see) (the )?attach',
                            '__DRUGS_ERECTILE4,[l=1]' => '(?i)\\bC(?:alis|ilias|ilais)\\b',
                            '__KAM_CASINO2,[l=0]' => '(?i)Online Casino',
                            '__KAM_TAX3,[l=1]' => '(?i)File your taxes for free|need more time|back.taxes|tax relief|irs offer|avoid penalty|stop.aggressive.collections|relief.(program|package)|tax.settlement|settlement.package|paying.bills|paying.tax|back.tax|wage..?garnish|tax.help|remove.lien|bankrupt|urgent.tax.notice|could.change.everything|instantly.save.you',
                            '__VBOUNCE_ATTACHMENT0,[l=1]' => '(?:Attachment.{0,40}was Deleted|the infected attachment)',
                            '__INVEST_MONEY,[l=1]' => '(?i)\\binvest(?:ir)?\\s(?:this|ces|d[ae]s|sur ce|de ces)\\s(?:money|f[ou]nds?)\\b',
                            '__I_WILL_YOU,[l=1]' => '(?i)\\bwill(?:ed)?\\s(?:[a-z\\s]{0,20}(?:fortune|money|\\$[\\d,]+[a-z]{0,9})\\s)?to\\syou\\b',
                            'REFINANCE_YOUR_HOME,[l=1]' => '(?i)\\brefinance your(?: current)? (?:home|house)\\b',
                            '__ADMAIL,[l=1]' => '(?i)(?:\\b|_)ad-?(?:mail|message)s?(?:\\b|_)',
                            '__KAM_DRUG2_5,[l=1]' => '(?i)0nline|hassle[~-]free|favored rx|branded solutions|branded remedies|v[1i]cod[!i]n|Penhtremine|prxpills|ultimaterxhere|insanerx|speedymed4u|mightymeds1|coolestrxhere|hotrxmedspot|topshoprx|mightyrxhere|qualityrxmedz|legitrxlife|dealsformeds|simplyrxdeals|bestrxlight|ezprescriptz|reliablerxsource1|freetrusted-rx|hotmedsourcehere|CabinetOfMeds|mytrusted-rx|RxwarehouseHere|WarehouseofRxMeds|GreatrxMedsRus|rxmedsrus|(come by|Come to|Check Out) our web site|browse [0o]ur (website|selection)|Visit_0ur Web|Order_Now|available_this week|(buy|order) (n[0o]w|today|right.now|instantly|at [0o]nce|immediately)|check it out today|ord3r|0rder|0rd3r|browseour|rx ?unit',
                            '__KAM_JOINT3,[l=1]' => '(?i)TFX.?(?:health|flex)|tflex',
                            '__KAM_REMEMBERWHEN2,[l=1]' => '(?i)hello.brother|remember(ed)?.you|i.remember',
                            '__KAM_DOMAIN_SALE1,[l=1]' => '(?i)\\b(related|similar) domain\\b',
                            'BANG_GUAR,[l=1]' => '(?i)\\bguaranteed?\\!',
                            '__FRAUD_XJR,[l=0]' => '(?i)(?:who was a|as a|an? honest|you being a|to any) foreigner',
                            '__KAM_SCOOTER3,[l=0]' => '(?i)the scooter store',
                            '__COPY_PASTE_DE,[l=0]' => '(?i)Kopieren Sie es und f(?:\\xfc|\\xc3\\xbc)gen Sie es ein|Kopieren \\& Einf(?:\\xfc|\\xc3\\xbc)gen',
                            '__KAM_WEB2_3,[l=0]' => '(?i)web (designer|develop)|new website',
                            '__TRAVEL_BUSINESS,[l=1]' => '(?i)\\bbusiness\\stravel\\b',
                            '__KAM_CEP6,[l=1]' => '(?i)\\d (week|month)',
                            '__KAM_ERP2,[l=0]' => '(?i)K9ERP',
                            'BANKING_LAWS,[l=0]' => '(?i)banking laws',
                            '__KAM_SEX1,[l=1]' => '(?i)(?:double[ -]?headed|pornstar|huge weenie|male power|\\d\\dper\\. of men|male enhancement product|enlarge patch|boost up your virility|clinically tested|improve manhood|Bigger Pen..is|Big Penis|incredible gains to your manhood|muscular manhood|nights unsatisfied|climaxes|sensual enhancer|love instrument|bigger member|excitement with girls|fucker|animal sex)|adds \\d inches to your manhood|pussy licked|hard.erection',
                            '__KAM_BLOOD3,[l=1]' => '(?i)Secret Big Pharma|conspiracy|Breaking.Health.Stories',
                            '__PUMPDUMP_09,[l=1]' => '(?i)\\b(?:buy|get|snap up|grab) as many shares (?:of it )?as (?:you|I) can\\b',
                            '__KAM_LABEL3b,[l=1]' => 'PPE',
                            '__KAM_STUDENTLOAN1,[l=0]' => '(?i)(National|Federal) Student Loan Status',
                            '__KAM_CRYPTO1,[l=1]' => '(?i)swiss.?coin|[{(]SIC[)}]',
                            '__LARGE_PERCENT_AFTER,[l=1]' => '(?i)\\d{3}% after',
                            '__KAM_CAREER2,[l=1]' => '(?is)Get your Healthcare Degree|Billing and Coding degree|job.placement|great.opportunity|training.start(s|ing).soon|job.growth',
                            '__KAM_URGENT5,[l=0]' => '(?i)address still valid',
                            '__KAM_ORDER1,[l=0]' => '(?i)Please find document attached',
                            '__KAM_JOB2_3,[l=0]' => '(?i)Singapore',
                            '__KAM_FAKE_FAX4,[l=0]' => '(?i)invoice',
                            '__WITHOUT_EFFORT,[l=1]' => '(?i)\\bwith(?:out(?: a(?:ny)?| the)?| no)(?: great| special| extra)? effort\\b',
                            '__KAM_UKINV2,[l=0]' => '(?i)View (and pay )?(scan|invoice)',
                            '__KAM_GINA3,[l=0]' => '(?i)Genetic Information Nondiscrimination Act',
                            '__SYSADMIN,[l=1]' => '(?i)\\b(?:help?[- ]?desk|(?:(?:web ?)?mail ?|sys(?:tem )?)admin(?:istrator)|local[- ]host|(?:support|upgrade|management|security|admin(?:istrat(?:or|ion))?) (?:team|center)|message from administrator|university mail server copyright|suporte t(?:=E9|[\\xe9]|[\\xc3][\\xa9])cnico|administrador do sistema)\\b',
                            '__KAM_CONTACTME2,[l=0]' => '(?i)read the attached letter',
                            '__KAM_LOTTO3,[l=1]' => '(?is)(won|claim|cash prize|pounds? sterling|over \\$500|award sum of US\\$|NOTIFICATION FOR CASH AID)',
                            '__KAM_AUTO3,[l=1]' => '(?i)(car|truck).dealer|clearance.price|shop.cars|\\d+.vehicles|dealership|deep.discount|liquidating|vehicle.options|auto.news|old.clunker|dream.car|clearance.inventory|dealer.clearance|special.clearance|auto(mobile?).recall|clearance.pric|new.ride|dealers.{1,40}.scrambling|sell.yours.for.more|car.is.worth|auto.parts.brand|blowout|incredible.discount',
                            '__SECURITY_DEPT,[l=1]' => '(?i)\\bsecurity dep(?:artmen)?t\\b',
                            '__KAM_ALARM2,[l=1]' => '(?i)free Quote|burglaries|wireless.security.camera|(Guard|protect) Your Family|ADT is Number One|monitored security system|install from ADT|with ADT security|keep(ing)?.your.home.safe|home.is.your.castle|sleep.with.security|home.security.system|remote.access|video.security',
                            '__KAM_SHAM4,[l=0]' => '(?i)20(X| times) its weight',
                            '__TRAVEL_AGENT,[l=1]' => '(?i)\\btravel\\sagen(?:t|cy)\\b',
                            '__FRAUD_NRG,[l=0]' => '(?i)i am contacting you',
                            '__KAM_OCEANSBOUNTY3,[l=1]' => '(?i)years.of.aging|medical.doctor|age.revers|turn.back.the.clock|reactivate.your.heart',
                            '__YOUR_PERM,[l=1]' => '(?i)\\byour\\spermission\\b',
                            '__FRAUD_RLX,[l=1]' => '(?i)lott(?:o|ery) (?:co,?ordinator|international)',
                            '__KAM_CAREER1,[l=1]' => '(?is)Hospitals need you|Medical Billing and Coding|medical.coding',
                            '__KAM_STOCKTIP139,[l=1]' => '(?is)Solanex Management|(\\b|^)SLNX(\\b|$)',
                            '__JMQ_IMPORTANT3,[l=0]' => '(?i)please visit',
                            '__KAM_PHISH2_6,[l=1]' => '(?i)confirm your online banking details|payment.advice|online.fraud|billing.information',
                            '__KAM_ASSASSIN2,[l=0]' => '(?i)my identity',
                            '__KAM_SELLPHONE2,[l=0]' => '(?i)used or broken|pre-paid envelope',
                            '__KAM_SILD2,[l=0]' => '(?i)(XtraSize\\+|Sildenafil Citrate)',
                            '__KAM_LABEL6,[l=0]' => '(?i)\\| Label|Label Health',
                            '__KAM_CASINO1,[l=0]' => '(?i)Elite World Casino',
                            '__KAM_FAKEDELIVER11,[l=0]' => '(?i)DPD',
                            '__AFF_LOTTERY,[l=0]' => '(?i)(?:lottery|winner)',
                            '__KAM_GREYEAGLE_2,[l=0]' => '(?i)grey eagle funding',
                            '__KAM_PIZZA3,[l=1]' => '(?i)free.pizza.coupon',
                            '__BOUNCE_OOO_CB4,[l=1]' => '(?i)\\breturn to (?:the )?office\\b',
                            '__KAM_STOCKTIP135,[l=1]' => '(?is)(Dominion Minerals|(\\b|^)DMNM(\\b|$))',
                            '__DOS_MY_OLD_JOB,[l=1]' => 'my old job',
                            'DEAR_WINNER,[l=1]' => '(?i)\\bdear.{1,20}winner',
                            '__DOS_I_AM_25,[l=1]' => 'I a.?m 25',
                            '__KAM_WORKHOME2,[l=0]' => '(?i)#1 site|view here|information here',
                            '__KAM_DIABETES1,[l=1]' => '(?i)- - Diabetes News Today - -|diabetes.health|blood.sugar',
                            '__KAM_SMOKE4,[l=1]' => '(?i)No carbon monoxide|Smokeless Direct|No Tobacco|no tar|no cancer|quit smoking|electronic cig|sinless.vapor',
                            '__VBOUNCE_AMAVISD2,[l=1]' => '\\bV I R U S\\b',
                            '__KAM_PHISH2_5,[l=1]' => '(?i)account suspension|temporary locked|temporarily.suspend|your.reference|accurately.detail',
                            '__KAM_GIRLS1,[l=0]' => '(?i)Lack of sex',
                            '__KAM_RAT2_1,[l=0]' => '(?i)job description',
                            '__KAM_NIGERIAN2_5,[l=1]' => '(?i)fund code|cheque|bank draft|oil.and.gas',
                            '__KAM_BACKUP3,[l=1]' => '(?i)backup.necessary|marketing|infographic|charge.more',
                            '__KAM_RUIN3,[l=0]' => '(?i)banking institutions',
                            '__TVD_PH_BODY_07,[l=1]' => '(?i)\\bguarantee the safety of your (?:[a-z_,-]+ )*?account',
                            'KAM_OBFU_LOANS,[l=0]' => '(?i)StÃ¼dÃ©nt LÃ³ans',
                            '__KAM_INQUIRY_3,[l=0]' => '(?i)terms? (\\&|and) conditions?|rightful dep',
                            '__DRUGS_ERECTILE_L,[l=1]' => '(?i)\\bLevitra\\b',
                            '__KAM_LISTSALE2,[l=0]' => '(?i)contact list|list of customers|list of decision makers|list for marketing',
                            '__KAM_SANTA2,[l=0]' => '(?i)Santa Letter|Letter from Santa|sent by Santa',
                            '__KAM_TINNI1,[l=0]' => '(?i)TinniFix',
                            '__KAM_STOCK2_3,[l=0]' => '(?i)stock',
                            '__FOR_SALE_PRC_1K,[l=1]' => '(?i)\\bprice:? \\$\\d,?\\d\\d\\d[.\\s]',
                            '__KAM_VIAGRA4A,[l=1]' => '(?i)V (. )?A (. )?L (. )?[I\\/t] (. )?U (. )?M',
                            '__NIGERIA,[l=1]' => '(?i)\\bnigeria\\b',
                            '__KAM_REWARD1,[l=1]' => '(?i)walgreens|ikea|sephora|sams.?club',
                            '__KAM_SUNGLASSES2,[l=1]' => '(?i)great ray|hot.deal',
                            '__KAM_SECURITY3,[l=1]' => '(?i)information.security|cyber.?criminal',
                            '__KAM_NOMORE1,[l=1]' => '(?i)no.more.of.this',
                            '__FRAUD_AXF,[l=0]' => '(?i)magnanimity',
                            '__KAM_BENEFICIARY3,[l=1]' => '(?i)(gold|diamonds|inherit|foreign customer|risk.?free|less.privilege|next of kin|nearest airport|certain funds|partnership to transfer|repatriation|co.fiscate|separate account|christian activit|receiving bank|donate the sum|money left|sweepstakes|lucky winner|get rich|\\d% of the total|investment fund)|moving some money|god has blessed|contributions to humanity|partake in the deal|pledge dep|over-?due compensation|left your check',
                            '__KAM_SELL2,[l=0]' => '(?i)Easy Money',
                            '__PDS_SENT_TO_EMAIL_ADDR,[l=0]' => '(?i)This message was sent to Email Address\\.',
                            'DRUG_ED_GENERIC,[l=1]' => '\\bGeneric Viagra\\b',
                            '__JAPANESE_UCE_BODY,[l=1]' => '(?:L\\$>5Bz|EE;R%a!<%k)(?:8x|9-)9p',
                            '__KAM_FAKEINV2,[l=0]' => '(?i)dearest client',
                            '__HK_LOTTO_2,[l=1]' => '(?i)\\blot(?:eri[ej]|t(?:ery|o)) ?(?:(?:inter)?national|foundation|mercato|univers|euro ?million|e-?mail|euro-pw|bill ?gates|swiss|prestige|cristal|am.ricaine|coca.?cola|fiduciary|department)',
                            '__KAM_GRASS3,[l=0]' => '(?i)Grass Seed On Steroids|rich beautiful lawn|Patch Perfect Seeds|Grow Grass (anywhere|in the shade)',
                            '__INTL_BANK,[l=1]' => '(?i)\\b(?:international\\s(?:\\w+\\s)?bank|banque\\sinternationale)\\b',
                            '__KAM_SKYPE4,[l=1]' => '(?i)Promo Code: \\d',
                            '__KAM_STOCKTIP132,[l=1]' => '(?is)((\\b|^)AGMS(\\b|$)|Angstrom[- ]Microsystems)',
                            '__KAM_HIRE3,[l=1]' => '(?i)hiring.situation|recruiting|plans.to.hire|altera.staff',
                            '__KAM_PASSWORD2,[l=1]' => '(?i)validate.your.email',
                            '__KAM_COMPROMISED4,[l=1]' => '(?i)How are you\\? Look at this.{0,70}Do you know about this site|look at this site right now|I found (an amazing|great) site|hey\\. please have a look|have a look right now|breaking news',
                            '__KAM_URONLINE2,[l=1]' => '(?i)wanna talk|ur info|found your mail|found ur profile|mutual friend|katya from russia|you came to russia|my gentle sun|see this page I made|match making heaven|meet that special|comee see it over here|hexten.net|looking for a man|waiting for ur mail|found ur account|waiting for your message|casual.hookup',
                            '__KAM_PROPHET3,[l=0]' => '(?i)Dear Christian Friend',
                            '__KAM_ACNE3,[l=0]' => '(?i)proactiv',
                            '__KAM_DENTIST3,[l=0]' => '(?i)Find a dentist',
                            'EXCUSE_REMOVE,[l=1]' => '(?i)to be removed from.{0,20}(?:mailings|offers)',
                            '__KAM_POLY2,[l=0]' => '(?i)The End of Barack Obama',
                            '__KAM_ARREST2,[l=1]' => '(?i)Instant Checkmate|dirty Truth|\\brapist\\b|criminal.(background|record)|predator|stay.safe|child.offender|think.you.know|know.everything|database.screening|know.something|wanted.to.know|arrest.record',
                            '__KAM_FLASH2,[l=0]' => '(?i)Flash Player Update',
                            'ONLINE_PHARMACY,[l=1]' => '(?i)\\bonline pharmacy|\\b(?:drugs|medications) online',
                            'LONG_TERM_PRICE,[l=1]' => '(?i)long\\W+term\\W+(target|projected)(\\W+price)?',
                            '__KAM_MEDTOUR1,[l=1]' => '(?i)medical.tourism',
                            '__HK_SCAM_N8,[l=1]' => '(?i)\\byour compensation\\b',
                            '__KAM_LIKE4,[l=1]' => '(?is)HTML code for the link',
                            '__KAM_PHISH2_7,[l=1]' => '(?i)extra security check|security.tip',
                            '__KAM_NIGERIAN2_2,[l=1]' => '(?i)barrister|director of central bank|bank director|former.minister|gold.dealer',
                            '__KAM_SEX_EXPLICIT4,[l=1]' => '(?i)(?:fucked hardcore|dildoes her tight ass|kinky watersports|schoolgirls? slut|teens? porn|first anal(\\b|$)|pussy lips|kinky lesbian|sucks? cock|rub puss|spreads? cunt|fetish babe|kinky pee|muffdived \\& fuck|deepthroat on knees|hello.naughty.boy|certain.type.of.guy|girlfriend.trick|sexual.stamina|sex...toy|porn.link|cunt.fuck|c-o-c-k|non.stop.sex|porn.industry|stronger.erection|make.her.moan|extreme.pro.abortion|erection.problem|your.erection|get.an.erection|hardest.erection|get.erect|xxx gay|asian porn|blowjob porn|anal xxx|huge tits tube|xxx tube|porn tube|fuckbook|portal for xxx|3d porn|DrPEnterprise|girlfriends.porn|\\bsex.galler|pussy.eaten|shemale|(\\b|^)anal.adventure|black.girls.video|gay.porn|pussy.wet|make.her.horny|crave sex|women.fuck|women.horny|wanting.to.bang|getting.laid.is.simple|woman.on.her.knees|b r e a s t|generic.ed.product|best.sex|f[^a-z]cking.you|f[^a-z]ckbuddy|F#ckFriends|Milf Selfies|need.a.horny.man|cute.sex.lover|horny.as.f.ck|fun.in.the.bedroom|my.tits.are|be.horny|horny.girl|horny.i.am|horny.latina|huge.dildo|made.me.climax|sex in my office|a.good.f\\@ck|married.horny.woman|sucked.your.d\\@ck|horny.milf|suck.you.off|horny.stories|all.my.h[o0]les|cum.heavily|sucking.your.c[o0]ck|to.get.f[^a-z]cked)|h00kup|s\\*xy|\\bh0rny|ch0ked|pu\\$\\$y|f\\*cked|F\\*ck_|find milfs',
                            '__KAM_LOGO1,[l=1]' => '(?i)guru.level logo',
                            'DX_TEXT_03,[l=1]' => '\\b[A-Z]{3} Media (?:Group|Relations)\\b',
                            '__KAM_URUNIT6,[l=1]' => '(?is)(majority of women|shrinking .{0,12} baby fat|winning guy|huge explosion)',
                            '__KAM_UNSUB1,[l=0]' => '(?i)cancel 0ffers',
                            '__KAM_RBL_OBFU2,[l=1]' => '(?i)quin.{0,3}for.{0,3}ce.com',
                            '__FRAUD_PVN,[l=0]' => '(?i)as the beneficiary',
                            '__KAM_WORKFROMHOME1,[l=0]' => '(?i)work from home',
                            '__KAM_WIFE2,[l=1]' => '(?i)marry a Russian|sizzling photos|(russian|asian|ukrai?nian) (women|beaut|bride|girl)|Slavic babes|Russian ?lad(y|ies)|sexy photos',
                            '__KAM_NIGERIAN3_1,[l=0]' => '(?i)congo',
                            '__KAM_CREDIT4,[l=1]' => '(?i)CHANGES TO YOUR CREDIT[- ]SCORE|credit score has changed|Triple Bureau Credit Alerts|score\\s+may\\s+have\\s+(been)?\\s*changed|ThinkCredit|Debunk Credit Card Processing Myths|costs for your business|TransUnion,? Experian and Equifax Scores|ha(s|ve).been.updated|what.?s.your.credit|sensitive.information',
                            '__KAM_MERCHANT2,[l=1]' => '(?i)business.owner|merchant.processor|processing.fee|average.bank|interchange.fee',
                            '__KAM_COVID3,[l=1]' => '(?i)COVID.{0,12}(empowerment|payment)|W\\.?H\\.?O\\.? trust.?fund',
                            '__KAM_SWIFT2,[l=0]' => '(?i)swift copy',
                            '__FRAUD_XVW,[l=1]' => '(?i)\\bhonest cooperation\\b',
                            '__KAM_MEDICARE4,[l=1]' => '(?i)over.(65|sixty.?five)|most.affordable|lower.your.premium|medicare basics guide',
                            '__KAM_LIST3,[l=1]' => '(?is)price\\:|prices for our director',
                            '__KAM_LIST3_2,[l=1]' => '(?i)list services|email campaign|global marketing|(sales|event|campaign) manager|marketing (coordinator|campaign|manager|exec|project|team)|(lead|demand) generation|(business|Data|event) (analyst|coordinator)|(potential|professionals?|qualified) lead|(marketing|lead|attendees?|data) specialist|(marketing|Business) Co-?ordinator|marketing and comm|inside sales|pre-?sales|(email|attendee)s? list|global leads',
                            '__KAM_STOCKTIP131,[l=1]' => '(?is)(Greenstone Holdings|(\\b|^)GSHN(\\b|$))',
                            '__KAM_SPAMKING4,[l=1]' => '(?is)notify .{0,30} that you no longer wish to receive (?:promotional )?messages',
                            '__KAM_JOINT4,[l=0]' => '(?i)Joint Relief|effective as glucosamine',
                            '__KAM_STOCKTIP167,[l=1]' => '(?is)(\\b|^)(QSMS|Quest Science Management Gate)(\\b|$)',
                            '__KAM_TV2,[l=1]' => '(?i)without a monthly fee|pay a cable or satellite bill|no monthly fee|watch uncensored|movies online|no censorship|favorite.channels|online.television|\\d{3}.channels|high.speed|sysview',
                            '__KAM_BANK_2,[l=0]' => '(?i)beneficiary|agent|investment group|deceased',
                            '__KAM_CELEB2,[l=0]' => '(?i)resugar',
                            '__KAM_HOME2,[l=1]' => '(?i)Build your equity faster|refund is not reversible|rent.to.own',
                            '__KAM_NIGERIAN2_7,[l=0]' => '(?i)bank|smuggle',
                            '__KAM_AQUA1,[l=1]' => '(?is)Aqua Globe',
                            '__KAM_ATTORNEY3,[l=1]' => '(?i)find.a.\\b[a-z]+\\b.attorney',
                            '__KAM_NOMORE2,[l=1]' => '(?i)no.more.at.all',
                            '__FRAUD_TCC,[l=0]' => '(?i)foreign (?:offshore )?(?:bank|account)',
                            '__KAM_LABEL3a,[l=0]' => '(?i)make custom (shirts|sports|jackets|suits)',
                            '__KAM_JOB2_4,[l=1]' => '(?i)\\d,?000 USD (monthly|weekly)',
                            '__hk_win_7,[l=1]' => '(?i)\\bcongratulations? to your',
                            '__PASSIVE_INCOME,[l=1]' => '(?i)\\bpassive income\\b',
                            'KAM_CANSPAM,[l=1]' => '(?is)(full compliance with the U.S. Federal-?Can-?Spam-Act|provides CAN-SPAM compliant email|consistent with the provisions of the CAN-SPAM Act|compliance with the CanSpam Act|no deceptive subject lines|compliant with all legal provisions of the CAN-SPAM Act)',
                            '__KAM_WHITEN2,[l=0]' => '(?i)whitener',
                            '__BONUS_LAST_DAY,[l=1]' => '(?i)\\b(?:last|final) day of the (?:\\$\\d+ |\\d+ dollars? )?bonus offer(?:ing)?\\b',
                            '__KAM_RELIGION3,[l=0]' => '(?i)Dear Christian|Christian Media',
                            '__KAM_VIAGRA8A,[l=1]' => '(?i)VI...?AGRA',
                            '__CASHPRZ,[l=1]' => 'cash prize of',
                            '__HK_LOTTO_STAATS,[l=1]' => '(?i)\\bstaatsloteri',
                            '__KAM_LABEL2,[l=0]' => '(?i)meet at your office|quick lead time',
                            '__KAM_WATER3,[l=0]' => '(?i)filtered tap water',
                            '__JMQ_HEARINGLOSS3,[l=1]' => '(?i)going.crazy|natural.formula|restore.your.hearing|click.here.to.see|off.hearing.aid',
                            '__KAM_INVEST2,[l=1]' => '(?i)apprehensive|unstable investment|(honest|well.?established|reliable) (individual|partner|person)|wealthy client|legal paper|branch manager|director finance|business man|family asset|personal assistant|found your (detail|contact)|consultant|project financing|my name is|i am the lawyer|need your assistance',
                            '__KAM_COVID3_3,[l=1]' => '(?i)\\$[\\d\\.,]+ mil',
                            '__KAM_GEVALIA3,[l=1]' => '(?is)No Further Obligation',
                            'KAM_PUBLIC,[l=1]' => '(?is)obtained your email address from a publicly available list|find your mail in public forum',
                            '__KAM_BENEFICIARY6,[l=0]' => '(?i)(deceased|late) (customer|husband|client|father)|death of my husband|cancer|power of attorney|customer who died|orphan|no beneficiary|terminal|family treasure|not criminal|send (you )?more (information|details)|wife ran away|inability to release|terrorist attack|sterile|foreigner who died|corrupt officials|could not complete',
                            '__KAM_STAR1,[l=0]' => '(?i)REMOVE ("\\*"|space) (in the above|to make the) link',
                            'BODY_ENHANCEMENT2,[l=1]' => '(?i)\\b(?:penis|male organ|pee[ -]?pee|dick|sc?hlong|wh?anger|breast(?!\\s+cancer)).{0,50}\\b(?:enlarge|increase|grow|lengthen|larger\\b|bigger\\b|longer\\b|thicker\\b|\\binches\\b|size)',
                            'KAM_ADVERT3,[l=1]' => '(?i)AllExpiringDomains.com',
                            '__KAM_GOOGLE4,[l=0]' => '(?i)with Google|Google Pie|Google Cash',
                            '__KAM_URUNIT1,[l=1]' => '(?is)\\bur (unit|liveliness|energy level|endurance level)',
                            '__KAM_ANCESTOR3,[l=1]' => '(?i)family.history|your family|share.the.stories',
                            '__KAM_SMOKE5,[l=0]' => '(?i)you have qualified',
                            '__KAM_HOWRU4,[l=1]' => '(?i)gmx.com|rambler.ru',
                            '__KAM_CLOUD3,[l=1]' => '(?i)big data|powering apps|reduce.tech.costs|backup.solution|bundling.the.service',
                            '__KAM_FUN7,[l=1]' => '(?i)nerve pain|poor vision|lasik|sleep deeper|smart.?watch|fever|hearing aids|diabetes|gum problem|blood sugar|sugar disease|bad breath|fish oil|ultra ?boost|soothing relief|older women|belly fat|reverse alzheimer|personal safety|gadget.?junk|Insta ?heater|need boyfriends',
                            '__BARRISTER,[l=1]' => '(?i)\\b(?:barrister|solicitor at law|barr\\.)',
                            '__ACH_CANCELLED_03,[l=1]' => '(?i)\\bwire[-_ ]?(?:payment|transfer|transaction)[-_ ](?:(?:was|is)[-_ ])?(?:rejected|cancel+ed|declined|disabled|not[-_ ]accepted|(?:technical )?error)',
                            '__KAM_INVESTCOUNTRY2,[l=0]' => '(?i)invest in your country',
                            '__KAM_FINGERHUT3,[l=1]' => '(?i)important.message|what.you.want|monthly.pay|your.account|credit.account|holiday.shopping|are.you.approved|fingerhut.buying',
                            '__FOR_SALE_LTP,[l=1]' => '(?i)00\\.? (?:less 10%|LTP)',
                            '__KAM_GERMAN_BUSINESS_CONTACTS3,[l=0]' => '(?i)German business phone numbers',
                            '__KAM_UNIV14,[l=1]' => '(?is)(earn a|full) transcript',
                            '__SUSPICION_LOGIN,[l=1]' => '(?i)\\bsuspicion login\\b',
                            '__KAM_WEED4,[l=1]' => '(?i)(weed|pot).stock',
                            '__KAM_UNIV6B,[l=1]' => 'DIP\\sLOMA',
                            '__KAM_CARD3,[l=1]' => '(?i)I[\'`]m in hurry, but i still love you...|has (issued you a greeting|made you an Ecard)|^(Follow this link:|click (here to enter our secure server:))?\\s*?http:\\/\\/\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}|eCard, open attached',
                            '__KAM_TIME2,[l=1]' => '(?is)(replica(\\b|$)|diamond|designer[-_ ](piece|collections|watch)|time[-_ ]piece|wrist|time-keeper|\\/\\/atch)',
                            '__KAM_BADCRED_1,[l=0]' => '(?i)bad credit',
                            '__KAM_UNIV3,[l=1]' => '(?is)(past work|based on your|earned from|life|life and work|present work) experience',
                            '__TRAVEL_RESERV,[l=1]' => '(?i)\\b(?:reservation\\s(?:confirmed|number)|travel\\sreservations?)\\b',
                            'DRUG_ED_CAPS,[l=1]' => '\\b(?:CIALIS|LEVITRA|VIAGRA)',
                            '__KAM_WEBINAR4,[l=1]' => '(?i)executive.education|contactid|register now|\\d+.minute webinar|management.position|supervising.skills|discover.tips|register.early|take.control|marketing.capabilit|drive.more.sales|leveraging.cloud|solution.provider|have.a.handle|plan.to.divest|being.informed|upcoming.webinar|spearfishing.email|increase.revenue|industry.podcast|\\d+.in.depth.tips|early.bird.offer|pmp.certified|lunch.briefing',
                            '__KAM_LED2,[l=1]' => '(?i)(garage|LED Fan) Light|sun-?like|\\dx the brightness',
                            '__KAM_URGENT4,[l=0]' => '(?i)god bless',
                            '__FRAUD_MCQ,[l=1]' => '(?i)\\btransaction\\b.{1,30}\\b(?:magnitude|diplomatic|strict|absolute|secret|confiden(?:tial|ce)|guarantee)',
                            '__KAM_FAKEVOUCHER2,[l=1]' => '(?i)\\$\\d+ amazon(.com)? Card|redeem.your.\\$\\d+|join.amazon|bonus voucher|spring.rewards|new.gift.card|exclusive.for|shopper.bucks|activate.here|cash.in.your',
                            '__DOS_BODY_FRI,[l=1]' => '(?i)\\bfri(?:day)?\\b',
                            'NOT_SPAM,[l=1]' => '(?i)\\b(?:(?:this (?:e?-?mail|message)|we) (?:is not|are not|cannot be considered) Spam|ESTE CORREO NO PUEDE SER CONSIDERADO (?:INTRUSIVO|spam)|Diese Nachricht ist KEIN SPAM)',
                            '__KAM_HOSE3,[l=1]' => '(?i)pocket hose|garden.hose|stays.strong|grows.to.full.size|never.kinks',
                            '__KAM_OPRAH1,[l=0]' => '(?i)airfare',
                            '__KAM_NEUROLOGICAL3,[l=0]' => '(?i)at risk for alzheimers|alzheimers conspiracy|doctors hate him',
                            '__KAM_STOCKOBFU2,[l=0]' => '(?i)first letter',
                            'PRICES_ARE_AFFORDABLE,[l=1]' => '(?i)\\baffordable .{0,10}prices\\b',
                            '__PUMPDUMP_04,[l=1]' => '(?i)\\bmake you (?:big bucks|hundreds|thousands)\\b',
                            'TVD_PH_REC,[l=1]' => '(?i)\\byour .{0,40}account .{0,40}record',
                            '__KAM_TELEWORK5,[l=1]' => '(?is)work (?:online )?from home|process(?:ing)? rebates (?:at|from) home|set your own hours|100% no risk|Western Union fees|new job or career',
                            '__KAM_FRIEND2,[l=1]' => '(?i)wants.to.follow',
                            '__YOUR_PROFIT,[l=1]' => '(?i)\\byour?\\sprofit',
                            '__KAM_NIGERIAN5,[l=1]' => '(?i)Western Union Money Transfer|Money Gram|form of Money Orders|to apply for this job, please send the following|process our payments|not traceable|risk free transation|transfer to a designated bank account|inheritance return|my.inheritance|my.wealth|donation.to.you|out.of.country|charitable.trust',
                            '__KAM_GOOGLEPHISH1,[l=0]' => '(?i)copy of the signed agreement',
                            '__KAM_REP3_2,[l=1]' => '(?i).\\s+(COM|org|net|info)$',
                            '__KAM_DRUG4,[l=1]' => '(?is)click to buy|no previous doctors direction|No prescript[oi]{2}n needed|no script necessary|medicine assistance supplier|mail[- ]?order medicine',
                            '__KAM_HOLIDAY3,[l=0]' => '(?i)star special|Hotel Opening|(Request|order) a brochure',
                            '__OUR_BEHALF,[l=1]' => '(?i)\\b(?:on\\s(?:my|our)\\sbehalf|of\\sbehalf\\sof)\\b',
                            'INVESTMENT_ADVICE,[l=1]' => '(?i)\\binvestment advice',
                            '__DOS_BODY_WED,[l=1]' => '(?i)\\bwed(?:nesday)?\\b',
                            'KAM_PERPARK,[l=0]' => '(?i)P e r i m e t e r P a r k C e n t e r',
                            '__KAM_PHISH4_3,[l=1]' => '(?i)(confirm|verify|update).your.(identity|account)|account.password|credit.(bureau|profile)|identity.theft|accredited.commission|security.concern|kindly.find.enclosed|owner of this account',
                            '__KAM_ASSASSIN3,[l=0]' => '(?i)assassinate',
                            '__KAM_COVID5,[l=1]' => '(?i)00 ?(EUR|USD|Dollar)',
                            '__CHARITY,[l=1]' => '(?i)\\b(?:charit(?:y|[ai]ble)|orphans?|homeless|orphelins|sans\\sabri)\\b',
                            '__FRAUD_JBU,[l=1]' => '(?i)\\bforeign account\\b',
                            '__KAM_MOTHER3,[l=1]' => '(?i)pro.?flowers|flowers.fresh|freshness.guarantee|shop.now|mom.?s.delight',
                            '__KAM_SHOCK1,[l=1]' => '(?i)shocking.beverage',
                            '__KAM_URUNIT2,[l=1]' => '(?is)\\bur (gf|girl|wife|size|thing|partner|significant other)',
                            '__DAY_I_EARNED,[l=1]' => '(?i)day,?\\sI\\s(?:earned|got|received|made|brought\\sin)\\s\\$\\s?\\d{3}',
                            '__KAM_NIGERIAN2_9,[l=0]' => '(?i)scam|don\'t let them know that it is money|bank transfer charges',
                            '__KAM_MEMBER3,[l=1]' => '(?i)(\\b|^)dating|eharmony|Find.Your.Perfect.Match|thousands.of.single.women|singles?.photos?|local.cougar|successfully matched|blind date|(available|black|latin[oa]|jewish).singles|photos of 50\\+',
                            'LOW_PRICE,[l=1]' => '(?i)\\blow.{0,4} (?-i:P)rice',
                            '__KAM_DRUG2_4,[l=1]' => '(?i)grab hold|at[_ ~]your[_ ~]finger[_ ~]?tip|placing your order|questions about drugs|prescription is not|don\'t care about prescription|without a doctor|no need for a doctor|affor[df]able.prices|best daily rx|Fav.Prescript|unmatched.prices|rx.med|millions.are.praising',
                            '__KAM_TELEWORK6,[l=1]' => '(?is)earning up to \\d+USD|earn thousands of dollars|\\d% commission|get rich quick|manager training|real.payoff',
                            '__KAM_TINNITUS3,[l=1]' => '(?i)scientifically.proven|end.tinnitus|get rid of the ringing',
                            '__KAM_PRIV1,[l=0]' => '(?i)private message|horny|sweet ass',
                            '__KAM_USB2,[l=0]' => '(?i)person (that|who) handles the promotions',
                            '__KAM_CHECK1,[l=0]' => '(?i)delivery fee for your che(que|ck) draft',
                            '__KAM_WARRANTY3,[l=0]' => '(?i)home warrant|complimentary insurance quote',
                            '__KAM_SHARKTANK_BODY,[l=0]' => '(?i)shark tank',
                            '__KAM_REAL3,[l=1]' => '(?is)(vacation|second) (home|place)',
                            '__STOCK_TIP,[l=1]' => '(?i)\\bsto[ck]{2}\\s?tip\\b',
                            '__KAM_BLOOD6,[l=0]' => '(?i)Blood pressure',
                            '__DRUGS_PAIN_VIOXX,[l=0]' => '(?i)vioxx',
                            '__KAM_DRUG2_3,[l=1]' => '(?i)Medi?cati[o0]ns|desired meds|favou?red (rx)?med|buy remedies|drug store|medicants|medicaments|sexual stim|sex stim|pain killer|(purchase|loved|preferred|favou?rite) (?:rx.?)?(deal|med)[sz]|rx.?Meds?.?deal|buy your meds|choice of meds|Rx.?(deal|Med|Sale)|v[i1]agra|medz.special|loved meds|(rx|medication) ?discount|Get the edge|joint.pain.relief|neuropathy|nerve.pain',
                            '__KAM_CONTRACT3,[l=0]' => '(?i)buy you out|service management|management solution',
                            '__PERFECT_BINARY,[l=1]' => '(?i)\\bperfect binary option\\b',
                            '__DRUGS_ANXIETY8,[l=1]' => '(?i)\\bklonopin\\b',
                            '__KAM_ANA1,[l=1]' => '(?i)(anatrim|Green ?Tea|cortitherm|PHENTERTHIN|Phentremine|Acai Ultra|Civ-xR|WuYi Tea|Wu-?Yi Source|FRS Healthy Energy|Acai Berry|Chinese secret|Ephedra|Cholestapro|ColonMedic|Pure Cleanse|AcaiBurn|Acai Elite|Garcinia|Chlorogenic Acid|green coffee)',
                            '__WIRE_XFR,[l=1]' => '(?i)\\b(?:wire|telegraph(?:ic)?|bank)\\s?transfer',
                            '__KAM_GOOGLE_AWARD2,[l=0]' => '(?i)selected as a winner',
                            '__KAM_FAKEWEST3,[l=0]' => '(?i)United Nation',
                            '__KAM_REHAB3,[l=0]' => '(?i)(?:drug|alcohol) (recovery|rehab|dependenc|addict|treatment)|help for alcoholism|life from alcohol|end your drinking|think about rehab',
                            '__CONTACT_YOU,[l=1]' => '(?i)\\b(?:contact(?:ing)\\syou|vous\\scontacter?)\\b',
                            '__KAM_PASSWORDSCAM1,[l=0]' => '(?i)pass word',
                            '__KAM_STOCKTIP147,[l=1]' => '(?is)Beamz Interactive|(\\b|^)BZIC(\\b|$)',
                            '__KAM_FARM3,[l=0]' => '(?i)(blueberry|Tomatoe?) giant',
                            '__KAM_PIC4,[l=1]' => '(?is)(like to share some of my pics|some (?:great )?pictures of me|sending some of my pictures|To see my pic|hope you like my pic|will reply with my pics|show you some pic|chat with me and see|that\'s my photo)|will send you my pictures|view my profile|describe yourself|chat with me|bad girl|view your snapshot|want to watch video|erotic pics',
                            '__KAM_SANTA3,[l=1]' => '(?i)the .?perfect.? gift|personalized letter',
                            '__WE_PAID,[l=1]' => '(?i)\\bwe have (?:already )?(?:paid|sent|remitted|issued) \\$?\\d+(?:,\\d+)* (?:thousand )?(?:dollars )?to our (?:users|subscribers|members|clients|affiliates|partners)\\b',
                            '__PUMPDUMP_03,[l=1]' => '(?i)\\bbuy (?:[^.!]{1,30} )?(?:(?:(?:mon|tues|wednes|thurs|fri)day|tomorrow) (?:first thing|open|morning)|(?:first thing|opens|before) (?:(?:mon|tues|wednes|thurs|fri)day|tomorrow))',
                            '__HK_SCAM_S1,[l=0]' => '(?i)pay you the sum of',
                            '__FRAUD_PTS,[l=1]' => '(?i)\\b(?:ass?ass?inat(?:ed|ion)|murder(?:e?d)?|kill(?:ed|ing)\\b[^.]{0,99}\\b(?:war veterans|rebels?))\\b',
                            '__KAM_URGENT3,[l=0]' => '(?i)private e?mail',
                            '__KAM_GRANT2,[l=0]' => '(?i)find out if you qualify',
                            '__KAM_TUPPERWARE3,[l=0]' => '(?i)tupperware lid|food storage|storage container',
                            '__KAM_TIMESHARE1,[l=1]' => '(?is)Get[- ]Cash for Your Timeshare|not using your timeshare|(unwanted|ugly) timeshare|cash out quickly',
                            '__KAM_FAKEINV2_3,[l=0]' => '(?i)not mail the check|typeform\\.com',
                            '__KAM_UKINV4,[l=0]' => '(?i)&pound;',
                            '__KAM_STOCKOBFU1,[l=1]' => '(?i)make up the \\d letter symbol',
                            'MALE_ENHANCE,[l=0]' => '(?i)male enhancement',
                            '__KAM_VERIZON4,[l=0]' => '(?i)Update required immediately',
                            '__KAM_DISCLAIMER1,[l=0]' => '(?i)receives compensation',
                            '__KAM_DEATH1,[l=1]' => '(?i)prevent early.death',
                            '__KAM_POWER1,[l=0]' => '(?i)hoveround',
                            '__KAM_PROFORMA3,[l=0]' => '(?i)highly encrypted',
                            '__KAM_MEDICAL2,[l=0]' => '(?i)Safe - Natural - Effective',
                            '__KAM_STUDENTLOAN5,[l=0]' => '(?i)(financial troubles|debt) is (understood|forgiven)',
                            '__KAM_DOMAIN_SALE2,[l=1]' => '(?i)\\b(interested in|obtaining) .{5,20} domain\\b',
                            '__KAM_BANK_3,[l=1]' => '(?i)re\\-?verification|clearance tax|possible funding|same last name|nominated bank account',
                            '__KAM_CELEB3,[l=1]' => '(?i)fat.burning',
                            '__CONTACT_ATTY,[l=1]' => '(?i)\\bcontact(?:er)?\\s(?:my|(?:de\\s)?mon)\\s(?:barrister|attou?rney|lawyer|avocat|gestionnaire)\\b',
                            '__KAM_REFI5,[l=1]' => '(?is)([\\d,]{5,6}|\\d{2}\\s*%) savings|principal \\d+% less|\\d+\\.\\d+%.fixed|refi.calculator|lowered.requirements|home.?owner',
                            '__KAM_UNIV18,[l=1]' => '(?is)100% discrete',
                            '__KAM_HOMESALE3,[l=0]' => '(?i)Cash Offer for Your Home',
                            '__KAM_SKIN4,[l=1]' => '(?i)feet feel smooth and healthy|calluses and dead skin|silky smooth skin|tighter skin|\\d.years.younger|anti[- ]aging|look younger|free trial|lose 25 years|angered plastic surge|quick and easy trick|anti-?aging|blood pressure low|heart rate monitor|selfies|just.one.month|just.four.weeks|medical.research|rebuild.your.skin|decades.younger|erase.time|gossip|smooth.lines',
                            'DRUGS_SMEAR1,[l=1]' => '(?i)(?:Viagra|Valium|Xanax|Soma|Cialis){2}',
                            '__KAM_1LINE1,[l=1]' => '(?is)(free score and report|Did you overpay\\?)',
                            '__KAM_JESUS1,[l=1]' => '(?i)jesus lovely|the.lord|touched.by.christ',
                            'ONE_TIME,[l=1]' => '(?i)\\bone\\W+time (?:charge|investment|offer|promotion)',
                            '__KAM_FDA2,[l=1]' => '(?i)not intended to diagnose,? treat,? cure,? or prevent',
                            'NO_PRESCRIPTION,[l=1]' => '(?i)N[o0].{1,10}P(?:er|re)scr[i1]pt[i1][o0]n.{1,10}(?:n[e3][e3]d[e3]d|requ[1i]re|n[e3]c[e3]ssary)',
                            '__KAM_BUS1,[l=0]' => '(?i)business proposal',
                            '__KAM_CHANGELOG2,[l=0]' => '(?i)as promised chnglog update',
                            '__FRAUD_KJV,[l=0]' => '(?i)(?:claim|concerning) (?:the|this) money',
                            '__FB_S_STOCK,[l=1]' => '(?i)\\bstock',
                            'DRUG_ED_ONLINE,[l=1]' => '(?i)\\bviagra .{0,25}(?:express|online|overnight)',
                            '__KAM_GIFT2,[l=1]' => '(?is)(unsubscribe from this advertiseme(tn|nt)|exit future communications|to unsubscribe from this|to stop any offers from us)',
                            '__hk_win_5,[l=1]' => '(?i)\\b(?:notice the|your) winning',
                            'KAM_REACHBASE,[l=0]' => '(?i)ReachBase is committed to providing you with relevant business information',
                            '__KAM_INTRUDE,[l=1]' => '(?i)\\b(hope I am not intruding|out of the blue|I will never contact you again if you go here)\\b',
                            'NA_DOLLARS,[l=1]' => '(?i)\\b(?:\\d{1,3})?Million\\b.{0,40}\\b(?:Canadian Dollar?s?|US\\$|U\\.? ?S\\.? Dollar)',
                            '__OBFU_UNSUB_UL,[l=1]' => '(?:click_here|remove_your|our_e?mail|this_list|to_unsubscribe|future_e?mail|our_list)',
                            '__KAM_SHOP2,[l=1]' => '(?is)Do you like to shop',
                            '__KAM_JUDGE2,[l=1]' => '(?is)(funds|receive what) you are (due|owed)',
                            '__TVD_PH_BODY_08,[l=1]' => '(?i)\\bmultiple password failures',
                            '__KAM_STOCKTIP129,[l=1]' => '(?is)(EnerBrite Technologies Group|(\\b|^)eTgU(\\b|$))',
                            '__JMQ_IMPORTANT2,[l=0]' => '(?i)important message',
                            '__YOU_WON_05,[l=1]' => '(?i)\\bI won(?!\\xe2\\x80\\x99t)(?![`\'\\x92]t)\\b',
                            '__KAM_STUDENTLOAN2,[l=0]' => '(?i)consolidate your loan',
                            '__KAM_VIAGRA7C,[l=1]' => '(?i)(^|\\b)AMB[ij]+EN($|\\b)',
                            'BILLION_DOLLARS,[l=1]' => '[BM]ILLION DOLLAR',
                            'EMRCP,[l=1]' => '(?i)\\bExcess (?:Maximum )?Return Capital (?:Profits?|Funds?)\\b',
                            '__PILL_PRICE_02,[l=1]' => '(?i)(?=[ptc])(?:pill|tablet|cap(?:sule|let))s[-= :]{1,5}\\$?[\\d .]{3}',
                            '__KAM_BEAUTY3,[l=0]' => '(?i)most amazing transformation',
                            '__KAM_EBAY2,[l=0]' => '(?i)Auction success kit|Great Money Maker|documented program|Chuck Mullaney|more bills than money',
                            '__KAM_ADVERT3,[l=1]' => '(?is)Email Ad Broadcast|Double OPT IN list|making.some.changes',
                            '__BOUNCE_OOO_CB3,[l=1]' => '(?i)\\bolen lomalla\\b',
                            '__KAM_ACCOUNTPHISH4,[l=1]' => '(?i)webmail|all.systems|storage.limit|get.back.into|update.your.account|kindly.click|very.private.message|this.is.honest|fill.the.form|click.on.send|follow.here|for.all.user|one.click.away|mail.desk',
                            '__KAM_PROPERTY3,[l=1]' => '(?i)convenient.location',
                            '__MAIL_ACCT_ACCESS2,[l=1]' => '(?i)\\blo+se ac+es+ to your (?:web|e-?)?mail ?(?:account|log-?in|box|address)\\b',
                            '__KAM_BOXVERIFY,[l=1]' => '(?i)Verify.{0,10}Mail.?box|retrieve messages',
                            '__KAM_PIC1,[l=1]' => '(?is)(tired|bored) (this )?(today|tonight|evening|morning|afternoon)|saw your email address|online right now|can name me|found you on this site|I am alone|my next boyfriend|blonde with blue|like the girls|crush on you',
                            '__KAM_EGG1,[l=1]' => '(?is)Egg Genie',
                            '__FRAUD_IOV,[l=1]' => '(?i)\\b(?:no risks?|risky?[- ]{0,3}free|free of risks?|100% safe|v\\S{1,3}llig Risikofrei ist)\\b',
                            '__RUDE_HTML_1,[l=0]' => '(?i)Get a capable html e-mailer',
                            '__KAM_VIAGRA9D,[l=1]' => '(?i)C[IL1]A..LIS',
                            '__KAM_GAS1,[l=1]' => '(?i)Gas prices are at an? all time high|\\$\\d per gallon|gasoline cards',
                            '__KAM_SEX06_1,[l=0]' => '(?i)more fire and passion',
                            '__KAM_PSYCHIC3,[l=0]' => '(?i)psychic Chris|free psychic reading',
                            '__TRANSFORM_LIFE,[l=1]' => '(?i)\\b(transform|change) your (?:daily )?life(?:style)?\\b',
                            '__KAM_NIGERIAN2,[l=1]' => '(?is)(?:looking for dynamic representative|seek your partnership|new online business model|seek to transfer this money|completely legal activity|never ask you to pay or invest|in search of trustworthy representatives|establishing a new liaison network|rec[ei]{2}ving payment on our behalf|assist me in transferring those funds|make money at home|requiring rep to work on a part time|part time job\\/full time|organization for the good work of the lord|job search directory|investor willing to invest in lebanon|invest in Real Estate|Your kind assistance|next of kin|gold.exportation|calgary.lotto)|oil.producing|import.firm|oil.and.gas|petroleum|asset.available|urgent.reply|(cash|credit.cards?|cell(.phone)?).(were|was).stolen',
                            '__KAM_TELEWORK2,[l=1]' => '(?is)have a (?:tele)?phone|money making challenge|has full internet',
                            '__FRAUD_AON,[l=1]' => '(?i)\\b(?:confidential|private|alternate|alternative) (?:(?:e-? *)?mail)\\b',
                            '__KAM_WEIRDC19_3,[l=0]' => '(?i)The virus that causes COVID-19',
                            '__KAM_REP1,[l=1]' => '(?is)Replace \\[?[-!~\\.]\\]? with \\.',
                            '__KAM_MEDICAL1,[l=0]' => '(?i)million who suffer from|suffered from organ failure|Medical Billing and Coding|medical doctor',
                            '__KAM_CREDIT3,[l=1]' => '(?i)NO COST|it\'s on us|3 companies for free|freescore360|Scoresense|score.report(?:ing)?.team|stand in the rating scales|view your higher credit|(score|credit).alert|provide.faster.service|your credit score|free.credit.score|score.generation|new.score.immediately|score.notification|your report',
                            '__KAM_HONOR4,[l=0]' => '(?i)invitation',
                            '__KAM_FUN5,[l=1]' => '(?i)\\d million americans|less than \\d+ (weeks|days|hours)|temporary feeling|\\d+ ?lbs|[\\d+,]+ Asian babes',
                            '__DORMANT_ACCT,[l=1]' => '(?i)\\b(?:(?:dormant|abandoned|left\\s?over)\\s(?:account|fund|transaction|sum|deposit)|fonds\\sdorment)',
                            '__KAM_AUGER2,[l=0]' => '(?i)Awesome Auger',
                            '__KAM_WEED3,[l=0]' => '(?i)doubled? (there|their) money|Triple this afternoon',
                            '__hk_win_4,[l=1]' => '(?i)\\bpleas(?:ure|ed) to inform',
                            '__KAM_COVID2_1,[l=0]' => '(?i)COVID-19 (CHARITY )?(fund|donated relief)',
                            '__KAM_HEART3,[l=1]' => '(?i)Knowing this could very well save your life|\\d+.second trick|#1 Trick|Prevent(ing)? A Heart Attack|will you be killed|heart disease|silent heart attack',
                            '__KAM_SHARP2,[l=0]' => '(?i)yoshiblade',
                            '__KAM_FAKEAD2,[l=0]' => '(?i)click here to UNSUBSCRIBE|start shopping|here\\\'s how',
                            '__FRAUD_YQV,[l=0]' => '(?i)nigerian? (?:national|government)',
                            '__KAM_OBFURL1,[l=1]' => '(?i)A\\s+D\\s+I\\s+L\\s+I\\s+Z\\+E\\s+R\\s+.\\s+C\\s+O\\s+M|insidesaleswiz\\.\\s+com',
                            '__KAM_FAKEDELIVER1,[l=1]' => '(?i)courier couldn.?t make the delivery|Courier was unable to deliver|courier company was not able to deliver|memo.of.application|delivering.address|make.the.delivery|see.attached.file|attention.please|event.invitation|could not deliver|delivery.label|postal.noti(fication|ce)|parcels.(has|have).been.shipped|shipment.label.is.attached|confirm your shipping|view file in attach|unable to locate your address',
                            '__FRAUD_ULK,[l=1]' => '(?i)\\baffidavits?\\b',
                            '__KAM_DOMAIN1,[l=1]' => '(?i)Domain (opportunity|notification|release|Availability|club)|Notification for Domain|availability.notice|time.draws.near|submit.a.bid|your.business|exclusive.rights|free.registration|the.domain.provider|website.wizard|increase.your.{0,50}.traffic|domain.extension|brand.can.leverage|like.to.obtain|buy(ing)?.this.domain',
                            '__KAM_VACATION3,[l=1]' => '(?i)Resorts FOR FREE|(carr?ibb?ean|alaskan?).cruise|top deals',
                            '__KAM_STOCKTIP149,[l=1]' => '(?i)LifeApps|(\\b|^)LFAP(\\b|$)',
                            '__KAM_2020_2,[l=1]' => '(?i)T-?shirt|printed in the US|stink stank stunk|officially licensed|star wars',
                            '__HK_SCAM_S15,[l=0]' => '(?i)(?:discovered a dormant account|can you be my partner)',
                            '__KAM_UNIV16,[l=1]' => '(?is)\\d weeks.{0,30}graduated',
                            'MILLION_HUNDRED,[l=1]' => '(?i)Million\\s+\\S+\\s+Hundred',
                            '__VBOUNCE_AVREPORT0,[l=0]' => '(?i)(antivirus system report|the antivirus module has|illegal attachment|Unrepairable Virus Detected)',
                            '__KAM_FOOTBALL4,[l=0]' => '(?i)Football',
                            '__TRUSTED_CHECK,[l=1]' => '(?i)\\b(?:cashier\'?s?|certified)\\sche(?:ck|que)',
                            '__KAM_PROPHET5,[l=0]' => '(?i)prophecy|rapture',
                            '__KAM_SOFTWARE3,[l=0]' => '(?i)Fix file errors',
                            '__KAM_BUS4,[l=0]' => '(?i)view my attach',
                            '__YOUR_BANK,[l=1]' => '(?i)\\byour?\\s(?:full\\s)?bank(?:ing)?\\sinformations?\\b',
                            '__KAM_DOMAIN2,[l=1]' => '(?i)(?:available|listed) (?:by|for|at|in) auction|confirm interest in (this domain|owning)|capturing this domain|proposal.on.the.domain|exclusive.owner|online.search|web.form|counting.down|potential.buyer|interested.parties|secure.{1,50}.today|drive.more.leads|targeted.traffic|similar.domain|exclusive.regis',
                            'KAM_FILE,[l=0]' => '(?i)file:\\/\\/\\/\\/',
                            '__KAM_STOCKTIP127,[l=1]' => '(?is)(Physical Property Holdings|(\\b|^)PPYH(\\b|$))',
                            '__KAM_WEB_OBFUSCATION1,[l=1]' => '(?i)check over this commercial|see the commercial.advertisement',
                            '__NOT_SCAM,[l=1]' => '(?i)\\b(?:not\\sa\\sscam|(?:not|never)\\sscam\\syou)\\b',
                            '__KAM_PHISH3_2,[l=1]' => 'accessed by someone else.',
                            '__NEVER_HEAR_IT,[l=0]' => '(?i)eliminare tutti i tuoi segreti|Ti garantisco che non ti disturbe',
                            '__KAM_DUTCHGLOW3,[l=1]' => '(?i)wood milk|dutch glow|wood\'s natural beauty|nourish wood|wax build up|your furniture|woodworking.plans',
                            '__KAM_DIDYOUBODY,[l=0]' => '(?i)Did you (receive it|get my message)',
                            '__KAM_LENS3,[l=0]' => '(?i)amazing lens|hdx-lens|hdrx'
                          },
           'base_string' => {
                              'taking home ' => '__DOS_TAKING_HOME,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'dirtypix' => '__JMQ_PICKUP2,[l=1]',
                              'le copier et le coller' => '__COPY_PASTE_FR,[l=0]',
                              'sams' => '__KAM_REWARD1,[l=1]',
                              'shop' => '__KAM_MOTHER3,[l=1]',
                              'design' => '__KAM_LANDSCAPE3,[l=1]',
                              'email me back as soon as possible' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FAVOR3,[l=0] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1] __KAM_WEB3,[l=1] __YOU_WON_01,[l=1]',
                              'ihr' => '__YOUR_FUND,[l=1]',
                              'wanting to quit' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SMOKE1,[l=1]',
                              'order' => '__KAM_BADZIP3,[l=0]',
                              'claim this money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1] __THIS_AD,[l=1]',
                              'accurately' => '__KAM_INSURE4,[l=1] __KAM_PHISH2_5,[l=1]',
                              'dangers' => '__KAM_VISION3,[l=1]',
                              'yourself' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTO3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME5,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'we are not spam' => 'NOT_SPAM,[l=1]',
                              'touchless thermometer' => '__DEAL,[l=1] __KAM_SALE3,[l=1] __KAM_SPO2_1,[l=0]',
                              'possible funding' => '__KAM_BANK_3,[l=1] __KAM_WEB3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'amb pro cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'affordable quot' => 'PRICES_ARE_AFFORDABLE,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEB2_2,[l=0] __YOU_WON_02,[l=1]',
                              'invoice' => '__FRAUD_QFY,[l=1] __KAM_FAKE_FAX4,[l=0] __KAM_TOLL3,[l=1] __KAM_VM3,[l=1]',
                              'rub puss' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'asset & background search' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK1,[l=1] __KAM_BACK2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'came across your web' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEO3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'what' => '__KAM_FINGERHUT3,[l=1]',
                              'marketing exec' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'suspected online scam' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_HACK1,[l=0] __KAM_NIGERIAN2_9,[l=0] __KAM_PHISH2_6,[l=1] __NOT_SCAM,[l=1] __SCAM,[l=1]',
                              'lift your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'statements above are an' => 'KAM_ADVERT2,[l=1] __KAM_FDA1,[l=1]',
                              'ratemarketplace' => '__KAM_BADNAME1,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1]',
                              'bank draft' => '__BANK_DRAFT,[l=1] __JMQ_WIRE3,[l=1] __KAM_INVEST3,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1]',
                              ' thursday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __KAM_STOCK2_1,[l=1] __PUMPDUMP_03,[l=1]',
                              'update' => '__KAM_INSURE4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'som pro som' => 'KAM_VIAGRA2,[l=0]',
                              'kennett pike' => '__KAM_FUN2,[l=1] __KAM_REP3_2,[l=1]',
                              'usaa' => '__KAM_PHISH2_2,[l=1]',
                              'to apply for this job, please send the following' => '__DEAL,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FRIEND2,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_PATRIOT3,[l=1] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'great ray' => '__KAM_SUNGLASSES2,[l=1]',
                              'votre' => '__YOU_ASSIST,[l=1]',
                              'customs' => '__KAM_NIGERIAN2_3,[l=1] __STOCK_TIP,[l=1]',
                              'unrepairable virus detected' => 'BAD_CREDIT,[l=1] __KAM_AUTONEW3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_REPAIR2_3,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'lev xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'b\\351nin' => '__BENIN,[l=1]',
                              'preston energy' => '__KAM_BADNAME1,[l=1] __KAM_NUWAVE3,[l=1] __KAM_SNORE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_WINDOWS3,[l=1] __STOCK_TIP,[l=1]',
                              'touched' => '__KAM_JESUS1,[l=1] __KAM_SALE3,[l=1]',
                              'trading company' => '__KAM_INQUIRY_4,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'lev amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'recommends this stock' => '__DEAL,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_3,[l=0] __KAM_WEED4,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1] __THIS_AD,[l=1]',
                              'elig' => '__KAM_REFI2,[l=1]',
                              'movie extra' => 'DIET_1,[l=1] __KAM_GIFT3,[l=1] __KAM_MOVIE2,[l=0] __RECEIVE_BONUS,[l=1]',
                              'mer val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'cia lev som' => 'KAM_VIAGRA2,[l=0]',
                              'assassination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __KAM_PATRIOT3,[l=1]',
                              'upgrade center' => '__KAM_GIFT4,[l=1] __KAM_SWIPE4,[l=1] __KAM_VIAGRA9A,[l=1] __SYSADMIN,[l=1]',
                              'invoice copy attached' => '__FRAUD_QFY,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_FAKE_FAX4,[l=0] __KAM_LOTTO6,[l=1] __KAM_TOLL3,[l=1] __KAM_UPS3,[l=0] __KAM_VM3,[l=1] __PLS_REVIEW,[l=1]',
                              'build a better you' => '__KAM_CEP2,[l=1] __KAM_CHICKEN3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'emails list' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1] __YOU_WON_01,[l=1]',
                              'tits' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'consolidate your loan' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_STUDENTLOAN2,[l=0] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev lev som' => 'KAM_VIAGRA2,[l=0]',
                              'buy you the dyson animal' => '__DEAL,[l=1] __KAM_GIFT4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'gift' => '__KAM_FAKEVOUCHER2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'phentermine' => '__DRUGS_DIET_PHEN,[l=1] __KAM_GIFT4,[l=1] __KAM_INSURE4,[l=1]',
                              'the attachement' => '__DEAL,[l=1] __KAM_PRIV3,[l=0]',
                              'complaint id' => '__KAM_FAKEBBB3,[l=0] __KAM_REP3_2,[l=1]',
                              'could not deliver' => '__KAM_DEBT1,[l=1] __KAM_FAKEDELIVER1,[l=1]',
                              'support center' => '__KAM_GIFT4,[l=1] __KAM_SWIPE4,[l=1] __SYSADMIN,[l=1]',
                              'ving payment on our behalf' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __OUR_BEHALF,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'best' => '__KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'records ' => '__KAM_REFI6,[l=1] __TVD_PH_BODY_02,[l=1]',
                              'xan som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'natural medicine' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_FUN6,[l=0] __KAM_LUNAR4,[l=1] __KAM_MED1,[l=1] __KAM_VISION3,[l=1]',
                              's greetings' => '__FRAUD_IRT,[l=1]',
                              'huge explosion' => '__KAM_URUNIT6,[l=1]',
                              'cia amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'wks it has been since we\'ve chatted' => '__KAM_URZEST4,[l=0]',
                              'property & personal history search' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_ANCESTOR3,[l=1] __KAM_BACK2,[l=1] __KAM_REAL2_4,[l=1] __KAM_REVIEW3,[l=1] __STOCK_TIP,[l=1]',
                              'online ph' => 'FREE_QUOTE_INSTANT,[l=1] TVD_VISIT_PHARMA,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1]',
                              'card will be yours free' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_AUTO3,[l=1] __KAM_GIFT4,[l=1] __KAM_INSURE4,[l=1] __KAM_QUOTA2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'overstocked auctions' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STOCK2_3,[l=0] __KAM_SWIPE4,[l=1] __KAM_WEED4,[l=1] __STOCK_TIP,[l=1]',
                              'larger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'd\\303\\251nt' => '__DECEASED,[l=1]',
                              'me financially independent' => 'FIN_FREE,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1] __KAM_RICH4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'be the boss' => '__DEAL,[l=1] __KAM_GOOGLE2,[l=0]',
                              'tax saving plans' => '__KAM_HEALTH2,[l=1] __KAM_HIRE3,[l=1] __KAM_HOME3,[l=1]',
                              'l$>5bz9-9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'in bath' => '__KAM_TUB3,[l=1]',
                              'american oil merchant' => '__KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1]',
                              'thermal vest' => '__DEAL,[l=1] __KAM_VEST1,[l=0]',
                              'overpaying' => '__FEES,[l=1] __FRAUD_QFY,[l=1] __KAM_AUTONEW3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __PAY_YOU,[l=1]',
                              'express' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DRUG2_6,[l=1]',
                              'refreshed' => '__KAM_CHICKEN3,[l=1] __KAM_LUNAR4,[l=1]',
                              'val pro cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'ultimate collection' => '__KAM_GALLERY2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'hello!' => '__KAM_NEWS2,[l=0]',
                              'i am the lawyer' => '__DEAL,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_INVEST2,[l=1]',
                              'dealsformeds' => '__DEAL,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SUNGLASSES2,[l=1] __YOU_WON_02,[l=1]',
                              'sales manager' => '__KAM_DRUG2_3,[l=1] __KAM_LIST3_2,[l=1]',
                              'university mail server copyright' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_2,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_DETOX3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_UNIV9,[l=1] __SYSADMIN,[l=1] __YOU_WON_01,[l=1]',
                              'you have received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'savage' => '__KAM_PRODUCT2_2,[l=1]',
                              'next tax return' => '__KAM_ADMIN3,[l=0] __KAM_POLITICS2,[l=1] __NEXT_OF_KIN,[l=1]',
                              'removallink' => '__DOS_LINK,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'mer pro pro' => 'KAM_VIAGRA2,[l=0]',
                              'welcome' => '__KAM_CHOSEN3,[l=1] __KAM_REP3_2,[l=1]',
                              'hotmedsourcehere' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'pounds' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'stamina' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'business co' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST3_2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'drug treatment' => '__KAM_ANDROGEL3,[l=1] __KAM_GARAGE3,[l=1] __KAM_REHAB3,[l=0] __KAM_REMEMBERWHEN3,[l=1] __TRTMT_DEFILED,[l=1]',
                              'heave your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'supor-collosal mixture' => '__KAM_DRUG1,[l=1]',
                              'single' => '__KAM_MEMBER3,[l=1]',
                              'my name is' => '__JMQ_RESUME2,[l=0] __KAM_HOWRU2,[l=0] __KAM_INVEST2,[l=1]',
                              'research promo center' => '__KAM_BADNAME1,[l=1] __KAM_GIFT4,[l=1] __KAM_LOTTO4,[l=1] __KAM_REVIEW3,[l=1] __KAM_SKIN4,[l=1] __KAM_SWIPE4,[l=1] __THIS_AD,[l=1]',
                              'ran across someone like u' => '__KAM_LED2,[l=1] __KAM_URONLINE3,[l=1]',
                              'this offer only for usa' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'best camera' => '__KAM_LENS1,[l=0] __KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_SPY3,[l=1]',
                              'buy as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'line sweepstake' => '__HK_LOTTO_BALLOT,[l=1]',
                              'get rid of the ringing' => '__DEAL,[l=1] __KAM_TINNITUS3,[l=1]',
                              'do you use instagram' => '__KAM_DRUG2_3,[l=1] __KAM_SURVEY3,[l=0] __KAM_VIAGRA7A,[l=1] __KAM_VIAGRA8A,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'administration team' => '__SYSADMIN,[l=1]',
                              'cia cia cia' => 'KAM_VIAGRA2,[l=0]',
                              'you receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'deine zukunft zerst' => '__DESTROY_YOU,[l=1] __DRUGS_PAIN2,[l=1]',
                              'waiting for your message' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CREDIT2,[l=1] __KAM_INSURE4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URONLINE2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'ve received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'admin team' => '__SYSADMIN,[l=1]',
                              'f#ckfriends' => '__DOS_BODY_FRI,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'pro pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'detective' => '__KAM_BACK3,[l=1]',
                              'bored this today' => '__DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_GIFT3,[l=1] __KAM_PIC1,[l=1] __KAM_SUNGLASSES3,[l=1] __THIS_AD,[l=1]',
                              'per. of men' => '__KAM_SEX1,[l=1]',
                              'government' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1]',
                              'making serious money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_GOOGLE3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_VISION3,[l=1]',
                              'earned from experience' => '__DAY_I_EARNED,[l=1] __KAM_UNIV3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'volume of your loads' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX4,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' total records' => '__FRAUD_JYG,[l=1] __KAM_LIST4,[l=1] __KAM_REFI6,[l=1]',
                              'can\'t see the images, continue' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1]',
                              'full proposal' => '__DEAL,[l=1] __KAM_DOMAIN2,[l=1] __KAM_SEARCH4,[l=1] __URG_BIZ,[l=1]',
                              'optimization' => '__KAM_SEARCH4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'drugstore accredi' => '__KAM_ANDROGEL3,[l=1] __KAM_DRUG2,[l=1] __KAM_REMEMBERWHEN3,[l=1] __STOCK_TIP,[l=1]',
                              'value' => '__KAM_TIMESHARE2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'i remember you' => '__KAM_REMEMBERWHEN2,[l=1] __KAM_URONLINE3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'banking institutions' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_RUIN3,[l=0]',
                              'competitive rewards' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GAS2,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_REP3_2,[l=1]',
                              'plans starting at' => '__KAM_HIRE3,[l=1] __KAM_INSURE2,[l=1]',
                              'complaints' => '__KAM_REP3_2,[l=1] __KAM_URUNIT3,[l=1]',
                              'n collection' => '__KAM_GALLERY2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'sweet chick' => '__KAM_GALLERY4,[l=1]',
                              ' million americans' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_COVID3_3,[l=1] __KAM_FUN5,[l=1] __KAM_PATRIOT3,[l=1]',
                              'benefits' => '__BACK_SCRATCH,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'you receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'via pro som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'stories' => '__KAM_ANCESTOR3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'you\'ve receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'offering better rates' => '__KAM_CAR3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_GIFT4,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1]',
                              'build your equity faster' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CHICKEN3,[l=1] __KAM_HOME2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'the truth' => 'KAM_TRUTHINESS,[l=1] __DEAL,[l=1] __KAM_BACK3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'lev cia cia' => 'KAM_VIAGRA2,[l=0]',
                              'upgrade of your account' => '__ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' shared with you' => '__KAM_DROPBOX3,[l=1] __KAM_UKINV3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lis' => '__KAM_VIAGRA9D,[l=1]',
                              'background check' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK1,[l=1] __KAM_BACK3,[l=1] __KAM_CREDIT2,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1] __LOTTO_WIN_01,[l=1]',
                              'microsoft promotion' => '__KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_SEO6,[l=1] __LOTTO_ADMITS_2,[l=1] __THIS_AD,[l=1]',
                              'heart rate monitor' => '__DOS_BODY_MON,[l=1] __KAM_DEATH4,[l=1] __KAM_INSURE4,[l=1] __KAM_SKIN4,[l=1]',
                              'guarantee!' => 'BANG_GUAR,[l=1]',
                              'bad girl' => 'BAD_CREDIT,[l=1] __KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1] __KAM_PIC4,[l=1]',
                              'mer amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              ' summ' => '__KAM_LASIK3,[l=1]',
                              'val amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'capsule' => '__PILL_PRICE_01,[l=1]',
                              'xan cia val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'som via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'raise your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'prevent a heart attack' => '__KAM_DEATH4,[l=1] __KAM_HEART3,[l=1] __KAM_HEARTPROD1,[l=1] __KAM_TOURS3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'documented program' => '__KAM_DETOX3,[l=1] __KAM_EBAY2,[l=0] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'browseour' => '__KAM_DRUG2_5,[l=1]',
                              'som cia lev' => 'KAM_VIAGRA2,[l=0]',
                              'make you thousands' => '__FRAUD_LTX,[l=1] __KAM_MEMBER3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __PUMPDUMP_04,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'schoolgirl slut' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'via val som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'fix file errors' => '__JMQ_RESUME3,[l=1] __KAM_SOFTWARE3,[l=0]',
                              'audience' => '__DEAL,[l=1] __KAM_ENGINEER2,[l=1]',
                              'afortunados' => '__KAM_PATRIOT3,[l=1] __LUCKY_WINNER,[l=1] __YOU_WON_02,[l=1]',
                              'unsubscribe from this advertisemetn' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_GIFT2,[l=1] __SUBSCRIPTION_INFO,[l=1] __THIS_AD,[l=1]',
                              'monumental marketing' => '__DOS_BODY_MON,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_STOCKTIP128,[l=1] __KAM_WEBINAR4,[l=1]',
                              'buena vista catalogue' => '__KAM_BADNAME1,[l=1]',
                              'medicinal effect' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MARIJUANA2,[l=1] __KAM_MED1,[l=1] __KAM_SEX04_1,[l=1]',
                              'mega girl' => '__KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1]',
                              'val lev lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'be welcomed with' => '__KAM_CHOSEN3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_REP3_2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'pro via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'smartlash' => '__KAM_FUN7,[l=1] __KAM_MASCARA3,[l=0]',
                              'vindicated' => '__KAM_PATRIOT3,[l=1]',
                              'shopping' => '__KAM_FINGERHUT3,[l=1] __KAM_FLAG3,[l=1] __KAM_GIFT3,[l=1] __KAM_MOTHER3,[l=1]',
                              'notice' => '__KAM_JURY4,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'this message was delivered to you by' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_SPAMKING5,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1]',
                              'direct telephone number' => '__HK_SCAM_N3,[l=1] __KAM_CELL3,[l=1] __KAM_DIRECT4,[l=1] __LOTTO_WIN_01,[l=1]',
                              ' tomorrow morning' => '__KAM_STOCK2_1,[l=1] __PUMPDUMP_03,[l=1]',
                              'you are receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pro val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'sement' => '__ADMITS_SPAM,[l=1]',
                              'file for your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_RESUME3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'via xan amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'freakypic' => '__JMQ_PICKUP2,[l=1]',
                              ' read' => '__KAM_PRODUCT2_2,[l=1]',
                              'prescription' => 'NO_PRESCRIPTION,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MARIJUANA3,[l=1]',
                              'colonmedic' => '__KAM_ANA1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              'better sex' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SUPERHUMAN3,[l=1]',
                              'extra weight' => 'DIET_1,[l=1] __KAM_GIFT3,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'private mail' => '__ADMAIL,[l=1] __FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __GAPPY_SALES_LEADS,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_URGENT3,[l=0] __YOU_WON_01,[l=1]',
                              'vioxx' => '__DRUGS_PAIN_VIOXX,[l=0]',
                              'contacts contain' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_3,[l=1]',
                              'pro mer lev' => 'KAM_VIAGRA2,[l=0]',
                              'val som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'vlja' => 'KAM_VIAGRA5,[l=1]',
                              'sinless' => '__KAM_SMOKE4,[l=1]',
                              'purchase from your web' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'changes' => '__KAM_ADVERT3,[l=1] __KAM_OILCHANGE3,[l=1]',
                              '% is made available to you' => '__DAY_I_EARNED,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mer val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'sent you this item' => '__DEAL,[l=1] __JMQ_WIRE3,[l=1] __KAM_KORS3,[l=0] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mer lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'lev xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'identity' => '__DECEASED,[l=1] __KAM_PHISH4_3,[l=1]',
                              'not bad bonus' => 'BAD_CREDIT,[l=1] __KAM_SEX04_4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'xan som pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'forward postal correspondence to' => '__DRUGS_ERECTILE5,[l=1] __FRAUD_MLY,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SPAMKING6,[l=1] __YOU_WON_02,[l=1]',
                              'tell me your mobile' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URONLINE3,[l=1] __KAM_WEB3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'number' => '__LOTTO_WIN_01,[l=1]',
                              'slice-o-matic' => '__KAM_PRODUCT2_2,[l=1] __KAM_SLICEOMATIC3,[l=0]',
                              'cia xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'to view this email as a webpage' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_AUTONEW3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_ENGINEER2,[l=1] __KAM_HEALTH2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'val val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'i was layed off from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'tired morning' => '__KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              ' friend request' => '__DOS_BODY_FRI,[l=1] __KAM_NOTIFY2,[l=1] __URG_BIZ,[l=1]',
                              'new vehicles near you' => '__KAM_AUTO3,[l=1] __KAM_CARDEAL3,[l=1] __KAM_HOME1,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'telegraph' => '__KAM_VIAGRA9A,[l=1] __WIRE_XFR,[l=1]',
                              'confirm' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_PHISH4_3,[l=1] __KAM_TAX4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'stop the ringing in your ears' => '__DEAL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TINNI2,[l=0] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'update required immediately' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_CREDIT3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __KAM_MED1,[l=1] __KAM_VERIZON4,[l=0] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'win great prizes' => '__KAM_KORS3,[l=0] __LOTTO_WIN_01,[l=1]',
                              'via amb cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'boost up your virility' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dear it' => 'DEAR_SOMETHING,[l=1]',
                              'my name is engr' => '__FRAUD_QXX,[l=1] __JMQ_RESUME2,[l=0] __KAM_HOWRU2,[l=0] __KAM_INVEST2,[l=1]',
                              'unit' => '__LOTTO_DEPT,[l=1]',
                              'recommends a stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEED4,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1]',
                              'advert' => '__KAM_ADVERTISE3,[l=1] __THIS_AD,[l=1]',
                              'western union' => '__KAM_FAKEWEST2,[l=0]',
                              'attempted' => '__KAM_PHISH4_2,[l=1]',
                              'level logo' => '__KAM_LOGO1,[l=1] __KAM_LOGO3,[l=1]',
                              'hair restoration' => '__KAM_HAIRTRANS3,[l=1] __KAM_SNORE3,[l=1] __STOCK_TIP,[l=1]',
                              'refund is not reversible' => '__KAM_HOME2,[l=1] __KAM_OCEANSBOUNTY3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'amb amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'dynamic response group' => '__KAM_STOCKTIP137,[l=1] __LOTTO_DEPT,[l=1] __URG_BIZ,[l=1]',
                              'recently' => '__KAM_AUTONEW3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1]',
                              'strong cash flow' => '__DOS_STRONG_CF,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_HOSE3,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'with email address' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_3,[l=1] __YOU_WON_01,[l=1]',
                              'testament' => '__WILL_LEGAL,[l=1]',
                              'low interest rate' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1]',
                              'get naked' => '__KAM_URONLINE3,[l=1]',
                              'piling bills' => '__KAM_DEBT1,[l=1]',
                              'update preferences' => '__KAM_FUN3,[l=1] __KAM_INSURE4,[l=1] __KAM_PHISH2_5,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'new discovery' => '__FRAUD_QFY,[l=1] __KAM_FUN6,[l=0] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_WEBINAR4,[l=1]',
                              'expiration alert' => '__PDS_EXPIRATION_NOTICE,[l=1]',
                              'our_mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'send me you photo' => '__KAM_PIC5,[l=0] __KAM_URONLINE1,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amb lev lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              '2nd ammendment' => '__KAM_2ND_2,[l=0] __KAM_COMPROMISED3,[l=1]',
                              'family asset' => '__KAM_INVEST2,[l=1]',
                              'view my profile' => '__JMQ_RESUME3,[l=1] __KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_PIC4,[l=1]',
                              'with your boner' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'earn ' => '__KAM_INVEST3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'foreign bank' => '__FRAUD_TCC,[l=0] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'keep company with you' => '__KAM_ALARM2,[l=1] __KAM_HOWRU2,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you are invited' => '__KAM_CHOSEN3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan mer som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'som amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'will' => '__I_WILL_YOU,[l=1] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'size' => 'BODY_ENHANCEMENT2,[l=1]',
                              'vanish some of your bills' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DEBT1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mer pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'member services mgm, llc' => '__KAM_COMPANY2_1,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'ascent your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lowest monthly payment' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DOS_BODY_MON,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CEP6,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1] __KAM_UNIV2,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'big data' => '__KAM_CLOUD3,[l=1]',
                              'full transcript' => '__KAM_UNIV14,[l=1]',
                              'l$>5bz8x9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'istance' => '__YOU_ASSIST,[l=1]',
                              'milestone' => '__KAM_INSURE2,[l=1] __STOCK_TIP,[l=1]',
                              'or still drained all the time' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT3A,[l=1] __KAM_URZEST2,[l=0]',
                              'xan via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'foreign business partner' => '__DEAL,[l=1] __FRAUD_MQO,[l=0] __FRAUD_TDP,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEB3,[l=1] __LOTTO_DEPT,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1] __YOU_WON_02,[l=1]',
                              'branded remedies' => '__DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'ukranian women' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_WIFE2,[l=1]',
                              'fraud' => '__FRAUD,[l=1]',
                              'som val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'factory sealed ipads' => '__KAM_SWIPE3,[l=1] __TRUNK_BOX,[l=1]',
                              'bad' => 'BAD_CREDIT,[l=1]',
                              'remove space in the above link' => '__DEAL,[l=1] __DOS_LINK,[l=1] __KAM_STAR1,[l=0] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'via cia lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'target audience' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1] __DEAL,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_4,[l=1]',
                              'amb som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'reply urgently' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __KAM_BADZIP3,[l=0] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __URG_BIZ,[l=1]',
                              'patriotism' => '__KAM_PATRIOT3,[l=1]',
                              'fund code' => '__KAM_DRUG2_5,[l=1] __KAM_NIGERIAN2_5,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'language in just ' => '__KAM_LANG3,[l=1]',
                              'sto' => '__STOCK_TIP,[l=1]',
                              'pro xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'honest individual' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1] __KAM_INVEST2,[l=1] __LUCKY_WINNER,[l=1]',
                              'need for bible' => '__KAM_JESUS2,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'via via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'high court' => '__KAM_NIGERIAN2_3,[l=1]',
                              'we have already paid ' => '__FEES,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'you\'ve received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no need for a doctor' => '__KAM_DRUG2_4,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'payment agent' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_BANK_2,[l=0] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'amb val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'som xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'compliments of the' => '__DEAL,[l=1] __FRAUD_IRT,[l=1] __KAM_REP3_2,[l=1]',
                              'completely unsecured' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_REFI6,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'google' => '__KAM_SEO4,[l=1]',
                              'no previous doctors direction' => '__KAM_DIRECT4,[l=1] __KAM_DRUG4,[l=1] __KAM_MARIJUANA3,[l=1]',
                              'banner' => '__KAM_DRAPES3,[l=1]',
                              'm 25' => '__DOS_I_AM_25,[l=1]',
                              'trust bank' => '__FRAUD_BEP,[l=1] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'home sites' => '__KAM_CRIM2_3,[l=1] __KAM_REAL2_4,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'certain funds' => '__KAM_BENEFICIARY3,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              ' to your mail' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __MAIL_ACCT_ACCESS2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'click' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1]',
                              'glutting' => '__KAM_WEIGHT1,[l=1]',
                              'banking laws' => 'BANKING_LAWS,[l=0] __JMQ_WIRE3,[l=1] __KAM_DEBT1,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'listed for auction' => '__KAM_DOMAIN2,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA9D,[l=1] __YOU_WON_02,[l=1]',
                              'val som cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'medicare' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_MEDICARE3,[l=1] __KAM_VISION3,[l=1]',
                              'obtain your diploma' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX4,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV12,[l=1] __KAM_UNIV6B,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'world famous poet' => '__KAM_WRITING3,[l=0]',
                              'xan val pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'smart' => '__KAM_FUN7,[l=1]',
                              'rightful dep' => '__KAM_DETOX3,[l=1] __KAM_INQUIRY_3,[l=0] __KAM_PATRIOT3,[l=1]',
                              'charit' => '__CHARITY,[l=1]',
                              'xan lev amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'breaking news' => '__KAM_BLOOD3,[l=1] __KAM_COMPROMISED4,[l=1]',
                              'pay you the sum of' => '__DEAL,[l=1] __FEES,[l=1] __HK_SCAM_S1,[l=0] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'herede' => '__NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1]',
                              'copy and paste this link into your internet browser' => '__DEAL,[l=1] __DECEASED,[l=1] __DOS_LINK,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CLICK,[l=0] __KAM_INSURE4,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'latest updates' => '__DECEASED,[l=1] __KAM_CELL3,[l=1] __KAM_INSURE4,[l=1] __KAM_KORS3,[l=0] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'looking for a man' => '__JMQ_REALESTATE3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_URONLINE2,[l=1] __KAM_URONLINE3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'no monthly fee' => '__DOS_BODY_MON,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CEP6,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TV2,[l=1] __KAM_UNIV2,[l=1]',
                              'text me asap' => '__KAM_PIC3,[l=1]',
                              'adderrx' => '__KAM_DRUG2_6,[l=1]',
                              'quintupling your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'retrieve your ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'val val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'quemar' => '__DESTROY_ME,[l=1]',
                              'want to watch video' => '__KAM_PIC4,[l=1] __KAM_TIME4,[l=1]',
                              'have so much meat' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_SEX05_2,[l=0] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'contacte' => '__CONTACT_ATTY,[l=1] __CONTACT_YOU,[l=1] __FRAUD_JYG,[l=1]',
                              'be handed' => '__RECEIVE_BONUS,[l=1]',
                              'growth' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_CAREER2,[l=1]',
                              'incoming fax' => '__KAM_FAKE_FAX2,[l=0] __KAM_REP3_2,[l=1]',
                              'can\'t read or see this email' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_PRODUCT2_2,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'rebuild' => '__KAM_CHICKEN3,[l=1] __KAM_SKIN4,[l=1]',
                              'i am lonely and tired' => '__KAM_COMPROMISED3,[l=1] __KAM_SNORE3,[l=1] __KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1]',
                              'mer som pro' => 'KAM_VIAGRA2,[l=0]',
                              'via amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              ' that you no longer wish to receive messages' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __ADMAIL,[l=1] __KAM_PACKAGE2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_SPAMKING4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'generic' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'follow this link:' => '__DEAL,[l=1] __DOS_LINK,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CARD3,[l=1] __KAM_FRIEND2,[l=1] __THIS_AD,[l=1]',
                              'xxx gay' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'pro cia pro' => 'KAM_VIAGRA2,[l=0]',
                              'i found an amazing site' => '__FOUND_YOU,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_COMPROMISED4,[l=1] __KAM_STOCK2_2,[l=1]',
                              'covid-19 charity donated relief' => '__CHARITY,[l=1] __KAM_COVID2_1,[l=0] __KAM_DRUG2_3,[l=1]',
                              'discuss further' => '__DEAL,[l=1] __KAM_INVEST3,[l=1]',
                              'certified' => '__KAM_NURSE3,[l=1] __KAM_WEB2,[l=1] __KAM_WEBINAR4,[l=1] __TRUSTED_CHECK,[l=1]',
                              'som via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'you are received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'acaiburn' => 'DIET_1,[l=1] __KAM_ANA1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'clean up your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DETOX3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cholestapro' => '__KAM_ANA1,[l=1]',
                              'share counts and samples' => '__KAM_LISTSALE3,[l=0] __KAM_WEB2_4,[l=0]',
                              ' mask' => '__KAM_LABEL8,[l=1]',
                              'feet feel smooth and healthy' => '__KAM_JOINT3,[l=1] __KAM_SKIN4,[l=1]',
                              'bored this morning' => '__DEAL,[l=1] __KAM_PIC1,[l=1] __KAM_STOCK2_1,[l=1] __THIS_AD,[l=1]',
                              'you receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'job search directory' => '__KAM_DIRECT4,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REVIEW3,[l=1]',
                              'operation' => '__FRAUD_XWW,[l=1]',
                              'net' => '__KAM_REP3_2,[l=1]',
                              'promotion date' => '__KAM_LOTTO2,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'xan amb mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'pro som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'return' => '__KAM_POLITICS2,[l=1]',
                              'mittel' => '__SUM_OF_FUND,[l=1]',
                              'love instrument' => '__KAM_SEX1,[l=1]',
                              'inherit' => '__KAM_BENEFICIARY3,[l=1] __NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1] __YOU_INHERIT,[l=1]',
                              'mer cia val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' net' => '__FOR_SALE_NET,[l=1] __KAM_REP3_2,[l=1]',
                              'hearing date' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_JURY4,[l=1]',
                              'get you back on the right financial' => '__DEAL,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BITCOIN2,[l=1] __KAM_DETOX3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PATRIOT4,[l=1] __KAM_REFI6,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cxartier' => '__KAM_TIME6,[l=0]',
                              'amb xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'wish to receive future messages' => '__ADMAIL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'cette' => '__DEAL,[l=1]',
                              'coverage' => '__FRAUD_QFY,[l=1] __KAM_AUTONEW2,[l=1] __KAM_INSURE2,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1]',
                              'som mer pro' => 'KAM_VIAGRA2,[l=0]',
                              'big penis' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX1,[l=1]',
                              '\'s hottest ' => '__KAM_CELL3,[l=1] __KAM_WEIGHT2,[l=1]',
                              'amb via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'be smart, buy your medications' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_FUN7,[l=1] __KAM_INSURE4,[l=1] __KAM_MED1,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'naughtypix' => '__JMQ_PICKUP2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'expiration notice' => '__KAM_JURY4,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_STOCK2_2,[l=1] __PDS_EXPIRATION_NOTICE,[l=1]',
                              'triple an principal' => '__PUMPDUMP_01,[l=1]',
                              'inheri' => '__YOU_INHERIT,[l=1]',
                              'amb mer mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'v i a g r a' => 'KAM_VIAGRA5,[l=1] __KAM_VIAGRA1,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'info' => '__KAM_REP3_2,[l=1]',
                              'veuve' => '__WIDOW,[l=1]',
                              'via som som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'airfare' => '__KAM_OPRAH1,[l=0]',
                              'provides can-spam compliant email' => 'KAM_CANSPAM,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CREDIT3,[l=1] __KAM_ENGINEER2,[l=1] __KAM_REP3_2,[l=1] __YOU_WON_01,[l=1]',
                              'tax relief' => '__KAM_DRUG2_3,[l=1] __KAM_TAX3,[l=1]',
                              'cheap ipads' => '__KAM_SWIPE3,[l=1]',
                              'pro xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'administrator' => '__SYSADMIN,[l=1]',
                              'similar' => '__KAM_DOMAIN2,[l=1]',
                              'we are not spammers' => 'KAM_ADVERT2,[l=1] NOT_SPAM,[l=1] __KAM_LIST3_4,[l=1]',
                              'amb som cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'swipe auction' => '__KAM_SWIPE4,[l=1]',
                              'processing rebates at home' => '__FEES,[l=1] __KAM_CLAIMS3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1] __LOTTO_DEPT,[l=1]',
                              'alaska' => '__KAM_VACATION3,[l=1]',
                              'via via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'clean up any inacccuracies' => '__KAM_REFI2,[l=1]',
                              'pgne' => '__KAM_STOCKTIP136,[l=1]',
                              'pro lev mer' => 'KAM_VIAGRA2,[l=0]',
                              'personalized letter' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_SANTA3,[l=1]',
                              'dmnm' => '__KAM_STOCKTIP135,[l=1]',
                              'unmatched' => '__KAM_DRUG2_4,[l=1]',
                              'vagira' => '__DRUGS_ERECTILE2,[l=1]',
                              'going out of your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_HOME1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'promotional sweepstake' => '__HK_LOTTO_BALLOT,[l=1] __KAM_GIFT5,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'some pictures of me' => '__KAM_PIC4,[l=1] __KAM_PIC5,[l=0]',
                              'som som som' => 'KAM_VIAGRA2,[l=0]',
                              'losing your ' => 'DIET_1,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_TRACKR3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PDS_SEO2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'marketing lists' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WEBINAR4,[l=1]',
                              'nation' => '__KAM_PATRIOT3,[l=1]',
                              'amb val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'this is a commercial' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_RECALL3,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'lottery international' => '__AFF_LOTTERY,[l=0] __FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_LOTTO2,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'mutual friend' => '__DEAL,[l=1] __DOS_BODY_FRI,[l=1] __KAM_URONLINE2,[l=1]',
                              ' bank member' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0] __TVD_PH_BODY_06,[l=1]',
                              'via mer pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'contacts consist' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_3,[l=1]',
                              'security firm' => '__FEES,[l=1] __FRAUD_IRJ,[l=0] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __TRUNK_BOX,[l=1]',
                              'premium cigar' => '__KAM_AUTONEW2,[l=1] __KAM_AUTONEW3,[l=1] __KAM_CIGAR3,[l=0] __KAM_MEDICARE4,[l=1]',
                              'pr promotion' => '__KAM_LOTTO4,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'money left' => '__DORMANT_ACCT,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_BITCOIN2,[l=1]',
                              'personalized ornament' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_HOLIDAY2020_2,[l=0]',
                              'established individual' => 'BAD_CREDIT,[l=1] __KAM_INVEST2,[l=1] __KAM_VIAGRA9D,[l=1] __LUCKY_WINNER,[l=1]',
                              'processor' => '__KAM_MERCHANT2,[l=1]',
                              'pro amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'viaegra' => 'VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE2,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'zebutal' => '__DRUGS_PAIN11,[l=1]',
                              'alcohol dependenc' => '__KAM_REHAB3,[l=0]',
                              'cute lady' => '__KAM_PIC2,[l=1]',
                              'developers' => '__KAM_REAL2_5,[l=0]',
                              'list' => '__KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'download yourpending ' => '__DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'val xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'receive your gift' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_GIVE1,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'first letter' => '__KAM_STOCKOBFU2,[l=0]',
                              'white' => '__KAM_SEARCH4,[l=1]',
                              'government shutdown' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1]',
                              'skincell' => '__KAM_SKINCELL1,[l=1]',
                              'transactions from your web' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'targeted' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1] __KAM_DOMAIN2,[l=1] __KAM_SEO3,[l=1]',
                              'permanent' => '__KAM_HERPES3,[l=1]',
                              'make money while you shop' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_MOTHER3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_SHOP3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'promotional draw' => '__HK_LOTTO_BALLOT,[l=1] __KAM_GIFT5,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __LOTTO_WIN_01,[l=1] __THIS_AD,[l=1]',
                              'cannabis' => '__KAM_MARIJUANA1,[l=0] __KAM_MARIJUANA2,[l=1]',
                              'xan pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'buy for ' => '__KAM_PATRIOT3,[l=1] __PUMPDUMP_07,[l=1] __YOU_WON_02,[l=1]',
                              'pricester' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_STOCKTIP130,[l=1]',
                              'you\'re receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'val via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'alcohol rehab' => '__KAM_REHAB3,[l=0]',
                              'mer via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'boost your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'unsubscribe from lunarmessages' => '__ADMAIL,[l=1] __KAM_BADUNSUB,[l=0] __KAM_LUNAR4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'prefer not to receive future messages' => '__ADMAIL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'free porn' => 'FREE_PORN,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'results in thirty day' => '__DAY_I_EARNED,[l=1] __KAM_SEO5,[l=1]',
                              'quality' => '__KAM_DRUG1,[l=1]',
                              'beneficial' => '__BACK_SCRATCH,[l=1] __KAM_NIGERIAN4,[l=1]',
                              'lotto' => '__HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'professional lead' => '__KAM_GARAGE3,[l=1] __KAM_LIST3_2,[l=1]',
                              'oil company' => '__DRUGS_ERECTILE5,[l=1] __KAM_DRILL2,[l=0] __KAM_INVEST4,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'val mer mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'xps for ' => '__KAM_PATRIOT3,[l=1] __KAM_SWIPE3,[l=1] __YOU_WON_02,[l=1]',
                              'cycl' => '__DRUGS_MUSCLE2,[l=1]',
                              'mer mer som' => 'KAM_VIAGRA2,[l=0]',
                              'seek your partnership' => '__DEAL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'malta' => '__KAM_INVEST4,[l=1]',
                              'send you more information' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_BANK,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'donation' => '__KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_PATRIOT3,[l=1]',
                              'activat' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'rank well on ' => '__PDS_SEO2,[l=1]',
                              ' ticket agent' => '__KAM_BANK_2,[l=0] __LOTTO_AGENT_02,[l=1]',
                              'tired evening' => '__KAM_PIC1,[l=1] __KAM_SNORE3,[l=1]',
                              'xtrasize+' => 'BODY_ENHANCEMENT2,[l=1] __KAM_SILD2,[l=0]',
                              'your subscription' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'confirmation #' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_CREDIT2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_TAX4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'meet each other' => '__DEAL,[l=1] __DOS_MEET_EACH_OTHER,[l=1] __PILL_PRICE_01,[l=1]',
                              'this email is not unsolicited' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'cheque' => '__KAM_NIGERIAN2_5,[l=1] __LOTTO_WIN_01,[l=1]',
                              'water hack' => '__KAM_WATERHACK2,[l=0]',
                              'available for auction' => '__KAM_DOMAIN2,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __YOU_WON_02,[l=1]',
                              'download for no cost' => '__DLND_ATTACH,[l=1] __FB_COST,[l=1] __KAM_CREDIT3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SOFTWARE4,[l=0] __YOU_WON_02,[l=1]',
                              'no thanks' => 'REMOVE_BEFORE_LINK,[l=1]',
                              'buy as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'torn down to build' => '__KAM_CHICKEN3,[l=1] __KAM_LOAN3,[l=1] __KAM_REAL2_2,[l=1]',
                              'lower' => '__KAM_REFI3,[l=1]',
                              'wed' => '__DOS_BODY_WED,[l=1]',
                              'mer som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'quintuple your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'angered plastic surge' => '__KAM_SKIN4,[l=1]',
                              'send more details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_HOME3,[l=1] __KAM_INVEST3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __LOTTO_WIN_01,[l=1]',
                              'prince' => '__KAM_COVID3_1,[l=0]',
                              'reasonable interest rate' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1]',
                              'pro cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'xan' => '__DRUGS_ANXIETY_XAN,[l=1]',
                              'found you on this site' => '__DEAL,[l=1] __FOUND_YOU,[l=1] __KAM_PIC1,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'vega promotional sys' => '__KAM_GIFT5,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __KAM_STOCKTIP124,[l=1] __THIS_AD,[l=1]',
                              'campaign' => '__KAM_POLITICS2,[l=1]',
                              'extraordinary' => 'DIET_1,[l=1] __KAM_CAREER3,[l=1] __KAM_GIFT3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'message is from a ' => '__ADMAIL,[l=1] __KAM_FAKE_TRUST1,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'hospital' => '__KAM_LIST2,[l=1]',
                              'investigate backgrounds' => '__INVEST_MONEY,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK1,[l=1] __KAM_BACK3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'ask your name' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOWRU2,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'head of human resources' => '__KAM_NIGERIAN1,[l=1] __KAM_TRAINING3,[l=0]',
                              'nursing home list' => '__KAM_LIST1,[l=1] __KAM_LIST4,[l=1] __KAM_NURSE3,[l=1] __KAM_REFI3,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WINDOWS3,[l=1]',
                              'med' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              '-image click' => 'KAM_ADVERT2,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1]',
                              'increase your spending' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] MORE_SEX,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEBINAR4,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'person that handles the promotions' => '__DEAL,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __KAM_USB2,[l=0] __KAM_WEBINAR4,[l=1] __THIS_AD,[l=1]',
                              'you\'ve receive this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'meet at your office' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_LABEL2,[l=0] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'buy at ' => '__KAM_DRUG2_5,[l=1]',
                              'times an principle' => '__KAM_LOAN3,[l=1] __KAM_TIME4,[l=1] __PUMPDUMP_01,[l=1]',
                              'can help' => '__CAN_HELP,[l=1] __KAM_CREDIT2,[l=1] __KAM_TAX3,[l=1] __SYSADMIN,[l=1]',
                              'penntransportation' => '__KAM_POLITICS2,[l=1]',
                              'or still exasperated all the time' => '__DEAL,[l=1] __KAM_INSURE4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT3A,[l=1] __KAM_URZEST2,[l=0]',
                              'pro quality pic' => '__KAM_DRUG1,[l=1] __KAM_LENS1,[l=0]',
                              'i was dismissed from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'amb pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'cash out quickly' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_TIMESHARE1,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'fda recall' => '__KAM_FDA3,[l=0] __KAM_SEX_EXPLICIT4,[l=1]',
                              'talking about my blog' => '__KAM_BACK3,[l=1] __KAM_RICH3,[l=0]',
                              'research' => '__KAM_REVIEW3,[l=1] __KAM_SKIN4,[l=1]',
                              'letter from santa' => '__KAM_SANTA2,[l=0]',
                              'fox news' => '__KAM_TAX4,[l=1]',
                              'this message is an ad' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __THIS_AD,[l=1]',
                              'dear investor' => 'DEAR_SOMETHING,[l=1] __INVEST_MONEY,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_STOCK2_4,[l=0] __STOCK_TIP,[l=1]',
                              'forgiveness' => '__FRAUD_JYG,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __YOU_WON_02,[l=1]',
                              'contact record' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_4,[l=1]',
                              'delivering' => '__KAM_FAKEDELIVER1,[l=1]',
                              'photos of 50+' => '__KAM_MEMBER3,[l=1] __KAM_PIC5,[l=0]',
                              'you\'ve receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'only chance' => '__KAM_PATRIOT3,[l=1]',
                              'discontinue from this promotion' => '__DEAL,[l=1] __KAM_GRANT3,[l=0] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'inct' => '__KAM_STOCKTIP166,[l=1]',
                              'double there money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SEX1,[l=1] __KAM_WEED3,[l=0] __KAM_WINDOWS3,[l=1]',
                              'lost' => 'DIET_1,[l=1]',
                              'nearest airport' => '__KAM_BENEFICIARY3,[l=1] __KAM_HOME1,[l=1] __KAM_SNORE3,[l=1]',
                              'your p' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'improve your website traffice' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEARCH4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'low-interest refinance' => 'REFINANCE_NOW,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1]',
                              'diploma that you want' => '__KAM_UNIV12,[l=1] __KAM_UNIV6B,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'refinance your home' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pricing and further' => '__DEAL,[l=1] __KAM_LIST3_3,[l=1]',
                              'investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __SUM_OF_FUND,[l=1]',
                              'secure the fund' => '__DEAL,[l=1] __FRAUD_WFC,[l=1] __KAM_DOMAIN2,[l=1] __SUM_OF_FUND,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1]',
                              'stimulate your metabolism' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WEIGHT1,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'laywers database' => '__KAM_BACK3,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1]',
                              'day' => '__DAY_I_EARNED,[l=1]',
                              'hassle' => '__KAM_DRUG2_5,[l=1]',
                              'som mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'steady course' => '__DOS_STEADY_COURSE,[l=1]',
                              'gevalia kaffe' => '__KAM_GEVALIA1,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' homeowners' => '__KAM_REFI2,[l=1] __KAM_REFI3,[l=1] __KAM_REFI6,[l=1] __KAM_WINDOWS3,[l=1]',
                              'adoring asian' => '__KAM_ASIAN2,[l=0]',
                              'dirty truth' => '__KAM_ARREST2,[l=1] __KAM_BACK3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'online from home' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_GOOGLE2,[l=0] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'no required tests' => '__KAM_UNIV15,[l=1]',
                              'cheaper' => '__KAM_DRUG2,[l=1]',
                              'microsoft' => '__LOTTO_ADMITS_2,[l=1]',
                              'clinically tested' => '__KAM_DRUG2_6,[l=1] __KAM_SEX1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TVDOCTOR3,[l=1]',
                              'wks it has been since we have chatted' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_URZEST4,[l=0] __YOU_WON_01,[l=1]',
                              'cougar' => '__KAM_MEMBER3,[l=1]',
                              'qualified lead' => '__KAM_LIST3_2,[l=1]',
                              'prevent corona' => '__KAM_KN_2,[l=0] __KAM_TOURS3,[l=1]',
                              'libyan' => '__KAM_BENEFICIARY4,[l=0]',
                              'canadian dolla' => 'NA_DOLLARS,[l=1]',
                              'completely legal activity' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEED1,[l=1]',
                              'to your organi' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TO_YOUR_ORG,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '% for' => '__KAM_NIGERIAN3,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'mail account' => '__ADMAIL,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __WEBMAIL_ACCT,[l=1] __YOU_WON_01,[l=1]',
                              'oversea account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_N15,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI2,[l=1]',
                              'cia cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'limited access' => '__KAM_QUOTA2,[l=1] __KAM_TRIAL,[l=1]',
                              'fingerhut' => '__KAM_DRUG2_4,[l=1] __KAM_FINGERHUT3,[l=1]',
                              'behalf' => '__OUR_BEHALF,[l=1]',
                              'asset & background investigation' => '__INVEST_MONEY,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK1,[l=1] __KAM_BACK2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'excitement with girls' => '__KAM_PIC2,[l=1] __KAM_SEX1,[l=1]',
                              'positive work environment' => '__KAM_CAREER3,[l=1] __KAM_TELEWORK3,[l=1]',
                              'rapist' => '__KAM_ARREST2,[l=1]',
                              'cia via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'exit future communications' => '__KAM_GIFT2,[l=1] __KAM_REP3_2,[l=1]',
                              'you have received this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'generic viagra' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] DRUG_ED_GENERIC,[l=1] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE_V,[l=1] __KAM_DRUG2_3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA7A,[l=1] __KAM_VIAGRA8A,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'be thrifty, buy your drugs' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_INSURE4,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'buy today' => '__DAY_I_EARNED,[l=1] __KAM_DRILL4,[l=0] __KAM_DRUG2_5,[l=1] __KAM_GIFT3,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'bestrxlight' => '__KAM_DRUG2_5,[l=1] __KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'lev via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              ' contact' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1]',
                              'can name me' => '__KAM_PIC1,[l=1]',
                              ' bank customer' => '__JMQ_WIRE3,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_PHISH4_2,[l=1] __STOCK_TIP,[l=1] __TVD_PH_BODY_06,[l=1]',
                              'hoping to get into shape' => '__KAM_URZEST3,[l=0]',
                              'e me at' => '__DOS_WRITE_ME_AT,[l=1]',
                              'via mer xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              ' boost' => '__KAM_FUN7,[l=1]',
                              'sichere ' => '__FRAUD_XWW,[l=1] __KAM_CRYPTO1,[l=1]',
                              'unexpected luck' => '__hk_win_8,[l=1]',
                              'professional' => '__KAM_GARAGE3,[l=1]',
                              'vm meant' => '__KAM_VM3,[l=1]',
                              'asian bride' => '__KAM_AUTO3,[l=1] __KAM_WIFE2,[l=1]',
                              'tupperware lid' => '__KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_TUPPERWARE3,[l=0]',
                              'vista del mar productions' => '__KAM_BADNAME1,[l=1]',
                              'advertise with identity network' => 'KAM_ADVERT2,[l=1] __DECEASED,[l=1] __FOR_SALE_NET,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_CAREER3,[l=1] __KAM_IDENTNET2,[l=0] __KAM_PHISH4_3,[l=1] __KAM_REP3_2,[l=1] __THIS_AD,[l=1]',
                              'blog promotion' => '__KAM_LOTTO4,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'lev cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'going out of home' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1] __STAY_HOME,[l=1]',
                              'complete' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1]',
                              'can\'t see this image' => '__DEAL,[l=1] __KAM_FUN3,[l=1] __THIS_AD,[l=1]',
                              'increase' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] MORE_SEX,[l=1] __KAM_DOMAIN1,[l=1] __KAM_WEBINAR4,[l=1]',
                              'shore account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'mikhail fridman' => '__DOS_BODY_FRI,[l=1] __KAM_BENEFICIARY3_1,[l=0]',
                              'lev mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'management solution' => '__KAM_CLOUD3,[l=1] __KAM_CONTRACT3,[l=0] __KAM_LOAN3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'interested' => 'KAM_ADVERT2,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SNORE3,[l=1]',
                              'horny' => '__KAM_PRIV1,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __KAM_URONLINE3,[l=1]',
                              'respirator ' => '__KAM_KN_1,[l=1]',
                              'no tar' => '__KAM_SMOKE4,[l=1]',
                              'companies' => '__KAM_BLOOD4,[l=1] __KAM_REP3_2,[l=1]',
                              'i would really like to know you' => '__KAM_DATINGTIPS3,[l=1] __KAM_LED2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' masks' => '__KAM_LABEL4,[l=1] __KAM_LABEL8,[l=1]',
                              'list contain' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'continue in your secure web browser' => 'KAM_ADVERT2,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'curative effect' => '__KAM_SEX04_1,[l=1]',
                              'longer your tool' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_PACKAGE2,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'avoid double claiming' => '__DBLCLAIM,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEX1,[l=1] __KAM_WINDOWS3,[l=1] __LOTTO_DEPT,[l=1]',
                              '$1,000 a day atm' => '__DAY_I_EARNED,[l=1] __KAM_DON4,[l=0] __KAM_FAKEWEST5,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'specialize' => '__KAM_CAD2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1]',
                              'i was let go from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'to regain access' => '__ACCESS_RESTORE,[l=1]',
                              'val pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'multiple password failures' => '__KAM_PHISH4_3,[l=1] __TVD_PH_BODY_08,[l=1]',
                              'final day of the bonus offer' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'delight' => '__KAM_MOTHER3,[l=1] __KAM_REFI2,[l=1]',
                              'yoshiblade' => '__KAM_SHARP2,[l=0]',
                              'no examination' => '__KAM_INSURE2,[l=1] __KAM_PATRIOT3,[l=1]',
                              'secure fund' => '__FRAUD_WFC,[l=1] __KAM_DOMAIN2,[l=1] __SUM_OF_FUND,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1]',
                              'nerve pain' => '__KAM_FUN7,[l=1]',
                              'beat' => '__KAM_DIABETES2,[l=1]',
                              'wish to not receive these messages' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'untitled' => '__KAM_GOOGLEFORM_2,[l=0]',
                              'cia mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'european' => '__KAM_COVID5,[l=1] __KAM_INVEST4,[l=1]',
                              'financial troubles is forgiven' => '__DEAL,[l=1] __FRAUD_JYG,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PATRIOT4,[l=1] __KAM_REP3_2,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_STUDENTLOAN5,[l=0] __YOU_WON_02,[l=1]',
                              'xan pro pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'txiffany' => '__KAM_TIME6,[l=0]',
                              'get as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              'www(dot)domainregistryasia(dot)net' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKE_REGISTRY1,[l=0] __KAM_REP2,[l=1] __KAM_REP3_2,[l=1]',
                              'silent partner' => '__FRAUD_TDP,[l=1]',
                              'replacement' => '__JMQ_REALESTATE3,[l=1] __KAM_CAREER2,[l=1] __KAM_WINDOWS3,[l=1]',
                              'erectile dysfunction' => 'IMPOTENCE,[l=1] __KAM_PACKAGE1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'survival' => '__KAM_PATRIOT3,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              's too late' => '__DECEASED,[l=1] __KAM_DEATH3,[l=1]',
                              'kopieren sie es und f\\374gen sie es ein' => '__COPY_PASTE_DE,[l=0]',
                              'wish not to receive future messages' => '__ADMAIL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'ticket number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'quintupling an principle' => '__KAM_RBL_OBFU2,[l=1] __PUMPDUMP_01,[l=1]',
                              'xan pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'satisfaction effect' => '__DOS_BODY_SAT,[l=1] __KAM_SEX04_1,[l=1]',
                              'online pharmacy' => 'FREE_QUOTE_INSTANT,[l=1] ONLINE_PHARMACY,[l=1] TVD_VISIT_PHARMA,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1]',
                              'charge' => '__FEES,[l=1] __KAM_BACKUP3,[l=1]',
                              'som amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'by superclub' => '__KAM_BADNAME1,[l=1]',
                              'lucky number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1] __LUCKY_WINNER,[l=1]',
                              'fat burn' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'age is 25' => '__KAM_PIC2,[l=1]',
                              'obama' => '__KAM_INSURE2,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI3,[l=1]',
                              'international corporation' => '__DRUGS_ERECTILE5,[l=1] __HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'marketing manager' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'found ur profile' => '__FOUND_YOU,[l=1] __JMQ_RESUME3,[l=1] __KAM_PHISH4_3,[l=1] __KAM_URONLINE2,[l=1]',
                              'multiply an principle' => '__PUMPDUMP_01,[l=1]',
                              'order today' => '__DAY_I_EARNED,[l=1] __KAM_BADZIP3,[l=0] __KAM_DRUG2_5,[l=1] __KAM_GIFT3,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'cia som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'courier was unable to deliver' => '__COURIER,[l=1] __FEES,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_NIGERIAN2_8,[l=1]',
                              'ebay success' => '__KAM_EBAY1,[l=0]',
                              'dead end job' => '__KAM_UNIV3B,[l=1]',
                              'mer pro cia' => 'KAM_VIAGRA2,[l=0]',
                              'just type' => '__KAM_REP2_1,[l=1]',
                              'view' => '__KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1]',
                              'incredible chick' => '__KAM_GALLERY4,[l=1]',
                              '\\33$b' => '__ISO_2022_JP_DELIM,[l=1]',
                              'you have been invited' => '__KAM_CHOSEN3,[l=1] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fully qualified' => '__KAM_TELEWORK4,[l=1]',
                              'requirements' => '__KAM_REFI5,[l=1]',
                              'lev som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'upcoming' => '__KAM_REP3_2,[l=1] __KAM_WEBINAR4,[l=1]',
                              'to see my pic' => '__KAM_PIC4,[l=1]',
                              'grows' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_HOSE3,[l=1]',
                              'live ' => 'LIVE_PORN,[l=1]',
                              'purchases from your web' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'records' => '__KAM_REFI6,[l=1]',
                              'val pro pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'end these weekly ad-messages' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __KAM_CEP6,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'mountain' => '__KAM_REAL2_1,[l=1]',
                              'release' => '__SUM_OF_FUND,[l=1]',
                              'you receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bored this tonight' => '__DEAL,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_PIC1,[l=1] __THIS_AD,[l=1]',
                              'gorvernment not telling' => '__KAM_PATRIOT3,[l=1]',
                              'www' => '__KAM_REP2,[l=1]',
                              'attack' => '__KAM_DEATH4,[l=1] __KAM_HEARTPROD1,[l=1]',
                              'profession women' => '__KAM_HONOR3,[l=0] __KAM_SEX_EXPLICIT4,[l=1]',
                              'dog behavior' => '__KAM_BARK1,[l=1]',
                              '5k per month' => '__DOS_BODY_MON,[l=1] __KAM_CEP6,[l=1] __KAM_SKIN4,[l=1] __KAM_TELEWORK1,[l=1] __KAM_UNIV2,[l=1]',
                              '% after' => '__LARGE_PERCENT_AFTER,[l=1]',
                              'roofing' => '__KAM_REPAIR2_3,[l=1]',
                              'lev cia pro' => 'KAM_VIAGRA2,[l=0]',
                              ' million' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COVID3_3,[l=1]',
                              'b=e9nin' => '__BENIN,[l=1]',
                              'amb val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'blue pill' => '__KAM_SEX04_1,[l=1] __PILL_PRICE_01,[l=1]',
                              'contacts include' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_3,[l=1]',
                              'in court' => '__KAM_JURY4,[l=1]',
                              'untimely' => '__EARLY_DEMISE,[l=1] __KAM_TIME4,[l=1]',
                              'night' => '__KAM_DATINGTIPS3,[l=1]',
                              'lucky nl number' => '__LOTTO_WIN_01,[l=1] __LUCKY_WINNER,[l=1] __hk_win_9,[l=1]',
                              'visited' => '__KAM_SEO3,[l=1]',
                              'send me your photo' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC5,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URONLINE1,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'visibility' => '__KAM_DOMAIN3,[l=1]',
                              'pricing, counts' => '__KAM_LIST3_3,[l=1]',
                              'new cele' => '__KAM_GALLERY4,[l=1]',
                              'pre-screened housekeepers' => '__KAM_ALARM2,[l=1] __KAM_MAID3,[l=1]',
                              'via pro mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'concerned' => '__KAM_PATRIOT3,[l=1]',
                              'this email is a commercial' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_RECALL3,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'hoist your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'yearly' => '__JMQ_PICKUP4,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'get free quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_ALARM2,[l=1] __KAM_INSURE2,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'mail ballot' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_BALLOT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __YOU_WON_01,[l=1]',
                              'help for alcoholism' => '__KAM_CREDIT2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REHAB3,[l=0] __KAM_TAX3,[l=1] __KAM_VIAGRA9D,[l=1] __SYSADMIN,[l=1] __YOU_WON_02,[l=1]',
                              'wish not to receive these emails' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'hoping to get fit' => '__KAM_URZEST3,[l=0]',
                              'lead specialist' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_VISION3,[l=1]',
                              'rivotril' => '__DRUGS_ANXIETY9,[l=1]',
                              'burn calories' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'extraordinary chicks' => 'DIET_1,[l=1] __KAM_CAREER3,[l=1] __KAM_GALLERY4,[l=1] __KAM_GIFT3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'www(dot)domainregistryasia.net' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKE_REGISTRY1,[l=0] __KAM_REP2,[l=1] __KAM_REP3_2,[l=1]',
                              'kitchen' => '__KAM_KITCHEN3,[l=1]',
                              'nigerian national' => '__FRAUD_YQV,[l=0] __HK_LOTTO_2,[l=1] __KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __NIGERIA,[l=1]',
                              'lt passwords' => '__KAM_GALLERY2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'planners database' => '__KAM_BACK3,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1]',
                              'senior auditor' => '__KAM_NIGERIAN1,[l=1]',
                              'cia cia pro' => 'KAM_VIAGRA2,[l=0]',
                              'amb' => '__KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'admin center' => '__KAM_GIFT4,[l=1] __KAM_SWIPE4,[l=1] __SYSADMIN,[l=1]',
                              'snap up as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'administration center' => '__KAM_GIFT4,[l=1] __KAM_SWIPE4,[l=1] __SYSADMIN,[l=1]',
                              'good credit or not' => 'BAD_CREDIT,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'cia amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'write me tomorrow' => '__KAM_HOWRU3,[l=0]',
                              'through' => '__FRAUD_MLY,[l=1]',
                              'extra cash' => 'DIET_1,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT3,[l=1] __KAM_GOOGLE3,[l=1] __KAM_TIMESHARE2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'c-o-c-k' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'your bank account information' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VERIZON7,[l=0] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_BANK,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'retrieve yourunreceived ' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'find' => '__JMQ_TRACKR3,[l=1] __KAM_NEW_CREDITCARD3,[l=1]',
                              'managing expectations' => '__KAM_DRILL3,[l=1] __KAM_SKIN4,[l=1] __KAM_TELEWORK4,[l=1]',
                              'gave me your photos' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC3,[l=1] __KAM_PIC5,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'director finance' => '__KAM_DIRECT4,[l=1] __KAM_INVEST2,[l=1]',
                              'success story' => '__KAM_RICH1,[l=1] __STOCK_TIP,[l=1]',
                              'recompense' => '__COMPENSATION,[l=1] __KAM_REP3_2,[l=1]',
                              'guaranteed type of exposure' => '__KAM_SEARCH4,[l=1] __KAM_SEO5,[l=1]',
                              'requiring rep to work on a part time' => '__KAM_CAREER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_TIME4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'federal' => '__KAM_BACK1,[l=1] __KAM_STUDENT3,[l=1]',
                              '. grand promotions' => '__KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_SEO6,[l=1] __KAM_VIAGRA9A,[l=1] __THIS_AD,[l=1]',
                              'you have been chosen' => '__KAM_CHOSEN3,[l=1] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'triple an principle' => '__PUMPDUMP_01,[l=1]',
                              'you receive this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'awesome girl' => '__KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1]',
                              'attached document' => '__KAM_BADZIP1,[l=0] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1]',
                              'sharepoint fileshare' => '__JMQ_RESUME3,[l=1] __KAM_FAKESHAREPOINT4,[l=0]',
                              'amb pro pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'validated dataset' => '__KAM_LIST3_3,[l=1] __KAM_PASSWORD2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'business phone system' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BUSINESSPHONE3,[l=0] __KAM_CELL3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'terminale' => '__AM_DYING,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_INSURE4,[l=1]',
                              'garcinia' => '__KAM_ANA1,[l=1]',
                              'interna' => '__LOTTO_ADMITS_2,[l=1]',
                              'unlimited usage' => '__KAM_LIST3_4,[l=1] __KAM_TRIAL,[l=1]',
                              'lev amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'interest' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SNORE3,[l=1]',
                              'recipient' => '__KAM_MEDICARE3,[l=1]',
                              'each' => '__PILL_PRICE_01,[l=1]',
                              'search engine promotion' => '__KAM_LOTTO4,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'som pro mer' => 'KAM_VIAGRA2,[l=0]',
                              'medicinal' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MARIJUANA2,[l=1] __KAM_MED1,[l=1]',
                              'switch from an adjustable rate to a fixed' => '__KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REFI5,[l=1] __KAM_SOLAR3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'protect' => '__KAM_RECALL3,[l=1]',
                              'val val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'cia xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'siga resources' => '__KAM_STOCKTIP152,[l=0]',
                              'secure my fund' => '__KAM_DOMAIN2,[l=1] __KAM_INVEST3,[l=1] __SUM_OF_FUND,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1]',
                              'via amb xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'all model' => '__KAM_GALLERY4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'courier' => '__COURIER,[l=1] __FEES,[l=1] __KAM_NIGERIAN2_8,[l=1]',
                              'tour' => '__FB_TOUR,[l=1]',
                              'k9erp' => '__KAM_ERP2,[l=0]',
                              'ticketed itinerary' => '__TRAVEL_ITINERARY,[l=0]',
                              'faxed message' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_VM3,[l=1]',
                              'sym' => '__KAM_STOCK3,[l=1]',
                              'cia lev mer' => 'KAM_VIAGRA2,[l=0]',
                              'hello my name' => '__JMQ_RESUME2,[l=0]',
                              'j.o.b.' => '__KAM_DON4,[l=0]',
                              'foreigner who died' => '__DEAL,[l=1] __DIED_IN,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'choice home warranty' => '__KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_WARRANTY2,[l=0] __KAM_WARRANTY3,[l=0] __KAM_WINDOWS3,[l=1]',
                              'penalty' => '__KAM_STUDENT3,[l=1]',
                              'you deserve a treat' => '__KAM_CANDY3,[l=0] __KAM_GARAGE3,[l=1] __KAM_UNIV15,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ecard, open attached' => '__KAM_CARD3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1]',
                              'student' => '__DECEASED,[l=1] __KAM_STUDENT3,[l=1]',
                              'bad breath' => 'BAD_CREDIT,[l=1] __KAM_FUN7,[l=1]',
                              'advanced lender' => '__KAM_LOAN3,[l=1]',
                              'concealed' => '__HUSH_HUSH,[l=1]',
                              'accrediteed' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_UNIV9,[l=1]',
                              'government of nigeria' => '__FRAUD_NEB,[l=0] __FRAUD_QFY,[l=1] __KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1] __NIGERIA,[l=1]',
                              'este correo no puede ser considerado intrusivo' => 'NOT_SPAM,[l=1]',
                              'lev lev mer' => 'KAM_VIAGRA2,[l=0]',
                              'years' => '__JMQ_PICKUP4,[l=1] __KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'nederlandse internationale loterij' => '__HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'quintupling an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'val' => '__KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'british national online lottery' => 'FREE_QUOTE_INSTANT,[l=1] __AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'lev xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'prices' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1]',
                              'reference number' => '__KAM_LOTTO2,[l=1] __KAM_PHISH2_5,[l=1] __LOTTO_WIN_01,[l=1]',
                              'hwsyd' => '__KAM_STOCKTIP142,[l=1]',
                              'claim' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1]',
                              'partner website' => 'MARKETING_PARTNERS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1]',
                              'as a foreigner' => '__FRAUD_XJR,[l=0] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'today' => '__DAY_I_EARNED,[l=1] __KAM_GIFT3,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'jennifer aniston' => '__KAM_WEIGHT2,[l=1] __STOCK_TIP,[l=1]',
                              'blueberry giant' => '__KAM_FARM3,[l=0]',
                              'amb amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'lowered' => '__KAM_AUTONEW3,[l=1] __KAM_REFI3,[l=1]',
                              'not bother you again' => '__DEAL,[l=1] __NEVER_HEAR_EN,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'chosen to participate as a mystery shopper' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_MOTHER3,[l=1] __KAM_SHOP1,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __LOTTO_DEPT,[l=1]',
                              'civ-xr' => '__KAM_ANA1,[l=1]',
                              'data field' => '__KAM_LIST3_3,[l=1]',
                              'wish to not receive future emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'grab it for ' => '__KAM_PATRIOT3,[l=1] __KAM_VIAGRA9A,[l=1] __PUMPDUMP_07,[l=1] __YOU_WON_02,[l=1]',
                              'xan xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'priv\\351' => '__HUSH_HUSH,[l=1]',
                              'sticky' => '__KAM_GRIPPY3,[l=1]',
                              'overvalued' => '__FRAUD_QFY,[l=1] __KAM_GIFT3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_STOCK2_2,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '100% no risk' => '__FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_CAR3,[l=1] __KAM_INVEST3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_TELEWORK5,[l=1]',
                              'dick' => 'BODY_ENHANCEMENT2,[l=1]',
                              'have a phone' => '__KAM_CELL3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TELEWORK2,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_01,[l=1]',
                              'som amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'presence' => '__KAM_SEARCH4,[l=1]',
                              'united consortium' => '__KAM_NIGERIAN1,[l=1] __KAM_STOCKTIP134,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'spearfishing' => '__KAM_WEBINAR4,[l=1]',
                              'som xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'nursing directors' => '__KAM_DIRECT4,[l=1] __KAM_LIST2,[l=1] __KAM_NURSE3,[l=1]',
                              'doubled there money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SEX1,[l=1] __KAM_WEED3,[l=0] __KAM_WINDOWS3,[l=1]',
                              'stronger' => '__KAM_HOSE3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'holiday novelty' => '__DAY_I_EARNED,[l=1] __KAM_HOLIDAY2020_2,[l=0]',
                              'shipped' => '__KAM_DRUG2_6,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_SALE3,[l=1]',
                              'currently' => '__KAM_HOME2,[l=1] __KAM_VISION3,[l=1]',
                              'unpaid court' => '__FEES,[l=1] __KAM_JUDGE1,[l=1] __KAM_POLITICS2,[l=1]',
                              'carbamide peroxide' => '__KAM_WHITEN3,[l=0]',
                              '. password id' => '__KAM_CARD2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'represent the company' => '__DEAL,[l=1] __JMQ_WIRE3,[l=1] __KAM_JOB2_2,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'xan mer mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'view and pay scan' => '__FEES,[l=1] __KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_UKINV2,[l=0] __PAY_YOU,[l=1]',
                              'never drink water' => '__JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __KAM_WATER1,[l=0] __NOT_SCAM,[l=1]',
                              'quintupling an principal' => '__KAM_RBL_OBFU2,[l=1] __PUMPDUMP_01,[l=1]',
                              'email list' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1] __YOU_WON_01,[l=1]',
                              'dildo' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'yellow tablet' => '__KAM_SEX04_1,[l=1] __PILL_PRICE_01,[l=1]',
                              'manager training' => '__KAM_CAREER2,[l=1] __KAM_CEP1,[l=1] __KAM_TELEWORK6,[l=1]',
                              'term & condition' => '__KAM_INQUIRY_3,[l=0] __KAM_INSURE4,[l=1]',
                              'delivery fee for your check draft' => '__BANK_DRAFT,[l=1] __DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CHECK1,[l=0] __KAM_CREDIT2,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'somnapure' => '__KAM_LUNAR4,[l=1]',
                              'being' => '__NOT_DEAD_YET,[l=1]',
                              'high paying jobs' => '__FEES,[l=1] __KAM_TAX3,[l=1] __KAM_UNIV3B,[l=1] __PAY_YOU,[l=1]',
                              'xan via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'sites' => '__KAM_CRIM2_3,[l=1]',
                              'federal housing assistance program' => '__KAM_BACK1,[l=1] __KAM_DETOX3,[l=1] __KAM_HOME1,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA9A,[l=1] __URG_BIZ,[l=1] __YOU_ASSIST,[l=1]',
                              'via cia amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'val pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'must' => '__KAM_TAX4,[l=1]',
                              'beautiful' => '__KAM_HAPPYTALK3,[l=1]',
                              'i will do anything' => '__I_WILL_YOU,[l=1] __JMQ_TRACKR3,[l=1] __KAM_BACK2,[l=1] __KAM_QUOTA2,[l=1] __KAM_URONLINE3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'my country' => '__INVEST_COUNTRY,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN5,[l=1]',
                              'right vs left' => '__DORMANT_ACCT,[l=1] __KAM_DETOX3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_POLITICS2,[l=1]',
                              'as promised chnglog update' => '__KAM_CHANGELOG2,[l=0] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'via mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'wanting' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'ganador' => '__LUCKY_WINNER,[l=1]',
                              'som val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'vacancy in my company' => '__KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'join millions' => 'JOIN_MILLIONS,[l=1] MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COVID3_3,[l=1] __KAM_DRUG2_4,[l=1] __MILLIONS,[l=1]',
                              ' media relations' => 'DX_TEXT_03,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              'view my attach' => '__KAM_AUTONEW3,[l=1] __KAM_BUS4,[l=0] __KAM_HEALTH2,[l=1]',
                              'vertraulich' => '__HUSH_HUSH,[l=1]',
                              'gift card' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT1,[l=1] __RECEIVE_BONUS,[l=1]',
                              'with no effort' => '__KAM_PATRIOT3,[l=1] __KAM_WEIGHT2,[l=1] __WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'getting' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'amb val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'validate' => '__KAM_PASSWORD2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'score-update' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFINEW2,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'lev cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'amb lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'you\'ve received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'refinance your current home' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sweepstakes' => '__KAM_BENEFICIARY3,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'unprecedented' => '__DECEASED,[l=1] __KAM_PATRIOT3,[l=1]',
                              'price' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1]',
                              'cobra oil & gas' => '__KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_STOCKTIP138,[l=1]',
                              'efficient medicine' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_SEX2,[l=1] __KAM_WINDOWS3,[l=1]',
                              'intended' => '__ADMITS_SPAM,[l=1]',
                              '4 of my mastercard' => '__KAM_SHADYCC3,[l=0]',
                              'wife of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              'cia cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'ceramic knife' => '__KAM_SHARP4,[l=0]',
                              'affordable price' => 'LOW_PRICE,[l=1] PRICES_ARE_AFFORDABLE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEB2_2,[l=0] __YOU_WON_02,[l=1]',
                              'alzheimers conspiracy' => '__KAM_BLOOD3,[l=1] __KAM_NEUROLOGICAL3,[l=0]',
                              'job description' => '__KAM_RAT2_1,[l=0]',
                              'grow grass anywhere' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_GRASS3,[l=0] __KAM_SMOKE1,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'recommend this company' => '__DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_06,[l=1] __THIS_AD,[l=1]',
                              'christian activit' => '__KAM_BENEFICIARY3,[l=1] __KAM_PROPHET4,[l=1]',
                              'just changed' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT4,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'auto insurnace go with it' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_INSURE2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'mytrusted-rx' => '__KAM_DRUG2_5,[l=1]',
                              'see this page i made' => '__DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_URONLINE2,[l=1] __THIS_AD,[l=1]',
                              'bath and massage' => '__KAM_TUB3,[l=1]',
                              'ur selection' => '__KAM_CELL3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_POLITICS2,[l=1] __RANDOM_PICK,[l=1]',
                              'monthly' => '__DOS_BODY_MON,[l=1] __KAM_AUTONEW2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1]',
                              'watch uncensored' => '__KAM_TIME4,[l=1] __KAM_TV2,[l=1]',
                              'plandai' => '__KAM_STOCKTIP146,[l=1]',
                              'dear christian' => '__KAM_PROPHET4,[l=1] __KAM_RELIGION3,[l=0]',
                              'complete ownership transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_DOMAIN_SALE4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __WIRE_XFR,[l=1]',
                              'mer amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'dreaming to get fit' => '__KAM_AUTO3,[l=1] __KAM_URZEST3,[l=0]',
                              'superstore' => '__KAM_GIFT4,[l=1] __STOCK_TIP,[l=1]',
                              'utility' => '__KAM_SOLAR3,[l=1]',
                              'val amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'not see this image' => '__DEAL,[l=1] __KAM_FUN3,[l=1] __THIS_AD,[l=1]',
                              'som mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'claims office' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1]',
                              'before eating carbs' => '__KAM_PATRIOT3,[l=1] __KAM_WEIGHT2,[l=1] __YOU_WON_02,[l=1]',
                              'emarketing alliance' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_BADNAME1,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'via val mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'field of business services' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'genetic information nondiscrimination act' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_GINA3,[l=0] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'money orders' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BADZIP3,[l=0] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN4,[l=1]',
                              'mer lev lev' => 'KAM_VIAGRA2,[l=0]',
                              'my name is barrister' => '__BARRISTER,[l=1] __CONTACT_ATTY,[l=1] __FRAUD_QXX,[l=1] __JMQ_RESUME2,[l=0] __KAM_HOWRU2,[l=0] __KAM_INVEST2,[l=1] __KAM_INVEST4,[l=1] __KAM_NIGERIAN2_2,[l=1]',
                              'cilais' => '__DRUGS_ERECTILE4,[l=1]',
                              ' cents per gallon' => '__KAM_GAS1,[l=1] __KAM_GAS2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_SWIPE4,[l=1]',
                              'working a few hours each day' => '__DAY_I_EARNED,[l=1] __KAM_CAREER3,[l=1] __KAM_TELEWORK3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PILL_PRICE_01,[l=1]',
                              'credit score' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1]',
                              'debi' => '__KAM_USB1,[l=0]',
                              'html code for the link' => '__DEAL,[l=1] __DOS_LINK,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_DRUG2_5,[l=1] __KAM_LIKE4,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'shocking method' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SHOCK1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'amb pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'overpay for auto insurance' => '__FEES,[l=1] __FRAUD_QFY,[l=1] __KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR1_3,[l=1] __PAY_YOU,[l=1] __YOU_WON_02,[l=1]',
                              'pro mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'immediate response' => '__FRAUD_DPR,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __URG_BIZ,[l=1]',
                              'website rank higher' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEB2,[l=1]',
                              'this offer for united states' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'generation' => '__KAM_ADVERT2,[l=1] __KAM_CREDIT3,[l=1]',
                              'wavee' => '__KAM_SWIPE4,[l=1]',
                              'complete the survey' => '__DEAL,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_GIFT5,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_SURVEY3,[l=0] __SURVEY,[l=1]',
                              'insights' => '__KAM_WEB2_4,[l=0]',
                              'via xan lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'reference' => '__KAM_PHISH2_5,[l=1]',
                              'the only virginia team' => 'LIVE_PORN,[l=1] __DEAL,[l=1] __KAM_BADNAME1,[l=1]',
                              'ur gf' => '__KAM_URUNIT2,[l=1]',
                              'mer som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'sat' => '__DOS_BODY_SAT,[l=1]',
                              'via amb pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'name of' => '__KAM_LOTTO4,[l=1]',
                              'bank of nigeria' => '__FRAUD_BEP,[l=1] __FRAUD_NEB,[l=0] __JMQ_WIRE3,[l=1] __KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_7,[l=0] __NIGERIA,[l=1]',
                              'specialties:' => '__KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST3_4,[l=1] __KAM_VISION3,[l=1]',
                              'event coordinator' => '__FRAUD_RLX,[l=1] __KAM_LIST3_2,[l=1] __KAM_TOURS3,[l=1]',
                              'in search of trustworthy representatives' => '__JMQ_WIRE3,[l=1] __KAM_AUTO3,[l=1] __KAM_DRUG2_6,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REVIEW3,[l=1]',
                              'garden' => '__KAM_FLEXHOSE3,[l=1] __KAM_HOSE3,[l=1]',
                              'pro cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'val lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pro via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'receive what you are owed' => '__DOS_BODY_WED,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_JUDGE2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' before tuesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __KAM_PATRIOT3,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'shippin' => '__KAM_DRUG2_6,[l=1]',
                              'circle media bids' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_SWIPE4,[l=1]',
                              'val val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'top fabric' => '__KAM_LABEL5,[l=0]',
                              'free' => '__KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'xan som cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'aid your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'immediate' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              'true' => '__KAM_WEIGHT1,[l=1]',
                              'mer val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'shore bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'top in msn' => '__KAM_SEO2,[l=1]',
                              'ur endurance level' => '__KAM_URUNIT1,[l=1]',
                              'som cia amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'making' => '__KAM_VISION3,[l=1]',
                              'quintuple your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'porn' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'business project' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DRAPES3,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PROJECT2,[l=0] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'provider' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'slice' => '__KAM_PRODUCT2_2,[l=1]',
                              'strange' => '__KAM_WEIRDTRICK2,[l=1]',
                              'click here to enter our secure server:' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CARD3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_GIFT4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'dolphin sealer' => '__KAM_BAD_PRODUCT2,[l=0]',
                              'xan val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'building' => '__KAM_CHICKEN3,[l=1] __KAM_SEO2,[l=1]',
                              'cialis' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'see images for this offer' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'government funding' => '__FRAUD_QFY,[l=1] __KAM_GOVT2,[l=0] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'match making heaven' => '__KAM_URONLINE2,[l=1] __KAM_VISION3,[l=1]',
                              'guaranteed' => '__KAM_SEO5,[l=1]',
                              'alternate ' => '__FRAUD_AON,[l=1]',
                              'ful log' => '__FAILED_LOGINS,[l=1]',
                              'compulsory' => '__KAM_JURY4,[l=1] __KAM_REP3_2,[l=1]',
                              'christian media' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_PROPHET4,[l=1] __KAM_RELIGION3,[l=0]',
                              '3 companies for free' => '__KAM_BLOOD4,[l=1] __KAM_CREDIT3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1] __YOU_WON_02,[l=1]',
                              'you were recently chosen' => '__KAM_AUTONEW3,[l=1] __KAM_CHOSEN3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'via mer cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'younger' => '__KAM_HAIRTRANS3,[l=1] __KAM_SKIN4,[l=1] __KAM_TVDOCTOR3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ppe' => '__KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1]',
                              'bank account' => '__DORMANT_ACCT,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'prepared' => '__KAM_INSURE4,[l=1]',
                              'pro lev som' => 'KAM_VIAGRA2,[l=0]',
                              'calluses and dead skin' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SKIN4,[l=1]',
                              'link exchange' => '__DOS_LINK,[l=1] __KAM_LIKE3,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'time investment' => 'ONE_TIME,[l=1] __INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_TIME4,[l=1] __SUM_OF_FUND,[l=1]',
                              'financial collapse' => '__DEAL,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PATRIOT4,[l=1]',
                              'know your credit score' => 'BAD_CREDIT,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_INSURE4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_REFI6,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'remove "*" in the above link' => '__DEAL,[l=1] __DOS_LINK,[l=1] __KAM_STAR1,[l=0] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'pieniedz' => '__KAM_MM_FOREX_1,[l=1]',
                              'bedroom' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_URUNIT4,[l=1]',
                              'free lotto sweepstakes' => '__HK_LOTTO_2,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_LOTTO5,[l=1] __KAM_TRIAL,[l=1] __LOTTO_ADMITS_2,[l=1] __PILL_PRICE_01,[l=1]',
                              'grow' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'information' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'concerning this money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __THIS_AD,[l=1]',
                              'zabroniony' => '__KAM_MM_FOREX_1,[l=1]',
                              'you\'re receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som som mer' => 'KAM_VIAGRA2,[l=0]',
                              'new website' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1] __KAM_WEB2_3,[l=0]',
                              'user record' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST3_4,[l=1]',
                              'diplomatic courier' => '__COURIER,[l=1] __DIPLOMATIC,[l=1] __FEES,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_8,[l=1] __KAM_UNIV6B,[l=1]',
                              ' extended relative' => '__FRAUD_SNT,[l=1]',
                              ' to our affiliates' => '__WE_PAID,[l=1]',
                              'waiting for ur mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CREDIT2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_URONLINE2,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'more fire and passion' => '__KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SEX06_1,[l=0] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'via via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'winning numbers' => '__KAM_LOTTO6,[l=1] __KAM_POLITICS2,[l=1] __LOTTO_WIN_01,[l=1] __hk_win_a,[l=1]',
                              'advance details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_ADVANCE2,[l=0] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'you are receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no responds' => '__FRAUD_MLY,[l=1] __KAM_PROFORMA2,[l=0]',
                              'not interested' => 'KAM_ADVERT2,[l=1] REMOVE_BEFORE_LINK,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SNORE3,[l=1]',
                              'strong buy' => 'STRONG_BUY,[l=0] __KAM_HOSE3,[l=1]',
                              'amb som pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'complained' => '__KAM_REP3_2,[l=1] __KAM_URUNIT3,[l=1]',
                              'target industry' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1] __KAM_LIST3_4,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'vgpm' => '__KAM_STOCKTIP124,[l=1]',
                              'hey!' => '__KAM_NEWS2,[l=0]',
                              '/mo' => '__KAM_INSURE4,[l=1]',
                              'out of the office' => '__BOUNCE_OOO_CB1,[l=1] __DEAL,[l=1] __KAM_SALE3,[l=1]',
                              'pro xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'history' => '__KAM_ANCESTOR3,[l=1] __STOCK_TIP,[l=1]',
                              'some great pictures of me' => '__KAM_PIC4,[l=1] __KAM_PIC5,[l=0]',
                              'global who' => '__KAM_WHOSWHO3,[l=1]',
                              'via lev val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pro amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'tablets' => '__KAM_MARIJUANA3,[l=1] __PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'extreme p' => '__KAM_GALLERY4,[l=1]',
                              'can you be my partner' => '__HK_SCAM_S15,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' per mask' => '__KAM_LABEL4,[l=1] __KAM_LABEL8,[l=1]',
                              'full-time and part-time' => '__KAM_TIME4,[l=1] __KAM_WORKHOME1,[l=0]',
                              'buffett foundation' => '__FOUND_YOU,[l=1] __HK_LOTTO_2,[l=1] __KAM_BENEFICIARY4,[l=0]',
                              'bigger pen' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX1,[l=1]',
                              'eligible for auto' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR1_3,[l=1] __YOU_WON_02,[l=1]',
                              ' credit' => 'BAD_CREDIT,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'leaving home' => '__KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1] __STAY_HOME,[l=1]',
                              'raw land' => '__KAM_REAL2_4,[l=1]',
                              'caribbean' => '__KAM_VACATION3,[l=1]',
                              'orphelins' => '__CHARITY,[l=1]',
                              'loose' => '__KAM_TVDOCTOR3,[l=1]',
                              'compiled a dataset' => '__KAM_LISTSALE3,[l=0] __KAM_REP3_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'aqua globe' => '__KAM_AQUA1,[l=1] __KAM_AQUARUG3,[l=1]',
                              'amb cia val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'every girl loves to buy' => '__KAM_GIFT3,[l=1] __KAM_PIC2,[l=1]',
                              'release yourpending ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mer xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'abuse id' => '__KAM_FAKEBBB3,[l=0] __KAM_PATRIOT3,[l=1]',
                              'alcohol recovery' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_REHAB3,[l=0]',
                              'top in google' => '__KAM_SEARCH3,[l=1] __KAM_SEO2,[l=1] __KAM_SEO4,[l=1]',
                              'field of your choice' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV11,[l=1] __KAM_UNIV13,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cilias' => '__DRUGS_ERECTILE4,[l=1]',
                              'val via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'need more time' => '__KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __KAM_TAX3,[l=1] __KAM_TIME4,[l=1]',
                              'pocket hose' => '__KAM_HOSE3,[l=1] __KAM_REFI6,[l=1]',
                              'mer via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'you\'ve been ' => '__RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'friendly guy' => '__DOS_BODY_FRI,[l=1] __KAM_PIC3,[l=1]',
                              'no tobacco' => '__KAM_INSURE2,[l=1] __KAM_SMOKE4,[l=1]',
                              'touch' => '__KAM_SALE3,[l=1]',
                              'disburs' => '__FRAUD_FBI,[l=1] __FRAUD_WNY,[l=1]',
                              'obligation' => '__KAM_HEALTH2,[l=1]',
                              'project' => '__KAM_DRAPES3,[l=1]',
                              'attendees:' => '__KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1]',
                              'microsoft id' => '__KAM_LOTTO2,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'val mer som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'address direclty at' => '__DOS_EMAIL_DIRECTLY,[l=1]',
                              'full statement' => '__KAM_SHADYCC4,[l=0]',
                              'urgent' => '__KAM_BADZIP3,[l=0] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __URG_BIZ,[l=1]',
                              'mer mer mer' => 'KAM_VIAGRA2,[l=0]',
                              'you\'re receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cid:' => '__KAM_VM4,[l=1]',
                              'approval department' => '__HK_LOTTO_2,[l=1] __KAM_LOAN3,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'cia pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'efficient' => '__KAM_WINDOWS3,[l=1]',
                              'all adu' => '__KAM_GALLERY4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'unbelievable payment terms' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CAR3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_INSURE4,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'lucrative' => '__LUCRATIVE,[l=1]',
                              'job prospect newsletter' => '__KAM_CEP1,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'to unsubscribe from this' => '__DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_GIFT2,[l=1] __SUBSCRIPTION_INFO,[l=1] __THIS_AD,[l=1]',
                              'pro cia cia' => 'KAM_VIAGRA2,[l=0]',
                              ' first thing tuesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'upgrade team' => '__KAM_VIAGRA9A,[l=1] __SYSADMIN,[l=1]',
                              'cvs gift card' => '__KAM_CVS2,[l=1] __KAM_DUJOUR2,[l=0] __KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT1,[l=1] __RECEIVE_BONUS,[l=1]',
                              'https://docs.google.com/forms/' => '__KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEO4,[l=1] __UNSUB_GOOG_FORM,[l=1] __YOU_WON_02,[l=1]',
                              'ur unit' => '__KAM_URUNIT1,[l=1] __LOTTO_DEPT,[l=1]',
                              'buy as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              'mer som cia' => 'KAM_VIAGRA2,[l=0]',
                              'brought to you by:' => 'KAM_ADVERT2,[l=1] __DAY_I_EARNED,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'wish to receive these emails' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'xan som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'quest of love' => '__KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1]',
                              'my old job' => '__DOS_MY_OLD_JOB,[l=1]',
                              'morning' => '__KAM_STOCK2_1,[l=1]',
                              'permission' => '__YOUR_PERM,[l=1]',
                              'exclusive' => '__KAM_DEALS3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FAKEVOUCHER2,[l=1]',
                              'get out of ' => '__KAM_DEBT1,[l=1]',
                              'pluris energy' => '__KAM_NUWAVE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_STOCKTIP133,[l=1] __KAM_WINDOWS3,[l=1]',
                              'projectprophet' => '__KAM_DRAPES3,[l=1] __KAM_PATRIOT4,[l=1]',
                              'benefit' => '__BACK_SCRATCH,[l=1]',
                              'arrangement secret' => '__HK_SCAM_N16,[l=1] __HUSH_HUSH,[l=1] __KAM_WEIGHT2,[l=1]',
                              'clunker' => '__KAM_AUTO3,[l=1]',
                              'cash' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'breitling' => '__KAM_TIME6,[l=0]',
                              'certificate officer' => '__KAM_LOTTO4,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_SALE3,[l=1]',
                              'support team' => '__SYSADMIN,[l=1]',
                              'suffered from organ failure' => '__KAM_MEDICAL1,[l=0] __KAM_REP3_2,[l=1]',
                              'ckbuddy' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'microsoft email promo' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_ADMITS_2,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'mer val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'give' => '__FRAUD_JYG,[l=1]',
                              'return to office' => '__BOUNCE_OOO_CB4,[l=1] __KAM_POLITICS2,[l=1] __KAM_SALE3,[l=1]',
                              'we have a solution' => '__KAM_CLOUD3,[l=1] __KAM_GAS2,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEBINAR4,[l=1] __YOU_WON_01,[l=1]',
                              'installation' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_WINDOWS3,[l=1]',
                              'xan val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'business email database' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_ENGINEER2,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1] __YOU_WON_01,[l=1]',
                              'lev pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'program' => '__KAM_DETOX3,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'val som pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'government not telling' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1]',
                              'better business bureau' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_FAKEBBB2,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'multi access' => '__KAM_GALLERY2,[l=1]',
                              'direct email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_DIRECT4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_3,[l=1] __YOU_WON_01,[l=1]',
                              'mba' => '__KAM_CEP4,[l=1]',
                              'amount won:' => '__KAM_LOTTO3,[l=1] __KAM_LOTTO6,[l=1] __SUM_OF_FUND,[l=1]',
                              'quadruple your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'recommend a company' => '__KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_06,[l=1]',
                              'ugly timeshare' => '__KAM_LOAN3,[l=1] __KAM_TIME4,[l=1] __KAM_TIMESHARE1,[l=1]',
                              'year' => '__JMQ_PICKUP4,[l=1]',
                              'val cia val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'som mer cia' => 'KAM_VIAGRA2,[l=0]',
                              'international airport' => '__HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'xan amb som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'mega model' => '__KAM_GALLERY4,[l=1]',
                              'aboration' => '__FRAUD_XWW,[l=1]',
                              'marine essentials' => '__JMQ_WIRE3,[l=1] __KAM_BLOOD4,[l=1]',
                              'kevin james' => '__KAM_WEED1,[l=1]',
                              'falecido' => '__DECEASED,[l=1]',
                              'finansow' => '__KAM_MM_FOREX_1,[l=1]',
                              'pleasure to inform' => '__KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __YOU_WON_02,[l=1] __hk_win_4,[l=1]',
                              'who\'s who among executives' => '__DOS_BODY_MON,[l=1] __KAM_BADNAME1,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'late father' => '__DEAL,[l=1] __DECEASED,[l=1] __KAM_BENEFICIARY6,[l=0]',
                              'received a victoria\'s secret giftcard' => '__DAY_I_EARNED,[l=1] __HUSH_HUSH,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT1,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEIGHT2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'for' => '__KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              '% of the total sum for your partner' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_JYG,[l=1] __FRAUD_YPO,[l=0] __GAPPY_SALES_LEADS,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amb via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'questions about drugs' => '__KAM_ANDROGEL3,[l=1] __KAM_BACK3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'som lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'lottery coordinator' => '__AFF_LOTTERY,[l=0] __FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO4,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'the mop that' => '__DEAL,[l=1] __KAM_MOP3,[l=1]',
                              'contact details' => '__CONTACT_ATTY,[l=1] __FRAUD_ETX,[l=1] __FRAUD_JYG,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'xan lev lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'progress watch' => '__KAM_STOCKTIP156,[l=1] __KAM_TIME4,[l=1]',
                              'university administration' => '__HK_LOTTO_2,[l=1] __KAM_UNIV1,[l=1] __KAM_UNIV9,[l=1]',
                              'settlement' => '__KAM_TAX3,[l=1] __LOTTO_DEPT,[l=1]',
                              'via som mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'remove' => '__KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'financially free' => 'FIN_FREE,[l=1] __DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'honest' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1]',
                              'need to borrow' => '__KAM_LOAN3,[l=1]',
                              'singapore' => '__KAM_JOB2_3,[l=0]',
                              'detailed statement' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_SHADYCC4,[l=0]',
                              'amb mer som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'training calendar' => '__KAM_CAREER2,[l=1] __KAM_CEP1,[l=1] __KAM_TRAINING2,[l=0]',
                              'biggest tool' => '__KAM_SEX05_2,[l=0]',
                              'som via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              ' makes and models' => '__KAM_CARDEAL3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'claims agent' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BANK_2,[l=0] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1]',
                              'no obligation quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_CAR3,[l=1] __KAM_HEALTH2,[l=1]',
                              'shop michael kors' => '__KAM_KORS3,[l=0] __KAM_MOTHER3,[l=1]',
                              'costing' => '__FB_COST,[l=1] __FRAUD_QFY,[l=1]',
                              'slavic babes' => '__KAM_WIFE2,[l=1]',
                              'what\'s your name' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_HOWRU2,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'personal treasurer' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN1,[l=1]',
                              'scrambling' => '__KAM_AUTO3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'cia mer lev' => 'KAM_VIAGRA2,[l=0]',
                              'pussy licked' => '__KAM_SEX1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'you\'ve receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'global leads' => '__KAM_LIST3_2,[l=1]',
                              'in your browser' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP2_2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no dieting' => 'DIET_1,[l=1] __DEAL,[l=1]',
                              'you were chosen' => '__KAM_CHOSEN3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'promotional ballot' => '__HK_LOTTO_BALLOT,[l=1] __KAM_GIFT5,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __THIS_AD,[l=1]',
                              'abandoned' => '__DORMANT_ACCT,[l=1] __KAM_BITCOIN2,[l=1]',
                              'immediate reply' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              'weird trick' => '__KAM_LUNAR4,[l=1] __KAM_SUPERHUMAN3,[l=1] __KAM_WEIRDTRICK2,[l=1]',
                              'home ear endoscope' => '__KAM_HOLIDAY2020_2,[l=0] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'card link below' => '__DOS_LINK,[l=1] __KAM_CARD2,[l=1] __KAM_CERT3,[l=0]',
                              'free sample' => '__KAM_TRIAL,[l=1] __KAM_WEB2_4,[l=0] __KAM_WEIGHT1,[l=1] __PILL_PRICE_01,[l=1]',
                              'approved access' => 'TVD_APPROVED,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_GALLERY2,[l=1] __KAM_LOAN3,[l=1]',
                              'shandong zhouyuan seed and nursery' => '__KAM_STOCKTIP122,[l=1]',
                              'amb som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'waiting' => '__KAM_CREDIT2,[l=1]',
                              'powerball' => '__KAM_LOTTO5,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'pro xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'be we can meet' => '__DOS_MEET_EACH_OTHER,[l=1]',
                              'we cannot be considered spam' => 'NOT_SPAM,[l=1]',
                              'times an principal' => '__KAM_LOAN3,[l=1] __KAM_TIME4,[l=1] __PUMPDUMP_01,[l=1]',
                              'market facts' => '__KAM_PATRIOT3,[l=1] __KAM_STOCK2_2,[l=1]',
                              'be started with' => '__RECEIVE_BONUS,[l=1]',
                              'enerbrite technologies group' => '__KAM_STOCKTIP129,[l=1] __LOTTO_DEPT,[l=1]',
                              'ascent your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mail account has been accessed' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ADMAIL,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __MAIL_ACCT_ACCESS1,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __WEBMAIL_ACCT,[l=1] __YOU_WON_01,[l=1]',
                              'request' => '__URG_BIZ,[l=1]',
                              'lev mer lev' => 'KAM_VIAGRA2,[l=0]',
                              'save up to ' => '__KAM_CAR3,[l=1] __KAM_INSURE4,[l=1]',
                              'list consist' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'heave your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'aqua' => '__KAM_AQUARUG3,[l=1]',
                              'via via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'send more information' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'multiply your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'principal ' => '__KAM_REFI5,[l=1]',
                              'limited' => '__KAM_TRIAL,[l=1]',
                              'foreign bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_TCC,[l=0] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'capsules' => '__PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'samples for review' => '__KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_LIST3_3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEB2_4,[l=0] __YOU_WON_02,[l=1]',
                              'xan pro cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'lock in saving' => '__KAM_HEALTH2,[l=1] __KAM_REFI2,[l=1]',
                              'lev val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'prevent early' => '__KAM_DEATH1,[l=1] __KAM_TOURS3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'degree/certificates' => '__KAM_CEP5,[l=0] __KAM_UNIV2,[l=1]',
                              'do you like to shop' => '__KAM_LED2,[l=1] __KAM_MOTHER3,[l=1] __KAM_SHOP2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'anything' => '__JMQ_TRACKR3,[l=1] __KAM_BACK2,[l=1]',
                              'mer pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'suck' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'message' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'asassinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'term' => '__KAM_INSURE4,[l=1]',
                              'indispensable' => '__KAM_NURSE3,[l=1]',
                              'details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'foreign customer' => '__FRAUD_MQO,[l=0] __KAM_BENEFICIARY3,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __LOTTO_DEPT,[l=1] __STOCK_TIP,[l=1] __YOU_WON_02,[l=1]',
                              'foriegn bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0] __YOU_WON_02,[l=1]',
                              'ivory' => '__IVORY_COAST,[l=1]',
                              'revolutionary pest control system' => '__KAM_PEST3,[l=0] __KAM_WEBINAR4,[l=1]',
                              'lev via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'd=e9funt' => '__DECEASED,[l=1]',
                              'secure monies' => '__DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1] __KAM_DOMAIN2,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'not intended to diagnose' => '__ADMITS_SPAM,[l=1] __KAM_FDA2,[l=1]',
                              'get your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'read the attached letter' => '__DEAL,[l=1] __KAM_CONTACTME2,[l=0] __KAM_DOMAINEXPIRY2,[l=0] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1]',
                              'diethylpropion' => '__DEAL,[l=1] __DRUGS_DIET5,[l=1]',
                              '% commission' => '__KAM_INVEST3,[l=1] __KAM_REP3_2,[l=1] __KAM_TELEWORK6,[l=1]',
                              'china' => '__KAM_BENEFICIARY4,[l=0]',
                              'triple your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'unsubscribe from this advertisement' => 'KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_GIFT2,[l=1] __SUBSCRIPTION_INFO,[l=1] __THIS_AD,[l=1]',
                              'cia via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'excess return capital fund' => 'EMRCP,[l=1] __KAM_POLITICS2,[l=1] __KAM_WEIGHT2,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'honest person' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1] __KAM_INVEST2,[l=1]',
                              'without exercise' => 'DIET_1,[l=1] __KAM_MARIJUANA3,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'abortion' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'quadruple an principle' => '__PUMPDUMP_01,[l=1]',
                              'my gentle sun' => '__DOS_BODY_SUN,[l=1] __KAM_URONLINE2,[l=1]',
                              'internet ballot' => '__HK_LOTTO_BALLOT,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'chiropractor' => '__KAM_LIST2,[l=1]',
                              'etgu' => '__KAM_STOCKTIP129,[l=1]',
                              'reliablerxsource1' => '__KAM_DRUG2_5,[l=1] __KAM_DRUG2_6,[l=1] __KAM_TV1,[l=1]',
                              'cia val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'estates' => '__KAM_INSURE4,[l=1] __KAM_REAL2_5,[l=0]',
                              'great rate available' => '__KAM_INSURE4,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI2,[l=1] __KAM_REFI6,[l=1]',
                              'prefer to receive future emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'latina' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'cia xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'see the commercial' => '__DEAL,[l=1] __KAM_RECALL3,[l=1] __KAM_REP3_2,[l=1] __KAM_WEB_OBFUSCATION1,[l=1]',
                              'answering a short survey' => '__KAM_GIVE3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __SURVEY,[l=1]',
                              'right' => '__KAM_DETOX3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'administration office' => '__KAM_SALE3,[l=1] __KAM_UNIV1,[l=1]',
                              'ashray medical center' => '__DRUGS_ERECTILE5,[l=1] __JMQ_WIRE2,[l=1] __KAM_BADNAME1,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GIFT4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1] __KAM_SWIPE4,[l=1]',
                              'free access' => '__KAM_GALLERY2,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'early' => '__KAM_WEBINAR4,[l=1]',
                              'pricelist' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_LIST4,[l=1] __KAM_SEO5,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'form of money orders' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BADZIP3,[l=0] __KAM_BITCOIN2,[l=1] __KAM_DOMAIN2,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'contact my secretary' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __HUSH_HUSH,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'good' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'supress appetite' => '__KAM_HOODIA3,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1]',
                              'val som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'lev xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'this message brought to you' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'finance company' => '__FRAUD_IRJ,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'your kind assistance' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __URG_BIZ,[l=1] __YOUR_FUND,[l=1] __YOU_ASSIST,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'saudi arabia' => '__KAM_COVID3_5,[l=0]',
                              'respond' => '__FRAUD_MLY,[l=1]',
                              ' g r ' => '__KAM_VIAGRA4B,[l=1]',
                              'turn on your wife' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'death notification' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_FUNERAL3,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __LOTTO_WIN_01,[l=1] __NOT_DEAD_YET,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'you\'ve receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'nigeria' => '__KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_NIGERIAN1,[l=1] __NIGERIA,[l=1]',
                              'adult' => '__KAM_CRIM2_3,[l=1]',
                              'business analyst' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST3_2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_STOCK2_4,[l=0] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'showcase our capabilit' => '__KAM_LIST3_4,[l=1]',
                              'the desk of' => '__DEAL,[l=1] __FRAUD_AUM,[l=1] __SYSADMIN,[l=1]',
                              'alcohol treatment' => '__KAM_GARAGE3,[l=1] __KAM_REHAB3,[l=0] __TRTMT_DEFILED,[l=1]',
                              'karaluch' => '__KAM_MM_FOREX_1,[l=1]',
                              'verification' => '__TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'tripling an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'starbucks' => '__KAM_GIFT4,[l=1]',
                              'aid your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'more' => '__KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'intranet' => '__KAM_REP3_2,[l=1] __KAM_TRAINING2,[l=0]',
                              'wealthy client' => '__KAM_INVEST2,[l=1] __KAM_NIGERIAN5,[l=1]',
                              'excess maximum return capital fund' => 'EMRCP,[l=1] __KAM_POLITICS2,[l=1] __KAM_WEIGHT2,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'takeover' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI2,[l=1]',
                              'penis enlarge' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX2,[l=1]',
                              'my pics' => '__KAM_PIC5,[l=0]',
                              'som via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'did you receive it' => '__KAM_DIDYOUBODY,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lift your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'survey' => '__SURVEY,[l=1]',
                              'marketing and comm' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'segment' => '__KAM_WEIGHT1,[l=1]',
                              'return phone calls' => '__KAM_CELL3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK3,[l=1]',
                              'consignment' => '__KAM_INVOICEPO2,[l=0] __TRUNK_BOX,[l=1] __YOUR_CONSIGNMENT,[l=1]',
                              'count and cost' => '__FB_COST,[l=1] __KAM_LIST3_3,[l=1]',
                              'picture' => '__KAM_PIC5,[l=0]',
                              'reduce' => '__KAM_CLOUD3,[l=1] __KAM_PET3,[l=1] __KAM_STUDENT3,[l=1]',
                              'business solicitation message' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'blood' => '__KAM_DIABETES1,[l=1]',
                              'discussion' => '__KAM_NIGERIAN4,[l=1]',
                              'honest partner' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1] __KAM_INVEST2,[l=1]',
                              'sample file' => '__JMQ_RESUME3,[l=1] __KAM_LIST3_3,[l=1] __KAM_WEB2_4,[l=0]',
                              'used or broken' => '__KAM_SELLPHONE2,[l=0]',
                              'burn' => 'DIET_1,[l=1]',
                              'mer cia amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'caller' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_VM4,[l=1]',
                              'cartel' => '__KAM_BITCOIN2,[l=1]',
                              'lasik' => '__KAM_FUN7,[l=1]',
                              'amb xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'que ha ganado' => '__HAS_WON_01,[l=1]',
                              'depth' => '__KAM_WEBINAR4,[l=1] __LOTTO_DEPT,[l=1]',
                              'drive' => '__KAM_DOMAIN2,[l=1] __KAM_WEBINAR4,[l=1]',
                              'destroy' => '__DESTROY_ME,[l=1] __DESTROY_YOU,[l=1]',
                              'no censorship' => '__KAM_TV2,[l=1]',
                              'som val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pro som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'lev pro lev' => 'KAM_VIAGRA2,[l=0]',
                              'sugar disease' => '__KAM_FUN7,[l=1]',
                              'lack of sex' => '__KAM_GIRLS1,[l=0] __KAM_SEX_EXPLICIT4,[l=1]',
                              'cristal' => '__HK_LOTTO_2,[l=1]',
                              'compliant id' => '__KAM_FAKEBBB3,[l=0] __KAM_REP3_2,[l=1]',
                              'legacy' => '__KAM_INSURE4,[l=1]',
                              'marketing list' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WEBINAR4,[l=1]',
                              'cia pro lev' => 'KAM_VIAGRA2,[l=0]',
                              'overweight' => 'DIET_1,[l=1] __FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'users record' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST3_4,[l=1]',
                              'v i r u s' => '__VBOUNCE_AMAVISD2,[l=1]',
                              '4 of the mastercard' => '__DEAL,[l=1] __KAM_SHADYCC3,[l=0]',
                              'som som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'amb val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'final day of the $' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1]',
                              'losing your hair' => 'DIET_1,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_TRACKR3,[l=1] __KAM_HAIRTRANS3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PDS_SEO2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'more girl' => '__KAM_GALLERY4,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PIC2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'training' => '__KAM_CAREER2,[l=1] __KAM_CEP1,[l=1]',
                              ' to your webmail' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __MAIL_ACCT_ACCESS2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'please login to complete update process' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_EMAILPHISH1,[l=0] __KAM_INSURE4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'lottery co' => '__AFF_LOTTERY,[l=0] __FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'waiting on you' => '__KAM_CREDIT2,[l=1] __KAM_PIC3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'drug recovery' => '__FRAUD_QFY,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_REHAB3,[l=0] __KAM_REMEMBERWHEN3,[l=1]',
                              'our_list' => '__KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1] __OBFU_UNSUB_UL,[l=1]',
                              'show your girl' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __KAM_URUNIT4,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'batch number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'amb amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'xan via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'secret pin' => '__HUSH_HUSH,[l=1] __KAM_LOTTO2,[l=1] __KAM_WEIGHT2,[l=1]',
                              'long legs, cute' => '__KAM_PIC2,[l=1]',
                              'avai berry' => '__KAM_WEIGHT2,[l=1]',
                              'hope i am not intruding' => '__KAM_COMPROMISED3,[l=1] __KAM_INTRUDE,[l=1]',
                              'application' => '__KAM_ADVERTISE3,[l=1] __KAM_FAKEDELIVER1,[l=1]',
                              ' opens wednesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'information field' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LIST3_3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'amount' => '__SUM_OF_FUND,[l=1]',
                              'ebay killer' => '__KAM_SWIPE3,[l=1]',
                              'the end of barack obama' => '__DEAL,[l=1] __KAM_INSURE2,[l=1] __KAM_POLITICS2,[l=1] __KAM_POLY2,[l=0] __KAM_REFI3,[l=1]',
                              'som lev lev' => 'KAM_VIAGRA2,[l=0]',
                              'experian report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1]',
                              'boost your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan lev val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'drug rehab' => '__KAM_ANDROGEL3,[l=1] __KAM_REHAB3,[l=0] __KAM_REMEMBERWHEN3,[l=1]',
                              'work from home part' => '__KAM_CAREER3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1] __KAM_WORKFROMHOME1,[l=0]',
                              'get extra income' => 'DIET_1,[l=1] __KAM_GIFT3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'you are received this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'b r e a s t' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'stay hot and sexy' => '__KAM_ARREST2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_SUPERHUMAN3,[l=1]',
                              'administrador do sistema' => '__SYSADMIN,[l=1]',
                              'online right now' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DETOX3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_PIC1,[l=1]',
                              'controversial' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_MILLIONAIRE2,[l=0] __KAM_REFI2,[l=1]',
                              'quadruple your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'naughty toys' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_URONLINE3,[l=1]',
                              'won' => '__KAM_LOTTO3,[l=1]',
                              'som amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'ascent your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'recommended this company' => '__DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_06,[l=1] __THIS_AD,[l=1]',
                              'xan mer cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'verstorbenen' => '__DECEASED,[l=1] __STOCK_TIP,[l=1]',
                              'dick dangl' => 'BODY_ENHANCEMENT2,[l=1] __KAM_SEX2,[l=1]',
                              'bark' => '__KAM_BARK1,[l=1]',
                              'val via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'invoice copies' => '__FRAUD_QFY,[l=1] __KAM_FAKE_FAX4,[l=0] __KAM_INVOICEPO3,[l=0] __KAM_TOLL3,[l=1] __KAM_VM3,[l=1]',
                              'attention:winner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __hk_win_2,[l=1]',
                              'colon cure' => '__KAM_WEIGHT2,[l=1]',
                              'lfap' => '__KAM_STOCKTIP149,[l=1]',
                              'trouble' => '__KAM_REPAIR2_3,[l=1]',
                              'retrieve messages' => '__ADMAIL,[l=1] __KAM_BOXVERIFY,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'val cia lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'award notification' => '__FRAUD_FVU,[l=0] __KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'database' => '__KAM_BACK3,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1]',
                              'nurses are needed' => '__KAM_NURSE3,[l=1]',
                              'career education program' => '__KAM_CEP3,[l=1] __KAM_DETOX3,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA9A,[l=1] __KAM_VISION3,[l=1]',
                              'mon' => '__DOS_BODY_MON,[l=1]',
                              'nurses are now in high' => '__KAM_NURSE3,[l=1]',
                              'mer mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'account ' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'eharmony' => '__DOS_BODY_MON,[l=1] __KAM_MEMBER3,[l=1]',
                              'deepthroat on knees' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'bad babe' => 'BAD_CREDIT,[l=1] __KAM_GALLERY4,[l=1]',
                              'buyer flying in' => '__KAM_REAL2_5,[l=0]',
                              'losses and victories' => '__KAM_STOCK2_2,[l=1]',
                              'deal' => '__DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_SUNGLASSES2,[l=1]',
                              'val xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'health' => '__KAM_JOINT3,[l=1]',
                              'premium coffee delivered' => '__KAM_AUTONEW2,[l=1] __KAM_AUTONEW3,[l=1] __KAM_GEVALIA1,[l=1] __KAM_MEDICARE4,[l=1] __KAM_SALE3,[l=1]',
                              'goodbye to her waist' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2_1,[l=0]',
                              'plans as low as' => '__KAM_HIRE3,[l=1] __KAM_INSURE2,[l=1]',
                              'product catalog' => '__KAM_INQUIRY_1,[l=0]',
                              'phones for discerning individuals' => '__KAM_CELL3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PRODUCT2,[l=0] __LUCKY_WINNER,[l=1] __YOU_WON_02,[l=1]',
                              ' mil' => '__KAM_COVID3_3,[l=1]',
                              'view here' => '__KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_WORKHOME2,[l=0]',
                              'lottery approved courier' => 'TVD_APPROVED,[l=1] __AFF_LOTTERY,[l=0] __COURIER,[l=1] __FEES,[l=1] __HK_LOTTO_2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_LOAN3,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO4,[l=1] __KAM_NIGERIAN2_8,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'via lev lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'numbers' => '__KAM_LOTTO6,[l=1] __LOTTO_WIN_01,[l=1]',
                              'wanting to get in the gym' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_URZEST3,[l=0]',
                              'finance firm' => '__FRAUD_IRJ,[l=0]',
                              'resume' => '__JMQ_RESUME3,[l=1]',
                              'cmi free stuff' => '__KAM_BADNAME1,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'xan som mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'most amazing transformation' => '__KAM_BEAUTY3,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_STOCK2_2,[l=1] __YOU_WON_02,[l=1]',
                              'pro amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'for your compensation' => '__COMPENSATION,[l=1] __DECEASED,[l=1] __DOS_BODY_SAT,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_SCAM_N8,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'police can no longer be trusted' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_2ND_1,[l=1] __KAM_PACKAGE2,[l=1]',
                              'val val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'mer val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'ch0ked' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'pounds sterling' => 'DIET_1,[l=1] __KAM_LOTTO3,[l=1] __KAM_WEIGHT1,[l=1]',
                              'local' => '__KAM_MAID3,[l=1] __SYSADMIN,[l=1]',
                              'solicitor at law' => '__BARRISTER,[l=1]',
                              'change' => '__KAM_OILCHANGE3,[l=1]',
                              'floating deficit' => '__KAM_NIGERIAN3,[l=1]',
                              'fema stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_PATRIOT3,[l=1] __KAM_STOCK2_3,[l=0] __KAM_WEED4,[l=1] __STOCK_TIP,[l=1]',
                              'ultimate gallery' => '__KAM_GALLERY2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'via amb som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'make you big bucks' => '__KAM_SEX_EXPLICIT4,[l=1] __PUMPDUMP_04,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mysterious liquid' => '__KAM_FUN6,[l=0]',
                              'easy money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SELL2,[l=0]',
                              'quadrupling an principle' => '__PUMPDUMP_01,[l=1]',
                              'this offer is for united states' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FUN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              '{_body_html}' => 'KAM_BODY,[l=0]',
                              'free evaluation online' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LASIK3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI2,[l=1] __KAM_TRIAL,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __PILL_PRICE_01,[l=1]',
                              'reputation giant' => '__KAM_BACK1,[l=1] __KAM_BAD_REVIEW2,[l=0]',
                              'buying a new car' => '__KAM_CAR2,[l=0] __KAM_DOMAIN1,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'touchfire' => '__KAM_SALE3,[l=1] __KAM_SALEA_3,[l=1]',
                              'sements' => '__ADMITS_SPAM,[l=1] __THIS_AD,[l=1]',
                              'permanent removal of your ' => '__ACCESS_REVOKE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HERPES3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fresh p' => '__KAM_CHICKEN3,[l=1] __KAM_GALLERY4,[l=1]',
                              'suggestion' => '__DEAL,[l=1]',
                              'val amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'you are subscription' => '__RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'financial' => '__DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1]',
                              'bisu' => '__KAM_STOCKTIP140,[l=1]',
                              ' loss' => '__KAM_HAIRTRANS3,[l=1]',
                              'auto accident' => '__AUTO_ACCIDENT,[l=0] __DECEASED,[l=1] __KAM_ASSASSIN4,[l=1] __KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'preferred rx' => '__JMQ_REALESTATE3,[l=1] __KAM_DRUG2_3,[l=1]',
                              'quadrupling your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'counts:' => '__KAM_LIST3_3,[l=1]',
                              'via val cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'mega adu' => '__KAM_GALLERY4,[l=1]',
                              'http://' => '__KAM_CARD3,[l=1]',
                              'compensation fund' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __KAM_INVEST4,[l=1] __KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'window' => '__KAM_WINDOWS3,[l=1]',
                              'problems' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_GOVT4,[l=1] __KAM_LOAN3,[l=1]',
                              'fresh savings' => '__KAM_CHICKEN3,[l=1] __KAM_HEALTH2,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_REFI5,[l=1]',
                              'amb via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              ' dollars to our users' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_COVID5,[l=1] __WE_PAID,[l=1]',
                              'chat with me' => '__KAM_PIC4,[l=1]',
                              'chinese secret' => '__HUSH_HUSH,[l=1] __KAM_ANA1,[l=1] __KAM_WEIGHT2,[l=1]',
                              ' details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'r\\363zne komputery zalogowaniu sie' => '__LOTTO_DEPT,[l=1] __MAIL_ACCT_ACCESS1,[l=1]',
                              'field of financial services' => '__DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT4,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              '#1 trick' => '__KAM_HEART3,[l=1] __KAM_WEIRDTRICK2,[l=1]',
                              'mer xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              ' before friday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __KAM_PATRIOT3,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'wealth' => '__KAM_NIGERIAN5,[l=1]',
                              'amb cia lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'mer amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'via som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'buying' => '__KAM_DOMAIN1,[l=1]',
                              'une mallette m=e9tallique' => '__KAM_SEX_EXPLICIT4,[l=1] __TRUNK_BOX,[l=1]',
                              'cia cia som' => 'KAM_VIAGRA2,[l=0]',
                              'phenterthin' => '__KAM_ANA1,[l=1] __KAM_GIFT4,[l=1]',
                              'check p' => '__KAM_CREDIT2,[l=1] __KAM_GALLERY4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'found your pictures' => '__DECEASED,[l=1] __FOUND_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC3,[l=1] __KAM_PIC5,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'analysis' => '__KAM_SEO5,[l=1]',
                              'in return to me linking back' => '__DOS_LINK,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_LIKE3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'sweet tooth' => '__KAM_CANDY3,[l=0]',
                              'join, bid' => '__KAM_SWIPE3,[l=1]',
                              'no further obligation' => '__DEAL,[l=1] __KAM_GEVALIA3,[l=1] __KAM_HEALTH2,[l=1]',
                              'second' => '__KAM_FOUNTAINOFYOUTH3,[l=1]',
                              'via pro cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'prefer not to receive these messages' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'furnish you with' => '__FRAUD_YWW,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'discover' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_WEBINAR4,[l=1]',
                              'attached payment' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_PAYMENTSCAM2,[l=0] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __PLS_REVIEW,[l=1] __YOUR_FUND,[l=1]',
                              'you will have your email taken off' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST5,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_QUOTA2,[l=1] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'website' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1]',
                              'homeowner' => '__KAM_REFI2,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'transcript in any field' => '__KAM_UNIV11,[l=1]',
                              'our_email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'i was layed off from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'invitation' => '__KAM_FAKEDELIVER1,[l=1] __KAM_HONOR4,[l=0]',
                              'reply with catalog' => '__FRAUD_MLY,[l=1] __KAM_INQUIRY_1,[l=0]',
                              'emails for every state' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST1,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'restore' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_QUOTA2,[l=1] __KAM_SNORE3,[l=1] __STOCK_TIP,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'lenders' => '__KAM_AUTONEW3,[l=1]',
                              'spend a night with you' => '__KAM_DATINGTIPS3,[l=1] __KAM_SEX2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'my name is prince' => '__FRAUD_QXX,[l=1] __JMQ_RESUME2,[l=0] __KAM_COVID3_1,[l=0] __KAM_HOWRU2,[l=0] __KAM_INVEST2,[l=1]',
                              'procure the list' => '__DEAL,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'lev cia som' => 'KAM_VIAGRA2,[l=0]',
                              'asasination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __KAM_PATRIOT3,[l=1]',
                              'hearing aids' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_FUN7,[l=1]',
                              'was deleted' => '__VBOUNCE_ATTACHMENT0,[l=1]',
                              'fuckbook' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'regarding' => '__ACH_CANCELLED_04,[l=1]',
                              'son of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              'everywhere' => '__KAM_WEIGHT2,[l=1]',
                              'all' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'tired afternoon' => '__KAM_PIC1,[l=1] __KAM_SNORE3,[l=1]',
                              '100% safe' => '__FEES,[l=1] __FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1] __KAM_MERCHANT3,[l=1]',
                              'last a lot longer' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_PACKAGE2,[l=1] __KAM_SEX05_2,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'marketing campaign' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'to any foreigner' => '__FRAUD_XJR,[l=0] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'securing the monies' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1]',
                              'eliminare tutti i tuoi segreti' => '__NEVER_HEAR_IT,[l=0]',
                              'xan via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'buy right' => '__KAM_DETOX3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_PATRIOT3,[l=1]',
                              'mailbox ' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_VM4,[l=1] __YOU_WON_01,[l=1]',
                              'mer pro mer' => 'KAM_VIAGRA2,[l=0]',
                              'no examinations' => '__KAM_INSURE2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_UNIV15,[l=1] __UN,[l=1]',
                              'top of bing' => '__KAM_SEO2,[l=1]',
                              'val pro som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'dear christian friend' => '__DOS_BODY_FRI,[l=1] __KAM_PROPHET3,[l=0] __KAM_PROPHET4,[l=1] __KAM_RELIGION3,[l=0]',
                              'automated' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_PHISH4_2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'xanax' => 'DRUGS_SMEAR1,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'ascent your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bored today' => '__DAY_I_EARNED,[l=1] __KAM_GIFT3,[l=1] __KAM_PIC1,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'american grants and loans catalog' => '__KAM_AP3,[l=0] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'free quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_ALARM2,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'going out of your residence' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you are receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'contacts and email' => '__ADMAIL,[l=1] __CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_4,[l=1] __YOU_WON_01,[l=1]',
                              'consultant' => '__KAM_INVEST2,[l=1]',
                              ' opens tomorrow' => '__PUMPDUMP_03,[l=1]',
                              'older women' => '__KAM_FUN7,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'buy you out' => '__KAM_CONTRACT3,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'debt is understood' => '__KAM_STUDENTLOAN5,[l=0] __STOCK_TIP,[l=1]',
                              'you have receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'buyer with ca' => '__KAM_REAL2_3,[l=1]',
                              ' pm' => '__KAM_COMPROMISED3,[l=1]',
                              'as the beneficiary' => 'DEAR_BENEFICIARY,[l=1] __DEAL,[l=1] __FRAUD_PVN,[l=0] __KAM_BANK_2,[l=0]',
                              'hsrupdates' => '__KAM_HSR1,[l=1] __KAM_INSURE4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'geld' => '__YOUR_FUND,[l=1]',
                              'little' => '__KAM_DETOX3,[l=1]',
                              'made logo' => '__DAY_I_EARNED,[l=1] __KAM_LOGO3,[l=1]',
                              'gra' => '__KAM_VIAGRA9A,[l=1]',
                              'cia xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'une mallette m\\351tallique' => '__KAM_SEX_EXPLICIT4,[l=1] __TRUNK_BOX,[l=1]',
                              'exclusive place' => '__KAM_DEALS3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_REAL2_2,[l=1]',
                              'be clever, buy your medications' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE4,[l=1] __KAM_MED1,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you are receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bring your girlfriend back' => '__DECEASED,[l=1] __DOS_BODY_FRI,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC2,[l=1] __KAM_REFI3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEX4,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'o or msn' => '__KAM_URONLINE1,[l=1]',
                              'selected' => '__RANDOM_PICK,[l=1]',
                              'computer ballot' => '__HK_LOTTO_BALLOT,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __RANDOM_PICK,[l=1]',
                              'christian' => '__KAM_PROPHET4,[l=1]',
                              'problem with the address' => '__DEAL,[l=1] __KAM_GOVT4,[l=1] __KAM_INVOICE4,[l=1]',
                              'lev mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'cia lev cia' => 'KAM_VIAGRA2,[l=0]',
                              'guaranteed access' => '__KAM_GALLERY2,[l=1] __KAM_SEO5,[l=1]',
                              'set to expire' => '__KAM_INSURE4,[l=1]',
                              'complete information' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LIST3_4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'americans for limited government' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1] __KAM_TRIAL,[l=1] __YOU_WON_02,[l=1]',
                              'check it out today' => '__DAY_I_EARNED,[l=1] __KAM_CREDIT2,[l=1] __KAM_DRUG2_5,[l=1] __KAM_GIFT3,[l=1] __KAM_SUNGLASSES3,[l=1] __LOTTO_WIN_01,[l=1]',
                              ' a ' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'alkuper\\344inen viesti' => '__freemail_safe_fwd,[l=1]',
                              'lev lev cia' => 'KAM_VIAGRA2,[l=0]',
                              'clinically' => '__KAM_DRUG2_6,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TVDOCTOR3,[l=1]',
                              'fiduciary claims' => '__HK_LOTTO_2,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1]',
                              'you\'re received this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'keyword' => '__KAM_SEARCH4,[l=1]',
                              ' monday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'lev xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'personal video' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_PRIV2,[l=0]',
                              'therapy' => '__DEAL,[l=1] __KAM_ANDROGEL3,[l=1]',
                              'like to share some of my pics' => '__KAM_LED2,[l=1] __KAM_PIC4,[l=1] __KAM_PIC5,[l=0]',
                              'private ' => '__FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1]',
                              'vortex rug' => '__KAM_HOLIDAY2020_2,[l=0]',
                              'mutual' => '__DEAL,[l=1]',
                              'lots' => '__KAM_REMEMBERWHEN3,[l=1]',
                              'damag' => 'BAD_CREDIT,[l=1]',
                              'managing director email database' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_DIRECT4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_SKIN4,[l=1] __YOU_WON_01,[l=1]',
                              'data analyst' => '__KAM_LIST3_2,[l=1] __KAM_STOCK2_4,[l=0]',
                              'quality meds' => 'TVD_QUAL_MEDS,[l=1] __KAM_DRUG1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              'me a do' => '__KAM_UNIV3B,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'preventing a heart attack' => '__KAM_DEATH4,[l=1] __KAM_HEART3,[l=1] __KAM_HEARTPROD1,[l=1] __KAM_TOURS3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'using them for a couple months' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __KAM_CEP6,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SKIN4,[l=1] __KAM_UNIV1B,[l=1] __KAM_UNIV2,[l=1] __KAM_URUNIT5,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'virus on a porn web' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SEX_EXPLICIT6,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'enjoy your awesome card' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CARD2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'assasinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'amb pro som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'trading at a low' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_10,[l=1]',
                              'yellow pill' => '__KAM_SEX04_1,[l=1] __PILL_PRICE_01,[l=1]',
                              'typeform.com' => '__KAM_DOMAIN2,[l=1] __KAM_FAKEINV2_3,[l=0] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __YOU_WON_02,[l=1]',
                              'debt relief options' => '__KAM_DEBT1,[l=1] __KAM_DRUG2_3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'list services' => '__KAM_LIST3_2,[l=1] __KAM_LIST4,[l=1] __KAM_REFI2,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WEB3,[l=1]',
                              'indicate you interest' => '__BACK_SCRATCH,[l=1] __KAM_DISCLOSE1,[l=0] __KAM_DOMAIN3,[l=1] __KAM_SNORE3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'have some social networks' => '__FOR_SALE_NET,[l=1] __KAM_CAREER3,[l=1] __KAM_HOOKUP3,[l=1] __KAM_HOWRU3,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'zarobi' => '__KAM_MM_FOREX_1,[l=1]',
                              'trading at such a low' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_10,[l=1]',
                              'cia val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'youngest teen' => '__KAM_SEX4,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'interested in ' => 'KAM_ADVERT2,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE2,[l=1] __KAM_SNORE3,[l=1]',
                              'secret to their hearts' => '__DEAL,[l=1] __HUSH_HUSH,[l=1] __KAM_BACK2,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_DEATH4,[l=1] __KAM_WEIGHT2,[l=1]',
                              'field of your expertise' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV13,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'manhood' => '__KAM_ANDROGEL3,[l=1]',
                              'lev val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'disaster' => '__KAM_PATRIOT3,[l=1]',
                              'funds can be directed to your account as a grant' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_ERROR,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_DIRECT4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __TVD_PH_BODY_04,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mer amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'draw' => '__LOTTO_WIN_01,[l=1]',
                              'redeem' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT4,[l=1]',
                              'cellulite' => '__KAM_WEIGHT1,[l=1]',
                              'amerilithium' => '__KAM_STOCKTIP143,[l=1]',
                              'som pro cia' => 'KAM_VIAGRA2,[l=0]',
                              'gieldzie' => '__KAM_MM_FOREX_1,[l=1]',
                              'money making challenge' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK2,[l=1] __KAM_VISION3,[l=1]',
                              'extension' => '__KAM_DOMAIN1,[l=1]',
                              'complaining' => '__KAM_REP3_2,[l=1] __KAM_URUNIT3,[l=1]',
                              'recommended this stock' => '__DEAL,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_3,[l=0] __KAM_WEED4,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1] __THIS_AD,[l=1]',
                              'cash for your timeshare' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME4,[l=1] __KAM_TIMESHARE1,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'united states dollar' => 'MILLION_USD,[l=1] __KAM_COVID5,[l=1] __KAM_NIGERIAN1,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'hd access' => '__KAM_GALLERY2,[l=1]',
                              'mer via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'xan pro mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'hip replacement' => '__JMQ_REALESTATE3,[l=1] __KAM_CAREER2,[l=1] __KAM_HIP1,[l=0] __KAM_WINDOWS3,[l=1]',
                              'kinky pee' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'order n' => '__KAM_BADZIP3,[l=0] __KAM_DRUG2_5,[l=1]',
                              'director of central bank' => '__JMQ_WIRE3,[l=1] __KAM_DIRECT4,[l=1] __KAM_NIGERIAN2_2,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_SWIPE4,[l=1]',
                              'wish not to receive future emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'view now' => '__KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_URONLINE1,[l=1]',
                              'heave your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'advice' => '__KAM_ACCOUNTPHISH3,[l=1]',
                              'in has been accessed' => '__MAIL_ACCT_ACCESS1,[l=1]',
                              'brother of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1] __KAM_REMEMBERWHEN2,[l=1]',
                              'val mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'like to chat' => '__KAM_LED2,[l=1] __KAM_PIC3,[l=1]',
                              'syria' => '__KAM_BENEFICIARY4,[l=0]',
                              'caribean' => '__KAM_VACATION3,[l=1]',
                              'report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT3,[l=1]',
                              'colorado' => '__KAM_MARIJUANA3,[l=1]',
                              'suporte t=e9cnico' => '__SYSADMIN,[l=1]',
                              'black babe' => '__KAM_GALLERY4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'gas prices are at an all time high' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GAS1,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1]',
                              'russian' => '__KAM_WIFE2,[l=1]',
                              'leaving your house' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'important message from citizens' => '__ADMAIL,[l=1] __JMQ_IMPORTANT2,[l=0] __KAM_CITIZEN2,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'moving the funds' => '__DEAL,[l=1] __KAM_NIGERIAN4,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              ' that you no longer wish to receive promotional messages' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __ADMAIL,[l=1] __KAM_GIFT5,[l=1] __KAM_LOTTO4,[l=1] __KAM_PACKAGE2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_SEO6,[l=1] __KAM_SPAMKING4,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'visitor' => '__KAM_DIRECT3,[l=0]',
                              'improve your lovemaking' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX4,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'piece' => '__KAM_TIME2,[l=1]',
                              'instant access' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_GALLERY2,[l=1] __KAM_LOAN3,[l=1]',
                              'account suspension' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH2_5,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'the late president' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_EZY,[l=1] __KAM_STUDENT3,[l=1]',
                              'end users' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST3_4,[l=1]',
                              'winning guy' => '__KAM_POLITICS2,[l=1] __KAM_URUNIT6,[l=1]',
                              'rental' => '__KAM_HOME2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'market' => '__KAM_PATRIOT3,[l=1]',
                              'qsms' => '__KAM_STOCKTIP167,[l=1]',
                              'great bonus' => '__KAM_SEX04_4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'select legal' => '__KAM_DEBT1,[l=1] __KAM_WEED1,[l=1]',
                              'interested in the domain' => 'KAM_ADVERT2,[l=1] __BACK_SCRATCH,[l=1] __DEAL,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE2,[l=1] __KAM_DOMAIN_SALE4,[l=1] __KAM_SNORE3,[l=1]',
                              'higher limit' => '__KAM_NEW_CREDITCARD3,[l=1]',
                              'complimentary gift' => '__KAM_CLOUD4,[l=1] __KAM_DIRECT3,[l=0] __KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT1,[l=1] __KAM_REP3_2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'compliant with all legal provisions of the can-spam act' => 'KAM_CANSPAM,[l=1] __DEAL,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VISION3,[l=1] __KAM_WEED1,[l=1]',
                              'this offer for usa' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              '5k a day' => '__DAY_I_EARNED,[l=1] __KAM_TELEWORK1,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'premature ejaculation' => 'IMPOTENCE,[l=1]',
                              'few samples' => '__KAM_LIST3_3,[l=1] __KAM_WEB2_4,[l=0]',
                              'collection professionals' => '__KAM_COLLECT3,[l=0] __KAM_GARAGE3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'untimely death' => '__EARLY_DEMISE,[l=1] __KAM_FUNERAL3,[l=1] __KAM_TIME4,[l=1] __NOT_DEAD_YET,[l=1]',
                              'change your daily life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'top deals' => '__DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_SUNGLASSES2,[l=1] __KAM_VACATION3,[l=1]',
                              'green' => '__KAM_ANA1,[l=1]',
                              'phone' => '__KAM_CELL3,[l=1]',
                              'covid-19 charity fund' => '__CHARITY,[l=1] __KAM_COVID2_1,[l=0] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'attend our open house' => '__KAM_DIRECT3,[l=0]',
                              'electronic have been hacked' => '__KAM_HACK1,[l=0] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'photo' => '__KAM_PIC5,[l=0]',
                              'country' => '__INVEST_COUNTRY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN5,[l=1]',
                              'ticker' => '__KAM_STOCK3,[l=1]',
                              'via pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'unable to locate your address' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ihre kreditkarte weist einige sicherheitsprobleme' => '__ACCOUNT_SECURE,[l=1] __KAM_CRYPTO1,[l=1] __KAM_GOVT4,[l=1] __YOUR_FUND,[l=1]',
                              'extreme penetration' => '__KAM_GALLERY4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX4,[l=0]',
                              'feeling chubby' => '__KAM_DIET2_3,[l=1]',
                              'you came to russia' => '__KAM_URONLINE2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'male enhancement' => 'MALE_ENHANCE,[l=0] __KAM_PHISH2_4,[l=1]',
                              'heavily' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'you have received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'established partner' => 'BAD_CREDIT,[l=1] __KAM_INVEST2,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'acai elite' => '__KAM_ANA1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'quick and easy trick' => '__KAM_SKIN4,[l=1] __KAM_WEIRDTRICK2,[l=1]',
                              'aise ballot' => '__HK_LOTTO_BALLOT,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'pro lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'muslim' => '__KAM_JESUS3,[l=1] __KAM_WEIGHT1,[l=1]',
                              'thompson cigar' => '__KAM_CIGAR3,[l=0]',
                              'prize notification' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'retrieve yourheld ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev som lev' => 'KAM_VIAGRA2,[l=0]',
                              'more babe' => '__KAM_GALLERY4,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'resugar' => '__KAM_CELEB2,[l=0]',
                              'reply immediately' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CREDIT3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1]',
                              'press this web link' => '__DEAL,[l=1] __DOS_LINK,[l=1] __KAM_URONLINE1,[l=1] __THIS_AD,[l=1]',
                              'dropbox' => '__KAM_PHISH2_4,[l=1] __KAM_REFI6,[l=1]',
                              'herpes' => '__KAM_HERPES3,[l=1]',
                              'hoist your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'loan option' => '__KAM_LOAN3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'national' => '__HK_LOTTO_2,[l=1] __KAM_PATRIOT3,[l=1]',
                              'eliminate' => 'BAD_CREDIT,[l=1]',
                              'buil tech services' => '__KAM_BADNAME1,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'legitimate verifiable degree' => '__KAM_CEP2,[l=1] __KAM_UNIV2,[l=1]',
                              'let go from my employment i held for' => '__KAM_JOB1,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'pimsleur' => '__KAM_COVID5,[l=1] __KAM_LANG3,[l=1]',
                              'fresh girl' => '__KAM_CHICKEN3,[l=1] __KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1]',
                              'canadian pharmacy' => '__KAM_SEX04_1,[l=1]',
                              'accounts' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'update your account information' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_ERROR,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VERIZON5,[l=0] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_BANK,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'tinnitus' => '__KAM_DUJOUR2,[l=0] __KAM_TINNITUS3,[l=1]',
                              'of late president' => '__DECEASED,[l=1] __FRAUD_EZY,[l=1] __KAM_STUDENT3,[l=1]',
                              'ur info' => '__KAM_REP3_2,[l=1] __KAM_URONLINE2,[l=1]',
                              '&#x62;&#x69;&#x74;&#x63;&#x6f;&#x69;&#x6e;' => '__BTC_OBFU_5,[l=0]',
                              'pro pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'amb mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'can\'t see the images below' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1]',
                              'bureau' => '__LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'ppyh' => '__KAM_STOCKTIP127,[l=1]',
                              'card\'s direct www address below' => '__KAM_CARD2,[l=1] __KAM_DIRECT4,[l=1] __KAM_REP2,[l=1]',
                              'link is for removal' => 'KAM_ADVERT2,[l=1] __DOS_LINK,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOU_WON_02,[l=1]',
                              'quality junk spam' => '__KAM_DRUG1,[l=1] __KAM_SEO6,[l=1]',
                              'united' => '__KAM_NIGERIAN1,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'insurance' => '__KAM_AUTONEW2,[l=1] __KAM_INSURE4,[l=1]',
                              ' dollar bonus offer' => '__BONUS_LAST_DAY,[l=1] __KAM_COVID5,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'security center' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT4,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SWIPE4,[l=1] __SYSADMIN,[l=1] __TRUNK_BOX,[l=1]',
                              'ur significant other' => '__DEAL,[l=1] __KAM_URUNIT2,[l=1]',
                              'insane p' => '__KAM_GALLERY4,[l=1]',
                              'doesn\'t injured' => '__KAM_STUDENTLOAN3,[l=0]',
                              'aid your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'ve received this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'monster in his pants' => '__DOS_BODY_MON,[l=1] __KAM_SEX4,[l=0]',
                              'flowers' => '__KAM_MOTHER3,[l=1] __KAM_REFI3,[l=1]',
                              'central bank' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'to be removed' => 'EXCUSE_4,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'millon u' => '__FRAUD_LTX,[l=1]',
                              'cia som lev' => 'KAM_VIAGRA2,[l=0]',
                              'fax service' => '__KAM_PAPERLESS3,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'this offer is for usa' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FUN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'see the attach' => '__DEAL,[l=1] __KAM_FAKEINV2_2,[l=0]',
                              'xan amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'we is not spam' => 'NOT_SPAM,[l=1]',
                              'som pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'barr.' => '__BARRISTER,[l=1]',
                              'view scan' => '__KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_UKINV2,[l=0]',
                              'latest' => '__DECEASED,[l=1] __KAM_CELL3,[l=1]',
                              'mail account been accessed' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ADMAIL,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __MAIL_ACCT_ACCESS1,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __WEBMAIL_ACCT,[l=1] __YOU_WON_01,[l=1]',
                              'exceeded its storage limit' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_BOXQUOTA,[l=1] __KAM_QUOTA1,[l=0] __STOCK_TIP,[l=1]',
                              'petplan' => '__KAM_FUN2,[l=1]',
                              'trading at a cheap' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_10,[l=1]',
                              'desk' => '__SYSADMIN,[l=1]',
                              'insanerx' => '__KAM_DRUG2_5,[l=1]',
                              'cia lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              '.pk' => '__DOS_BODY_TICKER,[l=1]',
                              'vacation home' => '__KAM_REAL2_4,[l=1] __KAM_REAL3,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              ' thursday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'sensa' => '__KAM_WEIGHT2,[l=1]',
                              ' to our subscribers' => '__SUBSCRIPTION_INFO,[l=1] __WE_PAID,[l=1]',
                              'postal' => '__KAM_FAKEDELIVER1,[l=1]',
                              'solanex management' => '__KAM_STOCKTIP139,[l=1] __KAM_WEBINAR4,[l=1]',
                              'mail just w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1] __hk_win_0,[l=1]',
                              'weiter zur aktualisierung' => '__ACCOUNT_UPGRADE,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'vision' => '__KAM_VISION3,[l=1]',
                              'lev lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'marketing specialist' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_VISION3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'plpl' => '__KAM_STOCKTIP146,[l=1]',
                              'wax build up' => '__KAM_CHICKEN3,[l=1] __KAM_DUTCHGLOW3,[l=1]',
                              'discovered a dormant account' => '__DORMANT_ACCT,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_S15,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEBINAR4,[l=1]',
                              'formulaire sans titre' => '__CHARITY,[l=1] __KAM_DOMAIN2,[l=1] __KAM_GOOGLEFORM_2,[l=0] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'think' => '__KAM_ARREST2,[l=1]',
                              'deposit' => '__ACH_CANCELLED_02,[l=1] __DORMANT_ACCT,[l=1]',
                              'event manager' => '__KAM_LIST3_2,[l=1] __KAM_TOURS3,[l=1]',
                              'the chick' => '__DEAL,[l=1] __KAM_GALLERY4,[l=1]',
                              'excess' => '__KAM_WEIGHT2,[l=1]',
                              'back into shape' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1] __KAM_URZEST5,[l=0]',
                              'high revenue' => '__KAM_SEARCH4,[l=1] __KAM_SEO5,[l=1]',
                              'pro quality pho' => '__KAM_DRUG1,[l=1] __KAM_LENS1,[l=0]',
                              'mer lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'football' => '__KAM_FOOTBALL4,[l=0] __KAM_SEX_EXPLICIT4,[l=1]',
                              'i send you my tender love' => '__KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'val mer pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'first page of bing' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'urawinner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __KAM_LOTTO5,[l=1] __hk_win_2,[l=1]',
                              'amb amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'many p' => '__KAM_GALLERY4,[l=1]',
                              'unsatisfied judgments' => '__DOS_BODY_SAT,[l=1] __KAM_JUDGE1,[l=1] __KAM_JUDGE4,[l=0] __KAM_URUNIT3,[l=1]',
                              'account oversea' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_N15,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI2,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'mer via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'event analyst' => '__KAM_LIST3_2,[l=1] __KAM_STOCK2_4,[l=0] __KAM_TOURS3,[l=1]',
                              'goodpic' => '__JMQ_PICKUP2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'amazing' => '__KAM_STOCK2_2,[l=1]',
                              'person who handles the promotions' => '__DEAL,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __KAM_USB2,[l=0] __KAM_WEBINAR4,[l=1] __THIS_AD,[l=1]',
                              'xxx tube' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'mobile' => '__KAM_WEB3,[l=1]',
                              'ur size' => 'BODY_ENHANCEMENT2,[l=1] __KAM_URUNIT2,[l=1]',
                              'pet health insurance' => '__KAM_AUTONEW2,[l=1] __KAM_INSURE4,[l=1] __KAM_JOINT3,[l=1] __KAM_PET3,[l=1]',
                              'systems' => '__KAM_ACCOUNTPHISH4,[l=1]',
                              'committee' => '__KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'find your mail in public forum' => 'KAM_PUBLIC,[l=1] __ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_TRACKR3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_INSURE4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'property & personal history investigation' => '__INVEST_MONEY,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ANCESTOR3,[l=1] __KAM_BACK2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REAL2_4,[l=1] __STOCK_TIP,[l=1]',
                              'val via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'improve your future, and your income' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV3B,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'seeking fund' => '__KAM_INVEST3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'weeks' => '__KAM_SKIN4,[l=1]',
                              'xan mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'intestate' => '__KAM_INSURE4,[l=1] __WILL_LEGAL,[l=1]',
                              'mer mer cia' => 'KAM_VIAGRA2,[l=0]',
                              'secret' => '__HUSH_HUSH,[l=1] __KAM_WEIGHT2,[l=1]',
                              'recalls' => '__KAM_RECALL3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'keep and bear arms' => '__KAM_ALARM2,[l=1] __KAM_GUN1,[l=0]',
                              'ukrainian bride' => '__KAM_AUTO3,[l=1] __KAM_WIFE2,[l=1]',
                              'family treasure' => '__KAM_BENEFICIARY6,[l=0]',
                              'som val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'retired' => '__KAM_NIGERIAN1,[l=1] __KAM_SNORE3,[l=1]',
                              'recreational' => '__KAM_MARIJUANA2,[l=1]',
                              'amb som som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              '1 0 2 0 n h o l l y w o o d w a y ' => 'KAM_HOLLY,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              '20 times its weight' => 'DIET_1,[l=1] __KAM_LOAN3,[l=1] __KAM_SHAM4,[l=0] __KAM_TIME4,[l=1] __KAM_WEIGHT2,[l=1]',
                              'free bottle' => '__KAM_JOINT5,[l=0] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'diplomatic' => '__DIPLOMATIC,[l=1] __KAM_UNIV6B,[l=1]',
                              'checkmate' => '__KAM_BACK1,[l=1] __KAM_CREDIT2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'via mer mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'rxwarehousehere' => '__KAM_DRUG2_5,[l=1]',
                              'pro xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'xams' => '__KAM_UNIV15,[l=1]',
                              'xan cia amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'nations' => '__KAM_PATRIOT3,[l=1] __UN,[l=1]',
                              'supplies' => '__KAM_DRUG2,[l=1]',
                              'tired tonight' => '__KAM_DATINGTIPS3,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1]',
                              'doctor are raving' => '__KAM_DIET2_3,[l=1] __KAM_MARIJUANA3,[l=1]',
                              'radical' => '__KAM_POLITICS2,[l=1]',
                              'looking to get in the gym' => '__DEAL,[l=1] __JMQ_REALESTATE3,[l=1] __KAM_URONLINE3,[l=1] __KAM_URZEST3,[l=0]',
                              'join thousands' => 'JOIN_MILLIONS,[l=1] __FRAUD_LTX,[l=1] __KAM_MEMBER3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'via via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'pro lev pro' => 'KAM_VIAGRA2,[l=0]',
                              'past work experience' => '__KAM_CAREER3,[l=1] __KAM_UNIV3,[l=1]',
                              'via xan val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'contractual employment' => '__KAM_NIGERIAN4,[l=1]',
                              'som som cia' => 'KAM_VIAGRA2,[l=0]',
                              'pro val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'refinance your current house' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'empowerment' => '__KAM_COVID3,[l=1]',
                              'complimentary insurance quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CLOUD4,[l=1] __KAM_DIRECT3,[l=0] __KAM_INSURE4,[l=1] __KAM_REP3_2,[l=1] __KAM_WARRANTY3,[l=0]',
                              'bitcoin' => '__KAM_BITCOIN2,[l=1] __KAM_CRIM2_1,[l=1]',
                              ' media group' => 'DX_TEXT_03,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DUCHESS3,[l=1] __KAM_MED1,[l=1] __LOTTO_DEPT,[l=1]',
                              'offshore account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __HK_SCAM_N15,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SALE3,[l=1]',
                              'find better health insurance rates today' => '__DAY_I_EARNED,[l=1] __JMQ_TRACKR3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_GIFT3,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __KAM_JOINT3,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'enlarge patch' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX1,[l=1]',
                              'establish' => 'BAD_CREDIT,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'risk' => '__FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_INVEST3,[l=1]',
                              'pro via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'les tueurs' => '__DOS_BODY_TUE,[l=1] __FRAUD_PTX,[l=1] __KAM_COVID5,[l=1]',
                              'term and condition' => '__KAM_INQUIRY_3,[l=0] __KAM_INSURE4,[l=1]',
                              'liquidation' => '__KAM_REAL2_5,[l=0]',
                              'remove from lunarmessages' => '__ADMAIL,[l=1] __KAM_BADUNSUB,[l=0] __KAM_LUNAR4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'ukrainian girl' => '__KAM_PIC2,[l=1] __KAM_WIFE2,[l=1]',
                              'four legged' => '__KAM_BARK1,[l=1]',
                              'dear friend' => '__DOS_BODY_FRI,[l=1] __FRAUD_IRT,[l=1]',
                              'partner site' => 'MARKETING_PARTNERS,[l=1]',
                              'financing' => '__KAM_AUTONEW2,[l=1]',
                              'fri' => '__DOS_BODY_FRI,[l=1]',
                              'ukrainian beaut' => '__KAM_WIFE2,[l=1]',
                              'val amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'overpaid' => '__FEES,[l=1] __FRAUD_QFY,[l=1] __KAM_AUTONEW3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI2,[l=1]',
                              'unlimited exportation capabilities' => '__KAM_GERMAN_BUSINESS_CONTACTS4,[l=0] __KAM_NIGERIAN2,[l=1] __KAM_TRIAL,[l=1]',
                              'szsn' => '__KAM_STOCKTIP122,[l=1]',
                              'som via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'amb mer pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'meurs' => '__AM_DYING,[l=1] __KAM_COVID5,[l=1]',
                              'portal for xxx' => '__KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __YOU_WON_02,[l=1]',
                              'blood sugar' => '__KAM_DIABETES1,[l=1] __KAM_FUN7,[l=1]',
                              'momentum' => '__KAM_BADNAME1,[l=1]',
                              'via val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'jaw supporter' => '__KAM_SNORE3,[l=1]',
                              '% legit' => '__KAM_UNIV4B,[l=1]',
                              'please visit' => '__JMQ_IMPORTANT3,[l=0]',
                              'som mer mer' => 'KAM_VIAGRA2,[l=0]',
                              'washington' => '__KAM_MARIJUANA3,[l=1]',
                              'congratulations to your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_7,[l=1]',
                              'smoking alternative' => '__KAM_SMOKE1,[l=1]',
                              'women will be daydreaming' => '__DAY_I_EARNED,[l=1] __I_WILL_YOU,[l=1] __KAM_AUTO3,[l=1] __KAM_QUOTA2,[l=1] __KAM_SEX05_2,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'meal delivery' => '__FEES,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_NUWAVE3,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'size of there ' => 'BODY_ENHANCEMENT2,[l=1] TVD_INCREASE_SIZE,[l=1] __DEAL,[l=1] __KAM_URUNIT5,[l=1]',
                              'important' => '__KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_2,[l=1]',
                              'check out our web site' => '__KAM_CREDIT2,[l=1] __KAM_DRUG2_5,[l=1] __LOTTO_WIN_01,[l=1]',
                              'apprehensive' => '__KAM_INVEST2,[l=1]',
                              'finish building' => '__KAM_CHICKEN3,[l=1] __KAM_REAL2_2,[l=1] __KAM_SEO2,[l=1]',
                              'authority' => '__KAM_STOCK2_1,[l=1]',
                              'xan xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'save you ' => '__KAM_REFI6,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'repair' => 'BAD_CREDIT,[l=1] __KAM_AUTONEW3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_REPAIR2_3,[l=1]',
                              'free price quote' => 'FREE_QUOTE_INSTANT,[l=1] LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_CAR3,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'cuts cholesterol' => '__KAM_WEIGHT1,[l=1]',
                              'business card offer' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BIZ1,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_SALE3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'diamond' => '__DOS_BODY_MON,[l=1] __KAM_TIME2,[l=1]',
                              'xan amb pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'amb via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'decision' => '__KAM_LIST3_3,[l=1]',
                              'line draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1]',
                              'specific parameters' => '__KAM_LIST3_3,[l=1] __KAM_SEO3,[l=1]',
                              'data intelligence' => '__KAM_LIST3_4,[l=1]',
                              'tired this evening' => '__DEAL,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __THIS_AD,[l=1]',
                              'coolestrxhere' => '__KAM_DRUG2_5,[l=1]',
                              'via som cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'som xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'free evaluation on your home loan' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME1,[l=1] __KAM_INSURE4,[l=1] __KAM_LASIK3,[l=1] __KAM_REFI2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_TRIAL,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __KAM_WINDOWS3,[l=1] __PILL_PRICE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'delivery' => '__FEES,[l=1] __KAM_FAKEDELIVER1,[l=1]',
                              '0rder' => '__KAM_DRUG2_5,[l=1]',
                              'let go from a job i held for' => '__KAM_JOB1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'file' => '__JMQ_RESUME3,[l=1]',
                              'refinanc' => 'REFINANCE_NOW,[l=1]',
                              'be smart, buy your pills' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_FUN7,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'make an extra dollar' => 'DIET_1,[l=1] __KAM_COVID5,[l=1] __KAM_GIFT3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __MAKE_XTRA_DOLLAR,[l=1] __RECEIVE_BONUS,[l=1]',
                              'you are chosen' => '__KAM_CHOSEN3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pay later' => '__DECEASED,[l=1] __FEES,[l=1] __KAM_CAR3,[l=1] __PAY_YOU,[l=1]',
                              'pro cia mer' => 'KAM_VIAGRA2,[l=0]',
                              'val som som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'on holiday' => '__BOUNCE_OOO_CB2,[l=1] __DAY_I_EARNED,[l=1]',
                              'looking for dynamic representative' => '__JMQ_REALESTATE3,[l=1] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_URONLINE3,[l=1] __YOU_WON_02,[l=1]',
                              'all the training' => '__DEAL,[l=1] __KAM_CAREER2,[l=1] __KAM_CEP1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK4,[l=1]',
                              'mer som mer' => 'KAM_VIAGRA2,[l=0]',
                              'dirtypic' => '__JMQ_PICKUP2,[l=1]',
                              'direct' => '__KAM_DIRECT4,[l=1]',
                              'marketing project' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_DRAPES3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'visit the page below' => '__DEAL,[l=1] __KAM_FUN3,[l=1] __KAM_PAPERLESS3,[l=1]',
                              'inbox by requesting removal' => 'KAM_ADVERT2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __SUBSCRIPTION_INFO,[l=1] __URG_BIZ,[l=1]',
                              'draws' => '__KAM_DOMAIN1,[l=1] __LOTTO_WIN_01,[l=1]',
                              ' tomorrow open' => '__PUMPDUMP_03,[l=1]',
                              'compiled a list' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'proof' => '__TRUNK_BOX,[l=1]',
                              'salutary effect' => '__KAM_SEX04_1,[l=1]',
                              'good medical supplies' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1] __KAM_SEX04_1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'unwanted timeshare' => '__KAM_ARREST2,[l=1] __KAM_LOAN3,[l=1] __KAM_TIME4,[l=1] __KAM_TIMESHARE1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'first page of msn' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'recommend this stock' => '__DEAL,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_3,[l=0] __KAM_WEED4,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1] __THIS_AD,[l=1]',
                              'jrgpartners(.)com' => '__KAM_RBL_OBFU3,[l=0] __KAM_REP3_2,[l=1]',
                              'succeed in trading' => '__KAM_STOCK2_2,[l=1]',
                              'free software' => '__KAM_SOFTWARE4,[l=0] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'rising laptop' => '__KAM_HOLIDAY2020_2,[l=0] __KAM_REPAIR1_3,[l=1]',
                              'killed' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'read attached' => '__KAM_FAKEDELIVER1,[l=1] __KAM_HACK2,[l=0] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1]',
                              'attached to email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BADZIP1,[l=0] __KAM_ENGINEER2,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1] __YOU_WON_01,[l=1]',
                              'xan val mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'appetite suppressant' => '__KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_WEIGHT1,[l=1]',
                              'view and pay invoice' => '__FEES,[l=1] __FRAUD_QFY,[l=1] __KAM_AUTONEW3,[l=1] __KAM_FAKE_FAX4,[l=0] __KAM_HEALTH2,[l=1] __KAM_TOLL3,[l=1] __KAM_UKINV2,[l=0] __KAM_VM3,[l=1] __PAY_YOU,[l=1]',
                              'dear madam' => 'DEAR_SOMETHING,[l=1]',
                              'vous =c3=aates' => '__YOU_WON_04,[l=1]',
                              'be clever, buy your pills' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'service' => '__KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'adultdatingcompany' => '__ADULTDATINGCOMPANY_BODY,[l=1] __KAM_CRIM2_3,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'cons\\303\\251quence' => '__YOU_WON_04,[l=1]',
                              'obscure' => '__HUSH_HUSH,[l=1]',
                              'god has blessed' => '__KAM_BENEFICIARY3,[l=1]',
                              'find a dentist' => '__DECEASED,[l=1] __JMQ_TRACKR3,[l=1] __KAM_DENTIST3,[l=0] __KAM_LIST2,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'watersolutiontoday' => '__DAY_I_EARNED,[l=1] __KAM_CLOUD3,[l=1] __KAM_DON3,[l=1] __KAM_GIFT3,[l=1] __KAM_LOAN3,[l=1] __KAM_SUNGLASSES3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'poor' => 'BAD_CREDIT,[l=1]',
                              'commerce' => '__KAM_REP3_2,[l=1] __KAM_WEB3,[l=1]',
                              'over-invoice' => '__FRAUD_QFY,[l=1] __FRAUD_YJA,[l=0] __KAM_FAKE_FAX4,[l=0] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_TOLL3,[l=1] __KAM_VM3,[l=1]',
                              'ezprescriptz' => 'NO_PRESCRIPTION,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1]',
                              'amb cia amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'multiple orgasms' => '__KAM_REP3_2,[l=1] __KAM_SEX4,[l=0]',
                              'investor' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_STOCK2_4,[l=0] __STOCK_TIP,[l=1]',
                              'lev lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'mer xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'children' => '__KAM_SPY3,[l=1]',
                              'qualify for a va loan' => '__KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'swipebids' => '__KAM_SWIPE4,[l=1]',
                              'contacts:' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_4,[l=1]',
                              'double' => '__KAM_SEX1,[l=1] __KAM_WINDOWS3,[l=1]',
                              'winning e' => '__KAM_POLITICS2,[l=1] __hk_win_a,[l=1]',
                              'times your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME4,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cnn' => '__KAM_TAX4,[l=1]',
                              'xan som som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'start shopping' => '__KAM_FAKEAD2,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_FLAG3,[l=1] __KAM_GIFT3,[l=1] __KAM_MOTHER3,[l=1]',
                              ' day trial' => '__DAY_I_EARNED,[l=1] __KAM_TRIAL,[l=1]',
                              'visit_0ur web' => '__KAM_DRUG2_5,[l=1]',
                              'practicing medical doctors' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST1,[l=1] __KAM_LIST2,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_MED1,[l=1] __KAM_MEDICAL1,[l=0] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'this offer is only for usa' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FUN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'remain in compliance' => '__KAM_GINA4,[l=0] __KAM_REP3_2,[l=1]',
                              'trustworthy' => '__KAM_AUTO3,[l=1] __KAM_DRUG2_6,[l=1]',
                              'unique' => '__KAM_AQUARUG3,[l=1]',
                              'leaving your residence' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'been working very hard on my friend\'s website' => '__DOS_BODY_FRI,[l=1] __KAM_CAREER3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LIKE1,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1]',
                              'purchases from your online store' => 'FREE_QUOTE_INSTANT,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'val val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '-in emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'confidential' => '__DECEASED,[l=1] __FRAUD_MCQ,[l=1] __HUSH_HUSH,[l=1] __KAM_DRUG2_6,[l=1] __KAM_NOCONFIDENCE1,[l=1] __URG_BIZ,[l=1]',
                              'mer val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'non-accredited' => 'PREST_NON_ACCREDITED,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_UNIV4,[l=1] __KAM_UNIV4B,[l=1] __KAM_UNIV9,[l=1]',
                              'amazon' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT4,[l=1]',
                              'cia lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'quintuple an principle' => '__KAM_RBL_OBFU2,[l=1] __PUMPDUMP_01,[l=1]',
                              'instant traffic to your website' => 'FREE_QUOTE_INSTANT,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ADVERT2,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_REFI3,[l=1] __KAM_SEARCH3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'i was let go from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_JOB1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'drug' => '__KAM_ANDROGEL3,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'incurable' => '__AM_DYING,[l=1] __FRAUD_WNY,[l=1]',
                              'second chance' => '__FRAUD_GBW,[l=1] __KAM_FOUNTAINOFYOUTH3,[l=1]',
                              'via amb mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'fees' => '__FEES,[l=1]',
                              'online casino' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_CASINO2,[l=0] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1]',
                              'jim kramer' => '__KAM_WEED1,[l=1]',
                              'mer amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'buy n' => '__KAM_DRUG2_5,[l=1]',
                              'you have receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'improve xxx' => '__KAM_SEX4,[l=0]',
                              'official' => '__KAM_REFI3,[l=1] __KAM_SALE3,[l=1]',
                              'belly fat' => '__KAM_FUN7,[l=1]',
                              'lottery' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              ' down' => '__KAM_LOAN3,[l=1]',
                              'invest in your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __INVEST_MONEY,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INSURE4,[l=1] __KAM_INVESTCOUNTRY2,[l=0] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '4 of the card' => '__DEAL,[l=1] __KAM_SHADYCC3,[l=0]',
                              'more clients' => '__KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SEARCH3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'prefer to receive future messages' => '__ADMAIL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'holding storage house' => '__FRAUD_IRJ,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __KAM_PHISH2_4,[l=1] __STOCK_TIP,[l=1]',
                              'have a telephone' => '__KAM_CELL3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TELEWORK2,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_01,[l=1]',
                              ' weeks' => '__KAM_CEP6,[l=1] __KAM_SKIN4,[l=1] __KAM_UNIV1B,[l=1]',
                              'copy of the signed agreement' => '__DEAL,[l=1] __KAM_GOOGLEPHISH1,[l=0]',
                              'she now looks ' => '__KAM_BEAUTY1,[l=1] __KAM_WEIGHT2_3,[l=1]',
                              ' lucky recipients' => '__KAM_LOTTO2,[l=1] __KAM_MEDICARE3,[l=1] __LUCKY_WINNER,[l=1]',
                              'reliable person' => '__KAM_DRUG2_6,[l=1] __KAM_INVEST2,[l=1] __KAM_TV1,[l=1]',
                              'd\\351nt' => '__DECEASED,[l=1]',
                              'group' => '__LOTTO_DEPT,[l=1]',
                              'longer' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_PACKAGE2,[l=1]',
                              'xan amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'priv=e9' => '__HUSH_HUSH,[l=1]',
                              'som pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'life experience degree' => '__KAM_UNIV2,[l=1] __KAM_UNIV3,[l=1] __KAM_UNIV7,[l=1]',
                              'feel energized' => '__KAM_WEIGHT2,[l=1]',
                              'remmit' => '__FRAUD_WNY,[l=1]',
                              'data specialist' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_VISION3,[l=1]',
                              'via val pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '% of the money for your effort' => '__DEAL,[l=1] __DECEASED,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEIGHT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'vision airships' => '__KAM_STOCKTIP121,[l=1] __KAM_VISION3,[l=1]',
                              'anywhere' => '__KAM_SMOKE1,[l=1]',
                              'via lev amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'fantastic p' => '__KAM_GALLERY4,[l=1]',
                              'producing' => '__KAM_NIGERIAN2,[l=1]',
                              'crazy auctions' => '__KAM_SWIPE3,[l=1]',
                              'sildenafil' => 'DRUG_ED_SILD,[l=1]',
                              'business profiles' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_RESUME3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PHISH4_3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'wireless earbuds' => '__KAM_HOLIDAY2020_2,[l=0]',
                              'overnight' => 'DRUG_ED_ONLINE,[l=1] __FRAUD_QFY,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1]',
                              'do you need a new' => '__KAM_GIFT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'download them now' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __RELEASE_MESSAGES,[l=1]',
                              'val amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'follow' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_FRIEND2,[l=1]',
                              's with google' => '__KAM_GOOGLE3,[l=1] __KAM_GOOGLE4,[l=0] __KAM_SEO4,[l=1]',
                              'val xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'ikea' => '__KAM_REWARD1,[l=1]',
                              'rewards' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_NEW_CREDITCARD3,[l=1]',
                              '% verifiable' => '__KAM_UNIV4B,[l=1]',
                              'deine' => '__DRUGS_PAIN2,[l=1]',
                              'in your explorer' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP2_2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'you are recently chosen' => '__KAM_AUTONEW3,[l=1] __KAM_CHOSEN3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amb mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'last day of the $' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1]',
                              'calgary' => '__KAM_NIGERIAN2,[l=1]',
                              'loterie' => '__HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'doctor lists' => '__KAM_LIST1,[l=1] __KAM_LIST4,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'reduce your monthly payment ' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DECEASED,[l=1] __DOS_BODY_MON,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CEP6,[l=1] __KAM_CLAIMS3,[l=1] __KAM_CLOUD3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PET3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_REFI6,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV2,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sharing' => '__AGREED_RATIO,[l=1]',
                              'order instantly' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_BADZIP3,[l=0] __KAM_DRUG2_5,[l=1] __KAM_LOAN3,[l=1] __KAM_TAX3,[l=1]',
                              'truth' => '__KAM_BACK3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'qualify' => '__KAM_STUDENT3,[l=1] __KAM_TAX4,[l=1]',
                              'liberal' => '__KAM_POLITICS2,[l=1]',
                              'via pro xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'val cia amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'esgic plus' => '__DRUGS_PAIN12,[l=1]',
                              'mnum' => '__KAM_STOCKTIP128,[l=1]',
                              'order medicine' => '__KAM_BADZIP3,[l=0] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG4,[l=1] __KAM_MED1,[l=1]',
                              'famos pill' => '__KAM_SEX04_1,[l=1] __PILL_PRICE_01,[l=1]',
                              'no commitment' => '__KAM_CAR3,[l=1] __KAM_REP3_2,[l=1]',
                              'pro lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'prophecy' => '__KAM_PROPHET5,[l=0]',
                              'nationalhealthxchange' => '__HK_LOTTO_2,[l=1] __KAM_HEALTH2,[l=1] __KAM_JOINT3,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'copiarlo y pegarlo' => '__COPY_PASTE_ES,[l=0]',
                              'winning number' => '__KAM_LOTTO6,[l=1] __KAM_POLITICS2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'implant recall' => '__KAM_HIP2,[l=0] __KAM_SEX_EXPLICIT4,[l=1]',
                              'foreign partner' => '__KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'amb val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'www.domainregistryasia(dot)net' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKE_REGISTRY1,[l=0] __KAM_REP2,[l=1] __KAM_REP3_2,[l=1]',
                              'in hot' => '__KAM_TUB3,[l=1]',
                              'brokering the domain' => '__DEAL,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE4,[l=1]',
                              'drop ' => '__KAM_REFI6,[l=1] __KAM_WEIGHT1,[l=1]',
                              'find attach' => '__JMQ_TRACKR3,[l=1] __KAM_FAKEINV2_2,[l=0] __KAM_NEW_CREDITCARD3,[l=1]',
                              'drilling' => '__KAM_DRILL1,[l=0]',
                              'som lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'this offer is only for unite' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FUN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'register to receive' => '__KAM_KORS3,[l=0] __KAM_WEBINAR4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'save yourself' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTO3,[l=1] __KAM_HACK3,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME5,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'databank' => '__JMQ_WIRE3,[l=1] __KAM_ENGINEER2,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'business traveller' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_EXPOPIRATE2,[l=0] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_AGENT,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'tired all the time' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_SNORE3,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT3A,[l=1]',
                              'auto' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'get as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              'minuteman civil defense corps' => '__KAM_POLITICS2,[l=1]',
                              '% of the total will be set' => '__DEAL,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'seo specialists' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST4,[l=1] __KAM_SEO4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_VISION3,[l=1]',
                              'prices for our director' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DIRECT4,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_LIST3,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'diet of the year' => '__DEAL,[l=1] __JMQ_PICKUP4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'appetite out of control' => '__KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_WEBINAR4,[l=1] __KAM_WEIGHT2,[l=1]',
                              'completing the survey' => '__DEAL,[l=1] __KAM_GIFT5,[l=1] __KAM_REP3_2,[l=1] __SURVEY,[l=1]',
                              'zirconium oxide' => '__KAM_SHARP3,[l=0]',
                              'hangover patch' => '__FRAUD_QFY,[l=1] __KAM_HANGOVER3,[l=0] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1]',
                              'meal' => '__KAM_NUWAVE3,[l=1]',
                              'recommends a company' => '__KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_06,[l=1]',
                              'xan mer pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'cia pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'wish not to receive these messages' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'out of the blue' => '__DEAL,[l=1] __KAM_INTRUDE,[l=1]',
                              'account' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              ' g r a' => 'KAM_VIAGRA5,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'phentremine' => '__KAM_ANA1,[l=1]',
                              'password' => '__KAM_PHISH4_3,[l=1]',
                              'mer via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'laughing kitty card' => '__KAM_CARD2,[l=1]',
                              'important message' => '__ADMAIL,[l=1] __JMQ_IMPORTANT2,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'email ad broadcast' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ADVERT3,[l=1] __KAM_ENGINEER2,[l=1] __YOU_WON_01,[l=1]',
                              'hot babe' => '__KAM_GALLERY4,[l=1]',
                              'hdx-lens' => '__KAM_LENS3,[l=0]',
                              'contacts record' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_4,[l=1]',
                              'kopieren sie es und f\\303\\274gen sie es ein' => '__COPY_PASTE_DE,[l=0]',
                              'an honest foreigner' => '__FRAUD_XJR,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'lev pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'katya from russia' => '__KAM_URONLINE2,[l=1]',
                              'marketing team' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'som amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'fortune 500' => '__I_WILL_YOU,[l=1] __KAM_LABEL5,[l=0] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __MY_FORTUNE,[l=1] __YOU_WON_02,[l=1]',
                              'visitor list' => '__KAM_DIRECT3,[l=0] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'pro som lev' => 'KAM_VIAGRA2,[l=0]',
                              'val mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'this message cannot be considered spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __THIS_AD,[l=1]',
                              'web designer' => '__KAM_LANDSCAPE3,[l=1] __KAM_TIME2,[l=1] __KAM_WEB2_3,[l=0]',
                              'browser' => '__KAM_ACCOUNTPHISH3,[l=1]',
                              'announces' => '__KAM_REFI2,[l=1]',
                              'amb xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'last day of the bonus offer' => '__BONUS_LAST_DAY,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'mer cia lev' => 'KAM_VIAGRA2,[l=0]',
                              'xan via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'amb amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'bigger quantities and save' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_DRUG2,[l=1] __KAM_REFI2,[l=1]',
                              'quick delivery' => '__FEES,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_KN_2,[l=0]',
                              'cked' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'smokeless direct' => '__KAM_DIRECT4,[l=1] __KAM_SMOKE4,[l=1]',
                              'lev via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'beneficial effect' => '__BACK_SCRATCH,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_SEX04_1,[l=1]',
                              'cia xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'i need a favor from you' => '__KAM_FAVOR2,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'successfully matched' => '__KAM_MEMBER3,[l=1]',
                              'subscrib' => '__SUBSCRIPTION_INFO,[l=1]',
                              'squeeze into them' => '__DEAL,[l=1] __KAM_WEIGHT2,[l=1]',
                              'lev lev pro' => 'KAM_VIAGRA2,[l=0]',
                              'lev val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '30-day member' => '__DAY_I_EARNED,[l=1] __KAM_DIRECT3,[l=0]',
                              'offering' => '__KAM_DOMAIN3,[l=1] __KAM_GIFT4,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1]',
                              'we have paid ' => '__FEES,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'cia val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'acai berry' => '__KAM_ANA1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'promotion/prize award' => '__KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_SEO6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __THIS_AD,[l=1]',
                              'double their money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK2,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SEX1,[l=1] __KAM_WEED3,[l=0] __KAM_WINDOWS3,[l=1]',
                              'get competitive quotes' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_CAR3,[l=1] __KAM_REP3_2,[l=1]',
                              'establishing a new liaison network' => 'BAD_CREDIT,[l=1] __FOR_SALE_NET,[l=1] __KAM_CAREER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'cia lev pro' => 'KAM_VIAGRA2,[l=0]',
                              'clinical' => '__KAM_TVDOCTOR3,[l=1]',
                              'management team' => '__KAM_WEBINAR4,[l=1] __SYSADMIN,[l=1]',
                              ' shield' => '__KAM_PRODUCT2_2,[l=1]',
                              'oil' => '__KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1]',
                              'cia via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'nominated bank account' => '__DORMANT_ACCT,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BANK_3,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'joint relief' => '__KAM_DRUG2_3,[l=1] __KAM_JOINT4,[l=0]',
                              'you have receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'counts and pric' => '__KAM_LIST3_3,[l=1]',
                              'to zugreifen wiederhergestellt' => '__ACCESS_RESTORE,[l=1]',
                              'grab hold' => '__KAM_DRUG2_4,[l=1] __KAM_PHISH2_4,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'lev xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'insidesaleswiz.' => '__KAM_DRUG2_3,[l=1] __KAM_OBFURL1,[l=1]',
                              'via' => 'VIA_GAP_GRA,[l=1]',
                              'orphan' => '__CHARITY,[l=1] __KAM_BENEFICIARY6,[l=0]',
                              'first page of google' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1] __KAM_SEO4,[l=1]',
                              'share would be ' => '__KAM_NIGERIAN3,[l=1]',
                              'change your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DEBT1,[l=1] __KAM_INSURE4,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'profile' => '__JMQ_RESUME3,[l=1] __KAM_PHISH4_3,[l=1]',
                              'som pro pro' => 'KAM_VIAGRA2,[l=0]',
                              'enhancing formula' => '__KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_URUNIT5,[l=1] __YOU_WON_02,[l=1]',
                              'pennies' => '__KAM_REAL2_3,[l=1]',
                              'act of nineteen thirty' => 'TVD_ACT_193,[l=1] __KAM_REP3_2,[l=1]',
                              'leaving house' => '__STAY_HOME,[l=1]',
                              'mail are not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1]',
                              'ministry of ' => '__KAM_BENEFICIARY4,[l=0]',
                              'amb pro mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'no tests' => '__KAM_UNIV15,[l=1]',
                              'succeed on ebay' => '__KAM_EBAY1,[l=0]',
                              'watch unlimited television' => '__KAM_TIME4,[l=1] __KAM_TRIAL,[l=1] __KAM_TV1,[l=1] __KAM_VISION3,[l=1]',
                              'keeping' => '__FEES,[l=1] __KAM_ALARM2,[l=1]',
                              'responsive' => '__KAM_DOMAIN3,[l=1]',
                              'ink and toner' => '__KAM_INK1,[l=1]',
                              'needs fund' => '__KAM_FLAG3,[l=1] __KAM_INVEST3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'val amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'all you need to do is to copy' => '__KAM_REP2_1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'contact the bank director' => '__CONTACT_ATTY,[l=1] __DEAL,[l=1] __FRAUD_JYG,[l=1] __JMQ_WIRE3,[l=1] __KAM_DIRECT4,[l=1] __KAM_NIGERIAN2_2,[l=1] __KAM_NIGERIAN2_4,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'i am waiting for your answer' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_CREDIT2,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fresh babe' => '__KAM_CHICKEN3,[l=1] __KAM_GALLERY4,[l=1]',
                              'your region' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_INVEST4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fun in bed' => '__KAM_SEX04_2,[l=1]',
                              'to continue using your account' => '__ACCESS_RESTORE,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'apex bank' => '__FRAUD_BEP,[l=1] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              ' to our partners' => '__KAM_URUNIT2,[l=1] __WE_PAID,[l=1]',
                              'sample record' => '__KAM_LIST3_3,[l=1] __KAM_WEB2_4,[l=0]',
                              'via val xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'african' => '__AFR_UNION,[l=1] __DOS_BODY_FRI,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INVEST4,[l=1]',
                              ' closeout pricing' => 'DIET_1,[l=1] __KAM_CARDEAL3,[l=1] __KAM_WEIGHT1,[l=1]',
                              'filtered tap water' => '__KAM_WATER3,[l=0]',
                              'no study required' => '__KAM_UNIV15,[l=1]',
                              'job titles' => '__KAM_LIST3_3,[l=1]',
                              'mutual business' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_INVEST4,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'cia cia mer' => 'KAM_VIAGRA2,[l=0]',
                              'needs' => '__KAM_FLAG3,[l=1]',
                              'the virus that causes covid-19' => '__DEAL,[l=1] __KAM_WEIRDC19_3,[l=0]',
                              'inactive' => '__KAM_ACCOUNTPHISH3,[l=1]',
                              'left' => '__DORMANT_ACCT,[l=1]',
                              'instant checkmate' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK1,[l=1] __KAM_CREDIT2,[l=1] __KAM_LOAN3,[l=1] __LOTTO_WIN_01,[l=1]',
                              'drpenterprise' => '__KAM_GIFT4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'female orgasms' => '__JMQ_PICKUP4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX4,[l=0]',
                              'gnc' => '__KAM_SEX04_1,[l=1]',
                              'be thrifty, buy your pills' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'size of ' => 'BODY_ENHANCEMENT2,[l=1] TVD_INCREASE_SIZE,[l=1]',
                              's*xy' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'liberty' => '__KAM_POLITICS2,[l=1]',
                              'enjoying' => '__KAM_WEIGHT2,[l=1]',
                              'empowerment fund' => '__KAM_COVID1,[l=0] __KAM_COVID3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'via pro pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'private video' => '__FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_PRIV2,[l=0]',
                              'dear car shopper' => 'DEAR_SOMETHING,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_MOTHER3,[l=1]',
                              'som val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'vacation place' => '__KAM_REAL3,[l=1]',
                              'completely free' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEO5,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'simple tweak' => '__KAM_FUN6,[l=0]',
                              'life experience transcript' => '__KAM_UNIV3,[l=1] __KAM_UNIV7,[l=1]',
                              'recruiting' => '__KAM_HIRE3,[l=1]',
                              'foundation is donating' => '__FOUND_YOU,[l=1] __HK_LOTTO_2,[l=1] __KAM_GOOGLEFORM_3,[l=0]',
                              'coin' => '__KAM_CRIM2_1,[l=1]',
                              'wanger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'get the edge' => '__DEAL,[l=1] __KAM_DRUG2_3,[l=1]',
                              'mail has w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1] __hk_win_b,[l=1]',
                              'trading experience' => '__KAM_STOCK2_1,[l=1]',
                              'user list' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'buy as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              'i won' => '__KAM_LOTTO3,[l=1] __YOU_WON_05,[l=1]',
                              'night adventures' => '__DEAL,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TOURS3,[l=1]',
                              'odd' => '__KAM_WEIRDTRICK2,[l=1]',
                              'lev cia mer' => 'KAM_VIAGRA2,[l=0]',
                              'freshness' => '__KAM_CHICKEN3,[l=1] __KAM_MOTHER3,[l=1]',
                              'order right' => '__KAM_BADZIP3,[l=0] __KAM_DETOX3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_PATRIOT3,[l=1]',
                              'gadget' => '__KAM_FUN7,[l=1]',
                              'workout' => '__KAM_CAREER3,[l=1] __KAM_WEIGHT2,[l=1]',
                              'medicare basics guide' => '__KAM_CRYPTO1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_MEDICARE3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_VISION3,[l=1]',
                              'une mallette m\\303\\251tallique' => '__KAM_SEX_EXPLICIT4,[l=1] __TRUNK_BOX,[l=1]',
                              'chicken' => '__KAM_CHICKEN3,[l=1]',
                              'surpress appetite' => '__KAM_HOODIA3,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1]',
                              'to your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' week' => '__KAM_CEP6,[l=1]',
                              'reverse alzheimer' => '__KAM_DIABETES2,[l=1] __KAM_FUN7,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'never ask you to pay or invest' => '__FEES,[l=1] __INVEST_MONEY,[l=1] __JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __NOT_SCAM,[l=1] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'online book' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PHISH2_6,[l=1]',
                              'let a draft' => '__BANK_DRAFT,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WINDOWS3,[l=1]',
                              'xan mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'something' => '__KAM_ARREST2,[l=1]',
                              'nuke' => '__KAM_PATRIOT4,[l=1]',
                              'red base interactive' => '__KAM_BADNAME1,[l=1]',
                              'mer pro som' => 'KAM_VIAGRA2,[l=0]',
                              'free evaluation on your current home loan' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME2,[l=1] __KAM_INSURE4,[l=1] __KAM_LASIK3,[l=1] __KAM_REFI2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_TRIAL,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __KAM_WINDOWS3,[l=1] __PILL_PRICE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'transact' => '__DEAL,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'val pro mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'leverage' => '__KAM_DOMAIN1,[l=1]',
                              'recall list' => '__KAM_HIP2,[l=0] __KAM_LIST4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'died' => '__DEAL,[l=1] __DIED_IN,[l=1]',
                              'please copy' => '__KAM_REP2_1,[l=1]',
                              'redeem in bulk and save' => '__KAM_DRUG2,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT4,[l=1] __KAM_REFI2,[l=1]',
                              'buy instantly' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DRUG2_5,[l=1] __KAM_LOAN3,[l=1] __KAM_TAX3,[l=1]',
                              'diamonds' => '__DOS_BODY_MON,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_TIME2,[l=1]',
                              'ivoire' => '__IVORY_COAST,[l=1]',
                              'united state dollar' => 'MILLION_USD,[l=1] __KAM_COVID5,[l=1] __KAM_NIGERIAN1,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'obtaining ' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN_SALE2,[l=1] __KAM_TAX4,[l=1]',
                              'return calls' => '__KAM_POLITICS2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK3,[l=1]',
                              'private' => '__HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1]',
                              'industrial' => '__KAM_GARAGE3,[l=1]',
                              'tripling an principal' => '__PUMPDUMP_01,[l=1]',
                              'quintupling your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mandatory validation' => '__KAM_NOTIFY2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'partnership' => '__DEAL,[l=1]',
                              'amb amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'front' => '__FEES,[l=1]',
                              'web develop' => '__KAM_WEB2_3,[l=0]',
                              ' thousand to our users' => '__FRAUD_LTX,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __WE_PAID,[l=1]',
                              'free score and report' => '__KAM_1LINE1,[l=1] __KAM_BADZIP3,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'hoveround' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_POWER1,[l=0] __KAM_REFI2,[l=1]',
                              'without attending a single class' => '__KAM_MARIJUANA3,[l=1] __KAM_MEMBER3,[l=1] __KAM_UNIV15,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'you\'re receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'risk free transation' => '__DEAL,[l=1] __DOS_BODY_SAT,[l=1] __FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_INVEST3,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'effort' => '__KAM_PATRIOT3,[l=1] __KAM_WEIGHT2,[l=1] __YOU_WON_02,[l=1]',
                              'titles:' => '__KAM_LIST3_4,[l=1]',
                              'chat on y' => '__KAM_URONLINE1,[l=1]',
                              'judgment' => '__KAM_JUDGE4,[l=0]',
                              'rent' => '__KAM_HOME2,[l=1]',
                              'will not get your website banned' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_QUOTA2,[l=1] __KAM_REFI3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEO6,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amb via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'steelcityads' => '__KAM_BADNAME1,[l=1]',
                              'install from adt' => '__KAM_ALARM2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              ' mailing record' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST3_4,[l=1] __YOU_WON_01,[l=1]',
                              'valuables' => '__KAM_SPY3,[l=1] __KAM_STOCK2_1,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'addify link' => '__DOS_LINK,[l=1] __KAM_FUN2,[l=1]',
                              ' friday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'surgery' => '__KAM_VISION3,[l=1]',
                              'viagra ' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] DRUG_ED_ONLINE,[l=1] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE_V,[l=1] __KAM_DRUG2_3,[l=1] __KAM_VIAGRA7A,[l=1] __KAM_VIAGRA8A,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'dutch glow' => '__KAM_DUTCHGLOW3,[l=1]',
                              'mail is not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1]',
                              'case:' => '__KAM_FAKEBBB4,[l=1]',
                              'awesome bonus' => '__KAM_SEX04_4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'i found great site' => '__FOUND_YOU,[l=1] __KAM_COMPROMISED4,[l=1]',
                              'via som xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'saw your email address' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC1,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'executor' => '__KAM_NIGERIAN1,[l=1] __WILL_LEGAL,[l=1]',
                              'usbsmg' => '__KAM_USB3,[l=1]',
                              'emailed list' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1] __YOU_WON_01,[l=1]',
                              'be thrifty, buy your medications' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE4,[l=1] __KAM_MED1,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sweet passion' => '__KAM_FAKEAD4,[l=0]',
                              'wuyi tea' => '__KAM_ANA1,[l=1]',
                              'unsecured personal' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_REFI3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'parcels' => '__KAM_FAKEDELIVER1,[l=1]',
                              'this mineral' => '__DEAL,[l=1] __KAM_BLOOD4,[l=1] __KAM_INVEST4,[l=1] __THIS_AD,[l=1]',
                              'draft' => '__BANK_DRAFT,[l=1]',
                              'z+e' => '__KAM_OBFURL1,[l=1]',
                              'hole in the banking' => 'LOOPHOLE_1,[l=1] __DEAL,[l=1] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'protect home and belonging' => '__KAM_INSURE4,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'solicitation' => '__KAM_DOMAIN3,[l=1]',
                              'intrust domains' => '__KAM_BADNAME1,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1]',
                              ' lb lighter' => '__KAM_DIET2_3,[l=1]',
                              'sement_' => '__ADMITS_SPAM,[l=1] __THIS_AD,[l=1]',
                              'rising' => '__KAM_REPAIR1_3,[l=1]',
                              'see my pictures' => '__KAM_PIC2,[l=1] __KAM_PIC5,[l=0]',
                              'minute webinar' => '__KAM_WEBINAR4,[l=1]',
                              ' first thing monday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'flex' => '__KAM_FLEXHOSE3,[l=1] __KAM_JOINT3,[l=1]',
                              'your compensation' => '__COMPENSATION,[l=1] __DECEASED,[l=1] __DOS_BODY_SAT,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_SCAM_N8,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'industry' => '__KAM_SEARCH4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'miracle' => '__KAM_LUNAR4,[l=1] __KAM_TVDOCTOR3,[l=1]',
                              'tripling your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'finger' => '__KAM_DRUG2_4,[l=1]',
                              'dream' => '__KAM_AUTO3,[l=1]',
                              'you registered with one of our partners websites' => 'KAM_ADVERT2,[l=1] __KAM_BACK2,[l=1] __KAM_CRIM2_3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_URUNIT2,[l=1] __KAM_WEB2,[l=1] __KAM_WEBINAR4,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you\'ve received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'asian girl' => '__KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1] __KAM_WIFE2,[l=1]',
                              'out of office' => '__BOUNCE_OOO_CB1,[l=1] __KAM_SALE3,[l=1]',
                              'lowest' => '__KAM_REPAIR1_3,[l=1]',
                              'lunar' => '__KAM_LUNAR4,[l=1]',
                              'muscular manhood' => '__KAM_ANDROGEL3,[l=1] __KAM_SEX1,[l=1]',
                              'just been changed' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT4,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'sea account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'verified email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_3,[l=1] __YOU_WON_01,[l=1]',
                              'project financing' => '__KAM_AUTONEW2,[l=1] __KAM_DRAPES3,[l=1] __KAM_INVEST2,[l=1]',
                              'pro pro lev' => 'KAM_VIAGRA2,[l=0]',
                              'excessive scratching' => '__KAM_PRODUCT2_2,[l=1] __KAM_WEIGHT2,[l=1]',
                              'incur' => '__FRAUD_WNY,[l=1]',
                              'university enrollment' => '__HK_LOTTO_2,[l=1] __KAM_UNIV1,[l=1] __KAM_UNIV9,[l=1]',
                              'without a doctor' => '__KAM_DRUG2_4,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'work experience diploma' => '__KAM_CAREER3,[l=1] __KAM_UNIV6B,[l=1] __KAM_UNIV7,[l=1]',
                              'quadrupling an principal' => '__PUMPDUMP_01,[l=1]',
                              'bethany christian services' => '__KAM_BADNAME1,[l=1] __KAM_PROPHET4,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'money back guarantee' => 'MONEY_BACK,[l=0] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'a honest foreigner' => '__FRAUD_XJR,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'bxvlgari' => '__KAM_TIME6,[l=0]',
                              'chat with me on y' => '__KAM_PIC4,[l=1] __KAM_URONLINE1,[l=1]',
                              'you\'re received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'time charge' => 'ONE_TIME,[l=1] __FEES,[l=1] __KAM_BACKUP3,[l=1] __KAM_TIME4,[l=1]',
                              'privilege' => '__KAM_BENEFICIARY3,[l=1]',
                              'loved rx' => '__KAM_DEATHINSURE3,[l=1] __KAM_DRUG2_3,[l=1]',
                              'petzoom sonic' => '__KAM_BARK1,[l=1]',
                              'brain' => '__KAM_NIGERIAN1,[l=1]',
                              'security upgrade' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SETTING2,[l=0] __KAM_VIAGRA9A,[l=1] __TRUNK_BOX,[l=1]',
                              'all you need to do is to type' => '__KAM_REP2_1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'late client' => '__DECEASED,[l=1] __KAM_BENEFICIARY6,[l=0]',
                              'xan pro som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'home' => '__KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'investor willing to invest in lebanon' => '__INVEST_MONEY,[l=1] __I_WILL_YOU,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_QUOTA2,[l=1] __KAM_STOCK2_4,[l=0] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1]',
                              'estate' => '__KAM_INSURE4,[l=1]',
                              'val via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' in the subject' => '__DEAL,[l=1] __KAM_LIST5,[l=1]',
                              'dialogue' => '__KAM_BADZIP3,[l=0]',
                              'overseas account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_QFY,[l=1] __HK_SCAM_N15,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI2,[l=1]',
                              'transfer to a designated bank account' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DORMANT_ACCT,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_LANDSCAPE3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __WIRE_XFR,[l=1]',
                              'sent' => '__JMQ_WIRE3,[l=1]',
                              'four of the card' => '__DEAL,[l=1] __KAM_SHADYCC3,[l=0]',
                              'web analytics media llc' => '__KAM_BADNAME1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_SEARCH4,[l=1]',
                              'bank of ghana' => '__GHANA,[l=1] __HK_SCAM_S25,[l=1] __JMQ_WIRE3,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INVEST4,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'quick lead time' => '__KAM_LABEL2,[l=0] __KAM_TIME4,[l=1]',
                              'complete list' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'undereye bags' => '__KAM_TIP3,[l=0]',
                              'not mail the check' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CREDIT2,[l=1] __KAM_FAKEINV2_3,[l=0] __LOTTO_WIN_01,[l=1] __YOU_WON_01,[l=1]',
                              'card on us' => '__KAM_GIFT4,[l=1]',
                              'price list' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_INQUIRY_1,[l=0] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'everything' => '__KAM_ARREST2,[l=1] __KAM_TAX3,[l=1]',
                              'financial independence' => 'FIN_FREE,[l=1] __DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PATRIOT4,[l=1]',
                              'economical value' => '__KAM_DRUG2,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'you received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mer mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'murder' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              '% interest' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1]',
                              'on the water' => '__DEAL,[l=1] __KAM_REAL2_1,[l=1]',
                              'royal bank' => '__JMQ_WIRE3,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_NIGERIAN2_7,[l=0]',
                              'article submission' => '__KAM_SEARCH4,[l=1]',
                              'have been' => '__KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'you have receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SALE3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bigger bidder' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SWIPE4,[l=1]',
                              'tons of money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_GOOGLE3,[l=1]',
                              'worth' => '__KAM_AUTO3,[l=1]',
                              'detail' => '__KAM_NIGERIAN4,[l=1]',
                              'you always need new cards' => '__KAM_BIZ1,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'problem' => '__KAM_GOVT4,[l=1]',
                              'babes passwords' => '__KAM_GALLERY2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'restructure proposal' => '__DEAL,[l=1] __KAM_DOMAIN2,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1] __URG_BIZ,[l=1]',
                              'quadruple your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'make your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_REFI3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'cons=e9quence' => '__YOU_WON_04,[l=1]',
                              'burns fat' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'episode' => '__KAM_HERPES3,[l=1]',
                              'you receive this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'listed by auction' => '__KAM_DOMAIN2,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'resorts for free' => '__KAM_PATRIOT3,[l=1] __KAM_TRIAL,[l=1] __KAM_VACATION3,[l=1] __PILL_PRICE_01,[l=1] __YOU_WON_02,[l=1]',
                              'financially independen' => 'FIN_FREE,[l=1] __DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'elite collection' => '__KAM_GALLERY2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'loteri' => '__HK_LOTTO_2,[l=1]',
                              'glasses' => '__KAM_VISION3,[l=1]',
                              'certificate of origin' => '__KAM_INQUIRY_4,[l=0]',
                              'printer ink sale' => '__KAM_DRUG2_3,[l=1] __KAM_INK1,[l=1]',
                              'existing' => '__KAM_TV1,[l=1]',
                              'som som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'no beneficiary' => 'DEAR_BENEFICIARY,[l=1] __KAM_BANK_2,[l=0] __KAM_BENEFICIARY6,[l=0]',
                              'pornstar' => '__KAM_SEX1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'demographics' => '__KAM_LIST3_3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __YOU_WON_01,[l=1]',
                              'deceased father' => '__DEAL,[l=1] __DECEASED,[l=1] __KAM_BANK_2,[l=0] __KAM_BENEFICIARY6,[l=0]',
                              'unbelievable deals' => '__DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_REAL2_3,[l=1] __KAM_SUNGLASSES2,[l=1]',
                              'concrete' => '__KAM_GARAGE3,[l=1]',
                              ' first thing thursday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'nights unsatisfied' => '__DOS_BODY_SAT,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_SEX1,[l=1] __KAM_URUNIT3,[l=1]',
                              '866-351-4693' => '__KAM_STUDENTLOAN4,[l=0]',
                              'breaking' => '__KAM_BLOOD3,[l=1]',
                              'cia amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'service plan' => '__KAM_PAPERLESS3,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'portal' => '__KAM_SEARCH4,[l=1]',
                              'stay' => '__KAM_ARREST2,[l=1]',
                              'petition' => '__KAM_POLITICS2,[l=1]',
                              'bored this afternoon' => '__DEAL,[l=1] __KAM_PIC1,[l=1] __THIS_AD,[l=1]',
                              'secure the monies' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1] __KAM_DOMAIN2,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'portfolio' => '__KAM_WEB2_4,[l=0]',
                              'instant' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_LOAN3,[l=1]',
                              'defunt' => '__DECEASED,[l=1]',
                              'business directory' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DIRECT4,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'losing' => 'DIET_1,[l=1] __JMQ_TRACKR3,[l=1]',
                              'dear web' => 'DEAR_SOMETHING,[l=1]',
                              'pxatek' => '__KAM_TIME6,[l=0]',
                              'certificate agent' => '__KAM_BANK_2,[l=0] __KAM_LOTTO4,[l=1]',
                              'sharp for life' => '__KAM_PATRIOT3,[l=1] __KAM_SHARP1,[l=0] __YOU_WON_02,[l=1]',
                              'lev amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' opens friday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'wholesale direct pricing' => '__KAM_DIRECT3,[l=0] __KAM_DIRECT4,[l=1] __KAM_DRUG2_3,[l=1]',
                              'notification' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'taxes' => '__KAM_TAX3,[l=1]',
                              'shemale' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'you have receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SALE3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'd\\303\\251funt' => '__DECEASED,[l=1]',
                              'fields consist' => '__KAM_LIST3_3,[l=1]',
                              'phone have been hacked' => '__KAM_CELL3,[l=1] __KAM_HACK1,[l=0] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'amb lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'som via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'este correo no puede ser considerado spam' => 'NOT_SPAM,[l=1]',
                              'mer amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'via som pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'diploma of your expertise' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV13,[l=1] __KAM_UNIV6B,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'n model' => '__KAM_GALLERY4,[l=1]',
                              'we have already issued ' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'sleep deeper' => '__KAM_FUN7,[l=1] __KAM_LUNAR4,[l=1]',
                              'colonmate' => '__KAM_WEIGHT2,[l=1]',
                              'printed in the us' => '__DEAL,[l=1] __KAM_2020_2,[l=1]',
                              'urgent respond' => '__FRAUD_MLY,[l=1] __KAM_BADZIP3,[l=0] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __KAM_URGENT2,[l=0] __URG_BIZ,[l=1]',
                              'xan amb cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'amb via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'som mer som' => 'KAM_VIAGRA2,[l=0]',
                              'vpsn' => '__KAM_STOCKTIP121,[l=1]',
                              'found' => '__FOUND_YOU,[l=1]',
                              '1st page' => '__KAM_PAPERLESS3,[l=1] __KAM_SEARCH3,[l=1]',
                              'the attachment' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __KAM_PRIV3,[l=0] __PLS_REVIEW,[l=1]',
                              'refinance your house' => 'REFINANCE_NOW,[l=1] REFINANCE_YOUR_HOME,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dreaming to get into shape' => '__KAM_AUTO3,[l=1] __KAM_URZEST3,[l=0]',
                              'a d v e r t i s m e n t' => 'KAM_ADVERT2,[l=1] KAM_OVERPAY,[l=1]',
                              'nighttime activit' => '__KAM_DATINGTIPS3,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT4,[l=1]',
                              'mightymeds1' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'network partner' => 'MARKETING_PARTNERS,[l=1] __KAM_CAREER3,[l=1] __KAM_REP3_2,[l=1]',
                              'original message' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __freemail_safe_fwd,[l=1]',
                              'time-keeper' => '__KAM_ALARM2,[l=1] __KAM_TIME2,[l=1] __KAM_TIME4,[l=1]',
                              'performance' => '__KAM_DOMAIN2,[l=1] __KAM_FLAG3,[l=1] __KAM_PACKAGE2,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              ', experian and equifax scores' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1]',
                              'domain backordering' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_BADZIP3,[l=0] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE3,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'vehicle' => '__KAM_AUTO3,[l=1]',
                              'future_email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'new car you want' => '__KAM_CAR2,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bvlgari' => '__KAM_TIME6,[l=0]',
                              'you were invited' => '__KAM_CHOSEN3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'opt' => '__SUBSCRIPTION_INFO,[l=1]',
                              'leadz' => '__KAM_BADNAME1,[l=1]',
                              'diese nachricht ist kein spam' => 'NOT_SPAM,[l=1] __DEAL,[l=1]',
                              'costa rica' => '__FB_COST,[l=1] __KAM_REAL2_1,[l=1]',
                              'multiply your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amb mer cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'times an investment' => '__INVEST_MONEY,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_TIME4,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              ' opens thursday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'stronger results' => '__KAM_HOSE3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK4,[l=1]',
                              'share samples' => '__KAM_LIST3_4,[l=1] __KAM_WEB2_4,[l=0]',
                              'altera' => '__KAM_HIRE3,[l=1]',
                              'selection' => '__KAM_CELL3,[l=1] __KAM_POLITICS2,[l=1] __RANDOM_PICK,[l=1]',
                              'total' => '__FRAUD_JYG,[l=1]',
                              'available at auction' => '__KAM_DOMAIN2,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI2,[l=1]',
                              'val som mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'please find document attached' => '__JMQ_TRACKR3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_ORDER1,[l=0] __PLS_REVIEW,[l=1]',
                              'no risk' => '__FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_CAR3,[l=1] __KAM_INVEST3,[l=1]',
                              'safe - natural - effective' => '__FEES,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_LUNAR4,[l=1] __KAM_MEDICAL2,[l=0] __KAM_VISION3,[l=1]',
                              'universit' => '__HK_LOTTO_2,[l=1] __KAM_UNIV9,[l=1]',
                              'mer som som' => 'KAM_VIAGRA2,[l=0]',
                              'compromised' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_REP3_2,[l=1]',
                              'restructure opportunity' => '__KAM_CAREER2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'cooling' => '__KAM_WINDOWS3,[l=1]',
                              'aid your bed' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pro cia som' => 'KAM_VIAGRA2,[l=0]',
                              'secr' => '__HUSH_HUSH,[l=1]',
                              'visit your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'prominent registry' => '__KAM_WHOSWHO3,[l=1]',
                              '% no pre' => '__KAM_UNIV4B,[l=1]',
                              ' monday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __KAM_STOCK2_1,[l=1] __PUMPDUMP_03,[l=1]',
                              'moving some money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_BITCOIN2,[l=1]',
                              'impotence problem' => 'IMPOTENCE,[l=1] __KAM_GOVT4,[l=1]',
                              'to restore access' => '__ACCESS_RESTORE,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_QUOTA2,[l=1] __KAM_SNORE3,[l=1] __STOCK_TIP,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              ' allen media' => '__KAM_BADNAME1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'no fee' => '__KAM_COLLECT2,[l=0]',
                              'suspend ' => '__TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'you have receiving this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'affordable care act' => 'PRICES_ARE_AFFORDABLE,[l=1] __KAM_INSURE4,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VISION3,[l=1] __YOU_WON_02,[l=1]',
                              'help' => '__KAM_CREDIT2,[l=1] __KAM_TAX3,[l=1] __SYSADMIN,[l=1]',
                              'via cia val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'grab as many shares as i can' => '__KAM_VIAGRA9A,[l=1] __PUMPDUMP_09,[l=1]',
                              'position' => '__KAM_CAREER3,[l=1]',
                              'stock alert' => 'STOCK_ALERT,[l=1] __DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_STOCK2_3,[l=0] __KAM_WEED4,[l=1] __STOCK_TIP,[l=1]',
                              'national lottery' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'aging' => '__KAM_SKIN4,[l=1]',
                              'make your e' => '__ACCOUNT_SECURE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'remunerrate' => '__FRAUD_WNY,[l=1] __KAM_INSURE4,[l=1]',
                              '. trust' => '__KAM_COVID3,[l=1]',
                              'valuable medicines' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_SEX04_1,[l=1] __KAM_STOCK2_1,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '500 business cards' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BIZ1,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'profit' => '__KAM_MARIJUANA3,[l=1] __KAM_SOLAR3,[l=1] __YOUR_PROFIT,[l=1]',
                              'lover' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'wish to not receive these emails' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'xan val som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'anatrim' => '__KAM_ANA1,[l=1]',
                              'gmx' => '__KAM_HOWRU4,[l=1]',
                              'favorite' => '__KAM_OILCHANGE3,[l=1] __KAM_TV2,[l=1]',
                              'contactid' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_WEBINAR4,[l=1]',
                              'deceased' => '__DECEASED,[l=1] __KAM_BANK_2,[l=0]',
                              'guaranteed!' => 'BANG_GUAR,[l=1] __KAM_SEO5,[l=1]',
                              'attorney' => '__CONTACT_ATTY,[l=1] __KAM_ATTORNEY3,[l=1]',
                              'hacking' => '__KAM_CLOUD4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'degree of your expertise' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV13,[l=1] __KAM_UNIV2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'first page of yahoo' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'mer mer pro' => 'KAM_VIAGRA2,[l=0]',
                              'has full internet' => '__KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1] __KAM_TELEWORK2,[l=1]',
                              'this page are an' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __THIS_AD,[l=1]',
                              'val lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'get a free quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_ALARM2,[l=1] __KAM_INSURE2,[l=1] __KAM_TRIAL,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PILL_PRICE_01,[l=1]',
                              'calis' => '__DRUGS_ERECTILE4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'visit the site' => '__DEAL,[l=1] __KAM_HOWRU3,[l=0]',
                              'trugreen' => '__KAM_ANA1,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'suspicions' => '__KAM_PATRIOT3,[l=1]',
                              'a d v e r t i s e m e n t' => 'KAM_ADVERT2,[l=1] KAM_OVERPAY,[l=1]',
                              'business trip' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'email campaign' => '__ADMAIL,[l=1] __DRUGS_ERECTILE5,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_2,[l=1] __KAM_POLITICS2,[l=1] __YOU_WON_01,[l=1]',
                              'pro val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' thousand' => '__FRAUD_LTX,[l=1]',
                              'email advertising' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ADVERT1,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_ENGINEER2,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'extra' => 'DIET_1,[l=1] __KAM_GIFT3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'switch' => '__KAM_SOLAR3,[l=1]',
                              'camera' => '__KAM_SPY3,[l=1]',
                              'val via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'database provider' => '__KAM_BACK3,[l=1] __KAM_CREDIT3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'program is not endorsed, sponsored by or affiliated' => 'KAM_ADVERT2,[l=1] __KAM_DETOX3,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'claim the money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1]',
                              'encrypted zip' => '__KAM_BADZIP2,[l=0]',
                              'enrollment office' => '__KAM_SALE3,[l=1] __KAM_UNIV1,[l=1]',
                              'eating this' => '__DEAL,[l=1] __KAM_DEATH3,[l=1] __THIS_AD,[l=1]',
                              'xan cia lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'mer via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'buy a dataset' => '__KAM_LIST3_3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'sterile' => '__KAM_BENEFICIARY6,[l=0]',
                              'pay off all your debt' => '__DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DEBT1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'upgrade of your access' => '__ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'in tub' => '__KAM_TUB3,[l=1]',
                              'som cia val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'val mer cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pass word' => '__KAM_PASSWORDSCAM1,[l=0]',
                              'governor' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI2,[l=1]',
                              'view all 3 reports' => '__KAM_AUTONEW3,[l=1] __KAM_BADZIP3,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_HEALTH2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'dentist' => '__DECEASED,[l=1] __KAM_LIST2,[l=1]',
                              'more model' => '__KAM_GALLERY4,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'advantage' => '__KAM_SUPERHUMAN3,[l=1]',
                              'via mer som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'tablet' => '__PILL_PRICE_01,[l=1]',
                              'pro xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'breast' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'sea bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'sun' => '__DOS_BODY_SUN,[l=1]',
                              'amb som mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'enlarge your manhood' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'favourite rx' => '__KAM_DRUG2_3,[l=1]',
                              'infinite babe' => '__KAM_GALLERY4,[l=1]',
                              'confiden' => '__HUSH_HUSH,[l=1]',
                              'minister of' => '__KAM_INVEST4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_2,[l=1]',
                              'via via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'pretty russian' => '__KAM_PIC2,[l=1] __KAM_WIFE2,[l=1]',
                              'nandroderm' => '__KAM_TESTOSTERONE4,[l=1]',
                              'free analysis' => '__KAM_SEO5,[l=1] __KAM_SOFTWARE4,[l=0] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'specific lists' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_SEO3,[l=1] __KAM_VIAGRA9D,[l=1]',
                              '000' => '__KAM_FAKEWEST5,[l=1]',
                              'pro lev cia' => 'KAM_VIAGRA2,[l=0]',
                              'zippy' => '__KAM_LOAN3,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'boost your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som som pro' => 'KAM_VIAGRA2,[l=0]',
                              'better credit terms' => 'BAD_CREDIT,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_INSURE4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1]',
                              'computer ballot system' => '__FRAUD_CKF,[l=0] __HK_LOTTO_BALLOT,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __RANDOM_PICK,[l=1]',
                              ' great effort' => '__KAM_PATRIOT3,[l=1] __KAM_WEIGHT2,[l=1] __WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'response' => '__URG_BIZ,[l=1]',
                              ' before wednesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __KAM_PATRIOT3,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'sweet babe' => '__KAM_GALLERY4,[l=1]',
                              'pro mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'raise your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'huge success stories' => '__KAM_ANCESTOR3,[l=1] __KAM_MILLIONAIRE2,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              '20x its weight' => 'DIET_1,[l=1] __KAM_SHAM4,[l=0] __KAM_WEIGHT2,[l=1]',
                              'top of yahoo' => '__KAM_SEO2,[l=1]',
                              'make successful career at us' => '__DRUGS_ERECTILE5,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VISION3,[l=1]',
                              'your country' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sellmoo' => '__KAM_SWIPE4,[l=1]',
                              'this communication was delivered to you by' => '__DEAL,[l=1] __KAM_REP3_2,[l=1] __KAM_SPAMKING5,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'conventional' => '__KAM_DIABETES2,[l=1]',
                              'amb cia som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'mer xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'medicinal plants' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_FUN6,[l=0] __KAM_MARIJUANA2,[l=1] __KAM_MED1,[l=1]',
                              ' dollars bonus offer' => '__BONUS_LAST_DAY,[l=1] __KAM_COVID5,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'val xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'urgent reply' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __KAM_BADZIP3,[l=0] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __URG_BIZ,[l=1]',
                              'authorized' => '__KAM_PHISH4_2,[l=1]',
                              'economical amount' => '__KAM_COMPROMISED3,[l=1] __KAM_DRUG2,[l=1] __SUM_OF_FUND,[l=1]',
                              'get your body back' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_SEARCH3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX3,[l=1] __KAM_TESTOSTERONE3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bored tonight' => '__KAM_DATINGTIPS3,[l=1] __KAM_PIC1,[l=1]',
                              'branch manager' => '__KAM_INVEST2,[l=1]',
                              'pure cleanse' => '__KAM_ANA1,[l=1]',
                              'xan som amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'nigerian government' => '__FRAUD_QFY,[l=1] __FRAUD_YQV,[l=0] __KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1] __NIGERIA,[l=1]',
                              'remit' => '__FRAUD_WNY,[l=1]',
                              'card\'s link below' => '__DOS_LINK,[l=1] __KAM_CARD2,[l=1] __KAM_CERT3,[l=0]',
                              'doubled their money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK2,[l=1] __KAM_BITCOIN2,[l=1] __KAM_SEX1,[l=1] __KAM_WEED3,[l=0] __KAM_WINDOWS3,[l=1]',
                              'selfies' => '__KAM_SKIN4,[l=1]',
                              'click_here' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __OBFU_UNSUB_UL,[l=1]',
                              'val lev cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'congratulation to your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_7,[l=1]',
                              'get your diploma today' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GIFT3,[l=1] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_SUNGLASSES3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV3B,[l=1] __KAM_UNIV6B,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som cia cia' => 'KAM_VIAGRA2,[l=0]',
                              'mail address w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1] __hk_win_b,[l=1]',
                              'access to the funds' => '__DEAL,[l=1] __KAM_NIGERIAN4,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'ultimaterxhere' => '__KAM_DRUG2_5,[l=1]',
                              'val mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'mer val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'mer lev pro' => 'KAM_VIAGRA2,[l=0]',
                              'greece' => '__KAM_BENEFICIARY4,[l=0]',
                              'stand in the rating scales' => '__DEAL,[l=1] __KAM_CREDIT3,[l=1]',
                              'less than ' => '__KAM_FUN5,[l=1]',
                              'injured consumer' => '__KAM_MESH3,[l=0]',
                              'user' => '__KAM_ACCOUNTPHISH4,[l=1]',
                              'the n' => '__DEAL,[l=1] __KAM_GALLERY4,[l=1]',
                              'quit receiving these admail' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1]',
                              'beamz interactive' => '__KAM_STOCKTIP147,[l=1]',
                              'for claim and inquiring' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'mer via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'purehealth' => '__KAM_FUN2,[l=1] __KAM_JOINT3,[l=1]',
                              'declined' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1]',
                              'independent contractor' => '__DECEASED,[l=1] __KAM_NIGERIAN4,[l=1]',
                              'via amb lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'drugs online' => 'FREE_QUOTE_INSTANT,[l=1] ONLINE_PHARMACY,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'information here' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_WORKHOME2,[l=0] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'clickingz it research lab' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BADNAME1,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_SKIN4,[l=1]',
                              'blm marketing services' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_DUCHESS3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEB3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'via xan pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'pro lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pre-approved' => 'TVD_APPROVED,[l=1] __KAM_ADVANCE3,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_LOAN3,[l=1]',
                              'sensitive' => '__HUSH_HUSH,[l=1]',
                              'near' => '__KAM_HOME1,[l=1]',
                              'forwarded message' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __YOU_WON_02,[l=1] __freemail_safe_fwd,[l=1]',
                              'million u' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __FRAUD_LTX,[l=1]',
                              'plans and pric' => '__KAM_HIRE3,[l=1] __KAM_SEARCH4,[l=1]',
                              'supervising' => '__KAM_WEBINAR4,[l=1]',
                              'val val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'placement' => '__JMQ_REALESTATE3,[l=1] __KAM_CAREER2,[l=1]',
                              'pro via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'free adult' => 'FREE_PORN,[l=1] __KAM_CRIM2_3,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'dear sir' => 'DEAR_SOMETHING,[l=1] __FRAUD_IRT,[l=1]',
                              'vous etes' => '__YOU_WON_04,[l=1]',
                              'via lev som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'voice' => '__KAM_VM3,[l=1]',
                              'transakcji' => '__DEAL,[l=1] __KAM_MM_FOREX_1,[l=1]',
                              'ultramasx' => '__KAM_KN_1,[l=1]',
                              'lotto international' => '__FRAUD_RLX,[l=1] __HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'kindly' => '__KAM_ACCOUNTPHISH4,[l=1]',
                              'securities company' => '__FRAUD_IRJ,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'billing and coding degree' => '__KAM_CAREER2,[l=1] __KAM_DRUG2_5,[l=1] __KAM_UNIV2,[l=1]',
                              'contact name' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_4,[l=1]',
                              'kissing you' => '__KAM_URONLINE1,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'drug store' => '__KAM_ANDROGEL3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __STOCK_TIP,[l=1]',
                              'pro mer cia' => 'KAM_VIAGRA2,[l=0]',
                              'impotence cure' => 'IMPOTENCE,[l=1]',
                              'male power' => '__KAM_URUNIT4,[l=1]',
                              'hotel' => '__KAM_OPRAH2,[l=0]',
                              'confidential ' => '__DECEASED,[l=1] __FRAUD_AON,[l=1] __FRAUD_MCQ,[l=1] __HUSH_HUSH,[l=1] __KAM_DRUG2_6,[l=1] __KAM_NOCONFIDENCE1,[l=1] __URG_BIZ,[l=1]',
                              'multichannel marketing' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'fiduciary' => '__HK_LOTTO_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'pro som mer' => 'KAM_VIAGRA2,[l=0]',
                              'alis' => '__KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'xan amb val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'hoist your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pre-development prices' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_LOAN3,[l=1] __KAM_REAL2_2,[l=1]',
                              't r a c k' => '__KAM_UNIV5B,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'garage light' => '__KAM_LED2,[l=1]',
                              'amb xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'excess return capital profit' => 'EMRCP,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SOLAR3,[l=1] __KAM_WEIGHT2,[l=1] __YOUR_PROFIT,[l=1]',
                              'mer cia mer' => 'KAM_VIAGRA2,[l=0]',
                              'strategies' => '__KAM_INSURE4,[l=1] __KAM_LANDSCAPE3,[l=1]',
                              'looking' => '__JMQ_REALESTATE3,[l=1] __KAM_URONLINE3,[l=1]',
                              'val cia som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' thursday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __PUMPDUMP_03,[l=1]',
                              'development' => '__KAM_LOAN3,[l=1]',
                              'amb lev cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'lead generation' => '__KAM_ADVERT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_LIST3_2,[l=1]',
                              'cool cele' => '__DRUGS_ERECTILE5,[l=1] __KAM_GALLERY4,[l=1]',
                              '5k daily' => '__KAM_TELEWORK1,[l=1]',
                              'virgin' => 'LIVE_PORN,[l=1]',
                              'leaving residence' => '__STAY_HOME,[l=1]',
                              'wish to receive future emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'sans' => '__CHARITY,[l=1]',
                              'shrinking ' => '__KAM_URUNIT6,[l=1]',
                              'certain' => '__KAM_DATINGTIPS3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              '-shirt' => '__KAM_2020_2,[l=1]',
                              'cgca' => '__KAM_STOCKTIP138,[l=1]',
                              'sores' => '__KAM_HERPES3,[l=1]',
                              'som xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'accident' => '__DECEASED,[l=1] __KAM_ASSASSIN4,[l=1]',
                              'price:' => '__FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_LIST3,[l=1]',
                              'leveraging' => '__KAM_SKIN4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'steps' => '__KAM_AUTONEW3,[l=1]',
                              'som amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'marfil' => '__IVORY_COAST,[l=1]',
                              'amb mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'availability' => '__KAM_DOMAIN1,[l=1]',
                              'tomatoe giant' => '__KAM_FARM3,[l=0]',
                              'gas prices are going up' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_INSURE2,[l=1]',
                              'link to save' => 'TVD_LINK_SAVE,[l=1] __DOS_LINK,[l=1]',
                              'to remove the suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'great money maker' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_EBAY2,[l=0] __KAM_SEX_EXPLICIT4,[l=1]',
                              'fish oil' => '__KAM_FUN7,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1]',
                              'tinnifix' => '__KAM_TINNI1,[l=0]',
                              'like the girls' => '__DEAL,[l=1] __KAM_LED2,[l=1] __KAM_PIC1,[l=1] __KAM_PIC2,[l=1]',
                              'som lev som' => 'KAM_VIAGRA2,[l=0]',
                              'sexual experience' => '__KAM_SEX04_4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'reveals exactly' => '__KAM_BEAUTY2,[l=0]',
                              'for account number:' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_DUCHESS6,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOU_WON_02,[l=1]',
                              'life experience' => '__KAM_UNIV3,[l=1]',
                              'data include' => '__KAM_LIST3_4,[l=1]',
                              'late husband' => '__DECEASED,[l=1] __KAM_BENEFICIARY6,[l=0]',
                              'fax message' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_VM3,[l=1]',
                              'current itinerary' => '__KAM_HOME2,[l=1] __TRAVEL_ITINERARY,[l=0]',
                              'temporary locked' => '__KAM_PHISH2_5,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'recommend a stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEED4,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1]',
                              'financial relief' => '__DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT4,[l=1]',
                              'executive' => '__KAM_WEBINAR4,[l=1]',
                              'qualityrxmedz' => '__KAM_DRUG1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'asassination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __KAM_PATRIOT3,[l=1]',
                              'l c' => '__DRUGS_ERECTILE5,[l=1]',
                              'mail cannot be considered spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DRUGS_ERECTILE5,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1]',
                              'paid access to tools' => '__FEES,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEO3,[l=1]',
                              'amb val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'accredited' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_UNIV4,[l=1] __KAM_UNIV4B,[l=1] __KAM_UNIV9,[l=1]',
                              'female' => '__JMQ_PICKUP4,[l=1]',
                              'cia pro som' => 'KAM_VIAGRA2,[l=0]',
                              'not a registered investment advisor' => 'NOT_ADVISOR,[l=0] __INVEST_MONEY,[l=1] __KAM_BACK2,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEBINAR4,[l=1] __SUBSCRIPTION_INFO,[l=1] __SUM_OF_FUND,[l=1]',
                              'ride' => '__KAM_AUTO3,[l=1]',
                              'apply by sending' => '__KAM_REFI2,[l=1]',
                              'md directory' => '__KAM_DIRECT4,[l=1] __KAM_LIST1,[l=1]',
                              'bored this evening' => '__DEAL,[l=1] __KAM_PIC1,[l=1] __THIS_AD,[l=1]',
                              'cashier' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_TIMESHARE2,[l=1] __TRUSTED_CHECK,[l=1]',
                              ' and fees are gone' => '__FEES,[l=1] __KAM_DEBT1,[l=1]',
                              'speed' => '__KAM_TV2,[l=1]',
                              'attendees who might' => '__KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1]',
                              'amazing lens' => '__KAM_LENS3,[l=0] __KAM_STOCK2_2,[l=1]',
                              'page' => '__KAM_PAPERLESS3,[l=1]',
                              'lev pro som' => 'KAM_VIAGRA2,[l=0]',
                              'situation' => '__KAM_HIRE3,[l=1]',
                              'via cia cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'visit this site' => '__DEAL,[l=1] __KAM_HOWRU3,[l=0] __THIS_AD,[l=1]',
                              'girls passwords' => '__KAM_GALLERY2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'deceased husband' => '__DECEASED,[l=1] __KAM_BANK_2,[l=0] __KAM_BENEFICIARY6,[l=0]',
                              'come to our web site' => '__KAM_DRUG2_5,[l=1] __KAM_REP3_2,[l=1]',
                              'by clicking any image and/or text link in this email' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __DOS_LINK,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'jesus lovely' => '__KAM_JESUS1,[l=1]',
                              'potential' => '__KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1]',
                              'accumulated' => '__DECEASED,[l=1] __KAM_DEBT1,[l=1]',
                              'nice bonus' => '__KAM_SEX04_4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'you are receive this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'terrible' => '__KAM_SINGING3,[l=1]',
                              'private lawyer' => '__FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __FRAUD_WDR,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1]',
                              'black' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'get lasik info' => '__KAM_FUN7,[l=1] __KAM_LASIK3,[l=1] __KAM_REP3_2,[l=1]',
                              'multiply an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'llig risikofrei ist' => '__FRAUD_IOV,[l=1]',
                              'diploma of your choice' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV13,[l=1] __KAM_UNIV6B,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'enclosed' => 'DIET_1,[l=1] __KAM_ITC3,[l=0] __KAM_PHISH4_3,[l=1] __KAM_WEIGHT1,[l=1]',
                              'flash player update' => '__KAM_FLASH2,[l=0] __KAM_INSURE4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'need your contacts informations' => '__CONTACT_ATTY,[l=1] __DECEASED,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_BANK,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'complete your health profile' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_RESUME3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __KAM_JOINT3,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'hotrxmedspot' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'lev val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'sexual confidence' => '__DRUGS_ERECTILE5,[l=1] __HUSH_HUSH,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TESTOSTERONE4,[l=1]',
                              'bill gates' => '__HK_LOTTO_2,[l=1] __KAM_LENS1,[l=0]',
                              'thu' => '__DOS_BODY_THU,[l=1]',
                              'novelty degree' => '__KAM_UNIV2,[l=1] __KAM_UNIV5,[l=1]',
                              '-gun ban' => '__KAM_2ND_1,[l=1]',
                              'happily aannounce' => '__hk_win_3,[l=1]',
                              ' account more secure' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_SECURE,[l=1] __DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_HOME3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'cia val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'invention' => '__JMQ_TRACKR3,[l=1]',
                              'funny price' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_TIME5,[l=1]',
                              'hold' => '__KAM_PHISH2_4,[l=1]',
                              'agreed' => '__AGREED_RATIO,[l=1]',
                              'sign document' => '__KAM_VM4,[l=1]',
                              'amb pro lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'suppresses appetite' => '__KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_WEIGHT1,[l=1]',
                              'improve manhood' => '__KAM_ANDROGEL3,[l=1] __KAM_SEX1,[l=1]',
                              'no cancer' => '__AM_DYING,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_NIGERIAN1,[l=1] __KAM_SMOKE4,[l=1]',
                              'gossip' => '__KAM_SKIN4,[l=1]',
                              'avoid penalty' => '__KAM_STUDENT3,[l=1] __KAM_TAX3,[l=1]',
                              'dermatologist' => '__KAM_TVDOCTOR3,[l=1]',
                              'sexywebdating' => '__KAM_MEMBER3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_URONLINE3,[l=1]',
                              'penile enlarge' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX2,[l=1]',
                              'established person' => 'BAD_CREDIT,[l=1] __KAM_INVEST2,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'chatting with someone' => '__KAM_URONLINE3,[l=1]',
                              '1st avenue' => '__KAM_FUN2,[l=1]',
                              'mer lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'lev xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'get 250 more' => '__KAM_BIZ1,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'walgreens' => '__KAM_ANA1,[l=1] __KAM_REWARD1,[l=1]',
                              'grab as many shares of it as you can' => '__KAM_VIAGRA9A,[l=1] __PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'schools office' => '__KAM_SALE3,[l=1] __KAM_UNIV1,[l=1]',
                              'muffdived & fuck' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'temperature' => '__KAM_NUWAVE3,[l=1]',
                              'pro via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'cia amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'flush' => '__KAM_WEIGHT1,[l=1]',
                              ' am' => '__KAM_COMPROMISED3,[l=1]',
                              ' wednesday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __KAM_STOCK2_1,[l=1] __PUMPDUMP_03,[l=1]',
                              'learn how to earn' => '__KAM_GOOGLE2,[l=0] __KAM_INVEST3,[l=1] __RECEIVE_BONUS,[l=1]',
                              '000 usd weekly' => '__KAM_CEP6,[l=1] __KAM_COVID5,[l=1] __KAM_FAKEWEST5,[l=1] __KAM_JOB2_4,[l=1]',
                              'promo' => '__KAM_LOTTO4,[l=1] __THIS_AD,[l=1]',
                              'drinking this beverage' => '__DEAL,[l=1] __KAM_SHOCK3,[l=0] __THIS_AD,[l=1]',
                              'free eval' => '__KAM_LASIK3,[l=1] __KAM_TRIAL,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __PILL_PRICE_01,[l=1]',
                              'via xan xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'ordinator' => '__FRAUD_RLX,[l=1]',
                              'gestionnaire' => '__CONTACT_ATTY,[l=1]',
                              'article promotion' => '__KAM_LOTTO4,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'wholesome effect' => '__KAM_SEX04_1,[l=1]',
                              'prize' => '__LOTTO_WIN_01,[l=1]',
                              'been recently' => '__KAM_AUTONEW3,[l=1] __KAM_INSURE2,[l=1] __KAM_PAYMENT_LOWERED2,[l=1]',
                              'sex all night' => '__KAM_DATINGTIPS3,[l=1] __KAM_SEX04_4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'licensed physicians' => '__KAM_CRYPTO1,[l=1] __KAM_LIST1,[l=1] __KAM_LIST2,[l=1]',
                              'i apologize if this message was sent, in error' => '__ADMAIL,[l=1] __DEAL,[l=1] __JMQ_WIRE3,[l=1] __KAM_LIKE5,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __THIS_AD,[l=1]',
                              'tery' => '__LOTTO_DEPT,[l=1]',
                              'list of customers' => '__KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_LIST4,[l=1] __KAM_LISTSALE2,[l=0] __KAM_PHISH4_2,[l=1] __KAM_VIAGRA9D,[l=1] __STOCK_TIP,[l=1]',
                              'usd' => '__KAM_COVID5,[l=1]',
                              'snap up as many shares as i can' => '__PUMPDUMP_09,[l=1]',
                              'infinite access' => '__KAM_GALLERY2,[l=1]',
                              'acai diet' => '__DEAL,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'accountability' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_TELEWORK4,[l=1]',
                              'get your ornament' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOLIDAY2020_2,[l=0] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              ' girl' => '__KAM_PIC2,[l=1]',
                              'graduated' => '__KAM_UNIV16,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'fiduciary agent' => '__FRAUD_FCW,[l=0] __HK_LOTTO_2,[l=1] __KAM_BANK_2,[l=0] __KAM_LOTTO4,[l=1] __LOTTO_DEPT,[l=1]',
                              'top in bing' => '__KAM_SEO2,[l=1]',
                              ' tomorrow first thing' => '__PUMPDUMP_03,[l=1]',
                              'protect yourself' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_2ND_1,[l=1] __KAM_AUTO3,[l=1] __KAM_INSURE4,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME5,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'she sees your size' => 'BODY_ENHANCEMENT2,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX05_2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'wrist' => '__KAM_TIME2,[l=1]',
                              'h00kup' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              's list' => '__KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              '.ob' => '__DOS_BODY_TICKER,[l=1]',
                              'i am mr' => '__FRAUD_QXX,[l=1] __KAM_COMPROMISED3,[l=1]',
                              'destined to skyrocket' => '__KAM_STOCK2_2,[l=1]',
                              'make $' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK1,[l=1]',
                              'paying' => '__FEES,[l=1] __KAM_TAX3,[l=1] __PAY_YOU,[l=1]',
                              'som xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'opinion' => '__KAM_FAKEVOUCHER4,[l=1]',
                              'grass seed on steroids' => '__KAM_ADVERT1,[l=1] __KAM_GRASS3,[l=0] __KAM_VIAGRA9A,[l=1]',
                              'reduce your payments' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_CLOUD3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_DEBT1,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PET3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' to your e' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __MAIL_ACCT_ACCESS2,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'absolutely no cost' => '__FB_COST,[l=1] __KAM_CREDIT3,[l=1] __KAM_REFI2,[l=1]',
                              'underwater' => '__KAM_REFI2,[l=1]',
                              'instantly' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_LOAN3,[l=1] __KAM_TAX3,[l=1]',
                              'pics i took of my ex-wife' => '__KAM_CARD2,[l=1]',
                              'trader' => '__KAM_STOCK2_4,[l=0]',
                              'ee;r%a!<%k8x9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'fatigued all the time' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT3A,[l=1]',
                              'to be removed from receiving' => 'EXCUSE_4,[l=1] EXCUSE_REMOVE,[l=1] __KAM_FUN2,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'val pro lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'times' => '__KAM_LOAN3,[l=1] __KAM_TIME4,[l=1]',
                              'aise sweepstake' => '__HK_LOTTO_BALLOT,[l=1]',
                              'slipping' => '__KAM_AQUARUG3,[l=1]',
                              'current attendee' => '__KAM_HOME2,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1]',
                              'four of the mastercard' => '__DEAL,[l=1] __KAM_SHADYCC3,[l=0]',
                              'verify' => '__KAM_BOXVERIFY,[l=1]',
                              'processing' => '__FEES,[l=1] __KAM_CLAIMS3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_RECALL3,[l=1] __LOTTO_DEPT,[l=1]',
                              'release messages' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1]',
                              'raise your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'offer' => '__KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1]',
                              'arrest' => '__KAM_ARREST2,[l=1] __KAM_BACK3,[l=1] __KAM_SNORE3,[l=1]',
                              'you\'ve receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dear internet' => 'DEAR_SOMETHING,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1]',
                              'bargain offers on medic' => '__KAM_DOMAIN3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_LOAN3,[l=1] __KAM_MED1,[l=1] __KAM_SALE3,[l=1] __KAM_SEX4,[l=0]',
                              'lbs' => '__KAM_FUN5,[l=1]',
                              'mandatory poster' => '__KAM_GINA4,[l=0]',
                              'lev cia lev' => 'KAM_VIAGRA2,[l=0]',
                              'strong' => '__KAM_HOSE3,[l=1]',
                              'bank' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'cabinetofmeds' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1] __KAM_REP3_2,[l=1]',
                              'first-rated drugs' => '__KAM_ANDROGEL3,[l=1] __KAM_INSURE4,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_SEX04_1,[l=1]',
                              'complete your listing' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST4,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WHOSWHO3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'search' => '__KAM_REVIEW3,[l=1]',
                              'you are received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'selected as a winner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __KAM_GOOGLE_AWARD2,[l=0] __KAM_LOTTO6,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RANDOM_PICK,[l=1] __hk_win_2,[l=1]',
                              'www.domainregistryasia.net' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKE_REGISTRY1,[l=0] __KAM_REP2,[l=1] __KAM_REP3_2,[l=1]',
                              'opportunity' => '__KAM_CAREER2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_STOCK2_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'mer pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'selling a list' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'gripeez' => '__KAM_GRIPPY3,[l=1]',
                              'fresh adu' => '__KAM_CHICKEN3,[l=1] __KAM_GALLERY4,[l=1]',
                              'lev via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'team tpw' => '__KAM_BADNAME1,[l=1]',
                              'procedure' => '__KAM_KIWIBANK3,[l=1]',
                              'laptop giveaway' => '__FRAUD_JYG,[l=1] __KAM_GIVE2,[l=1]',
                              'made' => '__DAY_I_EARNED,[l=1]',
                              'three' => '__KAM_CREDIT2,[l=1]',
                              'trying this trick' => '__DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_WEIRDTRICK2,[l=1] __THIS_AD,[l=1]',
                              'legitrxlife' => '__KAM_DRUG2_5,[l=1]',
                              'criminal justice or homeland security degree' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_ARREST2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_SECURITY3,[l=1] __KAM_UNIV12,[l=1] __KAM_UNIV2,[l=1] __KAM_WINDOWS3,[l=1] __TRUNK_BOX,[l=1]',
                              'erase' => '__KAM_SKIN4,[l=1]',
                              'your mailer do not support html messages' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RUDE_HTML_4,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'tripling your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'covid-19 fund' => '__KAM_COVID2_1,[l=0] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'process our payments' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'cia cia lev' => 'KAM_VIAGRA2,[l=0]',
                              'aid your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'celebrity smile' => '__KAM_WHITEN3,[l=0]',
                              'winning notification' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_POLITICS2,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'n restricted status' => '__KAM_SNORE3,[l=1] __TVD_PH_BODY_01,[l=1]',
                              'girlfriend' => '__DOS_BODY_FRI,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'attendees list' => '__KAM_LIST3_2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'campaign manager' => '__KAM_LIST3_2,[l=1] __KAM_POLITICS2,[l=1]',
                              'lifeinsurance' => '__KAM_AUTONEW2,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1]',
                              'zquiet' => '__KAM_SNORE3,[l=1]',
                              'unverified' => '__KAM_ENGINEER2,[l=1] __KAM_REVIEW3,[l=1]',
                              'attached file' => '__JMQ_RESUME3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_PRIV3,[l=0] __PLS_REVIEW,[l=1]',
                              'monero (xmr)' => '__DOS_BODY_MON,[l=1] __MONERO_CURNCY,[l=1]',
                              'physician' => '__KAM_CRYPTO1,[l=1] __KAM_LIST2,[l=1]',
                              ' per eye' => '__KAM_LASIK3,[l=1]',
                              'cia amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'qualifies' => '__KAM_SOLAR3,[l=1]',
                              'foreign offshore account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __FRAUD_TCC,[l=0] __HK_SCAM_N15,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'employing your services' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'disabled' => '__ACH_CANCELLED_03,[l=1]',
                              'prado' => '__KAM_SMOKE1,[l=1]',
                              'this_list' => '__DEAL,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1] __OBFU_UNSUB_UL,[l=1] __THIS_AD,[l=1]',
                              'nourish wood' => '__KAM_DUTCHGLOW3,[l=1]',
                              'steady and increasing course' => '__DOS_STEADY_COURSE,[l=1]',
                              'medical billing and coding' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_MEDICAL1,[l=0] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'pro pro mer' => 'KAM_VIAGRA2,[l=0]',
                              'unique account' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_AQUARUG3,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_LIST3_4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'primegen energy' => '__KAM_NUWAVE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_STOCKTIP136,[l=1] __KAM_WINDOWS3,[l=1]',
                              'stone-hard manhood' => '__KAM_ANDROGEL3,[l=1] __KAM_SEX2,[l=1] __STOCK_TIP,[l=1]',
                              'cunt' => '__KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'facebook' => '__KAM_GIFT1,[l=1]',
                              'work experience transcript' => '__KAM_CAREER3,[l=1] __KAM_UNIV7,[l=1]',
                              'address still valid' => '__KAM_URGENT5,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'bored afternoon' => '__KAM_PIC1,[l=1]',
                              'drgz' => '__KAM_STOCKTIP137,[l=1]',
                              'found your detail' => '__DECEASED,[l=1] __FOUND_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_INVEST2,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'list for marketing' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST4,[l=1] __KAM_LISTSALE2,[l=0] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WEBINAR4,[l=1] __YOU_WON_02,[l=1]',
                              'caplet' => '__PILL_PRICE_01,[l=1]',
                              'predator' => '__KAM_ARREST2,[l=1]',
                              'off' => '__KAM_SALE3,[l=1]',
                              'daughter of the late' => '__DEAL,[l=1] __DECEASED,[l=1] __FRAUD_ZFJ,[l=1]',
                              'new tires' => '__KAM_TIRES3,[l=0]',
                              'egift' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'late' => '__DECEASED,[l=1]',
                              'quest science management gate' => '__KAM_STOCKTIP167,[l=1] __KAM_WEBINAR4,[l=1]',
                              '100% legal' => '__KAM_MERCHANT3,[l=1] __KAM_TV1,[l=1] __KAM_WEED1,[l=1]',
                              'received' => '__DAY_I_EARNED,[l=1]',
                              'tiffany' => '__KAM_TIME6,[l=0]',
                              'royal heritage lottery' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1] __MY_FORTUNE,[l=1]',
                              'you\'ve receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'shocking' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SHOCK1,[l=1]',
                              'lev amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'tired today' => '__DAY_I_EARNED,[l=1] __KAM_GIFT3,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'lookup' => '__KAM_STOCK3,[l=1]',
                              'mobie concepts, inc' => '__KAM_BADNAME1,[l=1] __KAM_CEP4,[l=1]',
                              'concealed carry' => '__HUSH_HUSH,[l=1] __KAM_2ND_2,[l=0]',
                              'neuropathy' => '__KAM_COVID5,[l=1] __KAM_DRUG2_3,[l=1]',
                              'stbv' => '__KAM_STOCKTIP148,[l=1]',
                              ' pounds' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'you will get ' => '__I_WILL_YOU,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ur thing' => '__KAM_URUNIT2,[l=1]',
                              'confirm interest in owning' => '__BACK_SCRATCH,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SNORE3,[l=1] __KAM_TAX4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'you\'re received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'online' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1]',
                              'compare' => '__KAM_AUTONEW2,[l=1] __KAM_REP3_2,[l=1]',
                              'consequence' => '__YOU_WON_04,[l=1]',
                              'serial number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'cia som som' => 'KAM_VIAGRA2,[l=0]',
                              'modality' => '__FRAUD_THJ,[l=0]',
                              'doctors hate him' => '__KAM_MARIJUANA3,[l=1] __KAM_NEUROLOGICAL3,[l=0]',
                              'boost your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'will send you my pictures' => '__I_WILL_YOU,[l=1] __KAM_PIC4,[l=1] __KAM_PIC5,[l=0] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'affordable ' => 'PRICES_ARE_AFFORDABLE,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'seleccion aleatoria' => '__RANDOM_PICK,[l=1]',
                              'costs for your business' => '__DEAL,[l=1] __DECEASED,[l=1] __FB_COST,[l=1] __FRAUD_QFY,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB3,[l=1] __RECEIVE_BONUS,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'wszystko' => '__KAM_MM_FOREX_1,[l=1]',
                              'plan and pric' => '__KAM_SEARCH4,[l=1]',
                              'kn95 ' => '__KAM_KN_1,[l=1]',
                              'seas bank account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'transform your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'com' => '__KAM_REP3_2,[l=1]',
                              ' opens monday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'terminal' => '__KAM_BENEFICIARY6,[l=0] __KAM_INSURE4,[l=1]',
                              'listed in auction' => '__KAM_DOMAIN2,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'burning' => 'DIET_1,[l=1] __KAM_CELEB3,[l=1]',
                              'investment fund' => '__INVEST_MONEY,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'triple your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'complimentary' => '__KAM_CLOUD4,[l=1] __KAM_DIRECT3,[l=0] __KAM_REP3_2,[l=1]',
                              ' gates' => '__HK_LOTTO_2,[l=1]',
                              'remote' => '__KAM_ALARM2,[l=1]',
                              'lev som som' => 'KAM_VIAGRA2,[l=0]',
                              'favorite rx' => '__KAM_DRUG2_3,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_TV2,[l=1]',
                              'cia mer pro' => 'KAM_VIAGRA2,[l=0]',
                              'i was fired from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'sealed' => '__TRUNK_BOX,[l=1]',
                              'xan pro amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'titan peeler' => '__KAM_PEEL1,[l=1]',
                              'extreme collection' => '__KAM_GALLERY2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'lev via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'securing fund' => '__FRAUD_WFC,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'penhtremine' => '__KAM_DRUG2_5,[l=1]',
                              'prefer to not receive future messages' => '__ADMAIL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              ' price' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1]',
                              'oil and gas rights' => '__KAM_DETOX3,[l=1] __KAM_DRILL2,[l=0] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_PATRIOT3,[l=1]',
                              'micros id' => '__KAM_LOTTO2,[l=1]',
                              'world health organization' => '__KAM_COVID1,[l=0] __KAM_JOINT3,[l=1] __KAM_REP3_2,[l=1]',
                              'sell your personal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_NOTIFY2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'attendee' => '__KAM_LIST3_4,[l=1]',
                              'spyware' => '__KAM_ABOUT2,[l=0]',
                              'each record' => '__KAM_LIST3_3,[l=1] __PILL_PRICE_01,[l=1]',
                              'cia via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'nursing assistant' => '__KAM_LIST2,[l=1] __KAM_NURSE3,[l=1] __YOU_ASSIST,[l=1]',
                              'pro amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'omegak, inc' => '__KAM_BADNAME1,[l=1]',
                              'our gift to you' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFTCERT1,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'recommends this company' => '__DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_06,[l=1] __THIS_AD,[l=1]',
                              'doctors are shocked' => '__KAM_FUN6,[l=0] __KAM_MARIJUANA3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'lev mer pro' => 'KAM_VIAGRA2,[l=0]',
                              'section 21b' => 'TVD_SECTION,[l=1]',
                              'channels' => '__KAM_TV2,[l=1]',
                              'this is an ad-coresspondance' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_FUN3,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'support best practices in responsible email marketing' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER2,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEBINAR4,[l=1] __YOU_WON_01,[l=1]',
                              'drug addict' => '__KAM_ANDROGEL3,[l=1] __KAM_REHAB3,[l=0] __KAM_REMEMBERWHEN3,[l=1]',
                              'reply' => '__FRAUD_MLY,[l=1]',
                              'escogidos aleatoria' => '__RANDOM_PICK,[l=1]',
                              'tripling an principle' => '__PUMPDUMP_01,[l=1]',
                              'terms & condition' => '__KAM_INQUIRY_3,[l=0] __KAM_INSURE4,[l=1]',
                              'married' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'inches' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] DIET_1,[l=1] __KAM_SEX2,[l=1]',
                              'flmg' => '__KAM_STOCKTIP144,[l=1]',
                              'obrzydliwie' => '__KAM_MM_FOREX_1,[l=1]',
                              'entitled to compensation' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __KAM_MESH3,[l=0] __KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1]',
                              ' digit level in ' => '__DOS_TAKING_HOME,[l=1]',
                              'sensual enhancer' => '__KAM_SEX1,[l=1]',
                              'naughty' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'have a mesh implant' => '__KAM_MESH3,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_01,[l=1]',
                              'promise' => '__KAM_NIGERIAN4,[l=1]',
                              'end your drinking' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REHAB3,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' friday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'interracial' => '__KAM_SEX2,[l=1]',
                              'i\'m 19' => '__KAM_PIC2,[l=1]',
                              'never find your web' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_INSURE4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __KAM_SEO3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __NOT_SCAM,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fund proposal' => '__DEAL,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INVEST4,[l=1] __SUM_OF_FUND,[l=1] __URG_BIZ,[l=1] __YOUR_FUND,[l=1]',
                              'marijuana' => '__KAM_MARIJUANA1,[l=0]',
                              'bxreitling' => '__KAM_TIME6,[l=0]',
                              'calorie burning machine' => 'DIET_1,[l=1] __KAM_CELEB3,[l=1] __KAM_WEIGHT1,[l=1]',
                              'fucker' => '__KAM_SEX1,[l=1]',
                              'crimes' => '__KAM_PATRIOT3,[l=1]',
                              'wood\'s natural beauty' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_DUTCHGLOW3,[l=1] __KAM_LUNAR4,[l=1] __KAM_VISION3,[l=1]',
                              'automobile accident' => '__AUTO_ACCIDENT,[l=0] __DECEASED,[l=1] __KAM_ASSASSIN4,[l=1] __KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_WEB3,[l=1]',
                              'claim the funds' => '__DEAL,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_DEPT,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'hexten' => '__KAM_URONLINE2,[l=1]',
                              'secret big pharma' => '__HUSH_HUSH,[l=1] __KAM_BLOOD3,[l=1] __KAM_WEIGHT2,[l=1]',
                              'account offshore' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __DORMANT_ACCT,[l=1] __HK_SCAM_N15,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SALE3,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'ready for pay' => '__FEES,[l=1] __KAM_PATRIOT3,[l=1] __PAY_YOU,[l=1] __YOU_WON_02,[l=1] __hk_win_j,[l=1]',
                              'contains forward-looking statements' => 'FORWARD_LOOKING,[l=1] __JMQ_REALESTATE3,[l=1] __KAM_FDA1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_URONLINE3,[l=1] __YOU_WON_02,[l=1]',
                              'restored' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_QUOTA2,[l=1] __KAM_SNORE3,[l=1] __KAM_VISION3,[l=1] __STOCK_TIP,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'ord3r' => '__KAM_DRUG2_5,[l=1]',
                              'treatment options' => '__KAM_ADHD3,[l=0] __KAM_GARAGE3,[l=1] __SUBSCRIPTION_INFO,[l=1] __TRTMT_DEFILED,[l=1]',
                              'central bank of' => '__FRAUD_BEP,[l=1] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'ukranian beaut' => '__KAM_WIFE2,[l=1]',
                              'backstage trading' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_SEARCH3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_TAX3,[l=1]',
                              'mlgt' => '__KAM_STOCKTIP154,[l=1]',
                              'attendees specialist' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_VISION3,[l=1]',
                              'i bet your wife won' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CARD2,[l=1] __KAM_INSURE4,[l=1] __KAM_LOTTO3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sell or rent it' => '__KAM_HOME2,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'online university' => 'FREE_QUOTE_INSTANT,[l=1] __HK_LOTTO_2,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_UNIV1,[l=1] __KAM_UNIV9,[l=1]',
                              'going out of house' => '__JMQ_HEARINGLOSS3,[l=1] __STAY_HOME,[l=1]',
                              'your winning' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_5,[l=1]',
                              'target geograph' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1] __KAM_LIST3_3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'premier fabric' => '__KAM_LABEL5,[l=0]',
                              'optimized' => '__KAM_SEARCH4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'you\'re receive this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'western union money transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DOS_BODY_MON,[l=1] __FEES,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_FAKEWEST2,[l=0] __KAM_NIGERIAN5,[l=1] __WIRE_XFR,[l=1]',
                              'offer pass you by' => '__KAM_DOMAIN3,[l=1] __KAM_GIFT3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'winner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __hk_win_2,[l=1]',
                              'with google' => '__KAM_GOOGLE4,[l=0] __KAM_SEO4,[l=1]',
                              'this email is an ad' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'empower your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'serious' => '__KAM_NIGERIAN1,[l=1]',
                              'practicing mds' => '__KAM_LIST1,[l=1]',
                              'save money on your auto' => '__DECEASED,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_BITCOIN2,[l=1] __KAM_CAR2,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'autowarranty' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_INSURE2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'no medical exam' => 'NO_MEDICAL,[l=1] __JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'officially licensed' => '__KAM_2020_2,[l=1] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'link expires' => '__DOS_LINK,[l=1] __KAM_PAPERLESS4,[l=0]',
                              'guest pass and catalog' => '__KAM_DIRECT3,[l=0]',
                              'six month ongoing campaign' => '__DOS_BODY_MON,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_CEP6,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEO6,[l=1] __KAM_SKIN4,[l=1] __KAM_UNIV2,[l=1]',
                              'score' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1]',
                              'blowout' => '__KAM_AUTO3,[l=1]',
                              'val som lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pro mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'federal student loan status' => '__DECEASED,[l=1] __KAM_BACK1,[l=1] __KAM_STUDENT3,[l=1] __KAM_STUDENTLOAN1,[l=0]',
                              'select your new card' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'your account ' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_ERROR,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mailbox quota has exceeded' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BOXQUOTA,[l=1] __KAM_QUOTA1,[l=0] __KAM_VM4,[l=1] __YOU_WON_01,[l=1]',
                              'the bed' => '__DEAL,[l=1] __KAM_URUNIT4,[l=1]',
                              'ready for release' => '__KAM_PATRIOT3,[l=1] __KAM_PAYMENTSCAM2,[l=0] __SUM_OF_FUND,[l=1] __YOU_WON_02,[l=1]',
                              'castle' => '__KAM_ALARM2,[l=1]',
                              'this message was sent to email address.' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_WIRE3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __PDS_SENT_TO_EMAIL_ADDR,[l=0] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              'mer som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'flooring' => '__KAM_GARAGE3,[l=1]',
                              'prescript' => 'NO_PRESCRIPTION,[l=1] __KAM_DRUG2_4,[l=1]',
                              'rate' => '__KAM_INSURE4,[l=1]',
                              'pro cia amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'get naughty' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_URONLINE3,[l=1]',
                              'construction' => '__KAM_ENGINEER3,[l=1] __KAM_REAL2_2,[l=1]',
                              'department' => '__HK_LOTTO_2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'prefer to receive these messages' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'summer' => '__KAM_WINDOWS3,[l=1]',
                              'human resources' => '__KAM_TRAINING3,[l=0]',
                              'oprah!' => 'BANG_OPRAH,[l=1] __KAM_OPRAH3,[l=0] __KAM_WEIGHT2,[l=1]',
                              'landscape' => '__KAM_LANDSCAPE3,[l=1]',
                              'xan xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'modalities' => '__FRAUD_THJ,[l=0]',
                              'president' => '__DECEASED,[l=1] __KAM_STUDENT3,[l=1]',
                              'transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __WIRE_XFR,[l=1]',
                              'val lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'excess maximum return capital profit' => 'EMRCP,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SOLAR3,[l=1] __KAM_WEIGHT2,[l=1] __YOUR_PROFIT,[l=1]',
                              'surfing' => '__KAM_SEARCH3,[l=1]',
                              'you are received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'msw mega jackpot' => '__KAM_LOTTO5,[l=1]',
                              'sincere congratulations' => '__KAM_LOTTO6,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'amalgamated bank' => '__FRAUD_BEP,[l=1] __JMQ_WIRE3,[l=1] __KAM_GALLERY4,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'new heights development and research' => '__KAM_BADNAME1,[l=1] __KAM_LOAN3,[l=1] __KAM_REVIEW3,[l=1] __KAM_SKIN4,[l=1]',
                              'k mortgage credit' => 'BAD_CREDIT,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_HOME3,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI2,[l=1]',
                              'compliance with the canspam act' => 'KAM_CANSPAM,[l=1] __DEAL,[l=1] __KAM_REP3_2,[l=1]',
                              'education assessment' => '__KAM_UNIV1,[l=1]',
                              'about' => '__KAM_BACK3,[l=1]',
                              'list include' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'award' => '__LOTTO_DEPT,[l=1]',
                              'crashing' => '__KAM_REAL2,[l=0]',
                              'picked' => '__KAM_SEX_EXPLICIT4,[l=1] __RANDOM_PICK,[l=1]',
                              'som cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'attached' => '__KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1]',
                              'your itinerary' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TRAVEL_ITINERARY,[l=0] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' lbs lighter' => '__KAM_DIET2_3,[l=1] __KAM_FUN5,[l=1]',
                              'provide' => '__KAM_CREDIT3,[l=1]',
                              'xan via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'ink n toner' => '__KAM_INK1,[l=1]',
                              'divest' => '__KAM_WEBINAR4,[l=1]',
                              'donnob.biz' => '__KAM_DON3,[l=1]',
                              'beyond human, llc' => '__KAM_BADNAME1,[l=1]',
                              'som via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'lose 25 years' => 'DIET_1,[l=1] __JMQ_PICKUP4,[l=1] __KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_OCEANSBOUNTY3,[l=1] __KAM_SKIN4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'hospital directory' => '__KAM_DIRECT4,[l=1] __KAM_LIST1,[l=1] __KAM_LIST2,[l=1]',
                              'incentive' => '__KAM_SOLAR3,[l=1]',
                              '4801 l' => '__KAM_DUCHESS3,[l=1]',
                              'counts and cost' => '__FB_COST,[l=1] __KAM_LIST3_3,[l=1]',
                              'asian beaut' => '__KAM_WIFE2,[l=1]',
                              'xan val amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'free website search engine optimi' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEARCH4,[l=1] __KAM_TRIAL,[l=1] __KAM_WEB2,[l=1] __PILL_PRICE_01,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'xan lev pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'activation of your ' => '__ACCESS_REVOKE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'transunion report' => '__DOS_BODY_SUN,[l=1] __KAM_BADZIP3,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1]',
                              'inside sales' => '__KAM_DRUG2_3,[l=1] __KAM_LIST3_2,[l=1]',
                              '% on health insurance' => '__KAM_AUTONEW2,[l=1] __KAM_HEALTH2,[l=1] __KAM_INSURE4,[l=1] __KAM_JOINT3,[l=1]',
                              'watch' => '__KAM_TIME4,[l=1]',
                              'luxury clothing' => '__KAM_LABEL5,[l=0]',
                              'hsbc' => '__KAM_PHISH2_2,[l=1]',
                              'property' => '__KAM_REAL2_4,[l=1]',
                              'oprah' => '__KAM_OPRAH3,[l=0] __KAM_WEIGHT2,[l=1]',
                              'i am dr' => '__FRAUD_QXX,[l=1] __KAM_COMPROMISED3,[l=1]',
                              'four of my mastercard' => '__KAM_SHADYCC3,[l=0]',
                              'viaggra' => 'VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE2,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'fat loss product' => '__KAM_HAIRTRANS3,[l=1] __KAM_HOODIA3,[l=1]',
                              'decorator' => '__KAM_GRIPPY3,[l=1]',
                              'first on the major search' => '__DEAL,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEARCH3,[l=1]',
                              'cia mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'dollar' => '__KAM_COVID5,[l=1]',
                              'repatriation' => '__KAM_BENEFICIARY3,[l=1]',
                              'download yourheld ' => '__DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'time' => '__KAM_TIME4,[l=1]',
                              'lev mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'p e r i m e t e r p a r k c e n t e r' => 'KAM_PERPARK,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'pound sterling' => '__KAM_LOTTO3,[l=1]',
                              'rest' => '__KAM_SNORE3,[l=1]',
                              'prefer to receive these emails' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'via via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              ' tuesday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __KAM_STOCK2_1,[l=1] __PUMPDUMP_03,[l=1]',
                              'you\'re receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'smuggle' => '__KAM_NIGERIAN2_7,[l=0]',
                              'fantastic adu' => '__KAM_GALLERY4,[l=1]',
                              'forced' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'suporte t\\351cnico' => '__SYSADMIN,[l=1]',
                              'pro amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'projected' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1] __KAM_DRAPES3,[l=1]',
                              'security company' => '__FEES,[l=1] __FRAUD_IRJ,[l=0] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __TRUNK_BOX,[l=1]',
                              'life and work experience' => '__KAM_CAREER3,[l=1] __KAM_UNIV3,[l=1]',
                              'pro xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'second home' => '__KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_REAL3,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'inv-' => '__KAM_UKINV3,[l=1]',
                              'via cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'available by auction' => '__KAM_DOMAIN2,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI2,[l=1]',
                              'attendee specialist' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_C,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_LIST3_2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA8D,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_VISION3,[l=1]',
                              'climax' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'amb som lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'back' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'nigeria government' => '__FRAUD_QFY,[l=1] __FRAUD_YQV,[l=0] __KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_MEDICARE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1] __NIGERIA,[l=1]',
                              'via mer amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'earliest response' => '__FRAUD_DPR,[l=1] __URG_BIZ,[l=1]',
                              'respond immediately' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CREDIT3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1]',
                              'reimbursement' => '__ADMITS_SPAM,[l=1] __LOTTO_DEPT,[l=1]',
                              'correspond with me using my email' => '__ADMAIL,[l=1] __DOS_CORRESPOND_EMAIL,[l=1] __FRAUD_MLY,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __YOU_WON_01,[l=1]',
                              'pay a cable or satellite bill' => '__DOS_BODY_SAT,[l=1] __FEES,[l=1] __KAM_TV2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PAY_YOU,[l=1]',
                              'it\'s on us' => '__KAM_CREDIT3,[l=1]',
                              'government grant' => '__FRAUD_QFY,[l=1] __KAM_GRANT1,[l=0] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SOLAR3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'professional writing' => '__KAM_GARAGE3,[l=1] __KAM_WRITING3,[l=0]',
                              'lowest cost in india' => '__FB_COST,[l=1] __KAM_MEDTOUR2,[l=0] __KAM_REPAIR1_3,[l=1] __KAM_SEARCH3,[l=1]',
                              'never receive these again' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __NOT_SCAM,[l=1]',
                              'mer amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'heart' => '__KAM_DEATH4,[l=1]',
                              'amb lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'drop' => '__KAM_REFI6,[l=1]',
                              'xan cia mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              '-pharmacy' => '__KAM_DRUG1,[l=1]',
                              'opporttunity' => '__KAM_DOMAIN3,[l=1] __LOTTO_DEPT,[l=1]',
                              'their financial dreams' => '__DEAL,[l=1] __KAM_AUTO3,[l=1] __KAM_BACK2,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PATRIOT4,[l=1]',
                              'univers' => '__HK_LOTTO_2,[l=1]',
                              'uk national online lottery' => 'FREE_QUOTE_INSTANT,[l=1] __AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'pro val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'the total sum' => '__DEAL,[l=1] __FRAUD_JYG,[l=1] __FRAUD_YPO,[l=0]',
                              'citizen' => '__KAM_NIGERIAN1,[l=1]',
                              'to uplift the suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1]',
                              'lovers package' => '__FRAUD_QFY,[l=1] __KAM_INSURE4,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SEX04_4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TAX3,[l=1] __KAM_TRIAL,[l=1]',
                              'compliment of the' => '__DEAL,[l=1] __FRAUD_IRT,[l=1] __KAM_REP3_2,[l=1]',
                              'scientifically shown' => '__KAM_FUN6,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TINNITUS3,[l=1]',
                              'cpanel cloud service' => '__DRUGS_ERECTILE5,[l=1] __KAM_PHISHCP3_1,[l=1] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1]',
                              'power of attorney' => '__CONTACT_ATTY,[l=1] __KAM_ATTORNEY3,[l=1] __KAM_BENEFICIARY6,[l=0]',
                              'hr directors email database' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_DIRECT4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'warning' => '__KAM_REPAIR2_3,[l=1]',
                              'instructor' => '__KAM_CEP3,[l=1]',
                              'microsystems' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_STOCKTIP132,[l=1]',
                              'splendid drugs' => '__KAM_ANDROGEL3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_SEX04_1,[l=1]',
                              'blue tablet' => '__KAM_SEX04_1,[l=1] __PILL_PRICE_01,[l=1]',
                              'inquiry for purchase' => '__KAM_INQUIRY_1,[l=0] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'fleet management solutions' => '__KAM_CLOUD3,[l=1] __KAM_CONTRACT3,[l=0] __KAM_LOAN3,[l=1] __KAM_STOCKTIP144,[l=1] __KAM_WEBINAR4,[l=1]',
                              'listed at auction' => '__KAM_DOMAIN2,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'mer cia som' => 'KAM_VIAGRA2,[l=0]',
                              'amb xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'bad trading day' => 'BAD_CREDIT,[l=1] __DAY_I_EARNED,[l=1] __KAM_STOCK2_1,[l=1]',
                              'proforma invoice' => '__FRAUD_QFY,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FAKE_FAX4,[l=0] __KAM_PATRIOT3,[l=1] __KAM_PROFORMA4,[l=0] __KAM_TOLL3,[l=1] __KAM_VM3,[l=1] __YOU_WON_02,[l=1]',
                              'val cia mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'attached herewith' => '__KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_PAYMENTSCAM2,[l=0] __PLS_REVIEW,[l=1]',
                              'pro som som' => 'KAM_VIAGRA2,[l=0]',
                              'ipads on auction' => '__KAM_SWIPE3,[l=1]',
                              'honest cooperation' => '__FRAUD_XVW,[l=1] __FRAUD_XWW,[l=1] __JMQ_RESUME3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1]',
                              'expanding' => '__KAM_FLEXHOSE3,[l=1]',
                              'm in hurry, but i still love you' => '__KAM_CARD3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'loan processing' => '__FEES,[l=1] __KAM_CLAIMS3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI2,[l=1] __LOTTO_DEPT,[l=1]',
                              'wanted' => '__KAM_ARREST2,[l=1]',
                              'do you know about this site' => '__DEAL,[l=1] __KAM_BACK3,[l=1] __KAM_COMPROMISED4,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'monarchy resources' => '__DOS_BODY_MON,[l=1] __KAM_STOCKTIP150,[l=0]',
                              ' tuesday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'honestly' => '__FRAUD_XWW,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_HAPPYTALK2,[l=1]',
                              'som xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'get report today' => '__DAY_I_EARNED,[l=1] __KAM_BADZIP3,[l=0] __KAM_CREDIT3,[l=1] __KAM_GIFT3,[l=1] __KAM_REFI6,[l=1] __KAM_SUNGLASSES3,[l=1]',
                              'via som val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'you\'ve receiving this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sweet ass' => '__KAM_PRIV1,[l=0]',
                              'mugged' => '__KAM_NIGERIAN1,[l=1]',
                              'amb val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'amb lev pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'deceased customer' => '__DECEASED,[l=1] __KAM_BANK_2,[l=0] __KAM_BENEFICIARY6,[l=0] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_PHISH4_2,[l=1] __STOCK_TIP,[l=1]',
                              'dear traveller' => 'DEAR_SOMETHING,[l=1] __TRAVEL_AGENT,[l=1]',
                              'also' => '__RECEIVE_BONUS,[l=1]',
                              ' friday morning' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __KAM_STOCK2_1,[l=1] __PUMPDUMP_03,[l=1]',
                              'visitor record' => '__KAM_DIRECT3,[l=0] __KAM_LIST3_4,[l=1]',
                              'make custom shirts' => '__KAM_LABEL3a,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'easy transfer from a wheelchair' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_TUB3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __WIRE_XFR,[l=1]',
                              '-cig' => '__KAM_SMOKE1,[l=1]',
                              'act of 193' => 'TVD_ACT_193,[l=1]',
                              'set your own hours' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' month' => '__DOS_BODY_MON,[l=1] __KAM_CEP6,[l=1] __KAM_SKIN4,[l=1] __KAM_UNIV2,[l=1]',
                              'fields include' => '__KAM_LIST3_3,[l=1]',
                              'greatest thing of your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HONOR1,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'congo' => '__KAM_NIGERIAN3_1,[l=0]',
                              'som lev mer' => 'KAM_VIAGRA2,[l=0]',
                              'internet millionaire' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COVID3_3,[l=1] __KAM_MILLIONAIRE1,[l=0] __KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1]',
                              'amb via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'unexpected repair' => 'BAD_CREDIT,[l=1] __KAM_AUTONEW3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_WARRANTY2,[l=0]',
                              ' company in india' => '__KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEO4,[l=1] __KAM_STOCK2_2,[l=1]',
                              'bzic' => '__KAM_STOCKTIP147,[l=1]',
                              'pro amb via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'respond urgently' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1] __KAM_BADZIP3,[l=0] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __URG_BIZ,[l=1]',
                              'you\'re receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' v ' => 'KAM_OVERPAY,[l=1]',
                              'cklich' => '__LUCKY_WINNER,[l=1]',
                              'quote' => 'FREE_QUOTE_INSTANT,[l=1]',
                              'hospitals need you' => '__KAM_CAREER1,[l=1] __KAM_LIST2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'via cia pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'get babe' => '__KAM_GALLERY4,[l=1]',
                              'heave your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'eur' => '__KAM_COVID5,[l=1]',
                              'cia pro mer' => 'KAM_VIAGRA2,[l=0]',
                              'wild transformation' => '__KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEIGHT2_1,[l=0] __YOU_WON_02,[l=1]',
                              'fair labor standards act' => '__KAM_FAKEBBB2,[l=1]',
                              'instantly connect with' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_LOAN3,[l=1] __KAM_REFI6,[l=1] __KAM_TAX3,[l=1]',
                              'second place' => '__KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_REAL3,[l=1]',
                              'mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1]',
                              'domain' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1]',
                              'inteligentny' => '__KAM_MM_FOREX_1,[l=1] __KAM_REFI2,[l=1]',
                              'fax received' => '__DAY_I_EARNED,[l=1] __KAM_FAKE_FAX2,[l=0]',
                              'som amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'stop' => '__KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'lev pro mer' => 'KAM_VIAGRA2,[l=0]',
                              'attachment' => '__DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1]',
                              'look at this site right now' => '__DEAL,[l=1] __KAM_COMPROMISED4,[l=1] __KAM_DETOX3,[l=1] __KAM_PATRIOT3,[l=1] __THIS_AD,[l=1]',
                              'f-a-t' => '__KAM_WEIGHT2,[l=1]',
                              'dove lighting co' => '__KAM_BADNAME1,[l=1]',
                              'cons\\351quence' => '__YOU_WON_04,[l=1]',
                              'quit smoking' => '__KAM_SMOKE4,[l=1]',
                              'password is due for expiration yesterday' => '__DAY_I_EARNED,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_3,[l=1] __PASSWORD_EXP_CLUMSY,[l=1] __YOU_WON_02,[l=1]',
                              'contact information' => '__CONTACT_ATTY,[l=1] __FRAUD_ETX,[l=1] __FRAUD_JYG,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LIST3_4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'did you overpay?' => '__FEES,[l=1] __FRAUD_QFY,[l=1] __KAM_1LINE1,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'deliver your dell' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GIVE2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'nigeria national' => '__FRAUD_YQV,[l=0] __HK_LOTTO_2,[l=1] __KAM_JESUS3,[l=1] __KAM_LOTTO5,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __NIGERIA,[l=1]',
                              'viagra' => 'DRUGS_SMEAR1,[l=1] DRUG_ED_CAPS,[l=1] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE_V,[l=1] __KAM_DRUG2_3,[l=1] __KAM_VIAGRA7A,[l=1] __KAM_VIAGRA8A,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'bare' => '__KAM_AQUARUG3,[l=1]',
                              'charitable' => '__CHARITY,[l=1] __KAM_NIGERIAN5,[l=1]',
                              'random' => '__RANDOM_PICK,[l=1]',
                              'xan lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'mer xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'label health' => '__KAM_JOINT3,[l=1] __KAM_LABEL6,[l=0]',
                              'amb cia mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'transaction from your online store' => 'FREE_QUOTE_INSTANT,[l=1] __ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'val xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'petroleum' => '__KAM_NIGERIAN2,[l=1]',
                              'mer lev cia' => 'KAM_VIAGRA2,[l=0]',
                              'casual' => '__KAM_URONLINE2,[l=1]',
                              'you\'ve receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'hope you like my pic' => '__KAM_LED2,[l=1] __KAM_PIC4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'enzyme' => '__KAM_HEARTPROD2,[l=0]',
                              'maintenance process on our email system ' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_SETTING2,[l=0] __YOU_WON_01,[l=1]',
                              'winning pay' => '__FEES,[l=1] __KAM_POLITICS2,[l=1] __PAY_YOU,[l=1] __hk_win_j,[l=1]',
                              'som cia pro' => 'KAM_VIAGRA2,[l=0]',
                              'google cash' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GOOGLE4,[l=0] __KAM_SEO4,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'for the datacard' => '__DEAL,[l=1] __KAM_LIST5,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'offender' => '__KAM_ARREST2,[l=1] __KAM_SALE3,[l=1]',
                              'promotion' => '__KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'val lev pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'no textbooks' => '__KAM_UNIV15,[l=1]',
                              'mer mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'val val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'doctor' => '__KAM_MARIJUANA3,[l=1]',
                              'watch now' => '__KAM_FUN3,[l=1] __KAM_TIME4,[l=1]',
                              'could' => '__KAM_DEBT1,[l=1]',
                              'mail draw' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_BALLOT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __LOTTO_WIN_01,[l=1] __YOU_WON_01,[l=1]',
                              'top clothing' => '__KAM_LABEL5,[l=0]',
                              'pre-paid envelope' => '__FEES,[l=1] __KAM_POLITICS2,[l=1] __KAM_SELLPHONE2,[l=0]',
                              'accessed by someone else' => '__KAM_PHISH3_2,[l=1]',
                              'customize a learning program' => '__KAM_CEP3,[l=1] __KAM_DETOX3,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_VIAGRA9A,[l=1] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1]',
                              'val via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'unsolicited email?' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __YOU_WON_01,[l=1]',
                              'testosterone' => '__KAM_ANDROGEL3,[l=1] __KAM_DIET2_3,[l=1] __KAM_SUPERHUMAN3,[l=1] __KAM_TESTOSTERONE3,[l=1] __STOCK_TIP,[l=1]',
                              'this is ' => '__DEAL,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'walk' => '__KAM_WALKINTUB3,[l=1]',
                              'stink stank stunk' => '__KAM_2020_2,[l=1]',
                              'you\'re receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' mailing list' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1] __YOU_WON_01,[l=1]',
                              'via amb amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              '% of the total' => '__DEAL,[l=1] __FRAUD_JYG,[l=1] __KAM_BENEFICIARY3,[l=1]',
                              'premium' => '__KAM_AUTONEW2,[l=1] __KAM_AUTONEW3,[l=1] __KAM_MEDICARE4,[l=1]',
                              'style rocks' => '__KAM_SUNGLASSES3,[l=1]',
                              'extended warranty' => '__KAM_CAR2,[l=0] __KAM_REPAIR1_3,[l=1]',
                              'business partner' => '__DEAL,[l=1] __FRAUD_TDP,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'now looks ' => '__KAM_WEIGHT2_3,[l=1]',
                              'sister' => '__KAM_JESUS2,[l=1]',
                              'pro mer pro' => 'KAM_VIAGRA2,[l=0]',
                              'prestige' => '__HK_LOTTO_2,[l=1] __KAM_SNORE3,[l=1]',
                              'work online from home' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_CAREER3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_GOOGLE2,[l=0] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1]',
                              'google pie' => '__KAM_GOOGLE4,[l=0] __KAM_SEO4,[l=1]',
                              'mer val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'designer' => '__KAM_LANDSCAPE3,[l=1] __KAM_TIME2,[l=1]',
                              'lev amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'life from alcohol' => '__KAM_REHAB3,[l=0]',
                              'personal assistant' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_INVEST2,[l=1] __YOU_ASSIST,[l=1]',
                              'mightyrxhere' => '__KAM_DRUG2_5,[l=1]',
                              'ricaine' => '__HK_LOTTO_2,[l=1]',
                              'cia amb xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'pro via cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'nagging' => '__KAM_URUNIT3,[l=1]',
                              'be awarded' => '__LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1]',
                              'via lev mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'xan som lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'bequest' => '__WILL_LEGAL,[l=1]',
                              'similar domain' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE1,[l=1]',
                              'som som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'via xan cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'fiducia' => '__LOTTO_DEPT,[l=1]',
                              'snoring' => '__KAM_SNORE3,[l=1]',
                              'click here for verification' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_HACK2,[l=0] __KAM_PATRIOT3,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOU_WON_02,[l=1]',
                              'personal' => '__KAM_ACCOUNTPHISH3,[l=1]',
                              'be given' => '__FRAUD_JYG,[l=1] __RECEIVE_BONUS,[l=1]',
                              'promotional' => '__KAM_GIFT5,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __THIS_AD,[l=1]',
                              'release yourheld ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'infographic' => '__KAM_BACKUP3,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'going out of residence' => '__JMQ_HEARINGLOSS3,[l=1] __STAY_HOME,[l=1]',
                              'accuquote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1]',
                              'you receiving this recurring' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia cia amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'new p' => '__KAM_GALLERY4,[l=1]',
                              'the adu' => '__DEAL,[l=1] __KAM_GALLERY4,[l=1]',
                              'triple an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'assist me' => '__KAM_COVID3_4,[l=0]',
                              'view invoice' => '__FRAUD_QFY,[l=1] __KAM_AUTONEW3,[l=1] __KAM_FAKE_FAX4,[l=0] __KAM_HEALTH2,[l=1] __KAM_TOLL3,[l=1] __KAM_UKINV2,[l=0] __KAM_VM3,[l=1]',
                              'find out if you qualify' => '__JMQ_TRACKR3,[l=1] __KAM_GRANT2,[l=0] __KAM_NEW_CREDITCARD3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'salutaire' => '__LUCRATIVE,[l=1]',
                              'at home employment' => '__KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1] __KAM_WORKHOME1,[l=0]',
                              'payout of' => '__FEES,[l=1] __KAM_LOTTO6,[l=1] __PAY_YOU,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'knowing this could very well save your life' => '__DEAL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DEBT1,[l=1] __KAM_HEART3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'testoril' => '__KAM_TESTOSTERONE4,[l=1] __STOCK_TIP,[l=1]',
                              'elite gallery' => '__KAM_GALLERY2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'mega p' => '__KAM_GALLERY4,[l=1]',
                              'msnlottery' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'brities elite' => '__KAM_GALLERY4,[l=1]',
                              'mer pro lev' => 'KAM_VIAGRA2,[l=0]',
                              'drained all the time' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT3A,[l=1]',
                              'delivery fee for your cheque draft' => '__BANK_DRAFT,[l=1] __DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CHECK1,[l=0] __KAM_FAKEDELIVER1,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'validate ' => '__KAM_PASSWORD2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'scam' => '__KAM_NIGERIAN2_9,[l=0] __NOT_SCAM,[l=1] __SCAM,[l=1]',
                              'bank transfer charges' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE3,[l=1] __KAM_BACKUP3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_NIGERIAN2_9,[l=0] __WIRE_XFR,[l=1]',
                              'chlorogenic acid' => '__KAM_ANA1,[l=1]',
                              'sent by santa' => '__JMQ_WIRE3,[l=1] __KAM_SANTA2,[l=0]',
                              ' and save' => '__KAM_REFI2,[l=1]',
                              'gas prices are at a all time high' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DRUG2_4,[l=1] __KAM_GAS1,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'watering your plants' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AQUA2,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev cia amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'amb lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'lift your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'qualification number' => '__KAM_LOTTO6,[l=1] __LOTTO_WIN_01,[l=1]',
                              'prefer not to receive future emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'no experience needed' => '__KAM_TELEWORK4,[l=1]',
                              'online marketing services' => 'FREE_QUOTE_INSTANT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI2,[l=1] __KAM_SEARCH4,[l=1] __KAM_SEO4,[l=1] __KAM_WEB3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'awesome auger' => '__KAM_AUGER2,[l=0]',
                              'analyst' => '__KAM_STOCK2_4,[l=0]',
                              'lev mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'barrister' => '__BARRISTER,[l=1] __CONTACT_ATTY,[l=1] __KAM_INVEST4,[l=1] __KAM_NIGERIAN2_2,[l=1]',
                              'whatsapp' => '__KAM_FINGERHUT3,[l=1] __KAM_WHATS3,[l=1]',
                              'market watch' => '__KAM_PATRIOT3,[l=1] __KAM_STOCK2_1,[l=1] __KAM_TIME4,[l=1]',
                              'prive' => '__HUSH_HUSH,[l=1]',
                              'advertising' => 'KAM_ADVERT2,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ADVERTISE3,[l=1] __THIS_AD,[l=1]',
                              'turn iphones into cash' => '__KAM_CELL3,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_SELLPHONE1,[l=0] __KAM_TIMESHARE2,[l=1]',
                              'dept' => '__LOTTO_DEPT,[l=1]',
                              'securing monies' => '__DOS_BODY_MON,[l=1] __FRAUD_WFC,[l=1]',
                              'valued' => '__KAM_GIFT3,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'acai ultra' => '__KAM_ANA1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'percent' => '__AGREED_RATIO,[l=1] __FRAUD_JYG,[l=1]',
                              'verified' => '__KAM_ENGINEER2,[l=1]',
                              'payment officer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'via cia xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'india based it' => '__KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1]',
                              'val pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'degree of your choice' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV13,[l=1] __KAM_UNIV2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no more incoming messages will be delivered' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __I_WILL_YOU,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_QUOTA2,[l=1] __KAM_REP3_2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __RECEIVE_BONUS,[l=1]',
                              'seek to transfer this money' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DOS_BODY_MON,[l=1] __FEES,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN2,[l=1] __THIS_AD,[l=1] __WIRE_XFR,[l=1]',
                              'united nation' => '__KAM_FAKEWEST3,[l=0] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'this advertisement is presented by' => 'KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __JMQ_WIRE3,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_SPAMKING1,[l=1] __THIS_AD,[l=1]',
                              'secret to being skinny' => '__HUSH_HUSH,[l=1] __KAM_DIET2_3,[l=1] __KAM_WEIGHT2,[l=1] __NOT_DEAD_YET,[l=1]',
                              'mortgage' => '__KAM_REFI2,[l=1]',
                              'worst food' => '__KAM_BLOOD5,[l=1] __KAM_DUJOUR2,[l=0]',
                              'new automobiles' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CARDEAL3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_WEB3,[l=1]',
                              'reliable' => '__KAM_DRUG2_6,[l=1] __KAM_TV1,[l=1]',
                              'official notification letter' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_GOOGLE_AWARD4,[l=0] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'has been reduced' => '__KAM_AUTONEW3,[l=1] __KAM_CLOUD3,[l=1] __KAM_INSURE2,[l=1] __KAM_PET3,[l=1] __KAM_STUDENT3,[l=1]',
                              'quadruple an principal' => '__PUMPDUMP_01,[l=1]',
                              'tomato giant' => '__KAM_FARM3,[l=0]',
                              'event' => '__KAM_TOURS3,[l=1]',
                              ' monday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __PUMPDUMP_03,[l=1]',
                              'to continue using your online' => 'FREE_QUOTE_INSTANT,[l=1] __ACCESS_RESTORE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'education office' => '__KAM_SALE3,[l=1] __KAM_UNIV1,[l=1]',
                              ' before monday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_MON,[l=1] __KAM_PATRIOT3,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'pinksheets' => '__KAM_STOCK3,[l=1]',
                              'msnbc' => '__KAM_TAX4,[l=1]',
                              'cia mer via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'xjs*c4jdbqadn1.nsbn3*2idnen*gtube-standard-anti-ube-test-ema' => 'GTUBE,[l=1]',
                              'wanna talk' => '__KAM_URONLINE2,[l=1]',
                              '-due compensation' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'interested in obtain' => 'KAM_ADVERT2,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE2,[l=1] __KAM_DOMAIN_SALE4,[l=1] __KAM_SNORE3,[l=1] __KAM_TAX4,[l=1]',
                              'many cele' => '__KAM_GALLERY4,[l=1]',
                              'without dieting' => 'DIET_1,[l=1] __DEAL,[l=1] __KAM_MARIJUANA3,[l=1] __WITHOUT_EFFORT,[l=1]',
                              ' asian babes' => '__KAM_FUN5,[l=1]',
                              ' to our members' => '__WE_PAID,[l=1]',
                              'promo code: ' => '__KAM_DRUG2_5,[l=1] __KAM_LOTTO4,[l=1] __KAM_SKYPE4,[l=1] __THIS_AD,[l=1]',
                              'unlimited prowess' => '__KAM_STOCKTIP156,[l=1] __KAM_TRIAL,[l=1] __KAM_URUNIT3,[l=1]',
                              'make you hundreds' => '__KAM_SEX_EXPLICIT4,[l=1] __PUMPDUMP_04,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'certificate claims' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1]',
                              'expenses' => '__KAM_LOAN3,[l=1]',
                              'som cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'united kingdom' => '__KAM_BENEFICIARY4,[l=0] __KAM_NIGERIAN1,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              'reflux' => '__KAM_DUJOUR2,[l=0]',
                              'garnish' => '__KAM_STUDENT3,[l=1] __KAM_TAX3,[l=1]',
                              'smart mask' => '__KAM_FUN7,[l=1] __KAM_KN_2,[l=0] __KAM_LABEL8,[l=1]',
                              'reader 2010' => '__KAM_FAKEPDF2,[l=1]',
                              'pieniadz' => '__KAM_MM_FOREX_1,[l=1]',
                              'for the public' => '__DEAL,[l=1] __KAM_BACK3,[l=1] __KAM_KN_2,[l=0] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'no exercise' => 'DIET_1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'lev val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' before tomorrow' => '__KAM_PATRIOT3,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'or best offer' => '__FOR_SALE_OBO,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'ultimate access' => '__KAM_GALLERY2,[l=1]',
                              'foreign op' => '__KAM_BENEFICIARY4,[l=0] __KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'no upfront fees' => '__FEES,[l=1] __KAM_SEO5,[l=1]',
                              'com card' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_REP3_2,[l=1]',
                              'all that debt' => '__KAM_DEBT1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'for termination of this mail' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST5,[l=1] __KAM_PATRIOT3,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cortitherm' => '__DEAL,[l=1] __KAM_ANA1,[l=1]',
                              'four of my card' => '__KAM_SHADYCC3,[l=0]',
                              'computer' => '__KAM_REP3_2,[l=1] __RANDOM_PICK,[l=1]',
                              'insane chick' => '__KAM_GALLERY4,[l=1]',
                              'cia val mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'tired this afternoon' => '__DEAL,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __THIS_AD,[l=1]',
                              'contributions to humanity' => '__KAM_BENEFICIARY3,[l=1]',
                              'val lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'swiss' => '__KAM_CRYPTO1,[l=1]',
                              'world company register' => '__KAM_BADNAME1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __KAM_WEBINAR4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'purchase from your online store' => 'FREE_QUOTE_INSTANT,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'password upgrade' => '__KAM_PHISH4_3,[l=1] __KAM_VIAGRA9A,[l=1] __PASSWORD_UPGRADE,[l=1]',
                              'internet draw' => '__HK_LOTTO_BALLOT,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'patriotnewsnet' => '__KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1]',
                              'lev amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'vous \\352tes' => '__YOU_WON_04,[l=1]',
                              'representing partner' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN1,[l=1]',
                              'business proposal' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BUS1,[l=0] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE2,[l=1] __KAM_INVEST4,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'lev xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'trading at such a bargain' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_10,[l=1]',
                              'pro mer xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'excited' => '__KAM_DATINGTIPS3,[l=1]',
                              'security dept' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __LOTTO_DEPT,[l=1] __SECURITY_DEPT,[l=1] __TRUNK_BOX,[l=1]',
                              'attached letter' => '__KAM_DOMAINEXPIRY2,[l=0] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __PLS_REVIEW,[l=1]',
                              'magnanimity' => '__FRAUD_AXF,[l=0]',
                              'amb pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'domain advanced avail' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE3,[l=1]',
                              'samples and pricing' => '__KAM_LIST3_3,[l=1] __KAM_WEB2_4,[l=0]',
                              'terrorist attack' => '__KAM_BENEFICIARY6,[l=0] __KAM_DEATH4,[l=1] __KAM_HEARTPROD1,[l=1]',
                              'virginia credit union' => 'BAD_CREDIT,[l=1] LIVE_PORN,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH2_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'courier company was not able to deliver' => '__COURIER,[l=1] __FEES,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_NIGERIAN2_8,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'bankrupt' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_TAX3,[l=1]',
                              'cia xan lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'b\\303\\251nin' => '__BENIN,[l=1]',
                              'earned' => '__DAY_I_EARNED,[l=1] __RECEIVE_BONUS,[l=1]',
                              'cia amb pro' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              ' u m' => '__KAM_VIAGRA4A,[l=1]',
                              'asasinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'anal xxx' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'storage container' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_TUPPERWARE3,[l=0] __STOCK_TIP,[l=1]',
                              'lo & incolla' => '__COPY_PASTE_IT,[l=1]',
                              'be greeted with' => '__RECEIVE_BONUS,[l=1]',
                              'medical doctor' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_MED1,[l=1] __KAM_MEDICAL1,[l=0] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'automated income kit' => '__KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_GOOGLE2,[l=0] __KAM_PHISH4_2,[l=1] __KAM_REP3_2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'cia lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'samples for your review' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST3_3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB2_4,[l=0] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'have a look right now' => '__KAM_COMPROMISED4,[l=1] __KAM_DETOX3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_01,[l=1]',
                              'lev mer cia' => 'KAM_VIAGRA2,[l=0]',
                              'your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'address directly at' => '__DOS_EMAIL_DIRECTLY,[l=1] __KAM_DIRECT4,[l=1]',
                              'online gift rewards' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_ACNE4,[l=0] __KAM_DOMAIN2,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_PHISH2_6,[l=1] __RECEIVE_BONUS,[l=1]',
                              'sample' => '__KAM_WEB2_4,[l=0]',
                              'changed' => '__KAM_CREDIT4,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'describe yourself' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTO3,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC4,[l=1] __KAM_REFI3,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME5,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'free trial' => '__KAM_SEO5,[l=1] __KAM_SKIN4,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'cia via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'transaction' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'widowe' => '__WIDOW,[l=1]',
                              'show you some pic' => '__KAM_PIC4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ur girl' => '__KAM_PIC2,[l=1] __KAM_URUNIT2,[l=1]',
                              'happily announce' => '__hk_win_3,[l=1]',
                              'read this document' => '__DEAL,[l=1] __KAM_ADMIN4,[l=0] __THIS_AD,[l=1]',
                              'psychic chris' => '__KAM_PSYCHIC3,[l=0]',
                              'lev via pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'if you have any questions or concerns regarding this communi' => '__ACH_CANCELLED_04,[l=1] __DEAL,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_SPAMKING2,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'their' => '__DEAL,[l=1] __KAM_BACK2,[l=1]',
                              'world famous writer' => '__KAM_WRITING3,[l=0]',
                              'free dvd-cd burner' => 'DIET_1,[l=1] __KAM_TRIAL,[l=1] __KAM_TV1,[l=1] __PILL_PRICE_01,[l=1]',
                              'venture' => '__DEAL,[l=1]',
                              'professional list' => '__KAM_GARAGE3,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'slnx' => '__KAM_STOCKTIP139,[l=1]',
                              'conservative' => '__KAM_POLITICS2,[l=1]',
                              'tired' => '__KAM_SNORE3,[l=1]',
                              'you received this special' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia mer cia' => 'KAM_VIAGRA2,[l=0]',
                              'alanco tech' => '__KAM_STOCKTIP151,[l=0]',
                              'lev lev val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'fortune' => '__I_WILL_YOU,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __MY_FORTUNE,[l=1] __YOU_WON_02,[l=1]',
                              'reservation' => '__TRAVEL_RESERV,[l=1]',
                              'you have been recently invited' => '__KAM_AUTONEW3,[l=1] __KAM_CHOSEN3,[l=1] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'alcohol addict' => '__KAM_REHAB3,[l=0]',
                              'faxed document' => '__KAM_VM3,[l=1]',
                              'registration' => '__FEES,[l=1] __KAM_DOMAIN1,[l=1]',
                              'consolidation loan' => '__KAM_REFI2,[l=1]',
                              'codicil' => '__KAM_DRUG2_5,[l=1] __WILL_LEGAL,[l=1]',
                              'incredible gains to your manhood' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'release your ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'warehouseofrxmeds' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'replace ' => '__KAM_HIDDEN_URI2,[l=1] __KAM_REP1,[l=1]',
                              'i drive a' => '__DOS_I_DRIVE_A,[l=1] __KAM_DOMAIN2,[l=1] __KAM_WEBINAR4,[l=1]',
                              'satell center for executive education' => '__DOS_BODY_SAT,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_BADNAME1,[l=1] __KAM_GIFT4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SWIPE4,[l=1] __KAM_WEBINAR4,[l=1] __YOU_WON_02,[l=1]',
                              'rich beautiful lawn' => '__KAM_GRASS3,[l=0] __KAM_HAPPYTALK3,[l=1]',
                              'mails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'som pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'remuneration' => '__FRAUD_WNY,[l=1]',
                              'le copier + coller' => '__COPY_PASTE_FR,[l=0]',
                              'sell/rent your time' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME4,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'rejected' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1]',
                              'travel' => '__TRAVEL_AGENT,[l=1]',
                              'wish to receive these messages' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'gina regulations' => '__KAM_GINA4,[l=0]',
                              'power bill in half' => '__KAM_SOLAR3,[l=1]',
                              'leave any time' => '__KAM_FUN2,[l=1] __KAM_TIME4,[l=1]',
                              'no diet changes' => '__DEAL,[l=1] __KAM_ADVERT3,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_WEIGHT2,[l=1]',
                              'prow' => '__KAM_STOCKTIP156,[l=1]',
                              'hidden agenda' => '__KAM_PATRIOT3,[l=1] __KAM_SPY3,[l=1]',
                              'returning calls' => '__KAM_POLITICS2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK3,[l=1]',
                              'fresh' => '__KAM_CHICKEN3,[l=1]',
                              'gshn' => '__KAM_STOCKTIP131,[l=1]',
                              'valium' => 'DRUGS_SMEAR1,[l=1] __DRUGS_ANXIETY_VAL,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA8C,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'loved' => '__KAM_DEATHINSURE3,[l=1]',
                              'xan pro lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'hi!' => '__KAM_NEWS2,[l=0]',
                              'cking' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'you have receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fill' => '__KAM_ACCOUNTPHISH4,[l=1]',
                              'olen lomalla' => '__BOUNCE_OOO_CB3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_UNIV6B,[l=1]',
                              'leave you alone' => '__NEVER_HEAR_EN,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'funds you are owed' => '__DOS_BODY_WED,[l=1] __KAM_JUDGE2,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'e direclty at' => '__DOS_EMAIL_DIRECTLY,[l=1]',
                              'unrest' => '__KAM_PATRIOT3,[l=1] __KAM_SNORE3,[l=1]',
                              'newsletter' => '__SUBSCRIPTION_INFO,[l=1]',
                              'ejaculate' => '__DECEASED,[l=1] __KAM_SEX4,[l=0]',
                              'heart disease' => '__KAM_DEATH4,[l=1] __KAM_HEART3,[l=1]',
                              'make money at home' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WINDOWS3,[l=1]',
                              'seek fund' => '__KAM_INVEST3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'transactions from your online store' => 'FREE_QUOTE_INSTANT,[l=1] __ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STOCK_TIP,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'incapta' => '__KAM_STOCKTIP166,[l=1]',
                              'staatsloteri' => '__HK_LOTTO_2,[l=1] __HK_LOTTO_STAATS,[l=1]',
                              'just copy' => '__KAM_REP2_1,[l=1]',
                              'present work experience' => '__JMQ_WIRE3,[l=1] __KAM_CAREER3,[l=1] __KAM_UNIV3,[l=1]',
                              'receive what you are due' => '__KAM_FINGERHUT3,[l=1] __KAM_JUDGE2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pro pro som' => 'KAM_VIAGRA2,[l=0]',
                              'email is active' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_PROJECT3,[l=0] __YOU_WON_01,[l=1]',
                              ' opens tuesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'click to buy' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_DRUG4,[l=1]',
                              'field of yourr ch' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV11,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'please click on the link below' => '__DEAL,[l=1] __DOS_LINK,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CERT3,[l=0] __KAM_CLICK,[l=0]',
                              'weird' => '__KAM_LUNAR4,[l=1] __KAM_WEIRDTRICK2,[l=1]',
                              'proposal' => '__DEAL,[l=1] __KAM_DOMAIN2,[l=1] __URG_BIZ,[l=1]',
                              'melissa sylvan' => '__KAM_USB1,[l=0] __KAM_VIAGRA9D,[l=1]',
                              'no chopping' => '__KAM_PRODUCT2_2,[l=1]',
                              'grey eagle funding' => '__KAM_GREYEAGLE_2,[l=0] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'business who\'s who' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BADNAME1,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'medicine assistance supplier' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG4,[l=1] __KAM_MED1,[l=1] __URG_BIZ,[l=1] __YOU_ASSIST,[l=1]',
                              'via pro val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '| label' => '__KAM_LABEL6,[l=0]',
                              'alternative ' => '__FRAUD_AON,[l=1]',
                              'allexpiringdomains' => 'KAM_ADVERT3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'rambler' => '__KAM_HOWRU4,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'poison' => '__FRAUD_PTX,[l=1]',
                              'death of my husband' => '__KAM_BENEFICIARY6,[l=0] __NOT_DEAD_YET,[l=1]',
                              'majority of women' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_URUNIT6,[l=1]',
                              'you have qualified' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_SMOKE5,[l=0] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'popular' => '__KAM_SEARCH4,[l=1]',
                              'real girl' => '__KAM_DATINGTIPS3,[l=1] __KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1]',
                              'special' => '__KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1]',
                              'cia som mer' => 'KAM_VIAGRA2,[l=0]',
                              'receiving bank' => '__JMQ_WIRE3,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'import\\33xport' => '__KAM_INQUIRY_4,[l=0] __KAM_NIGERIAN2,[l=1]',
                              'food storage' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_TUPPERWARE3,[l=0] __STOCK_TIP,[l=1]',
                              'free auto insurance quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CAR2,[l=0] __KAM_INSURE4,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'doggy' => '__KAM_PET3,[l=1]',
                              'make for your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'placing your order' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BADZIP3,[l=0] __KAM_DRUG2_4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'in your ie' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP2_2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'shamwow' => '__KAM_SHAM3,[l=0]',
                              'personal email at' => '__ADMAIL,[l=1] __DOS_PERSONAL_EMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __YOU_WON_01,[l=1]',
                              'management center' => '__KAM_GIFT4,[l=1] __KAM_SWIPE4,[l=1] __KAM_WEBINAR4,[l=1] __SYSADMIN,[l=1]',
                              'order_now' => '__KAM_BADZIP3,[l=0] __KAM_DRUG2_5,[l=1]',
                              'future_mail' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __OBFU_UNSUB_UL,[l=1] __YOU_WON_01,[l=1]',
                              'meet with such attractive' => '__KAM_PIC2,[l=1]',
                              'next' => '__NEXT_OF_KIN,[l=1]',
                              'bonus' => '__RECEIVE_BONUS,[l=1]',
                              'ban amnesty now' => '__KAM_BADNAME1,[l=1] __KAM_COMPROMISED3,[l=1]',
                              'odmieni' => '__KAM_MM_FOREX_1,[l=1]',
                              'active email address' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LOTTO6,[l=1] __YOU_WON_01,[l=1]',
                              'collaborate' => '__FRAUD_XWW,[l=1] __KAM_INSURE4,[l=1]',
                              'impotence solution' => 'IMPOTENCE,[l=1] __KAM_CLOUD3,[l=1] __KAM_LOAN3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'poor vision' => 'BAD_CREDIT,[l=1] __KAM_FUN7,[l=1] __KAM_VISION3,[l=1]',
                              'webpage' => '__KAM_DOMAIN3,[l=1] __KAM_PAPERLESS3,[l=1]',
                              ' ltp' => '__FOR_SALE_LTP,[l=1]',
                              'free full color business cards' => '__DEAL,[l=1] __DRUGS_ERECTILE5,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BIZ1,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_TRIAL,[l=1] __KAM_WEB3,[l=1] __PILL_PRICE_01,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'lev som mer' => 'KAM_VIAGRA2,[l=0]',
                              'cash offer for your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_HOME1,[l=1] __KAM_HOMESALE3,[l=0] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_TOLL3,[l=1] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sleep' => '__KAM_LUNAR4,[l=1]',
                              'unreal access' => '__KAM_DATINGTIPS3,[l=1] __KAM_GALLERY2,[l=1]',
                              'terminally' => '__AM_DYING,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_INSURE4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'generate ' => '__KAM_INSURE4,[l=1] __KAM_TELEWORK1,[l=1]',
                              'part time job/full time' => '__KAM_NIGERIAN2,[l=1] __KAM_TIME4,[l=1]',
                              'crazy cat card' => '__KAM_CARD2,[l=1]',
                              'luxury fabric' => '__KAM_LABEL5,[l=0]',
                              'http://docs.google.com/forms/' => '__KAM_CARD3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEO4,[l=1] __UNSUB_GOOG_FORM,[l=1] __YOU_WON_02,[l=1]',
                              'never hear me again' => '__JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __NEVER_HEAR_EN,[l=0] __NOT_SCAM,[l=1]',
                              'sexuality with assistance' => '__KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __URG_BIZ,[l=1] __YOU_ASSIST,[l=1]',
                              'section 27a' => 'TVD_SECTION,[l=1]',
                              'hoist your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'international monetary fund' => '__DOS_BODY_MON,[l=1] __HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_COVID1,[l=0] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'pro amb cia' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'find out this quick new trick' => '__DEAL,[l=1] __JMQ_TRACKR3,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_TIP4,[l=0] __KAM_WEIRDTRICK2,[l=1] __THIS_AD,[l=1]',
                              'cleaning up your life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DETOX3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'month' => '__DOS_BODY_MON,[l=1] __KAM_SKIN4,[l=1]',
                              'accepted' => '__ACH_CANCELLED_03,[l=1] __KAM_CEP4,[l=1]',
                              'property available' => '__KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REAL2_1,[l=1] __KAM_REAL2_4,[l=1] __KAM_REFI2,[l=1]',
                              'be clever, buy your drugs' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_INSURE4,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'transaction from your web' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __FRAUD_MCQ,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_SHADYCC1,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'collect' => '__RECEIVE_BONUS,[l=1]',
                              'asian women' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_WIFE2,[l=1]',
                              'list of decision makers' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_LISTSALE2,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'detailed' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN4,[l=1]',
                              'kopieren & einf\\374gen' => '__COPY_PASTE_DE,[l=0]',
                              'selling credit cards' => 'BAD_CREDIT,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SELL3,[l=0] __KAM_VERIZON7,[l=0]',
                              'security' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __TRUNK_BOX,[l=1]',
                              'surppress appetite' => '__KAM_HOODIA3,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1]',
                              'buy rubber friends' => '__DOS_BODY_FRI,[l=1] __KAM_SEX05_2,[l=0]',
                              'attached to ticket number' => '__FRAUD_BGP,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO6,[l=1] __LOTTO_WIN_01,[l=1] __PLS_REVIEW,[l=1]',
                              'continue reading' => '__KAM_FUN3,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'please respond' => '__FRAUD_MLY,[l=1] __KAM_PROJECT4,[l=0]',
                              'wrong transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_FAKEWEST4,[l=0] __WIRE_XFR,[l=1]',
                              'keep' => '__KAM_ALARM2,[l=1]',
                              'passive income' => '__KAM_REP3_2,[l=1] __PASSIVE_INCOME,[l=1]',
                              'confirm your shipping' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_DRUG2_6,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_INSURE4,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX4,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'illegal attachment' => '__DLND_ATTACH,[l=1] __KAM_WEED1,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'holding company' => '__FRAUD_IRJ,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_PHISH2_4,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'cancel 0ffers' => '__KAM_UNSUB1,[l=0]',
                              'lev via xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'expiration date' => '__PDS_EXPIRATION_NOTICE,[l=1]',
                              'legal paper' => '__KAM_INVEST2,[l=1] __KAM_WEED1,[l=1]',
                              'via mer lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'download' => '__DLND_ATTACH,[l=1]',
                              'struggling with add' => '__KAM_ADHD3,[l=0]',
                              'package' => '__KAM_INSURE4,[l=1] __KAM_TAX3,[l=1] __KAM_TRIAL,[l=1]',
                              'amb som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'are you in debt' => '__KAM_DEBT1,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'customer who died' => '__DEAL,[l=1] __DIED_IN,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_PHISH4_2,[l=1] __STOCK_TIP,[l=1]',
                              'billing error' => '__KAM_INVOICE4,[l=1]',
                              'lium' => '__KAM_VIAGRA8C,[l=1]',
                              'lose' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1]',
                              'loan of any amount' => '__KAM_COMPROMISED3,[l=1] __KAM_REFI2,[l=1] __SUM_OF_FUND,[l=1]',
                              'ukranian girl' => '__KAM_PIC2,[l=1] __KAM_WIFE2,[l=1]',
                              'removal from further update' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_INSURE4,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __SUBSCRIPTION_INFO,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'pro xan amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'covered' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR2_3,[l=1]',
                              'low interest loan' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1]',
                              'rapture' => '__KAM_PROPHET5,[l=0]',
                              'send me a note' => '__KAM_PIC3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'priv\\303\\251' => '__HUSH_HUSH,[l=1]',
                              'benin' => '__BENIN,[l=1] __KAM_BENEFICIARY4,[l=0]',
                              'via val val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'elite access' => '__KAM_GALLERY2,[l=1]',
                              'snap up as many shares of it as i can' => '__PUMPDUMP_09,[l=1]',
                              'xan cia som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'your girl' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'specific' => '__KAM_SEO3,[l=1]',
                              'get as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sephora' => '__KAM_REWARD1,[l=1]',
                              'counting' => '__KAM_DOMAIN2,[l=1]',
                              'via via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'breakdown' => '__KAM_CREDIT2,[l=1]',
                              'val amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'cash prize' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_LOTTO3,[l=1] __KAM_TIMESHARE2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'here\'s how' => '__KAM_FAKEAD2,[l=0]',
                              'topshoprx' => '__KAM_DRUG2_5,[l=1] __KAM_MOTHER3,[l=1]',
                              'pro val som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'immediately' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_CREDIT3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1]',
                              'handbag collection' => '__KAM_KORS3,[l=0] __RECEIVE_BONUS,[l=1]',
                              'quadruple an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'rolex' => 'EM_ROLEX,[l=1] __KAM_TIME6,[l=0]',
                              'major search engines' => '__KAM_REVIEW3,[l=1] __KAM_SEO3,[l=1]',
                              'som xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'tobacco' => '__KAM_INSURE2,[l=1]',
                              'agent' => '__KAM_BANK_2,[l=0]',
                              'abuse' => '__KAM_PATRIOT3,[l=1]',
                              'famos tablet' => '__KAM_SEX04_1,[l=1] __PILL_PRICE_01,[l=1]',
                              '#1 site' => '__KAM_WORKHOME2,[l=0]',
                              'gevalia coffee lover\'s kit' => '__FRAUD_QFY,[l=1] __KAM_GEVALIA2,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_SALE3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'carribbean' => '__KAM_VACATION3,[l=1]',
                              'heated vest' => '__KAM_VEST1,[l=0]',
                              ' to our clients' => '__WE_PAID,[l=1]',
                              'xan val lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'affidavit' => '__FRAUD_ULK,[l=1]',
                              'international trade council' => '__HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_ITC2,[l=0] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'shot' => 'CUM_SHOT,[l=1]',
                              'inherited' => '__I_INHERIT,[l=1] __KAM_BENEFICIARY3,[l=1] __NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1] __YOU_INHERIT,[l=1]',
                              'som via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'sensitive by nature' => '__HUSH_HUSH,[l=1] __KAM_BUS2,[l=0]',
                              'r=f3zne komputery zalogowaniu sie' => '__LOTTO_DEPT,[l=1] __MAIL_ACCT_ACCESS1,[l=1]',
                              'win a great prize' => '__KAM_SURVEY3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __LOTTO_WIN_01,[l=1]',
                              '100% populated' => '__DECEASED,[l=1] __KAM_LIST3_3,[l=1] __KAM_MERCHANT3,[l=1]',
                              'burkina' => '__BURKINA_FASO,[l=1]',
                              'payment' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'immense monster' => '__DOS_BODY_MON,[l=1] __KAM_SEX05_2,[l=0]',
                              'swift copy' => '__KAM_SWIFT2,[l=0]',
                              'my name is mr' => '__FRAUD_QXX,[l=1] __JMQ_RESUME2,[l=0] __KAM_HOWRU2,[l=0] __KAM_INVEST2,[l=1]',
                              'som val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'messages from third party advertisers' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_SPAMKING3,[l=1] __THIS_AD,[l=1]',
                              'suits start at $' => '__KAM_LABEL4,[l=1]',
                              '{!firstname_fix}' => '__KAM_MAILER1,[l=0]',
                              'based on your experience' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'travel itinerary' => '__TRAVEL_AGENT,[l=1] __TRAVEL_ITINERARY,[l=0]',
                              'winning information' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_POLITICS2,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1] __hk_win_a,[l=1]',
                              'data coordinator' => '__FRAUD_RLX,[l=1] __KAM_LIST3_2,[l=1]',
                              'nursing' => '__KAM_NURSE3,[l=1]',
                              'check' => '__KAM_CREDIT2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'computer sweepstake' => '__HK_LOTTO_BALLOT,[l=1] __KAM_REP3_2,[l=1] __RANDOM_PICK,[l=1]',
                              'probate' => '__WILL_LEGAL,[l=1]',
                              'sex' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'pro via via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'africa' => '__DOS_BODY_FRI,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INVEST4,[l=1]',
                              'verify your shipping address' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BOXVERIFY,[l=1] __KAM_DRUG2_6,[l=1] __KAM_GIVE4,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'laser' => '__KAM_VISION3,[l=1]',
                              'die' => '__DEAL,[l=1]',
                              'financial advantage' => '__DEAL,[l=1] __DOS_FIN_ADVANTAGE,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1] __KAM_SUPERHUMAN3,[l=1]',
                              'h0rny' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'newton sq' => '__KAM_FUN2,[l=1]',
                              'diplomat agent' => '__KAM_BANK_2,[l=0] __KAM_NIGERIAN2_8,[l=1] __KAM_UNIV6B,[l=1]',
                              'link' => '__DOS_LINK,[l=1]',
                              'empower your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pro cia lev' => 'KAM_VIAGRA2,[l=0]',
                              'climaxes' => '__KAM_SEX1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'enlarge' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'remunerate' => '__FRAUD_WNY,[l=1] __KAM_INSURE4,[l=1]',
                              'via xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'we have issued ' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'technical error' => '__ACH_CANCELLED_03,[l=1]',
                              'czlowieka' => '__KAM_MM_FOREX_1,[l=1]',
                              'securing the fund' => '__DEAL,[l=1] __FRAUD_WFC,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'mer som lev' => 'KAM_VIAGRA2,[l=0]',
                              'work from home' => '__KAM_CAREER3,[l=1] __KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1] __KAM_WORKFROMHOME1,[l=0]',
                              'xan lev cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'cvs' => '__KAM_CVS2,[l=1]',
                              ' including dental' => '__DECEASED,[l=1] __KAM_HEALTH1,[l=1]',
                              'inheritance' => '__INHERIT_PMT,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_DEATHINSURE3,[l=1] __KAM_NIGERIAN5,[l=1] __NOT_DEAD_YET,[l=1] __THEY_INHERIT,[l=1] __YOU_INHERIT,[l=1]',
                              '//atch' => '__KAM_TIME2,[l=1]',
                              'anti-aging expert' => '__KAM_BLOOD5,[l=1] __KAM_SKIN4,[l=1]',
                              'val som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'you are receiving this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'mandamus' => '__WILL_LEGAL,[l=1]',
                              'freakypix' => '__JMQ_PICKUP2,[l=1]',
                              'dear shopper' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_MOTHER3,[l=1] __KAM_RAT2_2,[l=0]',
                              'saving' => '__KAM_HEALTH2,[l=1]',
                              'amb amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'top in yahoo' => '__KAM_SEO2,[l=1]',
                              'not official degree' => '__KAM_REFI3,[l=1] __KAM_SALE3,[l=1] __KAM_UNIV2,[l=1] __KAM_UNIV4,[l=1]',
                              'financial troubles is understood' => '__DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_STUDENTLOAN5,[l=0] __STOCK_TIP,[l=1]',
                              'this offer is only for united states' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FUN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'mer lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'xan xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'physicians in america' => '__KAM_COMPROMISED3,[l=1] __KAM_CRYPTO1,[l=1] __KAM_LIST1,[l=1] __KAM_LIST2,[l=1]',
                              'geography' => '__KAM_LIST3_4,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'decades' => '__KAM_SKIN4,[l=1]',
                              'reply with "stop" as a subject' => '__FRAUD_MLY,[l=1] __KAM_LIST5,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __STOCK_TIP,[l=1]',
                              'som mer lev' => 'KAM_VIAGRA2,[l=0]',
                              'temporarily' => '__KAM_PHISH2_5,[l=1]',
                              'star wars' => '__KAM_2020_2,[l=1]',
                              'samples and cost' => '__FB_COST,[l=1] __KAM_LIST3_3,[l=1] __KAM_WEB2_4,[l=0]',
                              'card link:' => '__DOS_LINK,[l=1] __KAM_CARD2,[l=1]',
                              'limitation' => '__KAM_PAYPAL3D,[l=1]',
                              'remunerration' => '__FRAUD_WNY,[l=1]',
                              'international' => '__HK_LOTTO_2,[l=1] __INTL_BANK,[l=1] __KAM_PATRIOT3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'fund' => '__SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'xan mer val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'represent your community' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_WIRE3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WHOSWHO3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'clarification and procedure' => '__KAM_KIWIBANK3,[l=1] __hk_win_o,[l=1]',
                              ' extra effort' => 'DIET_1,[l=1] __KAM_GIFT3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEIGHT2,[l=1] __RECEIVE_BONUS,[l=1] __WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'i was dismissed from a job i had for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'you deserve' => '__KAM_UNIV15,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'trading at a bargain' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_10,[l=1]',
                              'liquidating' => '__KAM_AUTO3,[l=1] __KAM_MEMBER3,[l=1]',
                              'treat' => '__KAM_GARAGE3,[l=1]',
                              'obtained your email address from a publicly available list' => 'KAM_PUBLIC,[l=1] __ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BACK3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_ENGINEER2,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST4,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX4,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_VIAGRA9D,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'lengthen' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __DEAL,[l=1]',
                              'cooktop' => '__KAM_NUWAVE3,[l=1]',
                              'why pay more for' => '__FEES,[l=1] __KAM_HOME3,[l=1] __KAM_INSURE4,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __PAY_YOU,[l=1] __YOU_WON_02,[l=1]',
                              'possible' => '__KAM_WEB3,[l=1]',
                              'erect' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'not satisfied' => '__DOS_BODY_SAT,[l=1] __KAM_URUNIT3,[l=1]',
                              'funds you are due' => '__KAM_JUDGE2,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'via pro lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'free auto insurance-quote' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_AUTO3,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CAR2,[l=0] __KAM_INSURE4,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'in your internet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_REP2_2,[l=0] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'drug administration' => '__KAM_ANDROGEL3,[l=1] __KAM_FDA1,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'beautify' => '__KAM_GARAGE3,[l=1]',
                              'inscor' => '__KAM_STOCKTIP153,[l=1]',
                              'found your mail' => '__ADMAIL,[l=1] __DECEASED,[l=1] __FOUND_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URONLINE2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lets' => '__KAM_MARIJUANA3,[l=1]',
                              'awesome model' => '__KAM_GALLERY4,[l=1]',
                              'cod' => '__KAM_DRUG2_5,[l=1]',
                              'fund transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __SUM_OF_FUND,[l=1] __WIRE_XFR,[l=1] __YOUR_FUND,[l=1] __hk_win_i,[l=1]',
                              'refurbished' => '__KAM_CELL3,[l=1]',
                              'gold' => '__KAM_BENEFICIARY3,[l=1] __KAM_NIGERIAN2_8,[l=1]',
                              'website audit report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEO3,[l=1] __KAM_WEB2,[l=1]',
                              'care' => '__KAM_VISION3,[l=1]',
                              'order immediately' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BADZIP3,[l=0] __KAM_CREDIT3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1]',
                              'send post-mail to' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FUN2,[l=1] __YOU_WON_01,[l=1]',
                              'transa' => '__DEAL,[l=1]',
                              'full compliance with the u' => 'KAM_CANSPAM,[l=1] __DEAL,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_REP3_2,[l=1]',
                              'quadrupling an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'public relation officer' => '__KAM_BACK3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_SALE3,[l=1]',
                              ' would be greatly appreciated' => '__KAM_LIKE2,[l=1]',
                              'triple your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'elaborate details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_INVEST3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'c i a l i s' => '__KAM_VIAGRA1,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'hdrx' => '__KAM_LENS3,[l=0]',
                              'doprowadzil' => '__KAM_MM_FOREX_1,[l=1] __KAM_STOCKTIP156,[l=1]',
                              'claiming' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_POLITICS2,[l=1] __LOTTO_DEPT,[l=1]',
                              'get as many shares as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'same last name' => '__KAM_BANK_3,[l=1]',
                              'marketing' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'representative/book' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN1,[l=1]',
                              'your guns' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bored evening' => '__KAM_PIC1,[l=1]',
                              'mer cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'made me healthier after my disease' => '__DAY_I_EARNED,[l=1] __KAM_JOINT3,[l=1] __KAM_URZEST5,[l=0]',
                              'further info' => '__DEAL,[l=1] __KAM_REP3_2,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'amb xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'products' => '__KAM_CAD3,[l=1]',
                              'i am engr' => '__FRAUD_QXX,[l=1] __KAM_COMPROMISED3,[l=1]',
                              'compiled list' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'look & feel old' => '__KAM_FOUNTAINOFYOUTH3,[l=1]',
                              'holding firm' => '__FRAUD_IRJ,[l=0] __KAM_PHISH2_4,[l=1]',
                              'safety and health act' => '__FEES,[l=1] __KAM_FAKEBBB2,[l=1] __KAM_JOINT3,[l=1]',
                              'pro som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'vip database' => '__KAM_BACK3,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1]',
                              'ranking' => '__KAM_SEARCH3,[l=1] __KAM_SEO4,[l=1]',
                              'songs' => '__KAM_SINGING3,[l=1]',
                              'bio-solutions' => '__KAM_CLOUD3,[l=1] __KAM_LOAN3,[l=1] __KAM_STOCKTIP140,[l=1] __KAM_WEBINAR4,[l=1]',
                              'background' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK1,[l=1] __KAM_SEARCH3,[l=1] __KAM_TAX3,[l=1]',
                              'funds transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __SUM_OF_FUND,[l=1] __WIRE_XFR,[l=1] __YOUR_FUND,[l=1] __hk_win_i,[l=1]',
                              'no cost' => '__FB_COST,[l=1] __KAM_CREDIT3,[l=1]',
                              'soma' => 'DRUGS_SMEAR1,[l=1]',
                              'selling list' => '__KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'unsatisfied' => '__DOS_BODY_SAT,[l=1] __KAM_URUNIT3,[l=1]',
                              'unsubscribe from mindtcommunications' => '__KAM_BADUNSUB,[l=0] __KAM_REP3_2,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'comee see it over here' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_REP3_2,[l=1] __KAM_URONLINE2,[l=1]',
                              'restore america pac' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_POLITICS2,[l=1] __KAM_QUOTA2,[l=1] __KAM_SNORE3,[l=1] __STOCK_TIP,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'upgrading' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'domain name owner' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE3,[l=1]',
                              'cia amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'stolen' => '__KAM_NIGERIAN2,[l=1] __STOCK_TIP,[l=1]',
                              'balance payment' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_SWIFT3,[l=0] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'dating portal' => '__KAM_MEMBER3,[l=1] __KAM_SEARCH4,[l=1] __KAM_URONLINE3,[l=1]',
                              '-mail id is found among those that have been scammed' => '__ADMAIL,[l=1] __DOS_BODY_MON,[l=1] __FOUND_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_NIGERIAN2_4,[l=1] __KAM_NIGERIAN2_9,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __NOT_SCAM,[l=1] __SCAM,[l=1] __YOU_WON_01,[l=1]',
                              'find cobra health' => '__JMQ_TRACKR3,[l=1] __KAM_COBRA3,[l=0] __KAM_JOINT3,[l=1] __KAM_NEW_CREDITCARD3,[l=1]',
                              'send focused campaigns' => '__KAM_LISTSALE3,[l=0] __KAM_POLITICS2,[l=1]',
                              'hottest' => '__KAM_CELL3,[l=1]',
                              'free report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT3,[l=1] __KAM_SOFTWARE4,[l=0] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'fields contain' => '__KAM_LIST3_3,[l=1]',
                              'multiply your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev lev lev' => 'KAM_VIAGRA2,[l=0]',
                              'melissa mccarthy' => '__KAM_VIAGRA9D,[l=1] __KAM_WEIGHT2_3,[l=1]',
                              'microsoft lottery' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'hd video' => '__KAM_GALLERY2,[l=1]',
                              'complete access' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_GALLERY2,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1]',
                              'v-o-t-e' => '__KAM_POLITICS2,[l=1]',
                              'woodworking' => '__KAM_CAREER3,[l=1] __KAM_DUTCHGLOW3,[l=1]',
                              'brixmor' => '__KAM_STOCKTIP163,[l=1]',
                              'pill' => '__PILL_PRICE_01,[l=1]',
                              'average' => '__KAM_CREDIT2,[l=1] __KAM_MERCHANT2,[l=1]',
                              'cia lev lev' => 'KAM_VIAGRA2,[l=0]',
                              'recorded voice' => '__KAM_VM3,[l=1] __KAM_VM4,[l=1]',
                              'online tv code' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DRUG2_5,[l=1] __KAM_PHISH2_6,[l=1] __KAM_TV1,[l=1]',
                              'melt' => '__KAM_WEIGHT2,[l=1]',
                              'filthy floor' => '__KAM_MOP3,[l=1]',
                              'deduct your weekly salary ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CEP6,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'are you available to work on a request for me today' => '__DAY_I_EARNED,[l=1] __KAM_CAREER3,[l=1] __KAM_FAVOR2,[l=0] __KAM_GIFT3,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __KAM_SUNGLASSES3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1] __URG_BIZ,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'affordable' => '__KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'postmaster general' => '__KAM_BENEFICIARY4,[l=0]',
                              'n gallery' => '__KAM_GALLERY2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'check this deal out' => '__DEAL,[l=1] __KAM_CREDIT2,[l=1] __KAM_DRILL4,[l=0] __KAM_DRUG2_3,[l=1] __KAM_SUNGLASSES2,[l=1] __LOTTO_WIN_01,[l=1] __THIS_AD,[l=1]',
                              'see me on the channel ' => '__DEAL,[l=1] __KAM_RICH2,[l=1]',
                              'financial independen' => 'FIN_FREE,[l=1] __DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1]',
                              'ukrainian women' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_WIFE2,[l=1]',
                              'you are receiving this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som pro lev' => 'KAM_VIAGRA2,[l=0]',
                              'roadside assistance' => '__KAM_CAR2,[l=0] __URG_BIZ,[l=1] __YOU_ASSIST,[l=1]',
                              'herdei' => '__I_INHERIT,[l=1]',
                              'let\'s talk' => '__KAM_URONLINE3,[l=1]',
                              'no exercising' => 'DIET_1,[l=1]',
                              'fax document' => '__KAM_VM3,[l=1]',
                              'highest' => '__KAM_WEIGHT1,[l=1]',
                              'cia som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'ghana' => '__GHANA,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INVEST4,[l=1]',
                              'assassinate' => '__KAM_ASSASSIN3,[l=0]',
                              'emarketnow' => '__KAM_DON3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'buy immediately' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_CREDIT3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1]',
                              'offices and clinics' => '__KAM_LIST3_4,[l=1] __KAM_SALE3,[l=1]',
                              'reviews' => '__KAM_AUTONEW3,[l=1] __KAM_CELL3,[l=1] __KAM_HEALTH2,[l=1]',
                              'twice as much' => '__KAM_JOB2,[l=1]',
                              'lev val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'feelings can be true' => '__KAM_PIC3,[l=1] __KAM_WEIGHT1,[l=1]',
                              'potential lead' => '__KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LIST3_2,[l=1]',
                              'xan pro val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'grab as many shares as you can' => '__KAM_VIAGRA9A,[l=1] __PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'degree' => '__KAM_UNIV2,[l=1]',
                              'vicodin' => '__DRUGS_PAIN_VICO,[l=0] __KAM_DRUG2_5,[l=1]',
                              'full-time & part-time' => '__KAM_TIME4,[l=1] __KAM_WORKHOME1,[l=0]',
                              'returning phone calls' => '__KAM_CELL3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK3,[l=1]',
                              'computer have been hacked' => '__KAM_HACK1,[l=0] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TOLL3,[l=1] __RANDOM_PICK,[l=1] __YOU_WON_01,[l=1]',
                              'bien' => '__KAM_VIAGRA8B,[l=1]',
                              'you have receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' first thing wednesday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'cargo' => '__KAM_FAKEDELIVER9,[l=1]',
                              'huge success story' => '__KAM_MILLIONAIRE2,[l=0] __KAM_RICH1,[l=1] __STOCK_TIP,[l=1]',
                              'mail address has w' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1] __hk_win_b,[l=1]',
                              'val xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'cia val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '1ink' => '__KAM_INK1,[l=1]',
                              'insane model' => '__KAM_GALLERY4,[l=1]',
                              'hunt' => '__DESTROY_ME,[l=1]',
                              'notification for cash aid' => '__KAM_CREDIT3,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_LOTTO3,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_TIMESHARE2,[l=1] __LOTTO_WIN_01,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOU_WON_02,[l=1]',
                              'beneficiary' => 'DEAR_BENEFICIARY,[l=1] __KAM_BANK_2,[l=0]',
                              'dtv4pc' => '__KAM_TV1,[l=1]',
                              'lev som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'criminal' => '__KAM_ARREST2,[l=1] __KAM_SECURITY3,[l=1]',
                              'male enhancement product' => 'MALE_ENHANCE,[l=0] __KAM_PHISH2_4,[l=1] __KAM_SEX1,[l=1]',
                              'no deceptive subject lines' => 'KAM_CANSPAM,[l=1] __KAM_CEP4,[l=1]',
                              'my identity' => '__DECEASED,[l=1] __KAM_ASSASSIN2,[l=0] __KAM_PHISH4_3,[l=1]',
                              'recommended a company' => '__KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_06,[l=1]',
                              'file:////' => 'KAM_FILE,[l=0] __JMQ_RESUME3,[l=1]',
                              'quintupling your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              ' special effort' => '__KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VISION3,[l=1] __KAM_WEIGHT2,[l=1] __WITHOUT_EFFORT,[l=1] __YOU_WON_02,[l=1]',
                              'reclaim your glory' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_SUPERHUMAN3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'securities storage house' => '__FRAUD_IRJ,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __STOCK_TIP,[l=1]',
                              'to your white' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEARCH4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'this offer is for unite' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_FUN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __THIS_AD,[l=1] __YOU_WON_02,[l=1]',
                              'surface protection plus' => '__KAM_GARAGE3,[l=1] __KAM_RECALL3,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'oil partnership' => '__DEAL,[l=1] __KAM_DRILL2,[l=0] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1]',
                              'shirts at $' => '__KAM_LABEL4,[l=1]',
                              'you have receive this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'found your contact' => '__CONTACT_ATTY,[l=1] __DECEASED,[l=1] __FOUND_YOU,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_INVEST2,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'costco' => '__FB_COST,[l=1] __KAM_GIFT1,[l=1]',
                              'get better rates' => '__KAM_DEBT1,[l=1] __KAM_INSURE4,[l=1]',
                              'executive who' => '__KAM_WEBINAR4,[l=1] __KAM_WHOSWHO3,[l=1]',
                              'protect your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME1,[l=1] __KAM_INSURE4,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WARRANTY2,[l=0] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dear traveler' => 'DEAR_SOMETHING,[l=1] __TRAVEL_AGENT,[l=1]',
                              'cia pro cia' => 'KAM_VIAGRA2,[l=0]',
                              'pro cia val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'guard your family' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ALARM2,[l=1] __KAM_ANCESTOR3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'complete name' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LIST3_4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1]',
                              'dysfunction' => '__KAM_PACKAGE1,[l=1]',
                              'protection' => '__KAM_RECALL3,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'mer som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'tired this morning' => '__DEAL,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __THIS_AD,[l=1]',
                              'health channel' => '__KAM_FUN6,[l=0] __KAM_JOINT3,[l=1]',
                              'lev pro cia' => 'KAM_VIAGRA2,[l=0]',
                              'home warrant' => '__KAM_REFI3,[l=1] __KAM_WARRANTY3,[l=0] __KAM_WINDOWS3,[l=1]',
                              'massive mistake' => '__KAM_FUN6,[l=0]',
                              'you' => '__RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pr submission' => '__KAM_SEARCH4,[l=1]',
                              'xan val val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'real' => '__KAM_DATINGTIPS3,[l=1]',
                              'amat' => '__KAM_GALLERY4,[l=1]',
                              'you\'ve receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pay off debt' => '__FEES,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __PAY_YOU,[l=1]',
                              'schoolgirls slut' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'xxl dick' => 'BODY_ENHANCEMENT2,[l=1] __KAM_SEX2,[l=1]',
                              'networks' => '__KAM_CAREER3,[l=1] __KAM_HOOKUP3,[l=1] __KAM_REP3_2,[l=1]',
                              'you have received this paid' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'capturing this domain' => '__DEAL,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __THIS_AD,[l=1]',
                              'finland' => '__KAM_NIGERIAN1,[l=1]',
                              'via cia som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'as you can see on the ecard' => '__DEAL,[l=1] __KAM_CARD2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'consistent with the provisions of the can-spam act' => 'KAM_CANSPAM,[l=1] __DEAL,[l=1] __KAM_VISION3,[l=1]',
                              'medwatch' => '__KAM_ANDROGEL3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_TIME4,[l=1]',
                              'incident:' => '__DECEASED,[l=1] __KAM_FAKEBBB4,[l=1]',
                              'som val lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'terms and condition' => '__KAM_INQUIRY_3,[l=0] __KAM_INSURE4,[l=1]',
                              'in been accessed' => '__MAIL_ACCT_ACCESS1,[l=1]',
                              'service management' => '__KAM_CONTRACT3,[l=0] __KAM_REFI2,[l=1] __KAM_WEB3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'internet sweepstake' => '__HK_LOTTO_BALLOT,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1]',
                              'reduced' => '__KAM_CLOUD3,[l=1] __KAM_INSURE2,[l=1] __KAM_PET3,[l=1] __KAM_STUDENT3,[l=1]',
                              'war veterans' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1]',
                              'more bills than money' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_EBAY2,[l=0] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'val cia cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'security team' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __SYSADMIN,[l=1] __TRUNK_BOX,[l=1]',
                              'setting' => '__KAM_SETTING3,[l=1]',
                              'you have been ' => '__KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'som mer val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'aid your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'diabetes' => '__KAM_DIABETES1,[l=1] __KAM_DIABETES2,[l=1] __KAM_FUN7,[l=1]',
                              'fema storing' => '__KAM_PATRIOT3,[l=1] __STOCK_TIP,[l=1]',
                              'file your claim' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_RESUME3,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INSURE4,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_DEPT,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_l,[l=1]',
                              'build' => '__KAM_CHICKEN3,[l=1]',
                              'frs healthy energy' => '__KAM_ANA1,[l=1] __KAM_JOINT3,[l=1] __KAM_NUWAVE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'xan mer lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'secure' => '__KAM_DOMAIN2,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'apple lottery online' => 'FREE_QUOTE_INSTANT,[l=1] __AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              '0rd3r' => '__KAM_DRUG2_5,[l=1]',
                              ' letter symbol' => '__KAM_STOCK3,[l=1] __KAM_STOCKOBFU1,[l=1]',
                              'blog submission' => '__KAM_SEARCH4,[l=1]',
                              'amb lev som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'mineral' => '__KAM_INVEST4,[l=1]',
                              'prefer to not receive these messages' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'som xan mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'at risk for alzheimers' => '__FRAUD_IOU,[l=1] __FRAUD_IOV,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_INVEST3,[l=1] __KAM_NEUROLOGICAL3,[l=0] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'reply to my alternative e' => '__FRAUD_AON,[l=1] __FRAUD_MLY,[l=1] __KAM_ALT1,[l=1]',
                              'dormant domiciliary account' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'ertisement' => 'KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1]',
                              'second civil war' => '__KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'your temporary login info' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CARD2,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'download pdf reader' => '__DLND_ATTACH,[l=1] __KAM_FAKEPDF1,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'or still worn all the time' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URZEST2,[l=0]',
                              'hard trading day' => '__DAY_I_EARNED,[l=1] __KAM_STOCK2_1,[l=1]',
                              'amb amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'awesome babe' => '__KAM_GALLERY4,[l=1]',
                              'amb xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'mer cia pro' => 'KAM_VIAGRA2,[l=0]',
                              ' before thursday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_THU,[l=1] __KAM_PATRIOT3,[l=1] __PUMPDUMP_03,[l=1] __YOU_WON_02,[l=1]',
                              'you\'re received this recurring' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'can u turn me on' => '__KAM_URONLINE1,[l=1]',
                              'review your account' => '__DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_AUTONEW3,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_HEALTH2,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_SIGN2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'expectations' => '__KAM_DRILL3,[l=1]',
                              'retirement plans' => '__KAM_HIRE3,[l=1] __KAM_REAL2_5,[l=0]',
                              'pro som pro' => 'KAM_VIAGRA2,[l=0]',
                              'som lev cia' => 'KAM_VIAGRA2,[l=0]',
                              'western union fees' => '__FEES,[l=1] __KAM_FAKEWEST2,[l=0] __KAM_TELEWORK5,[l=1]',
                              'second trick' => '__KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_HEART3,[l=1] __KAM_WEIRDTRICK2,[l=1]',
                              'you receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'foundation' => '__FOUND_YOU,[l=1] __HK_LOTTO_2,[l=1]',
                              'respect' => '__KAM_INSURE2,[l=1]',
                              'legal' => '__KAM_WEED1,[l=1]',
                              'god bless' => '__KAM_URGENT4,[l=0]',
                              'mer amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'going out of your house' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ur partner' => '__KAM_URUNIT2,[l=1]',
                              'asharpi media' => '__KAM_BADNAME1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1]',
                              'loma' => '__KAM_UNIV6B,[l=1]',
                              'assassinated' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __KAM_ASSASSIN3,[l=0]',
                              'bundling' => '__KAM_CLOUD3,[l=1]',
                              'lucky winner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __KAM_BENEFICIARY3,[l=1] __KAM_LOTTO6,[l=1] __LUCKY_WINNER,[l=1] __hk_win_2,[l=1]',
                              'million who suffer from' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __KAM_MEDICAL1,[l=0]',
                              'usps' => '__KAM_FAKEDELIVER7,[l=0]',
                              'i am contacting you' => '__CONTACT_ATTY,[l=1] __CONTACT_YOU,[l=1] __FRAUD_JYG,[l=1] __FRAUD_NRG,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'via mer val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'salesprospects' => '__KAM_DRUG2_3,[l=1] __KAM_RBL_OBFU1,[l=1]',
                              'too good to be true' => '__KAM_FUN2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'you received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'furnished' => '__KAM_DRIVE3,[l=1]',
                              'wife ran away' => '__KAM_BENEFICIARY6,[l=0]',
                              'pro via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'career path' => '__KAM_UNIV8,[l=1] __KAM_VISION3,[l=1]',
                              'meridian cbd' => '__KAM_CBD1,[l=0]',
                              'i am currently out of the office' => '__BOUNCE_OOO_B2,[l=1] __BOUNCE_OOO_CB1,[l=1] __DEAL,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_HOME2,[l=1] __KAM_SALE3,[l=1] __KAM_VISION3,[l=1]',
                              'via lev cia' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'freigabe' => '__SUM_OF_FUND,[l=1]',
                              'pussy' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'purchase rx' => '__KAM_DRUG2_3,[l=1]',
                              'more semen' => '__KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SEX4,[l=0] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1]',
                              'pro mer som' => 'KAM_VIAGRA2,[l=0]',
                              'via xan mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'seeking to get fit' => '__KAM_URZEST3,[l=0]',
                              'debt is forgiven' => '__FRAUD_JYG,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENTLOAN5,[l=0] __YOU_WON_02,[l=1]',
                              'cep' => '__KAM_CEP4,[l=1]',
                              's future' => '__KAM_POLITICS2,[l=1]',
                              'separate account' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'portugal' => '__KAM_BENEFICIARY4,[l=0]',
                              'quadrupling your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'more information about you' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_HOME3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_PIC3,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_BANK,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'organization for the good work of the lord' => '__DEAL,[l=1] __KAM_CAREER3,[l=1] __KAM_JESUS1,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1] __YOU_WON_02,[l=1]',
                              'please type' => '__KAM_REP2_1,[l=1]',
                              'comfy control harness' => '__KAM_BARK1,[l=1] __KAM_REP3_2,[l=1] __KAM_WEBINAR4,[l=1]',
                              'the infected attachment' => '__DEAL,[l=1] __DLND_ATTACH,[l=1] __PLS_REVIEW,[l=1] __VBOUNCE_ATTACHMENT0,[l=1]',
                              'mer xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'lift your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '3d rug' => '__KAM_HOLIDAY2020_2,[l=0]',
                              'amb cia cia' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'led fan light' => '__KAM_LED2,[l=1]',
                              'xan xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'mer lev mer' => 'KAM_VIAGRA2,[l=0]',
                              'you do' => '__RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'protect against identity' => '__DECEASED,[l=1] __KAM_PHISH4_3,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI6,[l=1]',
                              'see attach' => '__KAM_FAKEINV2_2,[l=0]',
                              'val lev som' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'special colored coin' => '__DRUGS_ERECTILE5,[l=1] __KAM_CRIM2_1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_TRUMPCOIN3,[l=0] __KAM_VISION3,[l=1]',
                              'great investment site' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_STOCK2_2,[l=1] __SUM_OF_FUND,[l=1]',
                              'dear google' => '__KAM_GOOGLE_AWARD3,[l=0] __KAM_SEO4,[l=1]',
                              'seo packages' => '__KAM_INSURE4,[l=1] __KAM_SEO4,[l=1] __KAM_TAX3,[l=1] __KAM_TRIAL,[l=1]',
                              'medications online' => 'FREE_QUOTE_INSTANT,[l=1] ONLINE_PHARMACY,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'link below' => '__DOS_LINK,[l=1] __KAM_CERT3,[l=0]',
                              'all my debt' => '__KAM_DEBT1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'temporary removal of your ' => '__ACCESS_REVOKE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'verify your account' => '__DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BOXVERIFY,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_NOTIFY2,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'informed' => '__KAM_DOMAIN2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __KAM_WEBINAR4,[l=1] __YOU_WON_02,[l=1]',
                              'discreet' => '__HUSH_HUSH,[l=1] __KAM_DRUG2_6,[l=1]',
                              'strategic development' => '__KAM_INSURE4,[l=1] __KAM_INVEST4,[l=1] __KAM_LOAN3,[l=1]',
                              'ascent your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'business man' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_INVEST2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'tripling your principal' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'earliest reply' => '__FRAUD_DPR,[l=1] __FRAUD_MLY,[l=1]',
                              'calculator' => '__KAM_REFI2,[l=1] __KAM_REFI5,[l=1]',
                              'klonopin' => '__DRUGS_ANXIETY8,[l=1]',
                              'personal safety' => '__FEES,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_FUN7,[l=1]',
                              'savings on tire' => '__KAM_HEALTH2,[l=1] __KAM_TIRES3,[l=0]',
                              'you received this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'will reply with my pics' => '__FRAUD_MLY,[l=1] __I_WILL_YOU,[l=1] __KAM_PIC4,[l=1] __KAM_PIC5,[l=0] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'via val lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '0nline' => '__KAM_DRUG2_5,[l=1]',
                              'marketing partner' => 'MARKETING_PARTNERS,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'som cia som' => 'KAM_VIAGRA2,[l=0]',
                              'necessary' => '__KAM_BACKUP3,[l=1]',
                              'business directories' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DIRECT4,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'agra' => '__KAM_DRUG2_3,[l=1] __KAM_VIAGRA7A,[l=1] __KAM_VIAGRA8A,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'recals' => '__KAM_RECALL3,[l=1]',
                              'clearance' => '__KAM_AUTO3,[l=1] __KAM_SWIPE3,[l=1]',
                              'profitable' => '__DEAL,[l=1] __KAM_INVEST3,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_SOLAR3,[l=1] __LUCRATIVE,[l=1] __YOUR_PROFIT,[l=1]',
                              'lucky' => '__LUCKY_WINNER,[l=1]',
                              'something important' => '__KAM_ARREST2,[l=1] __KAM_DISCLOSE1,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_2,[l=1]',
                              'wondercum' => '__KAM_LOTTO3,[l=1] __KAM_SEX4,[l=0]',
                              'val xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'val amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'ink & toner' => '__KAM_INK1,[l=1]',
                              'control' => '__KAM_WEBINAR4,[l=1]',
                              'cashiers check' => '__KAM_CREDIT2,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_TIMESHARE2,[l=1] __LOTTO_WIN_01,[l=1] __TRUSTED_CHECK,[l=1]',
                              'address:' => '__KAM_CRIM2_2,[l=0]',
                              'reactivate' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT3,[l=1] __KAM_OCEANSBOUNTY3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'shopper' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_MOTHER3,[l=1]',
                              'sildenafil citrate' => 'DRUG_ED_SILD,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_INSURE4,[l=1] __KAM_SILD2,[l=0]',
                              'istant' => '__YOU_ASSIST,[l=1]',
                              'mer mer lev' => 'KAM_VIAGRA2,[l=0]',
                              '2nd amendment' => '__KAM_2ND_2,[l=0] __KAM_COMPROMISED3,[l=1]',
                              'commercial' => '__KAM_RECALL3,[l=1] __KAM_REP3_2,[l=1]',
                              'experienced marketers' => '__KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1]',
                              'plans' => '__KAM_HIRE3,[l=1]',
                              'dogs behavior' => '__KAM_BARK1,[l=1]',
                              'val cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'in europe,' => '__KAM_COVID5,[l=1] __KAM_NIGERIAN4,[l=1]',
                              'ephedra' => '__KAM_ANA1,[l=1]',
                              'pro lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'val via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pro val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'delegates' => '__KAM_LIST3_4,[l=1]',
                              'wasteful' => '__KAM_POLITICS2,[l=1]',
                              'guarantee you 1st' => '__KAM_SEO2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'carving' => '__KAM_LANDSCAPE4,[l=1]',
                              'quality medications' => 'TVD_QUAL_MEDS,[l=1] __KAM_DRUG1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'get your healthcare degree' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_CAREER2,[l=1] __KAM_INSURE4,[l=1] __KAM_JOINT3,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV2,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'obtain' => '__KAM_DOMAIN1,[l=1] __KAM_TAX4,[l=1]',
                              'money-making secret' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __HUSH_HUSH,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_EBAY1,[l=0] __KAM_VISION3,[l=1] __KAM_WEIGHT2,[l=1]',
                              'seduction' => '__KAM_DATINGTIPS3,[l=1]',
                              'cooperation' => '__FRAUD_XWW,[l=1] __JMQ_RESUME3,[l=1]',
                              'free psychic reading' => '__KAM_PRODUCT2_2,[l=1] __KAM_PSYCHIC3,[l=0] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'the antivirus module has' => '__DEAL,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'xan cia pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              ' inches to your manhood' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] DIET_1,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX1,[l=1] __KAM_SEX2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'sum pay' => '__FEES,[l=1] __PAY_YOU,[l=1] __hk_win_j,[l=1]',
                              'included' => '__KAM_DOMAIN3,[l=1]',
                              'domain you might be interested' => 'KAM_ADVERT2,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE4,[l=1] __KAM_SNORE3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'd=e9nt' => '__DECEASED,[l=1]',
                              'som lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'bored morning' => '__KAM_PIC1,[l=1] __KAM_STOCK2_1,[l=1]',
                              'hoist your sweet' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'review this certificate' => '__DEAL,[l=1] __KAM_AUTONEW3,[l=1] __KAM_CERT2,[l=0] __KAM_HEALTH2,[l=1] __THIS_AD,[l=1]',
                              'progressiverailroading' => '__KAM_HSR1,[l=1]',
                              'infinite cele' => '__KAM_GALLERY4,[l=1]',
                              'verification is processed' => '__KAM_SIGN3,[l=0] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'for cancer patients' => '__AM_DYING,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_WEIGHT2,[l=1] __YOU_WON_02,[l=1]',
                              'cutie' => '__JMQ_PICKUP2,[l=1]',
                              'suporte t\\303\\251cnico' => '__SYSADMIN,[l=1]',
                              'pro amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'replica' => 'REPLICA_WATCH,[l=1] __KAM_TIME2,[l=1]',
                              'cartier' => '__KAM_TIME6,[l=0]',
                              'xan som val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              '<num_not_date_ip>' => '__LOTSA_MONEY_05,[l=1]',
                              'sales & marketing directors database' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACK3,[l=1] __KAM_BACKUP3,[l=1] __KAM_DIRECT4,[l=1] __KAM_DRUG2_3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST1,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'som som lev' => 'KAM_VIAGRA2,[l=0]',
                              ' and am unable to read your message' => '__ADMAIL,[l=1] __BOUNCE_OOO_B1,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_INSURE4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PRODUCT2_2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'not ranked number one' => '__KAM_SEARCH3,[l=1] __LOTTO_WIN_01,[l=1]',
                              'compensation' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'cia pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'check over this commercial' => '__DEAL,[l=1] __FRAUD_QFY,[l=1] __KAM_CREDIT2,[l=1] __KAM_MEDICARE4,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI2,[l=1] __KAM_REP3_2,[l=1] __KAM_WEB_OBFUSCATION1,[l=1] __LOTTO_WIN_01,[l=1] __THIS_AD,[l=1]',
                              'urgent response' => '__FRAUD_DPR,[l=1] __KAM_BADZIP3,[l=0] __KAM_REFI2,[l=1] __KAM_TAX3,[l=1] __URG_BIZ,[l=1]',
                              'vn audio' => '__KAM_VM3,[l=1]',
                              'first anal' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              '#1 weight loss' => 'DIET_1,[l=1] __KAM_HAIRTRANS3,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'mer via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'sending some of my pictures' => '__KAM_PIC4,[l=1] __KAM_PIC5,[l=0]',
                              'simplyrxdeals' => '__DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_SUNGLASSES2,[l=1]',
                              'this' => '__DEAL,[l=1] __THIS_AD,[l=1]',
                              'penalties' => '__KAM_STUDENT3,[l=1]',
                              'save yourself hundreds of dollars' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTO3,[l=1] __KAM_COVID5,[l=1] __KAM_HACK3,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_REFI6,[l=1] __KAM_REPAIR1_3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME5,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'unsightly bulges' => '__KAM_WEIGHT1,[l=1]',
                              'send me your personal cell phone number' => '__DECEASED,[l=1] __DRUGS_ERECTILE5,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CELL3,[l=1] __KAM_FAVOR3,[l=0] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'award sum of us$' => '__KAM_LOTTO3,[l=1] __LOTTO_DEPT,[l=1]',
                              'without a monthly fee' => '__DOS_BODY_MON,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CEP6,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TV2,[l=1] __KAM_UNIV2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'lev pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              ' please view this message in a different' => '__ADMAIL,[l=1] __DEAL,[l=1] __KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_HOME2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RUDE_HTML_2,[l=1] __THIS_AD,[l=1]',
                              'adventure' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TOURS3,[l=1]',
                              'medical' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'get a capable html e-mailer' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RUDE_HTML_1,[l=0] __YOU_WON_01,[l=1]',
                              'get your personalized christmas ornament' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_GALLERY4,[l=1] __KAM_HOLIDAY2020_2,[l=0] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'val mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'mer val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'your account is' => 'TVD_PH_REC,[l=1] TVD_PH_SEC,[l=1] __ACCOUNT_ERROR,[l=1] __ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __DORMANT_ACCT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'in your country' => '__DECEASED,[l=1] __FRAUD_IPK,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_COUNTRY,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'homeless' => '__CHARITY,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'huge weenie' => '__KAM_SEX1,[l=1]',
                              'xan lev mer' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'mer xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'amb cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'double opt in list' => '__KAM_ADVERT3,[l=1] __KAM_LIST4,[l=1] __KAM_SEX1,[l=1] __KAM_VIAGRA9D,[l=1] __KAM_WINDOWS3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'yours' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTO3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'via som lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'egg genie' => '__KAM_EGG1,[l=1]',
                              'certification' => '__KAM_CEP5,[l=0]',
                              'as much money as you wish' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_GOOGLE2,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'natural' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_LUNAR4,[l=1] __KAM_VISION3,[l=1]',
                              'order a brochure' => '__KAM_BADZIP3,[l=0] __KAM_HOLIDAY3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'winning sum' => '__KAM_LOTTO6,[l=1] __KAM_POLITICS2,[l=1]',
                              'search and selection of both experienced' => '__KAM_CELL3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_POLITICS2,[l=1] __KAM_REVIEW3,[l=1] __RANDOM_PICK,[l=1]',
                              'simplyink' => '__KAM_INK1,[l=1]',
                              'reduction' => '__KAM_REFINEW2,[l=1] __KAM_TVDOCTOR3,[l=1]',
                              'claims requirement' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_LOTTO6,[l=1] __LOTTO_DEPT,[l=1]',
                              'canvas print' => '__KAM_HOLIDAY2020_2,[l=0]',
                              'pills' => '__PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'accredited agent' => '__KAM_BANK_2,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_LOTTO4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_UNIV4,[l=1] __KAM_UNIV4B,[l=1] __KAM_UNIV9,[l=1]',
                              'goldmine' => '__KAM_BENEFICIARY3,[l=1] __KAM_NIGERIAN2_8,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'detoxify' => '__KAM_WEIGHT1,[l=1]',
                              'lloyds' => '__KAM_PHISH2_2,[l=1]',
                              'xan xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'late customer' => '__DECEASED,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_PHISH4_2,[l=1] __STOCK_TIP,[l=1]',
                              'amb via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'yi source' => '__KAM_ANA1,[l=1]',
                              'awareness' => '__KAM_SEARCH4,[l=1]',
                              'killing' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __KAM_POLITICS2,[l=1]',
                              'partnership to transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_BENEFICIARY3,[l=1] __WIRE_XFR,[l=1]',
                              'release yourunreceived ' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'euro - afro asian sweepstake' => '__KAM_COVID5,[l=1] __KAM_LOTTO5,[l=1]',
                              'visitors and price' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_DIRECT3,[l=0] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_LIST3_3,[l=1]',
                              'hardcore' => '__KAM_SEX2,[l=1]',
                              'heave your sex' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'more customers' => '__KAM_GIFT5,[l=1] __KAM_HOME3,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_PHISH4_2,[l=1] __KAM_SEARCH3,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __STOCK_TIP,[l=1]',
                              'corrective' => '__KAM_VISION3,[l=1]',
                              'aise draw' => '__HK_LOTTO_BALLOT,[l=1] __LOTTO_WIN_01,[l=1]',
                              ' gift certificate' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFTCERT2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'extreme gallery' => '__KAM_GALLERY2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'reasonable interest loan' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN3,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1]',
                              'generic quality' => '__KAM_DRUG1,[l=1] __KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'i love coffee kit' => '__KAM_GEVALIA2,[l=1] __KAM_SALE3,[l=1]',
                              'side socket' => '__KAM_SOCKET3,[l=0]',
                              'discount' => '__KAM_AUTO3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'brought' => '__DAY_I_EARNED,[l=1]',
                              'covid-19 donated relief' => '__KAM_COVID2_1,[l=0] __KAM_DRUG2_3,[l=1]',
                              'grow grass in the shade' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __DEAL,[l=1] __KAM_GRASS3,[l=0] __KAM_VIAGRA9A,[l=1]',
                              'find the attach' => '__DEAL,[l=1] __JMQ_TRACKR3,[l=1] __KAM_FAKEINV2_2,[l=0] __KAM_NEW_CREDITCARD3,[l=1]',
                              'confirm interest in this domain' => '__BACK_SCRATCH,[l=1] __DEAL,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_PHISH4_3,[l=1] __KAM_SNORE3,[l=1] __KAM_TAX4,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'view your snapshot' => 'CUM_SHOT,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTONEW3,[l=1] __KAM_HEALTH2,[l=1] __KAM_INSURE4,[l=1] __KAM_PIC4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'x longer' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_PACKAGE1,[l=1] __KAM_PACKAGE2,[l=1]',
                              'sixty' => '__KAM_MEDICARE4,[l=1]',
                              'cool girl' => '__KAM_GALLERY4,[l=1] __KAM_PIC2,[l=1]',
                              'cobra oil and gas' => '__KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_STOCKTIP138,[l=1]',
                              'totally msg me on msn' => '__FRAUD_JYG,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_URONLINE3,[l=1]',
                              'the' => '__DEAL,[l=1]',
                              'seeking to get in the gym' => '__DEAL,[l=1] __KAM_URZEST3,[l=0]',
                              'xan amb amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'whitener' => '__KAM_SEARCH4,[l=1] __KAM_WHITEN2,[l=0]',
                              'kinky lesbian' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'via lev via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'accounts ' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'zarabia' => '__KAM_MM_FOREX_1,[l=1]',
                              'leaving your home' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_HOME1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WINDOWS3,[l=1] __RECEIVE_BONUS,[l=1] __STAY_HOME,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dream car' => '__KAM_AUTO3,[l=1] __KAM_CAR2,[l=0]',
                              'blocked by mailsweeper' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_LIST4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __VBOUNCE_MAILSWEEP2,[l=1] __YOU_WON_01,[l=1]',
                              'earn a transcript' => '__KAM_INVEST3,[l=1] __KAM_UNIV14,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __RECEIVE_BONUS,[l=1]',
                              'soothing relief' => '__KAM_DRUG2_3,[l=1] __KAM_FUN7,[l=1]',
                              'grab as many shares of it as i can' => '__KAM_VIAGRA9A,[l=1] __PUMPDUMP_09,[l=1]',
                              'dearest client' => '__KAM_FAKEINV2,[l=0] __KAM_SNORE3,[l=1]',
                              'vigara' => '__DRUGS_ERECTILE2,[l=1]',
                              'you have received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SALE3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'consumer injury' => '__KAM_MESH3,[l=0]',
                              'ficiary' => 'DEAR_BENEFICIARY,[l=1]',
                              'rxolex' => '__KAM_TIME6,[l=0]',
                              'stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_STOCK2_3,[l=0] __KAM_WEED4,[l=1] __STOCK_TIP,[l=1]',
                              'quality term life insurance' => '__KAM_AUTONEW2,[l=1] __KAM_DRUG1,[l=1] __KAM_HEALTH2,[l=1] __KAM_INSURE4,[l=1]',
                              'ioga' => '__KAM_STOCKTIP153,[l=1]',
                              'unwanted' => '__KAM_ARREST2,[l=1] __KAM_WEIGHT1,[l=1]',
                              'amb mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'patek' => '__KAM_TIME6,[l=0]',
                              'reliable individual' => '__KAM_DRUG2_6,[l=1] __KAM_INVEST2,[l=1] __KAM_TV1,[l=1] __LUCKY_WINNER,[l=1]',
                              'acai' => '__KAM_WEIGHT1,[l=1]',
                              'pro pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'ultraslim' => '__KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'analytics' => '__KAM_SEARCH4,[l=1]',
                              'pacific shores investments' => '__INVEST_MONEY,[l=1] __KAM_BADNAME1,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __SUM_OF_FUND,[l=1]',
                              'pro val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'collect your money' => '__DECEASED,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_JUDGE3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'raise your darling' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you are recently invited' => '__KAM_AUTONEW3,[l=1] __KAM_CHOSEN3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '3 major sources' => '__KAM_CREDIT2,[l=1]',
                              'reasonable parentage' => '__KAM_HOME2,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'f*ck_' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'brandroot seo' => '__KAM_BADNAME1,[l=1]',
                              'qtjars' => '__KAM_QTJARS3,[l=1]',
                              'new online business model' => 'FREE_QUOTE_INSTANT,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'babes collection' => '__KAM_GALLERY2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'public' => '__KAM_BACK3,[l=1]',
                              'dominion minerals' => '__KAM_INVEST4,[l=1] __KAM_STOCKTIP135,[l=1]',
                              'intense pleasure' => '__KAM_SEX2,[l=1]',
                              'work' => '__KAM_CAREER3,[l=1]',
                              'xan cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'current price:' => 'CURR_PRICE,[l=1] LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_HOME2,[l=1] __KAM_INK1,[l=1] __KAM_LIST3,[l=1]',
                              'quadrupling your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'fiscate' => '__KAM_BENEFICIARY3,[l=1]',
                              '*omit empty spaces' => '__KAM_REP3_1,[l=1]',
                              'multiply an principal' => '__PUMPDUMP_01,[l=1]',
                              'investigator' => '__INVEST_MONEY,[l=1] __KAM_BACK3,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'download your ' => '__DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'your furniture' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DUTCHGLOW3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cash prize of' => '__CASHPRZ,[l=1] __KAM_FAKEVOUCHER2,[l=1] __KAM_LOTTO3,[l=1] __KAM_TIMESHARE2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'dating' => '__KAM_MEMBER3,[l=1]',
                              'hidden' => '__KAM_SPY3,[l=1]',
                              '100% discrete' => '__HUSH_HUSH,[l=1] __KAM_MERCHANT3,[l=1] __KAM_UNIV18,[l=1]',
                              'lev mer mer' => 'KAM_VIAGRA2,[l=0]',
                              'legitimate business' => '__DEAL,[l=1] __FRAUD_UUY,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'trick' => '__KAM_WEIRDTRICK2,[l=1]',
                              'mike statler' => '__KAM_STATLER3,[l=0]',
                              'bonus voucher' => '__KAM_FAKEVOUCHER2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'internet' => '__KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1]',
                              'cia xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'target' => 'LONG_TERM_PRICE,[l=1] SHORT_TERM_PRICE,[l=1]',
                              'escolhidos aleatoria' => '__RANDOM_PICK,[l=1]',
                              'alkuper\\303\\244inen viesti' => '__freemail_safe_fwd,[l=1]',
                              'computer draw' => '__HK_LOTTO_BALLOT,[l=1] __KAM_REP3_2,[l=1] __LOTTO_WIN_01,[l=1] __RANDOM_PICK,[l=1]',
                              'we have already sent ' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'lev via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'worsen' => '__KAM_VISION3,[l=1]',
                              'not ranking well' => '__KAM_SEARCH3,[l=1] __KAM_SEO3,[l=1] __KAM_SEO4,[l=1]',
                              'clearance tax' => '__KAM_AUTO3,[l=1] __KAM_BANK_3,[l=1] __KAM_SWIPE3,[l=1]',
                              'indicate your interest' => '__BACK_SCRATCH,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DISCLOSE1,[l=0] __KAM_DOMAIN3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'have' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'quin' => '__KAM_RBL_OBFU2,[l=1]',
                              'management' => '__KAM_WEBINAR4,[l=1]',
                              'acai burn' => 'DIET_1,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'power hcg' => '__KAM_WEIGHT2,[l=1]',
                              'lev xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'securities firm' => '__FRAUD_IRJ,[l=0]',
                              'been working extremely hard on my friend\'s website' => '__DOS_BODY_FRI,[l=1] __KAM_CAREER3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LIKE1,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1]',
                              'line ballot' => '__HK_LOTTO_BALLOT,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'cia via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'search engine submission' => '__KAM_REVIEW3,[l=1] __KAM_SEARCH4,[l=1]',
                              'your family' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANCESTOR3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'first page in bing' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'rank number one' => '__KAM_SEO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'verifiable university degree' => '__HK_LOTTO_2,[l=1] __KAM_UNIV1,[l=1] __KAM_UNIV2,[l=1] __KAM_UNIV6,[l=1] __KAM_UNIV9,[l=1]',
                              'weight' => 'DIET_1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'cia mer mer' => 'KAM_VIAGRA2,[l=0]',
                              'revolutionary pet control system' => '__KAM_PEST3,[l=0] __KAM_WEBINAR4,[l=1]',
                              'notice the winning' => '__DEAL,[l=1] __KAM_JURY4,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_POLITICS2,[l=1] __KAM_STOCK2_2,[l=1] __hk_win_5,[l=1]',
                              'visitors record' => '__KAM_DIRECT3,[l=0] __KAM_LIST3_4,[l=1]',
                              'unclaimed' => 'UNCLAIMED_MONEY,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO5,[l=1] __KAM_MED1,[l=1] __LOTTO_DEPT,[l=1]',
                              ' first thing friday' => '__DAY_I_EARNED,[l=1] __DOS_BODY_FRI,[l=1] __PUMPDUMP_03,[l=1]',
                              'carribean' => '__KAM_VACATION3,[l=1]',
                              'electronic cig' => '__KAM_SMOKE1,[l=1] __KAM_SMOKE4,[l=1]',
                              'perfect' => '__KAM_MEMBER3,[l=1] __KAM_SALE3,[l=1] __KAM_SALEA_3,[l=1] __KAM_SANTA3,[l=1] __KAM_VISION3,[l=1]',
                              'lead to your arrest' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ARREST2,[l=1] __KAM_BACK3,[l=1] __KAM_HACK3,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SNORE3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'register' => '__KAM_WEBINAR4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'cia som cia' => 'KAM_VIAGRA2,[l=0]',
                              're market' => '__KAM_PATRIOT3,[l=1] __KAM_REAL1,[l=1]',
                              'compensate' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __KAM_REP3_2,[l=1]',
                              'receives compensation' => '__COMPENSATION,[l=1] __DOS_BODY_SAT,[l=1] __KAM_DISCLAIMER1,[l=0] __KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'mer pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'greatrxmedsrus' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1]',
                              'lit\\303\\251' => '__HUSH_HUSH,[l=1]',
                              'dpd' => '__KAM_FAKEDELIVER11,[l=0]',
                              'trunk' => '__TRUNK_BOX,[l=1]',
                              'royal heritage promotion' => '__KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_SEO6,[l=1] __MY_FORTUNE,[l=1] __THIS_AD,[l=1]',
                              ' wednesday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'lev val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              ' cent' => '__KAM_SWIPE4,[l=1]',
                              'alanco technologies' => '__KAM_STOCKTIP151,[l=0] __KAM_STOCKTIP155,[l=1]',
                              'ur wife' => '__KAM_URUNIT2,[l=1]',
                              'penis' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'vip pass' => '__KAM_DIRECT3,[l=0]',
                              'storage' => '__KAM_ACCOUNTPHISH4,[l=1] __STOCK_TIP,[l=1]',
                              'bid now' => '__KAM_SWIPE3,[l=1]',
                              'enhancement' => '__KAM_PHISH2_4,[l=1]',
                              'electric' => '__KAM_SOLAR3,[l=1]',
                              'org' => '__KAM_REP3_2,[l=1]',
                              'this  is an ad' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __THIS_AD,[l=1]',
                              'prefer to not receive these emails' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'contact list' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_LISTSALE2,[l=0] __KAM_VIAGRA9D,[l=1]',
                              'tired this today' => '__DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_GIFT3,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __KAM_SUNGLASSES3,[l=1] __THIS_AD,[l=1]',
                              'free xxx' => 'FREE_PORN,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'make custom jackets' => '__KAM_LABEL3a,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'dubai' => '__KAM_INVEST4,[l=1]',
                              '100% guaranteed' => 'GUARANTEED_100_PERCENT,[l=0] __KAM_MERCHANT3,[l=1] __KAM_SEO5,[l=1]',
                              'transform your daily life' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TRANSFORM_LIFE,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'full contact information requested' => '__CONTACT_ATTY,[l=1] __DRUGS_ERECTILE5,[l=1] __FRAUD_ETX,[l=1] __FRAUD_JYG,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_NIGERIAN2_6,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __URG_BIZ,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'no strings attached' => '__KAM_FAKEDELIVER1,[l=1] __KAM_LOTTO6,[l=1] __KAM_REFI2,[l=1] __PLS_REVIEW,[l=1]',
                              'big bait in your pants' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX05_2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'emails, phone' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CELL3,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'available in auction' => '__KAM_DOMAIN2,[l=1] __KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI2,[l=1]',
                              'seeking to get into shape' => '__KAM_URZEST3,[l=0]',
                              'cia val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'first page in msn' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'meet that special' => '__KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_URONLINE2,[l=1] __KAM_VISION3,[l=1]',
                              'seen' => '__KAM_SEENTHIS1,[l=1]',
                              'credit card account' => '__DORMANT_ACCT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH2_2,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'declining' => '__ACH_CANCELLED_02,[l=1] __KAM_REAL2,[l=0]',
                              'millions' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __KAM_DRUG2_4,[l=1] __MILLIONS,[l=1]',
                              'd\\351funt' => '__DECEASED,[l=1]',
                              'lev som cia' => 'KAM_VIAGRA2,[l=0]',
                              'size of your ' => 'BODY_ENHANCEMENT2,[l=1] TVD_INCREASE_SIZE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT5,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'summary' => '__KAM_CREDIT2,[l=1]',
                              'lifeapps' => '__KAM_STOCKTIP149,[l=1]',
                              'don\'t let them know that it is money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN2_9,[l=0]',
                              'no carbon monoxide' => '__DOS_BODY_MON,[l=1] __KAM_SMOKE4,[l=1]',
                              'illion dollar' => 'BILLION_DOLLARS,[l=1] __KAM_COVID5,[l=1]',
                              'alprazolam' => '__DRUGS_ANXIETY2,[l=1]',
                              'lo e incolla' => '__COPY_PASTE_IT,[l=1]',
                              'favored rx' => '__KAM_DRUG2_5,[l=1]',
                              'blonde with blue' => '__KAM_PIC1,[l=1]',
                              'retrieve yourpending ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'faculty assessment' => '__KAM_UNIV1,[l=1]',
                              'i was fired from a job i held for ' => '__DOS_LET_GO_JOB,[l=1] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_02,[l=1]',
                              'bank director' => '__JMQ_WIRE3,[l=1] __KAM_DIRECT4,[l=1] __KAM_NIGERIAN2_2,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'kors insider' => '__KAM_KORS3,[l=0]',
                              'going' => '__JMQ_HEARINGLOSS3,[l=1]',
                              'make traders rich' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STOCK2_4,[l=0]',
                              'prcc' => '__KAM_STOCKTIP130,[l=1]',
                              'mlight tech' => '__KAM_STOCKTIP154,[l=1]',
                              'powering apps' => '__KAM_CLOUD3,[l=1]',
                              'transfer of the funds' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DEAL,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_NIGERIAN3,[l=1] __SUM_OF_FUND,[l=1] __WIRE_XFR,[l=1] __YOUR_FUND,[l=1]',
                              'recovery rate' => '__FRAUD_QFY,[l=1] __KAM_COLLECT4,[l=0] __KAM_INSURE4,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1]',
                              'caplets' => '__KAM_MARIJUANA3,[l=1] __PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'social security institute' => '__FEES,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __KAM_WTA2,[l=1] __TRUNK_BOX,[l=1]',
                              'ur energy level' => '__KAM_NUWAVE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_URUNIT1,[l=1] __KAM_WINDOWS3,[l=1]',
                              'visiting this website' => '__DEAL,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_HOWRU3,[l=0] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1] __THIS_AD,[l=1]',
                              'male organ' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_REP3_2,[l=1]',
                              'internet millionare' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COVID3_3,[l=1] __KAM_MILLIONAIRE1,[l=0] __KAM_MM_FOREX_1,[l=1] __KAM_REP3_2,[l=1]',
                              'this message is not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __THIS_AD,[l=1]',
                              'pro pro pro' => 'KAM_VIAGRA2,[l=0]',
                              'novelty use' => '__KAM_UNIV5,[l=1]',
                              'password:' => '__KAM_BADZIP4,[l=0] __KAM_PHISH4_3,[l=1]',
                              'yours faithfully' => '__DECEASED,[l=1] __FRAUD_IRT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_AUTO3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'perscr' => 'NO_PRESCRIPTION,[l=1]',
                              'return to the office' => '__BOUNCE_OOO_CB4,[l=1] __DEAL,[l=1] __KAM_POLITICS2,[l=1] __KAM_SALE3,[l=1]',
                              'new job or career' => '__KAM_TELEWORK5,[l=1] __KAM_VISION3,[l=1]',
                              'election' => '__KAM_POLITICS2,[l=1]',
                              'exceeded' => '__KAM_BOXQUOTA,[l=1]',
                              'coupon' => '__KAM_OILCHANGE3,[l=1] __KAM_PET3,[l=1] __KAM_PIZZA3,[l=1]',
                              'interchange' => '__KAM_MERCHANT2,[l=1] __KAM_OILCHANGE3,[l=1]',
                              'fiduciary officer' => '__HK_LOTTO_2,[l=1] __KAM_LOTTO4,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1]',
                              'triple this afternoon' => '__DEAL,[l=1] __KAM_WEED3,[l=0] __THIS_AD,[l=1]',
                              'dormant' => '__DORMANT_ACCT,[l=1]',
                              'relief' => '__KAM_DRUG2_3,[l=1]',
                              'via lev xan' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'see your brokers website' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DRILL3,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEARCH3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEB2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'appended my pic' => '__KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_PIC5,[l=0]',
                              'cia amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'like' => '__KAM_LED2,[l=1]',
                              'we have already remitted ' => '__FRAUD_WNY,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'paid' => '__FEES,[l=1] __KAM_POLITICS2,[l=1]',
                              'cola lotto online' => 'FREE_QUOTE_INSTANT,[l=1] __HK_LOTTO_2,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LOTTO5,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'changes in your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ADVERT3,[l=1] __KAM_CREDIT2,[l=1] __KAM_INSURE4,[l=1] __KAM_OILCHANGE3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'help button' => '__KAM_ALERT3,[l=0] __KAM_CREDIT2,[l=1] __KAM_TAX3,[l=1] __SYSADMIN,[l=1]',
                              'e directly at' => '__DOS_EMAIL_DIRECTLY,[l=1] __KAM_DIRECT4,[l=1]',
                              'field of your ch' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_UNIV11,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'you have been selected' => '__KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_WHOSWHO3,[l=1] __RANDOM_PICK,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'payment advice' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_FAKE_INVOICE2,[l=0] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'bahrain' => '__KAM_INVEST4,[l=1]',
                              'pro pro via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'fetish babe' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'discrete' => '__HUSH_HUSH,[l=1]',
                              'card will be aviailable' => 'VIA_GAP_GRA,[l=1] __I_WILL_YOU,[l=1] __KAM_CARD2,[l=1] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'for termination of this email' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_INSURE4,[l=1] __KAM_LIST5,[l=1] __KAM_PATRIOT3,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'drug dependenc' => '__KAM_ANDROGEL3,[l=1] __KAM_REHAB3,[l=0] __KAM_REMEMBERWHEN3,[l=1]',
                              'won\'t see this image' => '__DEAL,[l=1] __KAM_FUN3,[l=1] __KAM_LOTTO3,[l=1] __THIS_AD,[l=1]',
                              '101 inks' => '__KAM_INK1,[l=1]',
                              'behind' => '__KAM_PATRIOT3,[l=1]',
                              'pin number' => '__KAM_LOTTO2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'i am missing you all the time' => '__DEAL,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KB_WAM_LONELY_WOMEN_PHRASE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'personalized consultation' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_REFI2,[l=1]',
                              'remove "*" to make the link' => '__DEAL,[l=1] __DOS_LINK,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STAR1,[l=0] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'credit card' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'as low as $' => '__KAM_HEALTH1,[l=1]',
                              'quintuple an investment' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_STOCK2_2,[l=1] __PUMPDUMP_01,[l=1] __SUM_OF_FUND,[l=1]',
                              'i am barrister' => '__BARRISTER,[l=1] __CONTACT_ATTY,[l=1] __FRAUD_QXX,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_INVEST4,[l=1] __KAM_NIGERIAN2_2,[l=1]',
                              'technologia' => '__KAM_MM_FOREX_1,[l=1]',
                              'snap up as many shares of it as you can' => '__PUMPDUMP_09,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'without exercising' => 'DIET_1,[l=1] __KAM_MARIJUANA3,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'online jobs' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_WORKHOME1,[l=0]',
                              'grand chick' => '__KAM_GALLERY4,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'to stop any offers from us' => '__KAM_DOMAIN3,[l=1] __KAM_GIFT2,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'som pro amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'pulse oximeter' => '__KAM_SPO2_1,[l=0]',
                              'we have remitted ' => '__FRAUD_WNY,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'dorment' => '__DORMANT_ACCT,[l=1]',
                              'paid the fee for your cheque draft' => '__BANK_DRAFT,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN2_4,[l=1] __KAM_NIGERIAN2_5,[l=1] __KAM_PATRIOT3,[l=1] __KAM_POLITICS2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'lev amb mer' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'pledge dep' => '__KAM_BENEFICIARY3,[l=1]',
                              'to uplift this suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1] __THIS_AD,[l=1]',
                              'to unsubscribe' => '__KAM_FUN2,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'scientifically' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_TINNITUS3,[l=1]',
                              'approved' => 'TVD_APPROVED,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_LOAN3,[l=1]',
                              'bed experience' => '__KAM_SEX04_2,[l=1]',
                              'naughtypic' => '__JMQ_PICKUP2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'demand generation' => '__KAM_ADVERT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_LIST3_2,[l=1]',
                              'prevention' => '__KAM_TOURS3,[l=1] __KAM_TVDOCTOR3,[l=1]',
                              'be remitted' => '__FRAUD_WNY,[l=1] __RECEIVE_BONUS,[l=1]',
                              'seleccion al azar' => '__RANDOM_PICK,[l=1]',
                              'prxpills' => '__KAM_DRUG2_5,[l=1] __PILL_PRICE_01,[l=1] __PILL_PRICE_02,[l=1]',
                              'tue' => '__DOS_BODY_TUE,[l=1]',
                              'free lasik eval' => '__KAM_FUN7,[l=1] __KAM_LASIK3,[l=1] __KAM_TRIAL,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1] __PILL_PRICE_01,[l=1]',
                              'busty' => '__KAM_SEX2,[l=1]',
                              'lottery department uk' => '__AFF_LOTTERY,[l=0] __HK_LOTTO_2,[l=1] __KAM_LOTTO2,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'prefer to not receive future emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'handle' => '__KAM_WEBINAR4,[l=1]',
                              'did you get my message' => '__ADMAIL,[l=1] __KAM_DIDYOUBODY,[l=0] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'cia lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'make' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'claims manager' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __LOTTO_DEPT,[l=1]',
                              'doctors are raving' => '__KAM_DIET2_3,[l=1] __KAM_MARIJUANA3,[l=1]',
                              ' savings' => '__KAM_HEALTH2,[l=1] __KAM_REFI5,[l=1]',
                              'the scooter store' => '__DEAL,[l=1] __KAM_SCOOTER3,[l=0] __STOCK_TIP,[l=1]',
                              'speedymed4u' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG2_5,[l=1] __KAM_MED1,[l=1] __KAM_TV2,[l=1]',
                              'invest in real estate' => '__INVEST_MONEY,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'ukranian bride' => '__KAM_AUTO3,[l=1] __KAM_WIFE2,[l=1]',
                              'amb cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'flag' => '__KAM_FLAG3,[l=1]',
                              'never' => '__JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __NOT_SCAM,[l=1]',
                              'lev lev amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'been mos since we\'ve chatted' => '__KAM_URZEST4,[l=0]',
                              'mer xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'no prescript' => 'NO_PRESCRIPTION,[l=1] __KAM_DRUG2_4,[l=1] __KAM_DRUG4,[l=1]',
                              'ecowas' => '__KAM_LOTTO5,[l=1]',
                              'lev val pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'hearing' => '__JMQ_HEARINGLOSS3,[l=1]',
                              'santa letter' => '__KAM_SANTA2,[l=0]',
                              'credit report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DEBT1,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'reverse' => '__KAM_DIABETES2,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'check anyone' => '__KAM_BACK2,[l=1] __KAM_CREDIT2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'no classes' => '__KAM_2ND_1,[l=1] __KAM_UNIV15,[l=1]',
                              'activate' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'foreign account' => '__DORMANT_ACCT,[l=1] __FRAUD_JBU,[l=1] __FRAUD_JNB,[l=1] __FRAUD_TCC,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'growing' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_CAREER3,[l=1] __KAM_INSURE2,[l=1] __KAM_NURSE3,[l=1]',
                              'foriegn account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __YOU_WON_02,[l=1]',
                              'androgel' => '__KAM_TESTOSTERONE4,[l=1]',
                              'finds the secret' => '__DEAL,[l=1] __HUSH_HUSH,[l=1] __JMQ_TRACKR3,[l=1] __KAM_FUN6,[l=0] __KAM_NEW_CREDITCARD3,[l=1] __KAM_WEIGHT2,[l=1]',
                              'antivirus system report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT3,[l=1] __VBOUNCE_AVREPORT0,[l=0]',
                              'chairman of the finance committee' => '__DEAL,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_REP3_2,[l=1] __LOTTO_DEPT,[l=1]',
                              'top page rank' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'raise your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'top 5 organic' => '__KAM_REP3_2,[l=1] __KAM_SEO5,[l=1]',
                              'lev pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'minister' => '__KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2_2,[l=1]',
                              'jones blvd' => '__KAM_FUN2,[l=1]',
                              'euromillion loteria' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COVID5,[l=1] __KAM_LOTTO5,[l=1]',
                              'safe' => '__FEES,[l=1]',
                              'blood pressure' => '__KAM_BLOOD6,[l=0] __KAM_DIABETES1,[l=1]',
                              'elite world casino' => '__KAM_CASINO1,[l=0]',
                              '6130 w flamingo rd' => 'SCC_SPAMMER_ADDR_2,[l=1]',
                              ' per gallon' => '__KAM_GAS1,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'security department' => '__FEES,[l=1] __HK_LOTTO_2,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1] __SECURITY_DEPT,[l=1] __TRUNK_BOX,[l=1]',
                              'currencies' => '__KAM_BITCOIN2,[l=1]',
                              'your mask' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_LABEL8,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'boost your belove' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'ymbol' => '__KAM_STOCK3,[l=1]',
                              'remove_your' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TAX3,[l=1] __KAM_TOLL3,[l=1] __OBFU_UNSUB_UL,[l=1] __RECEIVE_BONUS,[l=1] __SUBSCRIPTION_INFO,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'medical doctors' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_INSURE2,[l=1] __KAM_LIST2,[l=1] __KAM_MARIJUANA3,[l=1] __KAM_MED1,[l=1] __KAM_MEDICAL1,[l=0] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'cia pro xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'finance storage house' => '__FRAUD_IRJ,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __STOCK_TIP,[l=1]',
                              'ti garantisco che non ti disturbe' => '__NEVER_HEAR_IT,[l=0]',
                              'auction success kit' => '__KAM_EBAY2,[l=0]',
                              'cleanse excess waste' => '__KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'make custom sports' => '__KAM_LABEL3a,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'rabbit tv' => '__KAM_TV1,[l=1]',
                              'woman' => '__KAM_ANDROGEL3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'to be removed from' => 'EXCUSE_4,[l=1] EXCUSE_REMOVE,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'biden wants to curb' => '__KAM_KN_2,[l=0]',
                              '% online' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_UNIV4B,[l=1]',
                              'debts disappear' => '__KAM_DEBT1,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1]',
                              'earning up to ' => '__KAM_TELEWORK6,[l=1] __RECEIVE_BONUS,[l=1]',
                              'please send correspondence to' => '__FRAUD_MLY,[l=1] __KAM_SPAMKING6,[l=1]',
                              'i am alone' => '__KAM_COMPROMISED3,[l=1] __KAM_PIC1,[l=1]',
                              'ease your stress' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'attourney' => '__CONTACT_ATTY,[l=1] __FB_TOUR,[l=1]',
                              'equipment' => '__KAM_DRIVE3,[l=1]',
                              'som lev xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              ' sortable fields' => '__KAM_LIST2,[l=1]',
                              'you\'re receive this special' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'kopieren & einf\\303\\274gen' => '__COPY_PASTE_DE,[l=0]',
                              'death' => '__NOT_DEAD_YET,[l=1]',
                              'escogidos al azar' => '__RANDOM_PICK,[l=1]',
                              'on vacation' => '__BOUNCE_OOO_CB2,[l=1]',
                              'recommended a stock' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEED4,[l=1] __PUMPDUMP_06,[l=1] __STOCK_TIP,[l=1]',
                              'private email' => '__ADMAIL,[l=1] __FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __GAPPY_SALES_LEADS,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_URGENT3,[l=0] __KAM_URONLINE3,[l=1] __YOU_WON_01,[l=1]',
                              'ucso' => '__KAM_STOCKTIP134,[l=1]',
                              'no script necessary' => '__KAM_BACKUP3,[l=1] __KAM_DRUG4,[l=1]',
                              'phendimetrazine' => '__DRUGS_DIET4,[l=1]',
                              'teen pics' => '__KAM_SEX4,[l=0]',
                              'worst' => '__KAM_BLOOD5,[l=1]',
                              'direct wire transfer' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_DIRECT4,[l=1] __KAM_NIGERIAN2_8,[l=1] __WIRE_XFR,[l=1]',
                              'via pro amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'val cia xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'barclay' => '__KAM_PHISH2_2,[l=1]',
                              'nuwave' => '__KAM_NUWAVE3,[l=1]',
                              'goodpix' => '__JMQ_PICKUP2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'registered' => '__KAM_BACK2,[l=1] __KAM_WEBINAR4,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'hey. please have a look' => '__KAM_COMPROMISED4,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __YOU_WON_01,[l=1]',
                              'to your ' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_04,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'over' => '__FRAUD_QFY,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1]',
                              'ur liveliness' => '__KAM_URUNIT1,[l=1]',
                              'internal cleansing' => '__DRUGS_ERECTILE5,[l=1] __KAM_WEIGHT1,[l=1] __LOTTO_ADMITS_2,[l=1]',
                              'engineering ' => '__KAM_ENGINEER3,[l=1]',
                              'foreign' => '__KAM_PATRIOT3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'brother' => '__DEAL,[l=1] __KAM_REMEMBERWHEN2,[l=1]',
                              'national student loan status' => '__DECEASED,[l=1] __HK_LOTTO_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_STUDENT3,[l=1] __KAM_STUDENTLOAN1,[l=0]',
                              'life experience diploma' => '__KAM_UNIV3,[l=1] __KAM_UNIV6B,[l=1] __KAM_UNIV7,[l=1]',
                              'business seo' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_SEO2,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'form' => '__KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'val amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'click here to unsubscribe' => '__JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FAKEAD2,[l=0] __KAM_FUN2,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'via via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'euro millions' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1] __HK_LOTTO_2,[l=1] __KAM_COVID3_3,[l=1] __KAM_COVID5,[l=1] __KAM_DRUG2_4,[l=1] __KAM_LOTTO5,[l=1] __MILLIONS,[l=1]',
                              'german business phone numbers' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CELL3,[l=1] __KAM_DOMAIN1,[l=1] __KAM_GERMAN_BUSINESS_CONTACTS3,[l=0] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_LOTTO6,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __LOTTO_WIN_01,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'promotion department' => '__HK_LOTTO_2,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_SEO6,[l=1] __LOTTO_ADMITS_2,[l=1] __LOTTO_DEPT,[l=1] __THIS_AD,[l=1]',
                              'sexual stim' => '__KAM_DRUG2_3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'this message contains an html formatted message but your ema' => '__ADMAIL,[l=1] __DEAL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN2,[l=1] __KAM_INSURE4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RUDE_HTML_3,[l=0] __THIS_AD,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'royalties' => '__KAM_STOCK2_4,[l=0]',
                              'via val amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'university degree' => '__HK_LOTTO_2,[l=1] __KAM_UNIV1,[l=1] __KAM_UNIV2,[l=1] __KAM_UNIV9,[l=1]',
                              'increase your volume' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] MORE_SEX,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT3,[l=1] __KAM_WEBINAR4,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'marketing co' => '__GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_ENGINEER3,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEBINAR4,[l=1]',
                              'medical alert' => '__JMQ_WIRE2,[l=1] __KAM_CAREER1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_HIP1,[l=0] __KAM_INSURE2,[l=1] __KAM_MED1,[l=1] __KAM_MEDTOUR1,[l=1] __KAM_OCEANSBOUNTY3,[l=1]',
                              'effective as glucosamine' => '__KAM_JOINT4,[l=0]',
                              'via lev pro' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'ihre kreditkarte wird gesperrt' => '__ACCESS_REVOKE,[l=1] __YOUR_FUND,[l=1]',
                              'cancel these ads go' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1]',
                              'funeral' => '__KAM_DEATHINSURE3,[l=1] __KAM_FUNERAL3,[l=1]',
                              'pro xan val' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'claims & management' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LOTTO3,[l=1] __KAM_LOTTO4,[l=1] __KAM_LOTTO5,[l=1] __KAM_WEBINAR4,[l=1] __LOTTO_DEPT,[l=1]',
                              'valuable' => '__KAM_STOCK2_1,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              's seo policies' => '__KAM_SEO6,[l=1]',
                              'you receiving this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'freetrusted-rx' => '__KAM_DRUG2_5,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'expired' => '__KAM_AUTONEW2,[l=1]',
                              'rities passwords' => '__KAM_GALLERY2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'amb som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'order at ' => '__KAM_BADZIP3,[l=0] __KAM_DRUG2_5,[l=1]',
                              'mercato' => '__HK_LOTTO_2,[l=1] __KAM_FOOTBALL3,[l=0]',
                              'take a look' => '__KAM_BADZIP1,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'pro via som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'unstable' => '__KAM_CAREER3,[l=1]',
                              'st\\x{fc}d\\x{e9}nt l\\x{f3}ans' => 'KAM_OBFU_LOANS,[l=0]',
                              'estonia' => '__KAM_BENEFICIARY4,[l=0] __STOCK_TIP,[l=1]',
                              'whanger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'first page in google' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1] __KAM_SEO4,[l=1]',
                              'outstanding debt' => '__KAM_DEBT1,[l=1]',
                              'lick their paws' => '__DEAL,[l=1] __KAM_BACK2,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'penguin' => '__KAM_SEO4,[l=1]',
                              'pro mer mer' => 'KAM_VIAGRA2,[l=0]',
                              'via xan som' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'wish to not receive future messages' => '__ADMAIL,[l=1] __KAM_FUN2,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1]',
                              'sale' => '__KAM_DRUG2_3,[l=1]',
                              'hawk systems inc' => '__KAM_ACCOUNTPHISH4,[l=1] __KAM_STOCKTIP142,[l=1]',
                              'movies online' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_TV2,[l=1]',
                              'refugees' => '__KAM_NIGERIAN4,[l=1]',
                              'cia val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'company' => '__KAM_NIGERIAN3,[l=1] __KAM_REP3_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'val xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'contact' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1]',
                              'partake in the deal' => '__DEAL,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_SUNGLASSES2,[l=1]',
                              'patch perfect seeds' => '__KAM_GRASS3,[l=0] __KAM_MEMBER3,[l=1] __KAM_SALE3,[l=1] __KAM_SALEA_3,[l=1] __KAM_SANTA3,[l=1] __KAM_VISION3,[l=1]',
                              'rapid thaw tray' => '__KAM_BAD_PRODUCT2,[l=0]',
                              'financial free' => 'FIN_FREE,[l=1] __DEAL,[l=1] __KAM_BITCOIN2,[l=1] __KAM_PATRIOT4,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1]',
                              'american' => '__KAM_PATRIOT3,[l=1]',
                              'mer lev som' => 'KAM_VIAGRA2,[l=0]',
                              'make custom suits' => '__KAM_LABEL3a,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __STOCK_TIP,[l=1]',
                              'val lev mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'som cia mer' => 'KAM_VIAGRA2,[l=0]',
                              '5k per day' => '__DAY_I_EARNED,[l=1] __KAM_TELEWORK1,[l=1]',
                              'customer' => '__KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_PHISH4_2,[l=1] __STOCK_TIP,[l=1]',
                              'bigger member' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX1,[l=1]',
                              'inability to release' => '__KAM_BENEFICIARY6,[l=0] __SUM_OF_FUND,[l=1]',
                              'exportation' => '__KAM_NIGERIAN2,[l=1]',
                              'makes $' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_TELEWORK1,[l=1]',
                              'looming bills' => '__KAM_DEBT1,[l=1]',
                              'over $500' => '__FRAUD_QFY,[l=1] __KAM_LOTTO3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1]',
                              'count of email' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST3_3,[l=1] __YOU_WON_01,[l=1]',
                              'mer amb lev' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'lev val xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'degree in any field' => '__KAM_UNIV11,[l=1] __KAM_UNIV2,[l=1]',
                              'cost' => '__FB_COST,[l=1]',
                              'found ur account' => '__DORMANT_ACCT,[l=1] __FOUND_YOU,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_URONLINE2,[l=1]',
                              ' heater' => '__KAM_FUN7,[l=1]',
                              'bidooka' => '__KAM_SWIPE4,[l=1]',
                              'mer xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'amb cia pro' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'full details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_INVEST3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'fever' => '__KAM_FUN7,[l=1]',
                              'need boyfriends' => '__DOS_BODY_FRI,[l=1] __KAM_FUN7,[l=1]',
                              'diet/detox' => '__DEAL,[l=1] __KAM_WEIGHT1,[l=1]',
                              'pocket' => '__KAM_REFI6,[l=1]',
                              'if you no longer wish to receive further offers' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_PACKAGE2,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'like to have friendship' => '__DOS_BODY_FRI,[l=1] __KAM_LED2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PIC3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'warranty' => '__KAM_REPAIR1_3,[l=1]',
                              '-verification' => '__KAM_BANK_3,[l=1] __TVD_PH_BODY_ACCOUNTS_PRE,[l=1]',
                              'many babe' => '__KAM_GALLERY4,[l=1]',
                              'man look as young' => '__KAM_HAIRTRANS3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'amb amb amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'val som val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'you being a foreigner' => '__FRAUD_XJR,[l=0] __KAM_PATRIOT3,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __LOTTO_DEPT,[l=1] __NOT_DEAD_YET,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'treatment' => '__KAM_GARAGE3,[l=1] __TRTMT_DEFILED,[l=1]',
                              'platform' => '__JMQ_REALESTATE3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __YOU_WON_02,[l=1]',
                              'download yourunreceived ' => '__DAY_I_EARNED,[l=1] __DECEASED,[l=1] __DLND_ATTACH,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __RELEASE_MESSAGES,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'collected judgments' => '__KAM_JUDGE1,[l=1] __KAM_JUDGE4,[l=0] __RECEIVE_BONUS,[l=1]',
                              'lev pro pro' => 'KAM_VIAGRA2,[l=0]',
                              'bed adventures' => '__DEAL,[l=1] __KAM_SEX04_2,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TOURS3,[l=1]',
                              'reachbase is committed to providing you with relevant busine' => 'KAM_REACHBASE,[l=0] __KAM_REP3_2,[l=1] __PILL_PRICE_01,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan mer amb' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'bigger' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'parts' => '__KAM_AUTO3,[l=1]',
                              'yard lights' => '__KAM_SOLAR3,[l=1]',
                              'currency' => '__KAM_BITCOIN2,[l=1]',
                              'you are receiving this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'cia pro pro' => 'KAM_VIAGRA2,[l=0]',
                              'seas account' => '__DORMANT_ACCT,[l=1] __FRAUD_JNB,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PHISH4_3,[l=1]',
                              ' winner' => 'DEAR_WINNER,[l=1] __AFF_LOTTERY,[l=0] __KAM_LOTTO6,[l=1] __hk_win_2,[l=1]',
                              'my name is dr' => '__FRAUD_QXX,[l=1] __JMQ_RESUME2,[l=0] __KAM_HOWRU2,[l=0] __KAM_INVEST2,[l=1]',
                              '4 of my card' => '__KAM_SHADYCC3,[l=0]',
                              'via cia mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'thousands' => '__KAM_MEMBER3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'free stock market outlook' => '__DOS_BODY_STOCK,[l=1] __FB_S_STOCK,[l=1] __KAM_PATRIOT3,[l=1] __KAM_STOCK2_1,[l=1] __KAM_STOCK2_3,[l=0] __KAM_TRIAL,[l=1] __KAM_WEED4,[l=1] __PILL_PRICE_01,[l=1] __STOCK_TIP,[l=1]',
                              'own a timeshare or condo' => '__KAM_LOAN3,[l=1] __KAM_TIME4,[l=1] __KAM_TIMESHARE2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'becoming our contract staff' => '__KAM_NIGERIAN4,[l=1] __KAM_REP3_2,[l=1]',
                              'peyg' => '__KAM_STOCKTIP133,[l=1]',
                              'you are receive this offer' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'no plastic surgery' => '__KAM_FAKEAD4,[l=0] __KAM_VISION3,[l=1]',
                              'we have sent ' => '__JMQ_WIRE3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __WE_PAID,[l=1] __YOU_WON_01,[l=1]',
                              'pro som cia' => 'KAM_VIAGRA2,[l=0]',
                              'som lev pro' => 'KAM_VIAGRA2,[l=0]',
                              ' months' => '__DOS_BODY_MON,[l=1] __KAM_CEP6,[l=1] __KAM_SKIN4,[l=1] __KAM_UNIV1B,[l=1] __KAM_UNIV2,[l=1]',
                              'som val amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'amb xan cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'top of msn' => '__KAM_SEO2,[l=1]',
                              '% will be mapped out' => '__I_WILL_YOU,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'mer cia cia' => 'KAM_VIAGRA2,[l=0]',
                              'xan via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'som via val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'amb lev mer' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'xan cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1]',
                              'cocomedia' => '__KAM_BADNAME1,[l=1] __KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_REP3_2,[l=1]',
                              'branded solutions' => '__KAM_CLOUD3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_LOAN3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'women will be funk' => '__I_WILL_YOU,[l=1] __KAM_QUOTA2,[l=1] __KAM_SEX05_2,[l=0] __KAM_SEX_EXPLICIT4,[l=1] __RECEIVE_BONUS,[l=1]',
                              'shared' => '__KAM_DROPBOX3,[l=1]',
                              'agms' => '__KAM_STOCKTIP132,[l=1]',
                              'pro val via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'to continue using your mailbox' => '__ACCESS_RESTORE,[l=1] __ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'invest' => '__INVEST_MONEY,[l=1] __KAM_NIGERIAN3,[l=1]',
                              'fly cheap in business class' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DISCAIR3,[l=0] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'complimentary information kit' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CLOUD4,[l=1] __KAM_CREDIT4,[l=1] __KAM_DIRECT3,[l=0] __KAM_DOMAIN2,[l=1] __KAM_GOVT3,[l=0] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'my next boyfriend' => '__DOS_BODY_FRI,[l=1] __KAM_PIC1,[l=1] __NEXT_OF_KIN,[l=1]',
                              'important notice from citizens' => '__KAM_CITIZEN2,[l=0] __KAM_FINGERHUT3,[l=1] __KAM_JURY4,[l=1] __KAM_NEWNOTICE1,[l=1] __KAM_NEWNOTICE2,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_2,[l=1] __KAM_STOCK2_2,[l=1]',
                              'million' => 'MILLION_HUNDRED,[l=1] MILLION_USD,[l=1] NA_DOLLARS,[l=1]',
                              'creditors' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DEBT1,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'deactivated' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_GIFT3,[l=1] __KAM_VERIZON6,[l=0] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'donnob.net' => '__KAM_DON3,[l=1] __KAM_REP3_2,[l=1]',
                              'pleased to inform' => '__KAM_DOMAIN2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REP3_2,[l=1] __YOU_WON_02,[l=1] __hk_win_4,[l=1]',
                              'commendable medicines' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_REP3_2,[l=1] __KAM_SEX04_1,[l=1]',
                              'som xan som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'omg!' => '__KAM_TVDOCTOR3,[l=1]',
                              'dear candidate' => 'DEAR_SOMETHING,[l=1]',
                              'levitra' => 'DRUG_ED_CAPS,[l=1] __DRUGS_ERECTILE_L,[l=1]',
                              'advertis' => 'KAM_ADVERT2,[l=1] __KAM_ADVERTISE3,[l=1] __THIS_AD,[l=1]',
                              'green fruit' => '__KAM_ANA1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'prefer not to receive these emails' => '__ADMAIL,[l=1] __DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_FUN2,[l=1] __KAM_LIST4,[l=1] __YOU_WON_01,[l=1]',
                              'best daily rx' => '__KAM_DRUG2_4,[l=1] __KAM_SEX2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'val cia pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'suspicion login' => '__SUSPICION_LOGIN,[l=1]',
                              'bontril' => '__DRUGS_DIET3,[l=1]',
                              'geheim' => '__HUSH_HUSH,[l=1]',
                              'ur website' => '__KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DRUG2_5,[l=1] __KAM_SEARCH3,[l=1] __KAM_WEB2,[l=1]',
                              'next of kin' => '__HK_SCAM_N2,[l=1] __KAM_BENEFICIARY3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_NIGERIAN4,[l=1] __NEXT_OF_KIN,[l=1]',
                              'amb mer lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'payment agency board' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_LOTTO4,[l=1] __KAM_PHISH2_6,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              ' tuesday open' => '__DAY_I_EARNED,[l=1] __DOS_BODY_TUE,[l=1] __PUMPDUMP_03,[l=1]',
                              'for your organi' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI3,[l=1] __KAM_REP3_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TO_YOUR_ORG,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'xan lev som' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'val xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'solution' => '__KAM_CLOUD3,[l=1] __KAM_LOAN3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'investment group' => '__INVEST_MONEY,[l=1] __KAM_BANK_2,[l=0] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __LOTTO_DEPT,[l=1] __SUM_OF_FUND,[l=1]',
                              'vitality' => '__KAM_SEX04_4,[l=1]',
                              'available' => '__KAM_MEMBER3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_REFI2,[l=1]',
                              'equifax report' => '__KAM_BADZIP3,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1]',
                              'foreign offshore bank' => '__FRAUD_TCC,[l=0] __JMQ_WIRE3,[l=1] __KAM_NIGERIAN2_7,[l=0] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __YOU_WON_02,[l=1]',
                              'less than half' => '__KAM_FUN5,[l=1] __KAM_WEB2_2,[l=0]',
                              'cancer' => '__AM_DYING,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_NIGERIAN1,[l=1]',
                              'lev som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'special bonus' => '__KAM_DRUG2_3,[l=1] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_SEX04_4,[l=1] __KAM_VISION3,[l=1] __RECEIVE_BONUS,[l=1]',
                              'india' => '__KAM_SEARCH3,[l=1]',
                              'premier clothing' => '__KAM_LABEL5,[l=0]',
                              'exasperated all the time' => '__DEAL,[l=1] __KAM_INSURE4,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URUNIT3A,[l=1]',
                              'xan amb lev' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'saw you by bjs' => '__KAM_URONLINE3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'processing rebates from home' => '__FEES,[l=1] __KAM_CLAIMS3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1] __LOTTO_DEPT,[l=1]',
                              'thicker' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'this message are not spam' => 'NOT_SPAM,[l=1] __ADMAIL,[l=1] __DEAL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __THIS_AD,[l=1]',
                              'xan xan pro' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              '100%' => '__KAM_MERCHANT3,[l=1]',
                              'give details' => '__FRAUD_JYG,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_INVEST3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __LOTTO_WIN_01,[l=1]',
                              'revers' => '__KAM_OCEANSBOUNTY3,[l=1]',
                              'right to carry' => '__KAM_2ND_2,[l=0] __KAM_DETOX3,[l=1] __KAM_PATRIOT3,[l=1]',
                              'cia som xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'pay' => '__FEES,[l=1] __PAY_YOU,[l=1]',
                              'in need of loan' => '__KAM_REFI2,[l=1]',
                              'nursing home directory' => '__KAM_DIRECT4,[l=1] __KAM_LIST1,[l=1] __KAM_NURSE3,[l=1] __KAM_REFI3,[l=1] __KAM_WINDOWS3,[l=1]',
                              ' years old' => '__JMQ_PICKUP4,[l=1] __KAM_FOUNTAINOFYOUTH3,[l=1] __KAM_OCEANSBOUNTY3,[l=1] __KAM_PIC2,[l=1]',
                              'quintuple an principal' => '__KAM_RBL_OBFU2,[l=1] __PUMPDUMP_01,[l=1]',
                              'late bills' => '__DECEASED,[l=1] __KAM_DEBT1,[l=1]',
                              'solar' => '__KAM_SOLAR3,[l=1]',
                              'records all with emails' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_LIST2,[l=1] __KAM_LIST4,[l=1] __KAM_REFI6,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __TVD_PH_BODY_02,[l=1] __YOU_WON_01,[l=1]',
                              'struggling with adhd' => '__KAM_ADHD3,[l=0]',
                              'convenient' => '__KAM_PROPERTY3,[l=1]',
                              'let me know when you recieve your money' => '__DECEASED,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __GAPPY_SALES_LEADS,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_CHECK2,[l=0] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'counts, pricing' => '__KAM_LIST3_3,[l=1]',
                              'been mos since we have chatted' => '__KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __KAM_URZEST4,[l=0] __YOU_WON_01,[l=1]',
                              'credit card debt' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DEBT1,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1] __KAM_VERIZON7,[l=0]',
                              'x a n a x' => '__KAM_VIAGRA1,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'som amb val' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'this is a commericial' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __KAM_REP3_2,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'kitchen gadget' => '__KAM_FUN7,[l=1] __KAM_KITCHEN3,[l=1] __KAM_PRODUCT2_2,[l=1]',
                              'information about the list' => '__DEAL,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BACK3,[l=1] __KAM_CELL3,[l=1] __KAM_CREDIT4,[l=1] __KAM_DOMAIN2,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_6,[l=1] __KAM_REP3_2,[l=1] __KAM_REVIEW3,[l=1] __KAM_SECURITY3,[l=1] __KAM_SETTLEMENT3,[l=1] __KAM_VIAGRA9D,[l=1] __LOTTO_WIN_01,[l=1] __YOUR_BANK,[l=1] __YOU_WON_02,[l=1]',
                              'united states dollars' => 'MILLION_USD,[l=1] __FRAUD_LTX,[l=1] __KAM_COVID5,[l=1] __KAM_NIGERIAN1,[l=1] __LOTTO_DEPT,[l=1] __UN,[l=1]',
                              '% yearly' => '__JMQ_PICKUP4,[l=1] __KAM_INVEST3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'popular keywords' => '__KAM_SEARCH3,[l=1] __KAM_SEARCH4,[l=1]',
                              'professionals lead' => '__KAM_GARAGE3,[l=1] __KAM_LIST3_2,[l=1]',
                              'individual' => '__LUCKY_WINNER,[l=1]',
                              'silky smooth skin' => '__KAM_SKIN4,[l=1]',
                              'assasination' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __KAM_PATRIOT3,[l=1]',
                              'meet you in private' => '__HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_HOWRU3,[l=0] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'flash player code: ' => '__KAM_DRUG2_5,[l=1] __KAM_FLASH1,[l=1]',
                              'be smart, buy your drugs' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ANDROGEL3,[l=1] __KAM_FUN7,[l=1] __KAM_INSURE4,[l=1] __KAM_PILLS2,[l=0] __KAM_REFI3,[l=1] __KAM_REMEMBERWHEN3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'shark tank' => '__KAM_SHARKTANK_BODY,[l=0]',
                              'lift your love' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX04_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'burglaries' => '__KAM_ALARM2,[l=1]',
                              'not criminal' => '__KAM_ARREST2,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_SECURITY3,[l=1]',
                              'amb via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'new monthly payment' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __DOS_BODY_MON,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CEP6,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_MERCHANT3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __KAM_PHISH2_6,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1] __KAM_UNIV2,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'this is an (adver' => 'KAM_ADVERT2,[l=1] __DEAL,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'anonymous packing' => '__KAM_BACK3,[l=1] __KAM_DRUG2_6,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'remov' => '__SUBSCRIPTION_INFO,[l=1]',
                              'submit' => '__KAM_DOMAIN1,[l=1] __KAM_FAKEVOUCHER4,[l=1]',
                              'ee;r%a!<%k9-9p' => '__JAPANESE_UCE_BODY,[l=1]',
                              'acai berry edge' => '__KAM_ANA1,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WEIGHT2,[l=1]',
                              'amb val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'via som amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'without' => '__KAM_MARIJUANA3,[l=1] __WITHOUT_EFFORT,[l=1]',
                              'top of google' => '__KAM_SEO2,[l=1] __KAM_SEO4,[l=1]',
                              'amb xan via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __DRUGS_ANXIETY_XAN,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'revenue' => '__KAM_SEARCH4,[l=1]',
                              'chuck mullaney' => '__KAM_EBAY2,[l=0]',
                              'mer cia via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'updated' => '__KAM_CREDIT4,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              'you were recently invited' => '__KAM_AUTONEW3,[l=1] __KAM_CHOSEN3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              '&#x200b;' => '__KAM_ZWNJ3,[l=0]',
                              'val mer lev' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'affordable health coverage' => 'PRICES_ARE_AFFORDABLE,[l=1] __FRAUD_QFY,[l=1] __KAM_AUTONEW2,[l=1] __KAM_HEALTH2,[l=1] __KAM_HEALTH2_1,[l=0] __KAM_INSURE2,[l=1] __KAM_JOINT3,[l=1] __KAM_MEDICARE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_REFI2,[l=1] __YOU_WON_02,[l=1]',
                              'escolhidos al azar' => '__RANDOM_PICK,[l=1]',
                              'pro som via' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'energy' => '__KAM_NUWAVE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_WINDOWS3,[l=1]',
                              'adt is number one' => '__KAM_ALARM2,[l=1] __LOTTO_WIN_01,[l=1]',
                              'interested in acquiring' => 'KAM_ADVERT2,[l=1] __BACK_SCRATCH,[l=1] __KAM_DOMAIN2,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE2,[l=1] __KAM_LISTSALE1,[l=0] __KAM_SNORE3,[l=1]',
                              'act now' => 'ACT_NOW_CAPS,[l=1]',
                              'winning' => '__KAM_POLITICS2,[l=1]',
                              'irs offer' => '__KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __KAM_TAX3,[l=1]',
                              'process rebates from home' => '__KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1]',
                              'low email storage' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_BOXQUOTA,[l=1] __KAM_ENGINEER2,[l=1] __STOCK_TIP,[l=1] __YOU_WON_01,[l=1]',
                              'zusammenarbeit' => '__FRAUD_XWW,[l=1]',
                              'skelaxin' => '__DRUGS_MUSCLE5,[l=1]',
                              'xan cia cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'mer via lev' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'girls gallery' => '__KAM_GALLERY2,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'size of their ' => 'BODY_ENHANCEMENT2,[l=1] TVD_INCREASE_SIZE,[l=1] __DEAL,[l=1] __KAM_BACK2,[l=1] __KAM_URUNIT5,[l=1]',
                              'milf selfies' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_SKIN4,[l=1]',
                              'activation' => '__KAM_ACCOUNTPHISH3,[l=1] __TVD_PH_BODY_ACCOUNTS_POST,[l=1]',
                              '000 usd monthly' => '__DOS_BODY_MON,[l=1] __KAM_AUTONEW2,[l=1] __KAM_CEP6,[l=1] __KAM_COVID5,[l=1] __KAM_FAKEWEST5,[l=1] __KAM_FINGERHUT3,[l=1] __KAM_JOB2_4,[l=1] __KAM_MERCHANT3,[l=1] __KAM_SKIN4,[l=1] __KAM_STUDENT3,[l=1] __KAM_UNIV2,[l=1]',
                              'extreme access' => '__KAM_GALLERY2,[l=1]',
                              'business' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'i will never contact you again if you go here' => '__CONTACT_ATTY,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __JMQ_TRACKR3,[l=1] __KAM_HOSE3,[l=1] __KAM_INTRUDE,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_QUOTA2,[l=1] __KAM_REPAIR2_3,[l=1] __KAM_SALEA_3,[l=1] __NOT_SCAM,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'destroy all your secrets' => '__DECEASED,[l=1] __DESTROY_ME,[l=1] __DESTROY_YOU,[l=1] __GAPPY_SALES_LEADS,[l=1] __HUSH_HUSH,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEIGHT2,[l=1] __NEVER_HEAR_EN,[l=0] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'pro val cia' => 'KAM_VIAGRA2,[l=0] __DRUGS_ERECTILE5,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'your access is' => '__ACCOUNT_UPGRADE,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'illusional rug' => '__KAM_HOLIDAY2020_2,[l=0]',
                              'gasoline cards' => '__KAM_GAS1,[l=1]',
                              'remove from mindtcommunications' => '__KAM_BADUNSUB,[l=0] __KAM_REP3_2,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'get rich quick' => '__KAM_TELEWORK6,[l=1]',
                              'som som amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'seeks fund' => '__KAM_INVEST3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'member incentive program' => '__KAM_DETOX3,[l=1] __KAM_GIFT5,[l=1] __KAM_MM_FOREX_1,[l=1] __KAM_REFI3,[l=1] __KAM_SOLAR3,[l=1] __KAM_TAX3,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'wood milk' => '__KAM_COVID3_3,[l=1] __KAM_DUTCHGLOW3,[l=1]',
                              'alliance for retirement prosperity association' => '__KAM_PATRIOT3,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_WTA2,[l=1] __YOU_WON_02,[l=1]',
                              'all cele' => '__DRUGS_ERECTILE5,[l=1] __KAM_GALLERY4,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'import' => '__KAM_NIGERIAN2,[l=1]',
                              'drop me a line at' => '__DOS_DROP_ME_A_LINE,[l=1] __KAM_REFI6,[l=1] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __KAM_WEIGHT1,[l=1]',
                              'new partner from uk' => '__KAM_GALLERY4,[l=1] __KAM_NIGERIAN4,[l=1]',
                              'thousands with ebay' => '__KAM_EBAY1,[l=0] __KAM_MEMBER3,[l=1] __KAM_REFI2,[l=1] __KAM_REPAIR1_3,[l=1]',
                              'assist me in transferring those funds' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __KAM_COVID3_4,[l=0] __KAM_NIGERIAN2,[l=1] __SUM_OF_FUND,[l=1] __WIRE_XFR,[l=1] __YOUR_FUND,[l=1]',
                              'receive my fund' => '__KAM_INVEST3,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1]',
                              'pay for performance' => '__FEES,[l=1] __KAM_DOMAIN2,[l=1] __KAM_FLAG3,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PACKAGE2,[l=1] __KAM_PATRIOT3,[l=1] __PAY_YOU,[l=1] __YOU_WON_02,[l=1]',
                              'sic' => '__KAM_CRYPTO1,[l=1]',
                              'pro amb som' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'euro-pw' => '__HK_LOTTO_2,[l=1] __KAM_COVID5,[l=1]',
                              'times your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME4,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'work experience degree' => '__KAM_CAREER3,[l=1] __KAM_UNIV2,[l=1] __KAM_UNIV7,[l=1]',
                              'metallic' => '__KAM_SEX_EXPLICIT4,[l=1] __TRUNK_BOX,[l=1]',
                              'you\'re received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'colon cleanse' => '__KAM_WEIGHT2,[l=1]',
                              'killers' => '__FRAUD_PTX,[l=1]',
                              'earn' => '__RECEIVE_BONUS,[l=1]',
                              'discretion' => '__HUSH_HUSH,[l=1]',
                              'complete details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_REP3_2,[l=1] __KAM_SEARCH3,[l=1] __LOTTO_WIN_01,[l=1]',
                              'slim' => '__KAM_WEIGHT1,[l=1]',
                              'suspended' => '__KAM_PHISH4_2,[l=1]',
                              'conspiracy' => '__KAM_BLOOD3,[l=1]',
                              'you have receive this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_POLITICS2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'remove space to make the link' => '__DEAL,[l=1] __DOS_LINK,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_STAR1,[l=0] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'try this trick' => '__DEAL,[l=1] __KAM_FUN2,[l=1] __KAM_WEIRDTRICK2,[l=1] __THIS_AD,[l=1]',
                              'corrupt officials' => '__KAM_BENEFICIARY6,[l=0] __KAM_REFI3,[l=1] __KAM_SALE3,[l=1]',
                              'vous \\303\\252tes' => '__YOU_WON_04,[l=1]',
                              'guarantee the safety of your ' => '__DEAL,[l=1] __DECEASED,[l=1] __FEES,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_07,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'transunion,' => '__DOS_BODY_SUN,[l=1] __KAM_CREDIT2,[l=1]',
                              'you are receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'unauthori' => '__KAM_PHISH2_4,[l=1]',
                              'online marketing consultant' => 'FREE_QUOTE_INSTANT,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_BACKUP3,[l=1] __KAM_DOMAIN2,[l=1] __KAM_ENGINEER3,[l=1] __KAM_INVEST2,[l=1] __KAM_LIST3_2,[l=1] __KAM_PATRIOT3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_SEARCH4,[l=1] __KAM_WEB3,[l=1] __KAM_WEBINAR4,[l=1]',
                              'via amb val' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'pro lev lev' => 'KAM_VIAGRA2,[l=0]',
                              'val via amb' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'une mallette metallique' => '__KAM_SEX_EXPLICIT4,[l=1] __TRUNK_BOX,[l=1]',
                              'collections' => '__KAM_TAX3,[l=1] __KAM_TIME2,[l=1] __RECEIVE_BONUS,[l=1]',
                              'deceased client' => '__DECEASED,[l=1] __KAM_BANK_2,[l=0] __KAM_BENEFICIARY6,[l=0]',
                              'view file in attach' => '__JMQ_RESUME3,[l=1] __KAM_AUTONEW3,[l=1] __KAM_FAKEDELIVER1,[l=1] __KAM_HEALTH2,[l=1]',
                              'proactiv' => '__KAM_ACNE3,[l=0]',
                              'val val val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'will you be killed' => '__FRAUD_PTS,[l=1] __FRAUD_PTX,[l=1] __I_WILL_YOU,[l=1] __KAM_HEART3,[l=1] __KAM_QUOTA2,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'highly encrypted' => '__KAM_PROFORMA3,[l=0]',
                              'mer mer amb' => 'KAM_VIAGRA2,[l=0] __KAM_COMPROMISED3,[l=1] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA9B,[l=1]',
                              'difunt' => '__DECEASED,[l=1]',
                              'suppress appetite' => '__KAM_HOODIA3,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_WEIGHT2,[l=1]',
                              'blood pressure low' => '__KAM_BLOOD6,[l=0] __KAM_DIABETES1,[l=1] __KAM_SKIN4,[l=1]',
                              'reliable partner' => '__KAM_DRUG2_6,[l=1] __KAM_INVEST2,[l=1] __KAM_TV1,[l=1]',
                              'send you more details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_BENEFICIARY6,[l=0] __KAM_HOME3,[l=1] __KAM_INVEST3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'to remove this suspens' => '__ACCESS_RESTORE,[l=1] __DEAL,[l=1] __KAM_TAX3,[l=1] __SUBSCRIPTION_INFO,[l=1] __THIS_AD,[l=1]',
                              'knowledge' => '__KAM_CEP2,[l=1]',
                              'retail' => '__KAM_SWIPE3,[l=1]',
                              'schlong' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'v a l i u m' => '__KAM_VIAGRA1,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1]',
                              'val pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'all of the major search' => '__DEAL,[l=1] __KAM_REVIEW3,[l=1] __KAM_SEARCH3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'lev som pro' => 'KAM_VIAGRA2,[l=0]',
                              'come by our web site' => '__KAM_DRUG2_5,[l=1] __KAM_REP3_2,[l=1]',
                              'have not met' => '__KAM_BUS3,[l=0] __KAM_NIGERIAN3,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __YOU_WON_01,[l=1]',
                              'credit' => '__KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'gap coverage' => '__FRAUD_QFY,[l=1] __KAM_AUTONEW2,[l=1] __KAM_INSURE2,[l=1] __KAM_MEDICARE4,[l=1] __KAM_REFI2,[l=1] __KAM_RXPLAN3,[l=0]',
                              'related domain' => '__DECEASED,[l=1] __KAM_DOMAIN1,[l=1] __KAM_DOMAIN3,[l=1] __KAM_DOMAIN_SALE1,[l=1]',
                              'reputation' => '__KAM_BACK1,[l=1]',
                              'anonymous' => '__KAM_BACK3,[l=1]',
                              'o tonight' => '__KAM_DATINGTIPS3,[l=1] __KAM_URONLINE1,[l=1]',
                              'am not spamming' => 'KAM_ADVERT2,[l=1]',
                              'no longer like to receive' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_FUN2,[l=1] __KAM_LED2,[l=1] __KAM_PACKAGE2,[l=1]',
                              'healthcare' => '__KAM_ANDROGEL3,[l=1] __KAM_JOINT3,[l=1] __KAM_VISION3,[l=1]',
                              'trading at such a cheap' => '__KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __PUMPDUMP_10,[l=1]',
                              'termination of your email' => '__ADMAIL,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ENGINEER2,[l=1] __KAM_INSURE4,[l=1] __KAM_PATRIOT3,[l=1] __KAM_QUOTA2,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              '-images click' => 'KAM_ADVERT2,[l=1] __JMQ_HEARINGLOSS3,[l=1] __KAM_ACCOUNTPHISH4,[l=1]',
                              'executive secretary' => '__HUSH_HUSH,[l=1] __KAM_LOTTO4,[l=1] __KAM_WEBINAR4,[l=1] __KAM_WEIGHT2,[l=1]',
                              'women' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'operate' => '__FRAUD_XWW,[l=1] __KAM_INSURE4,[l=1]',
                              'shipment' => '__KAM_FAKEDELIVER1,[l=1]',
                              'unsubscribe here' => 'REMOVE_BEFORE_LINK,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'pennies on the dollar' => '__DEAL,[l=1] __KAM_COVID5,[l=1] __KAM_REAL2_3,[l=1] __KAM_SWIPE3,[l=1]',
                              'xan xan xan' => 'KAM_VIAGRA2,[l=0] __DRUGS_ANXIETY_XAN,[l=1]',
                              'this offer only for united states' => '__DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_PATRIOT3,[l=1] __KAM_SALE3,[l=1] __LOTTO_DEPT,[l=1] __PDS_OFFER_ONLY_AMERICA,[l=0] __THIS_AD,[l=1] __UN,[l=1] __YOU_WON_02,[l=1]',
                              'cia som pro' => 'KAM_VIAGRA2,[l=0]',
                              'lord' => '__KAM_JESUS1,[l=1]',
                              'perfect binary option' => '__KAM_MEMBER3,[l=1] __KAM_SALE3,[l=1] __KAM_SALEA_3,[l=1] __KAM_SANTA3,[l=1] __KAM_VISION3,[l=1] __PERFECT_BINARY,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'shlong' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1]',
                              'screening' => '__KAM_ARREST2,[l=1]',
                              'costs' => '__FB_COST,[l=1] __FRAUD_QFY,[l=1]',
                              'greenstone holdings' => '__KAM_ANA1,[l=1] __KAM_PHISH2_4,[l=1] __KAM_STOCKTIP131,[l=1] __STOCK_TIP,[l=1]',
                              'ivory coast' => '__IVORY_COAST,[l=1] __KAM_BENEFICIARY4,[l=0]',
                              'free bonus' => '__KAM_SEX04_4,[l=1] __KAM_TRIAL,[l=1] __PILL_PRICE_01,[l=1] __RECEIVE_BONUS,[l=1]',
                              'enable me disclose' => 'DIET_1,[l=1] __KAM_DISCLOSE1,[l=0] __KAM_WEIGHT1,[l=1]',
                              'employ you' => '__KAM_INVEST3,[l=1] __RECEIVE_BONUS,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'bank in ghana' => '__GHANA,[l=1] __HK_SCAM_S25,[l=1] __JMQ_WIRE3,[l=1] __KAM_BENEFICIARY4,[l=0] __KAM_INVEST4,[l=1] __KAM_NIGERIAN2_7,[l=0]',
                              'cia cia val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'your e' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_b,[l=1]',
                              'pro pro cia' => 'KAM_VIAGRA2,[l=0]',
                              'more details' => '__KAM_ACCOUNTPHISH3,[l=1] __KAM_HOME3,[l=1] __KAM_INVEST3,[l=1] __KAM_LIST3_3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_NOMORE1,[l=1] __KAM_NOMORE2,[l=1] __KAM_SNORE3,[l=1] __KAM_STOCK2_1,[l=1] __LOTTO_WIN_01,[l=1]',
                              'clock' => '__KAM_OCEANSBOUNTY3,[l=1]',
                              '[dot]com' => '__KAM_HIDDEN_URI1,[l=1] __KAM_REP3_2,[l=1]',
                              'you\'re receiving this advertisement' => 'EXCUSE_24,[l=1] KAM_ADVERT2,[l=1] __ADMITS_SPAM,[l=1] __DEAL,[l=1] __KAM_ADVERTISE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'prescr' => 'NO_PRESCRIPTION,[l=1]',
                              'lev cia val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'fixed' => '__KAM_REFI5,[l=1]',
                              'private e' => '__FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_URONLINE3,[l=1]',
                              'concerning the money' => '__DEAL,[l=1] __DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __FRAUD_KJV,[l=0] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1]',
                              'pu$$y' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'fucking' => 'LIVE_PORN,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'contacting' => '__CONTACT_ATTY,[l=1] __CONTACT_YOU,[l=1] __FRAUD_JYG,[l=1]',
                              'you are received this offer' => 'EXCUSE_24,[l=1] __DAY_I_EARNED,[l=1] __DEAL,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'not spammer' => '__KAM_LIST3_4,[l=1]',
                              'investment advice' => 'INVESTMENT_ADVICE,[l=1] __INVEST_MONEY,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_STOCK2_2,[l=1] __SUM_OF_FUND,[l=1]',
                              'star special' => '__KAM_DRUG2_3,[l=1] __KAM_HOLIDAY3,[l=0] __KAM_INSURE2,[l=1] __KAM_KITCHEN3,[l=1] __KAM_VISION3,[l=1]',
                              'shed fat' => '__KAM_WEIGHT1,[l=1]',
                              'bigwigs' => '__KAM_POLITICS2,[l=1]',
                              'penis so huge and heavy' => 'BODY_ENHANCEMENT,[l=1] BODY_ENHANCEMENT2,[l=1] __KAM_SEX4,[l=0]',
                              'tired this tonight' => '__DEAL,[l=1] __KAM_DATINGTIPS3,[l=1] __KAM_PIC1,[l=1] __KAM_SNORE3,[l=1] __THIS_AD,[l=1]',
                              'do your part' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_KN_2,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'dealer' => '__DEAL,[l=1] __KAM_AUTO3,[l=1] __KAM_DRUG2_3,[l=1] __KAM_NIGERIAN2_2,[l=1] __KAM_SUNGLASSES2,[l=1]',
                              'this is an ad' => '__DEAL,[l=1] __KAM_FUN3,[l=1] __THIS_AD,[l=1] __TVD_PH_BODY_05,[l=1]',
                              'donate the sum' => '__DEAL,[l=1] __KAM_BENEFICIARY3,[l=1]',
                              'quintuple your investment' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __INVEST_MONEY,[l=1] __KAM_INSURE4,[l=1] __KAM_NIGERIAN1,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_RBL_OBFU2,[l=1] __KAM_REFI3,[l=1] __KAM_STOCK2_2,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __SUM_OF_FUND,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'database organization' => '__KAM_BACK3,[l=1] __KAM_LIST3_3,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_REP3_2,[l=1]',
                              'amb pro val' => 'KAM_VIAGRA2,[l=0] __KAM_VIAGRA7C,[l=1] __KAM_VIAGRA7D,[l=1] __KAM_VIAGRA9B,[l=1] __KAM_VIAGRA9C,[l=1]',
                              'gum problem' => '__KAM_FUN7,[l=1] __KAM_GOVT4,[l=1]',
                              'good trader' => '__KAM_SEX_EXPLICIT4,[l=1] __KAM_STOCK2_1,[l=1] __KAM_STOCK2_4,[l=0] __KAM_WEIGHT1,[l=1]',
                              'talent' => '__KAM_SINGING3,[l=1]',
                              'i am prince' => '__FRAUD_QXX,[l=1] __KAM_COMPROMISED3,[l=1] __KAM_COVID3_1,[l=0]',
                              'for pennies' => '__KAM_PATRIOT3,[l=1] __KAM_REAL2_3,[l=1] __KAM_SWIPE3,[l=1] __YOU_WON_02,[l=1]',
                              'while on vacation' => '__BOUNCE_OOO_CB2,[l=1] __KAM_AQUA3,[l=1]',
                              ' r a' => '__KAM_VIAGRA4B,[l=1]',
                              'bbb' => '__KAM_FAKEBBB2,[l=1]',
                              'ausgleich' => '__COMPENSATION,[l=1]',
                              'preferred' => '__JMQ_REALESTATE3,[l=1]',
                              '&pound;' => '__KAM_UKINV4,[l=0]',
                              'time promotion' => 'ONE_TIME,[l=1] __KAM_LOTTO4,[l=1] __KAM_SEO6,[l=1] __KAM_TIME4,[l=1] __THIS_AD,[l=1]',
                              'you receiving this paid' => 'EXCUSE_24,[l=1] __DEAL,[l=1] __FEES,[l=1] __KAM_POLITICS2,[l=1] __RECEIVE_BONUS,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'payment center' => '__ACH_CANCELLED_02,[l=1] __ACH_CANCELLED_03,[l=1] __FEES,[l=1] __JMQ_DROPBOX3,[l=1] __JMQ_WIRE2,[l=1] __KAM_CLAIMS3,[l=1] __KAM_COVID3,[l=1] __KAM_CREDIT2,[l=1] __KAM_GIFT4,[l=1] __KAM_NIGERIAN2_3,[l=1] __KAM_PHISH2_6,[l=1] __KAM_SWIPE4,[l=1] __LOTTO_DEPT,[l=1] __LOTTO_WIN_01,[l=1] __PAY_YOU,[l=1] __YOUR_FUND,[l=1]',
                              'that\'s my photo' => '__KAM_PIC4,[l=1] __KAM_PIC5,[l=0]',
                              'statements' => '__KAM_FDA1,[l=1]',
                              ' wednesday first thing' => '__DAY_I_EARNED,[l=1] __DOS_BODY_WED,[l=1] __PUMPDUMP_03,[l=1]',
                              'stretch but not kink' => '__KAM_FLEXHOSE3,[l=1]',
                              'dying' => '__AM_DYING,[l=1]',
                              'email from third party advertisers' => 'KAM_ADVERT2,[l=1] __ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ADVERTISE3,[l=1] __KAM_ENGINEER2,[l=1] __KAM_SPAMKING3,[l=1] __THIS_AD,[l=1] __YOU_WON_01,[l=1]',
                              ' first thing tomorrow' => '__PUMPDUMP_03,[l=1]',
                              'time offer' => 'ONE_TIME,[l=1] __KAM_DOMAIN3,[l=1] __KAM_LOAN3,[l=1] __KAM_SALE3,[l=1] __KAM_TIME4,[l=1]',
                              'physical property holdings' => '__KAM_CRYPTO1,[l=1] __KAM_PHISH2_4,[l=1] __KAM_REAL2_4,[l=1] __KAM_STOCKTIP127,[l=1]',
                              'vital documents' => '__FRAUD_UOQ,[l=0]',
                              'collect your prize' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __LOTTO_WIN_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1] __hk_win_n,[l=1]',
                              'dent' => '__DECEASED,[l=1]',
                              'deborah brown' => '__KAM_USB1,[l=0]',
                              'reduce your appetite' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_CLOUD3,[l=1] __KAM_HOODIA3,[l=1] __KAM_INSURE4,[l=1] __KAM_LABEL3b,[l=1] __KAM_LABEL8,[l=1] __KAM_PET3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'benefit acquiring' => '__BACK_SCRATCH,[l=1] __KAM_DOMAIN_SALE4,[l=1]',
                              'low price' => 'LOW_PRICE,[l=1] __FOR_SALE_PRC_100K,[l=1] __FOR_SALE_PRC_10K,[l=1] __FOR_SALE_PRC_1K,[l=1] __KAM_GIFT3,[l=1] __KAM_INK1,[l=1] __KAM_TIME5,[l=1]',
                              'request a brochure' => '__KAM_HOLIDAY3,[l=0] __KAM_VIAGRA4A,[l=1] __KAM_VIAGRA4B,[l=1] __URG_BIZ,[l=1]',
                              'duet of the year' => '__DEAL,[l=1] __JMQ_PICKUP4,[l=1] __KAM_WEIGHT1,[l=1]',
                              'prolonging your size' => 'BODY_ENHANCEMENT2,[l=1] __DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_REFI3,[l=1] __KAM_SEX05_2,[l=0] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_URUNIT2,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'money gram' => '__DOS_BODY_MON,[l=1] __FRAUD_JYG,[l=1] __I_WILL_YOU,[l=1] __KAM_ACCOUNTPHISH3,[l=1] __KAM_BITCOIN2,[l=1] __KAM_NIGERIAN5,[l=1] __KAM_VIAGRA9A,[l=1]',
                              'x the brightness' => '__DEAL,[l=1] __KAM_DETOX3,[l=1] __KAM_LED2,[l=1] __KAM_PATRIOT3,[l=1]',
                              'heritage' => '__MY_FORTUNE,[l=1]',
                              'private message' => '__ADMAIL,[l=1] __FRAUD_AON,[l=1] __FRAUD_ETX,[l=1] __HUSH_HUSH,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_PRIV1,[l=0] __KAM_QTJARS4,[l=1]',
                              'mail sweepstake' => '__ADMAIL,[l=1] __GAPPY_SALES_LEADS,[l=1] __HK_LOTTO_BALLOT,[l=1] __KAM_ACCOUNTPHISH4,[l=1] __YOU_WON_01,[l=1]',
                              'cut cleaning tim' => '__KAM_MOP3,[l=1]',
                              'protect your family' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_ALARM2,[l=1] __KAM_ANCESTOR3,[l=1] __KAM_INSURE2,[l=1] __KAM_INSURE4,[l=1] __KAM_RECALL3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'annual election' => '__KAM_MEDICARE3,[l=1] __KAM_POLITICS2,[l=1]',
                              'not traceable' => '__KAM_NIGERIAN5,[l=1]',
                              ' less 10%' => '__FOR_SALE_LTP,[l=1]',
                              'lev mer som' => 'KAM_VIAGRA2,[l=0]',
                              'hotstreak plug' => '__KAM_BAD_PRODUCT2,[l=0]',
                              'security storage house' => '__FEES,[l=1] __FRAUD_IRJ,[l=0] __KAM_ACCOUNTPHISH4,[l=1] __KAM_ALARM2,[l=1] __KAM_GIFT5,[l=1] __KAM_KIWIBANK3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_PAYPAL3D,[l=1] __KAM_PHISH2_7,[l=1] __KAM_PHISH4_3,[l=1] __STOCK_TIP,[l=1] __TRUNK_BOX,[l=1]',
                              'piloting the business' => '__DEAL,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_DOMAIN1,[l=1] __KAM_INSURE2,[l=1] __KAM_LOAN3,[l=1] __KAM_MERCHANT2,[l=1] __KAM_MERCHANT3,[l=1] __KAM_NIGERIAN4,[l=1] __KAM_WEB3,[l=1] __TRAVEL_BUSINESS,[l=1] __URG_BIZ,[l=1]',
                              'donald trump' => '__KAM_TRUMPCOIN1,[l=0]',
                              'or still jaded all the time' => '__DEAL,[l=1] __KAM_SEX_EXPLICIT4,[l=1] __KAM_TIME4,[l=1] __KAM_URZEST2,[l=0]',
                              'activities' => '__KAM_PHISH4_2,[l=1]',
                              'reliable source' => '__KAM_COVID3_2,[l=0] __KAM_DRUG2_6,[l=1] __KAM_TV1,[l=1]',
                              'kinky watersports' => '__KAM_SEX_EXPLICIT4,[l=1]',
                              'no hidden costs' => '__FB_COST,[l=1] __FRAUD_QFY,[l=1] __KAM_REFI2,[l=1] __KAM_SPY3,[l=1]',
                              'healthy energy boost' => '__KAM_FUN7,[l=1] __KAM_JOINT3,[l=1] __KAM_NUWAVE3,[l=1] __KAM_SOLAR3,[l=1] __KAM_WEIGHT1,[l=1] __KAM_WINDOWS3,[l=1]',
                              'lev via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'instant traffic and sales' => 'FREE_QUOTE_INSTANT,[l=1] __KAM_ADVERT2,[l=1] __KAM_DRUG2_3,[l=1] __KAM_LOAN3,[l=1]',
                              'sex stim' => '__KAM_DRUG2_3,[l=1] __KAM_SEX_EXPLICIT4,[l=1]',
                              'heating' => '__KAM_WINDOWS3,[l=1]',
                              'pimsleur approach' => '__KAM_BADNAME1,[l=1] __KAM_COVID5,[l=1] __KAM_LANG3,[l=1]',
                              'remember' => '__KAM_REMEMBERWHEN2,[l=1]',
                              'control your destiny' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_INSURE4,[l=1] __KAM_NUMEROLOGY3,[l=0] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TOLL3,[l=1] __KAM_WEBINAR4,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'satisfied with their size' => 'BODY_ENHANCEMENT2,[l=1] __DEAL,[l=1] __DOS_BODY_SAT,[l=1] __KAM_BACK2,[l=1] __KAM_SEX4,[l=0]',
                              'cia via mer' => 'KAM_VIAGRA2,[l=0] VIA_GAP_GRA,[l=1]',
                              'classified' => '__KAM_ACCOUNTPHISH3,[l=1]',
                              'assistance' => '__URG_BIZ,[l=1] __YOU_ASSIST,[l=1]',
                              'medication' => '__KAM_DRUG2_3,[l=1] __KAM_DRUG2_4,[l=1] __KAM_MED1,[l=1] __KAM_REMEMBERWHEN3,[l=1]',
                              'process rebates at home' => '__KAM_REFI3,[l=1] __KAM_TELEWORK5,[l=1] __KAM_WINDOWS3,[l=1]',
                              'times your principle' => '__DECEASED,[l=1] __GAPPY_SALES_LEADS,[l=1] __KAM_GALLERY4,[l=1] __KAM_INSURE4,[l=1] __KAM_LOAN3,[l=1] __KAM_REFI3,[l=1] __KAM_STUDENT3,[l=1] __KAM_TIME4,[l=1] __KAM_TOLL3,[l=1] __PUMPDUMP_01,[l=1] __RECEIVE_BONUS,[l=1] __YOUR_FUND,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]',
                              'secret arrangement' => '__HK_SCAM_N16,[l=1] __HUSH_HUSH,[l=1] __KAM_WEIGHT2,[l=1]',
                              'audio message' => '__ADMAIL,[l=1] __KAM_PAPERLESS3,[l=1] __KAM_PHISH4_2,[l=1] __KAM_VM4,[l=1]',
                              'roi' => '__KAM_ADVERT1,[l=1]',
                              'do not deposit' => '__ACH_CANCELLED_02,[l=1] __DORMANT_ACCT,[l=1] __KAM_RUIN1,[l=0]',
                              'card direct www address below' => '__KAM_CARD2,[l=1] __KAM_DIRECT4,[l=1] __KAM_REP2,[l=1]',
                              'attendee list' => '__KAM_LIST3_2,[l=1] __KAM_LIST3_4,[l=1] __KAM_LIST4,[l=1] __KAM_VIAGRA9D,[l=1]',
                              'easy cash' => '__KAM_FAKEVOUCHER2,[l=1] __KAM_STOCK2_2,[l=1] __KAM_TIMESHARE2,[l=1]',
                              'enter' => '__KAM_GIFT4,[l=1]',
                              'officer' => '__KAM_NIGERIAN2_3,[l=1] __KAM_SALE3,[l=1]',
                              'attention' => '__KAM_FAKEDELIVER1,[l=1]',
                              'cia mer som' => 'KAM_VIAGRA2,[l=0]',
                              'bad credit' => 'BAD_CREDIT,[l=1] __KAM_BADCRED_1,[l=0] __KAM_CREDIT2,[l=1] __KAM_CREDIT3,[l=1] __KAM_CREDIT4,[l=1] __KAM_NEW_CREDITCARD3,[l=1] __KAM_NIGERIAN2,[l=1] __KAM_PHISH4_3,[l=1]',
                              'to_unsubscribe' => '__OBFU_UNSUB_UL,[l=1] __SUBSCRIPTION_INFO,[l=1]',
                              'first page in yahoo' => '__KAM_PAPERLESS3,[l=1] __KAM_SEO2,[l=1]',
                              'you have been recently chosen' => '__KAM_AUTONEW3,[l=1] __KAM_CHOSEN3,[l=1] __KAM_INSURE2,[l=1] __KAM_NIGERIAN3,[l=1] __KAM_PAYMENT_LOWERED2,[l=1] __KAM_SEENTHIS1,[l=1] __KAM_TOLL3,[l=1] __RECEIVE_BONUS,[l=1] __TVD_PH_BODY_03,[l=1] __YOU_WON_01,[l=1] __YOU_WON_02,[l=1]'
                            },
           'name' => 'body_0'
         };
